@@ -478,6 +478,9 @@ void AIS_DiameterDimension::ComputeCircleDiameter(const Handle(Prs3d_Presentatio
   }
   else {
     curpos = myPosition;
+	// VRO (2007-05-17) inserted this IF.
+	if (myPlane.IsNull())
+		myPlane = new Geom_Plane(gp_Pln(gp_Ax3(myCircle.Position())));
     myPosition = AIS::ProjectPointOnPlane( curpos, myPlane->Pln() );
   }
 
@@ -715,5 +718,3 @@ void AIS_DiameterDimension::ComputeOnePlanarFaceDiameter(const Handle(Prs3d_Pres
 				     myCircle, myFirstPar, myLastPar, mySymbolPrs, myDiamSymbol );
 }
 
-
-
