@@ -40,6 +40,11 @@
 #include <V3d_SpotLight.hxx>
 #include <V3d_DirectionalLight.hxx>
 #include <V3d_AmbientLight.hxx>
+
+#include <TColStd_ListIteratorOfListOfInteger.hxx>
+#include <SelectMgr_Selection.hxx>
+#include <SelectBasics_SensitiveEntity.hxx>
+
 #ifdef IMP150501
 #include <Visual3d_TransientManager.hxx>
 #include <Prs3d_Presentation.hxx>
@@ -1200,7 +1205,45 @@ Handle(SelectMgr_EntityOwner) AIS_InteractiveContext::SelectedOwner() const
   
 }
 
+//=======================================================================
+//function : EntityOwners
+//purpose  : 
+//=======================================================================
+void AIS_InteractiveContext::EntityOwners(SelectMgr_IndexedMapOfOwner& theOwners,
+					  const Handle(AIS_InteractiveObject)& theIObj,
+					  const Standard_Integer theMode) const 
+{
+  if ( theIObj.IsNull() )
+      return;
 
+  TColStd_ListOfInteger aModes;
+  if ( theMode == -1 )
+    ActivatedModes( theIObj, aModes );
+  else
+    aModes.Append( theMode );
+
+  TColStd_ListIteratorOfListOfInteger anItr( aModes );
+  for (; anItr.More(); anItr.Next() )
+  {
+    int aMode = anItr.Value();
+    if ( !theIObj->HasSelection( aMode ) )
+      continue;
+
+    Handle(SelectMgr_Selection) aSel = theIObj->Selection( aMode );
+
+    for ( aSel->Init(); aSel->More(); aSel->Next() )
+    {
+      Handle(SelectBasics_SensitiveEntity) aEntity = aSel->Sensitive();
+      if ( aEntity.IsNull() )
+	continue;
+
+      Handle(SelectMgr_EntityOwner) aOwner =
+	Handle(SelectMgr_EntityOwner)::DownCast(aEntity->OwnerId());
+      if ( !aOwner.IsNull() )
+	theOwners.Add( aOwner );
+    }
+  }
+}
 
 Standard_Integer AIS_InteractiveContext::NbSelected() 
 {
