@@ -1140,7 +1140,12 @@ void AIS_LocalContext::ManageDetected(const Handle(SelectMgr_EntityOwner)& aPick
     else
       theNewIndex = myMapOfOwner.Add(aPickOwner);
 
-    if (theNewIndex != mylastindex) {
+    // For the advanced mesh selection mode the owner indices comparison
+    // is not effective because in that case only one owner manage the
+    // selection in current selection mode. It is necessary to check the current detected
+    // entity and hilight it only if the detected entity is not the same as 
+    // previous detected (IsForcedHilight call)
+    if (theNewIndex != mylastindex || aPickOwner->IsForcedHilight()) {
 
       if (mylastindex && mylastindex <= myMapOfOwner.Extent()) {
 
