@@ -87,23 +87,25 @@
 #include <TopoDS_Iterator.hxx>
 #endif
 
-#define MAX2(X, Y)	(  Abs(X) > Abs(Y)? Abs(X) : Abs(Y) )
-#define MAX3(X, Y, Z)	( MAX2 ( MAX2(X,Y) , Z) )
-
 static Standard_Boolean myFirstCompute;
 
 Standard_Real AIS_Shape::GetDeflection(const TopoDS_Shape& aShape,
 				   const Handle(Prs3d_Drawer)& aDrawer)
 {
+  // WARNING: this same piece of code appears several times in Prs3d classes
   Standard_Real aDeflection;
   if (aDrawer->TypeOfDeflection() == Aspect_TOD_RELATIVE) {
     Bnd_Box B;
     BRepBndLib::Add(aShape, B);
-
-    Standard_Real aXmin, aYmin, aZmin, aXmax, aYmax, aZmax;
-    B.Get(aXmin, aYmin, aZmin, aXmax, aYmax, aZmax);
-    aDeflection = MAX3( aXmax-aXmin , aYmax-aYmin , aZmax-aZmin) 
-      * aDrawer->DeviationCoefficient()*4;    
+    if ( ! B.IsVoid() )
+    {
+      Standard_Real aXmin, aYmin, aZmin, aXmax, aYmax, aZmax;
+      B.Get(aXmin, aYmin, aZmin, aXmax, aYmax, aZmax);
+      aDeflection = Max( aXmax-aXmin, Max(aYmax-aYmin, aZmax-aZmin)) *
+                    aDrawer->DeviationCoefficient() * 4;
+    }
+    else
+      aDeflection = aDrawer->MaximalChordialDeviation();
   }
   else
     aDeflection = aDrawer->MaximalChordialDeviation();
@@ -116,6 +118,8 @@ void AIS_Shape::DisplayBox(const Handle(Prs3d_Presentation)& aPrs,
 {
   Standard_Real X[2],Y[2],Z[2];
   Standard_Integer Indx [16] ;
+  if ( B.IsVoid() )
+    return; // nothing to show
 
 #ifdef BUC60577
   Indx [0]=1;Indx [1]=2;Indx [2]=4;Indx [3]=3;
