@@ -22,8 +22,9 @@
 #include <TColStd_Array2OfReal.hxx>
 #include <Convert_GridPolynomialToPoles.hxx>
 #include <Standard_ConstructionError.hxx>
-#include <ApproxF2var.h>
-#include <MathBase.h>
+
+#include <AdvApp2Var_ApproxF2var.hxx>
+#include <AdvApp2Var_MathBase.hxx>
 
 
 //============================================================================
@@ -303,7 +304,7 @@ void AdvApp2Var_Patch::Discretise(const AdvApp2Var_Context& Conditions,
   Standard_Integer IERCOD=0;
 
 //  discretisation des polynomes d'interpolation
-  Ma2cdi(&NDIMEN,&NBPNTU,UROOT,&NBPNTV,VROOT,&IORDRU,&IORDRV,
+  AdvApp2Var_ApproxF2var::mma2cdi_(&NDIMEN,&NBPNTU,UROOT,&NBPNTV,VROOT,&IORDRU,&IORDRV,
 	 C1,C2,C3,C4,SU0,SU1,DU0,DU1,SV0,SV1,DV0,DV1,
          SOSOTB,SODITB,DISOTB,DIDITB,&IERCOD);
 
@@ -328,8 +329,22 @@ void AdvApp2Var_Patch::Discretise(const AdvApp2Var_Context& Conditions,
   // GCC 3.0 would not accept this line without the void
   // pointer cast.  Perhaps the real problem is a definition
   // somewhere that has a void * in it.
-  Ma2ds1(&NDIMEN,UDBFN,VDBFN,(void *)Func,&NBPNTU,&NBPNTV,UROOT,VROOT,&ISOFAV,
-         SOSOTB,DISOTB,SODITB,DIDITB,PTS,TAB,&IERCOD);
+  AdvApp2Var_ApproxF2var::mma2ds1_(&NDIMEN,
+				   UDBFN,
+				   VDBFN,
+				   /*(void *)*/Func,
+				   &NBPNTU,
+				   &NBPNTV,
+				   UROOT,
+				   VROOT,
+				   &ISOFAV,
+				   SOSOTB,
+				   DISOTB,
+				   SODITB,
+				   DIDITB,
+				   PTS,
+				   TAB,
+				   &IERCOD);
 
 // on stocke les resultats
   if (IERCOD == 0) {
@@ -473,13 +488,22 @@ void AdvApp2Var_Patch::AddConstraints(const AdvApp2Var_Context& Conditions,
   Standard_Real *HermV = 
     (Standard_Real *) &HHERMV ->ChangeArray1()(HHERMV ->Lower());
   if (IORDRV>=0) {
-    Ma1her(&IORDRV,HermV,&IERCOD);
+    AdvApp2Var_ApproxF2var::mma1her_(&IORDRV,HermV,&IERCOD);
     if (IERCOD!=0) {
       Standard_ConstructionError::Raise
 	   ("AdvApp2Var_Patch::AddConstraints : Error in FORTRAN");
     }
-    Ma2ac2(&NDIMEN,&NDegU,&NDegV,&IORDRV,&NCFLMU,
-	     NCFV0,IsoV0,NCFV1,IsoV1,HermV,PATCAN);
+    AdvApp2Var_ApproxF2var::mma2ac2_(&NDIMEN,
+				     &NDegU,
+				     &NDegV,
+				     &IORDRV,
+				     &NCFLMU,
+				     NCFV0,
+				     IsoV0,
+				     NCFV1,
+				     IsoV1,
+				     HermV,
+				     PATCAN);
   }
 
 // ajout des contraintes a U constant
@@ -488,13 +512,13 @@ void AdvApp2Var_Patch::AddConstraints(const AdvApp2Var_Context& Conditions,
   Standard_Real *HermU = 
     (Standard_Real *) &HHERMU ->ChangeArray1()(HHERMU ->Lower());
   if (IORDRU>=0) {
-    Ma1her(&IORDRU,HermU,&IERCOD);
+    AdvApp2Var_ApproxF2var::mma1her_(&IORDRU,HermU,&IERCOD);
     if (IERCOD!=0) {
       Standard_ConstructionError::Raise
 	   ("AdvApp2Var_Patch::AddConstraints : Error in FORTRAN");
     }
-    Ma2ac3(&NDIMEN,&NDegU,&NDegV,&IORDRU,&NCFLMV,
-	     NCFU0,IsoU0,NCFU1,IsoU1,HermU,PATCAN);
+    AdvApp2Var_ApproxF2var::mma2ac3_(&NDIMEN,&NDegU,&NDegV,&IORDRU,&NCFLMV,
+				     NCFU0,IsoU0,NCFU1,IsoU1,HermU,PATCAN);
   }
 
 // ajout des contraintes de coins
@@ -565,14 +589,14 @@ void AdvApp2Var_Patch::AddConstraints(const AdvApp2Var_Context& Conditions,
     ncf1 = HCFU1->Value(HCFU1->Lower()+iu-1);
     for (idim=1;idim<=NDIMEN;idim++) {
       Is = IsoU0 + NCFLMV*(idim-1) + NCFLMV*NDIMEN*(iu-1);
-      Mdrc11(&IORDRV,&iun,&ncf0,Is,EXTR,FACT);
+      AdvApp2Var_MathBase::mmdrc11_(&IORDRV,&iun,&ncf0,Is,EXTR,FACT);
       for (iv=1;iv<=IORDRV+1;iv++) {
 	ideb = HCOINS->Lower() + NDIMEN*(iu-1)+NDIMEN*(IORDRU+2)*(iv-1) - 1;
 	HCOINS->ChangeValue(idim+ideb) += HEXTR->Value(1+2*(iv-1));
 	HCOINS->ChangeValue(2*SIZE+idim+ideb) += HEXTR->Value(2+2*(iv-1));
       }
       Is = IsoU1 + NCFLMV*(idim-1) + NCFLMV*NDIMEN*(iu-1);
-      Mdrc11(&IORDRV,&iun,&ncf1,Is,EXTR,FACT);
+      AdvApp2Var_MathBase::mmdrc11_(&IORDRV,&iun,&ncf1,Is,EXTR,FACT);
       for (iv=1;iv<=IORDRV+1;iv++) {
 	ideb = HCOINS->Lower() + NDIMEN*(iu-1)+NDIMEN*(IORDRU+2)*(iv-1) - 1;
 	HCOINS->ChangeValue(SIZE+idim+ideb) += HEXTR->Value(1+2*(iv-1));
@@ -587,14 +611,14 @@ void AdvApp2Var_Patch::AddConstraints(const AdvApp2Var_Context& Conditions,
     ncf1 = HCFV1->Value(HCFV1->Lower()+iv-1);
     for (idim=1;idim<=NDIMEN;idim++) {
       Is = IsoV0 + NCFLMU*(idim-1) + NCFLMU*NDIMEN*(iv-1);
-      Mdrc11(&IORDRU,&iun,&ncf0,Is,EXTR,FACT);
+      AdvApp2Var_MathBase::mmdrc11_(&IORDRU,&iun,&ncf0,Is,EXTR,FACT);
       for (iu=1;iu<=IORDRU+1;iu++) {
 	ideb = HCOINS->Lower() + NDIMEN*(iu-1)+NDIMEN*(IORDRU+2)*(iv-1) - 1;
 	HCOINS->ChangeValue(idim+ideb) += HEXTR->Value(1+2*(iu-1));
 	HCOINS->ChangeValue(SIZE+idim+ideb) += HEXTR->Value(2+2*(iu-1));
       }
       Is = IsoV1 + NCFLMU*(idim-1) + NCFLMU*NDIMEN*(iv-1);
-      Mdrc11(&IORDRU,&iun,&ncf1,Is,EXTR,FACT);
+      AdvApp2Var_MathBase::mmdrc11_(&IORDRU,&iun,&ncf1,Is,EXTR,FACT);
       for (iu=1;iu<=IORDRU+1;iu++) {
 	ideb = HCOINS->Lower() + NDIMEN*(iu-1)+NDIMEN*(IORDRU+2)*(iv-1) - 1;
 	HCOINS->ChangeValue(2*SIZE+idim+ideb) += HEXTR->Value(1+2*(iu-1));
@@ -610,8 +634,8 @@ void AdvApp2Var_Patch::AddConstraints(const AdvApp2Var_Context& Conditions,
   Standard_Real *C3 = C2 + SIZE;
   Standard_Real *C4 = C3 + SIZE;
   if ( IORDRU>=0 && IORDRV>=0 ) {
-    Ma2ac1(&NDIMEN,&NDegU,&NDegV,&IORDRU,&IORDRV,
-	   C1,C2,C3,C4,HermU,HermV,PATCAN);
+    AdvApp2Var_ApproxF2var::mma2ac1_(&NDIMEN,&NDegU,&NDegV,&IORDRU,&IORDRV,
+				     C1,C2,C3,C4,HermU,HermV,PATCAN);
   }
 }
 
@@ -829,10 +853,32 @@ void AdvApp2Var_Patch::MakeApprox(const AdvApp2Var_Context& Conditions,
   Standard_Integer iun=1,itrois=3;
   NCOEFU=0;
   NCOEFV=0;
-  Ma2ce1(&NumDec,&NDIMEN,&NBSESP,&NDIMSE,&NDMINU,&NDMINV,
-	 &NDegU,&NDegV,&NDJACU,&NDJACV,&IORDRU,&IORDRV,
-	 &NBPNTU,&NBPNTV,EPSAPR,SOSOTB,DISOTB,SODITB,DIDITB,
-	 PATJAC,ERRMAX,ERRMOY,&NCOEFU,&NCOEFV,&ITYDEC,&IERCOD);
+  AdvApp2Var_ApproxF2var::mma2ce1_((integer *)&NumDec,
+				   &NDIMEN,
+				   &NBSESP,
+				   &NDIMSE,
+				   &NDMINU,
+				   &NDMINV,
+				   &NDegU,
+				   &NDegV,
+				   &NDJACU,
+				   &NDJACV,
+				   &IORDRU,
+				   &IORDRV,
+				   &NBPNTU,
+				   &NBPNTV,
+				   EPSAPR,
+				   SOSOTB,
+				   DISOTB,
+				   SODITB,
+				   DIDITB,
+				   PATJAC,
+				   ERRMAX,
+				   ERRMOY,
+				   &NCOEFU,
+				   &NCOEFV,
+				   &ITYDEC,
+				   &IERCOD);
 
 // les resultats
   myCutSense = ITYDEC;
@@ -845,10 +891,12 @@ void AdvApp2Var_Patch::MakeApprox(const AdvApp2Var_Context& Conditions,
     myMoyErrors = HERRMOY;
 
 // Passage en canonique sur [-1,1]
-    Mfmca9(&NJacU,&NJacV,&NDIMEN,&myNbCoeffInU,&myNbCoeffInV,
-	                                     &NDIMEN,PATJAC,PATJAC);
-    Ma2can(&NCFLMU,&NCFLMV,&NDIMEN,&myOrdInU,&myOrdInV,&myNbCoeffInU,&myNbCoeffInV,
-                                             PATJAC,PATAUX,PATCAN,&IERCOD);
+    AdvApp2Var_MathBase::mmfmca9_(&NJacU,&NJacV,&NDIMEN,&myNbCoeffInU,&myNbCoeffInV,
+				  &NDIMEN,PATJAC,PATJAC);
+    AdvApp2Var_ApproxF2var::mma2can_(&NCFLMU,&NCFLMV,&NDIMEN,
+				     &myOrdInU,&myOrdInV,&myNbCoeffInU,
+				     &myNbCoeffInV,
+				     PATJAC,PATAUX,PATCAN,&IERCOD);
     if (IERCOD !=0) {
       Standard_ConstructionError::Raise
 	      ("AdvApp2Var_Patch::MakeApprox : Error in FORTRAN");
@@ -863,9 +911,22 @@ void AdvApp2Var_Patch::MakeApprox(const AdvApp2Var_Context& Conditions,
     PATCAN = (Standard_Real *) 
       &myEquation->ChangeArray1()(myEquation ->Lower());
 
-    Ma2fx6(&NCFLMU,&NCFLMV,&NDIMEN,&NBSESP,&itrois,&iun,&iun,&IORDRU,&IORDRV,EPSAPR,EPSFRO,
-	                     PATCAN,ERRMAX,&myNbCoeffInU,&myNbCoeffInV);
-
+    AdvApp2Var_ApproxF2var::mma2fx6_(&NCFLMU,
+				     &NCFLMV,
+				     &NDIMEN,
+				     &NBSESP,
+				     &itrois,
+				     &iun,
+				     &iun,
+				     &IORDRU,
+				     &IORDRV,
+				     EPSAPR,
+				     EPSFRO,
+				     PATCAN,
+				     ERRMAX,
+				     &myNbCoeffInU,
+				     &myNbCoeffInV);
+    
 // transposition (NCFLMU,NCFLMV,NDIMEN)Fortran-C++
     Standard_Integer IU, IN, dim, ii, jj;
     for (dim=1; dim<=NDIMEN; dim++){
