@@ -55,7 +55,7 @@ static Standard_Boolean iopen(	OSD_File &File,
 					unsigned int  );
 static void		iclose(   	OSD_File &File,AlienImage_SGIRGBFileHeader *);
 int 		iflush(   	OSD_File &File,AlienImage_SGIRGBFileHeader *);
-static void 		isetname( 	AlienImage_SGIRGBFileHeader *, char * );
+static void 		isetname( 	AlienImage_SGIRGBFileHeader *, const char * );
 #ifdef DEB
 static void 		isetcolormap(	AlienImage_SGIRGBFileHeader *, int );
 #endif
@@ -185,7 +185,7 @@ static void 		img_rle_expand(	unsigned short *,
 					unsigned short *,
 					int  );
 
-void i_errhdlr(char *fmt)
+void i_errhdlr(const char *fmt)
 {
 		printf("%s",fmt);
 		return;
@@ -266,7 +266,7 @@ int iflush( OSD_File& File, AlienImage_SGIRGBFileHeader *image)
  *
  */
 
-static void isetname( AlienImage_SGIRGBFileHeader *image, char *name )
+static void isetname( AlienImage_SGIRGBFileHeader *image, const char *name )
 {
     strncpy(image->name,name,80);
 }
@@ -1209,7 +1209,7 @@ Standard_Boolean AlienImage_SGIRGBAlienData::Write( OSD_File& file ) const
   }
 #endif
 
-    isetname( &WritedHeader, myName.ToCString() ) ;
+    isetname( &WritedHeader, (Standard_PCharacter)myName.ToCString() ) ;
 
     rbuf = ( unsigned short * ) myRedData ;
     gbuf = ( unsigned short * ) myGreenData ;
