@@ -537,7 +537,8 @@ void Approx_SameParameter::Build(const Standard_Real Tolerance)
 
 #ifdef DEB
   if (AffichFw) {
-    char* Name = "               ";
+    char Name[17];
+    Name[0]='\0';
     TColgp_Array1OfPnt2d    DEBP2d  (0,count);
     TColStd_Array1OfInteger DEBMults(0,count); 
     DEBMults.Init(1); DEBMults(0) = 2; DEBMults(count) = 2;
@@ -596,7 +597,8 @@ void Approx_SameParameter::Build(const Standard_Real Tolerance)
 #ifdef DEB
   if (AffichFw) {
     nbcoups ++;
-    char* Name = "               ";
+    char Name[17];
+    Name[0] = '\0';
     Standard_Integer nnn = 100;
     TColgp_Array1OfPnt2d    DEBP2d  (0,nnn);
     TColStd_Array1OfInteger DEBMults(0,nnn); 
