@@ -72,32 +72,32 @@
 Standard_STATIC(OSD_Chronometer, S_Chrono);
 static void StartChrono();
 static void StopChrono(Draw_Interpretor&); 
-Standard_Integer btimesum (Draw_Interpretor& , Standard_Integer n, char** a);
+Standard_Integer btimesum (Draw_Interpretor& , Standard_Integer n, const char** a);
 //XX
 
 //
-static   Standard_Integer bop        (Draw_Interpretor&,   Standard_Integer,   char**);
+static   Standard_Integer bop        (Draw_Interpretor&,   Standard_Integer,   const char**);
 //
-static   Standard_Integer bcommon    (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bfuse      (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bcut       (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bsection   (Draw_Interpretor& ,  Standard_Integer ,  char**);
+static   Standard_Integer bcommon    (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bfuse      (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bcut       (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bsection   (Draw_Interpretor& ,  Standard_Integer ,  const char**);
 
-static   Standard_Integer bFillDS    (Draw_Interpretor& ,  Standard_Integer  , char**);
+static   Standard_Integer bFillDS    (Draw_Interpretor& ,  Standard_Integer  , const char**);
 //
-static   Standard_Integer bopcommon  (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bopfuse    (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bopcut     (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer boptuc     (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static   Standard_Integer bopsection (Draw_Interpretor& ,  Standard_Integer ,  char**);
+static   Standard_Integer bopcommon  (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bopfuse    (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bopcut     (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer boptuc     (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static   Standard_Integer bopsection (Draw_Interpretor& ,  Standard_Integer ,  const char**);
 
-static   Standard_Integer boperationFiller (Standard_Integer n, char** a, const BOP_Operation anOp,
+static   Standard_Integer boperationFiller (Standard_Integer n, const char** a, const BOP_Operation anOp,
 					    Draw_Interpretor&);
 //
-static   Standard_Integer bopstates  (Draw_Interpretor& ,  Standard_Integer ,  char**);
+static   Standard_Integer bopstates  (Draw_Interpretor& ,  Standard_Integer ,  const char**);
 //
-static  Standard_Integer bopwho      (Draw_Interpretor& ,  Standard_Integer ,  char**);
-static  Standard_Integer bopsticks   (Draw_Interpretor& ,  Standard_Integer ,  char**);
+static  Standard_Integer bopwho      (Draw_Interpretor& ,  Standard_Integer ,  const char**);
+static  Standard_Integer bopsticks   (Draw_Interpretor& ,  Standard_Integer ,  const char**);
 
 
 static
@@ -116,7 +116,7 @@ static
 
   done = Standard_True;
   // Chapter's name
-  char* g = "CCR commands";
+  const char* g = "CCR commands";
   //
   // Using DSFiller that is ready.
   theCommands.Add("bop"       , "Use  >bop Shape1 Shape2", __FILE__,   bop, g);
@@ -157,7 +157,7 @@ BOPTools_DSFiller *pDF;
 //=======================================================================
 Standard_Integer bop (Draw_Interpretor& di, 
 		      Standard_Integer n, 
-		      char** a)
+		      const char** a)
 {
   StartChrono();
 
@@ -207,7 +207,7 @@ Standard_Integer bop (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bFillDS (Draw_Interpretor& di, 
 			  Standard_Integer n, 
-			  char** a)
+			  const char** a)
 {
   if (n!=4) {
     di << " Usage: >command  Result Shape1 Shape2\n";
@@ -223,7 +223,7 @@ Standard_Integer bFillDS (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bcommon (Draw_Interpretor& di, 
 			  Standard_Integer n, 
-			  char** a)
+			  const char** a)
 {
   Standard_Integer iFlag;
 
@@ -241,7 +241,7 @@ Standard_Integer bcommon (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer  bfuse(Draw_Interpretor& di, 
 			Standard_Integer n, 
-			char** a)
+			const char** a)
 {
   Standard_Integer iFlag;
 
@@ -260,7 +260,7 @@ Standard_Integer  bfuse(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer  bcut(Draw_Interpretor& di, 
 		       Standard_Integer n, 
-		       char** a)
+		       const char** a)
 {
   Standard_Integer iFlag;
 
@@ -278,9 +278,9 @@ Standard_Integer  bcut(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer  bsection(Draw_Interpretor& di, 
 			   Standard_Integer n, 
-			   char** a)
+			   const char** a)
 {
-  char* usage = " Usage: bsection Result s1 s2 [-2d/-2d1/-2d2] [-a]\n";
+  const char* usage = " Usage: bsection Result s1 s2 [-2d/-2d1/-2d2] [-a]\n";
   if (n < 4) {
     di << usage;
     return 1;
@@ -302,9 +302,9 @@ Standard_Integer  bsection(Draw_Interpretor& di,
   Standard_Boolean isbadparameter = Standard_False;
   
   if(n > 4) {
-    char* key1 = a[4];
-    char* key2 = (n > 5) ? a[5] : NULL;
-    char* pcurveconf = NULL;
+    const char* key1 = a[4];
+    const char* key2 = (n > 5) ? a[5] : NULL;
+    const char* pcurveconf = NULL;
     Standard_Boolean approx = Standard_False;
 
 #ifdef WNT
@@ -390,7 +390,7 @@ Standard_Integer  bsection(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopcommon (Draw_Interpretor& di, 
 			    Standard_Integer n, 
-			    char** a)
+			    const char** a)
 {
   return boperationFiller (n, a, BOP_COMMON, di); 
 }
@@ -401,7 +401,7 @@ Standard_Integer bopcommon (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer  bopfuse(Draw_Interpretor& di, 
 			    Standard_Integer n, 
-			    char** a)
+			    const char** a)
 {
   return boperationFiller (n, a, BOP_FUSE, di); 
 }
@@ -412,7 +412,7 @@ Standard_Integer  bopfuse(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopcut (Draw_Interpretor& di, 
 			 Standard_Integer n, 
-			 char** a)
+			 const char** a)
 {
   return boperationFiller (n, a, BOP_CUT, di); 
 }
@@ -422,7 +422,7 @@ Standard_Integer bopcut (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer boptuc (Draw_Interpretor& di, 
 			 Standard_Integer n, 
-			 char** a)
+			 const char** a)
 {
   return boperationFiller (n, a, BOP_CUT21, di); 
 }
@@ -432,7 +432,7 @@ Standard_Integer boptuc (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopsection (Draw_Interpretor& di, 
 			     Standard_Integer n, 
-			     char** a)
+			     const char** a)
 {
   return boperationFiller (n, a, BOP_SECTION, di); 
 }
@@ -442,7 +442,7 @@ Standard_Integer bopsection (Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 Standard_Integer boperationFiller (Standard_Integer n, 
-				   char** a,
+				   const char** a,
 				   const BOP_Operation anOp,
 				   Draw_Interpretor& di)
 {
@@ -528,7 +528,7 @@ static
 //=======================================================================
 Standard_Integer  bopstates(Draw_Interpretor& di, 
 			     Standard_Integer n, 
-			     char** a)
+			     const char** a)
 {
   if (n>4) {
     di << " Use bopstates [-f] [-t] [-out]\n";
@@ -813,7 +813,7 @@ void SaveTimeInFile(const Standard_CString aFileName,
 //=======================================================================
 Standard_Integer btimesum (Draw_Interpretor& di, 
 			   Standard_Integer n, 
-			   char** a)
+			   const char** a)
 {
   if (n!=2) {
     di << " Use >btimesum FileName\n";
@@ -925,15 +925,15 @@ Standard_Integer btimesum (Draw_Interpretor& di,
 #include <BOPTools_ListIteratorOfListOfPaveBlock.hxx>
 
 
-static Standard_Integer bopinterf (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopds     (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopsplits (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopscts   (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopsamedomain(Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopaves   (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopsinf   (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopsonf   (Draw_Interpretor&, Standard_Integer, char**);
-static Standard_Integer bopnews   (Draw_Interpretor& ,Standard_Integer, char**);
+static Standard_Integer bopinterf (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopds     (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopsplits (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopscts   (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopsamedomain(Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopaves   (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopsinf   (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopsonf   (Draw_Interpretor&, Standard_Integer, const char**);
+static Standard_Integer bopnews   (Draw_Interpretor& ,Standard_Integer, const char**);
 
 //=======================================================================
 //function : TSTCommands
@@ -945,7 +945,7 @@ static Standard_Integer bopnews   (Draw_Interpretor& ,Standard_Integer, char**);
   if (done) return;
   done = Standard_True;
   // Chapter's name
-  char* g = "CCR commands";
+  const char* g = "CCR commands";
   //
   theCommands.Add("bopinterf" , "", __FILE__, bopinterf, g);
   theCommands.Add("bopds"     , "Use  bopds [-sw]", __FILE__, bopds, g);
@@ -971,7 +971,7 @@ static Standard_Integer bopnews   (Draw_Interpretor& ,Standard_Integer, char**);
 //=======================================================================
 Standard_Integer bopinterf (Draw_Interpretor& di, 
 			    Standard_Integer /*n*/, 
-			    char** /*a*/)
+			    const char** /*a*/)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1024,7 +1024,7 @@ Standard_Integer bopinterf (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopds (Draw_Interpretor& di, 
 			Standard_Integer n, 
-			char** a)
+			const char** a)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1129,7 +1129,7 @@ Standard_Integer bopds (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer  bopaves(Draw_Interpretor& di, 
 			  Standard_Integer /*n*/, 
-			  char** /*a*/)
+			  const char** /*a*/)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1168,7 +1168,7 @@ Standard_Integer  bopaves(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopsamedomain (Draw_Interpretor& di, 
 				Standard_Integer /*n*/, 
-				char** /*a*/)
+				const char** /*a*/)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1246,7 +1246,7 @@ Standard_Integer bopsamedomain (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopnews (Draw_Interpretor& di, 
 			  Standard_Integer n, 
-			  char** a)
+			  const char** a)
 
 {
   if (pDF==NULL) {
@@ -1311,7 +1311,7 @@ Standard_Integer bopnews (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopsplits (Draw_Interpretor& di, 
 			    Standard_Integer /*n*/, 
-			    char** /*a*/)
+			    const char** /*a*/)
 
 {
   if (pDF==NULL) {
@@ -1375,7 +1375,7 @@ Standard_Integer bopsplits (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopscts (Draw_Interpretor& di, 
 			  Standard_Integer /*n*/, 
-			  char** /*a*/)
+			  const char** /*a*/)
 
 {
   if (pDF==NULL) {
@@ -1474,7 +1474,7 @@ Standard_Integer bopscts (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopsinf (Draw_Interpretor& di, 
 			  Standard_Integer n, 
-			  char** a)
+			  const char** a)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1536,7 +1536,7 @@ return 0;
 //=======================================================================
 Standard_Integer bopsonf (Draw_Interpretor& di, 
 			  Standard_Integer n, 
-			  char** a)
+			  const char** a)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1599,7 +1599,7 @@ Standard_Integer bopsonf (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopwho (Draw_Interpretor& di, 
 			 Standard_Integer n, 
-			 char** a)
+			 const char** a)
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
@@ -1839,7 +1839,7 @@ Standard_Integer bopwho (Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bopsticks (Draw_Interpretor& di, 
 			    Standard_Integer n, 
-			    char** )
+			    const char** )
 {
   if (pDF==NULL) {
     di << " Prepare BOPTools_DSFiller first >bop S1 S2\n";
