@@ -41,10 +41,10 @@
 
 //
 static 
-  Standard_Integer bopcheck (Draw_Interpretor&, Standard_Integer, char** );
+  Standard_Integer bopcheck (Draw_Interpretor&, Standard_Integer, const char** );
 
 static 
-  Standard_Integer bopargcheck (Draw_Interpretor&, Standard_Integer, char** );
+  Standard_Integer bopargcheck (Draw_Interpretor&, Standard_Integer, const char** );
 //
 
 //=======================================================================
@@ -59,7 +59,7 @@ static
 
   done = Standard_True;
   // Chapter's name
-  char* g = "CCR commands";
+  const char* g = "CCR commands";
   //
   theCommands.Add("bopcheck" ,  "Use >bopcheck Shape",  __FILE__, bopcheck, g);
   theCommands.Add("bopargcheck" ,  "Use bopargcheck without parameters to get ",  __FILE__, bopargcheck, g);
@@ -69,7 +69,7 @@ static
 //function : bopcheck
 //purpose  : 
 //=======================================================================
-Standard_Integer bopcheck (Draw_Interpretor& di, Standard_Integer n,  char** a )
+Standard_Integer bopcheck (Draw_Interpretor& di, Standard_Integer n,  const char** a )
 {
   
   if (n<2) {
@@ -161,7 +161,8 @@ Standard_Integer bopcheck (Draw_Interpretor& di, Standard_Integer n,  char** a )
 	if(bPrint) {
 	  TCollection_AsciiString anumbername(shapeit);
 	  TCollection_AsciiString aXName = aBaseName + anumbername;
-	  char* aname = aXName.ToCString();
+	  //char* aname = aXName.ToCString();
+	  Standard_CString aname=aXName.ToCString();
 	  DBRep::Set (aname, aSF2);
 	  //printf(aname);
 	  di << aname << " ";
@@ -178,7 +179,7 @@ Standard_Integer bopcheck (Draw_Interpretor& di, Standard_Integer n,  char** a )
       if (!aGG.IsNull()) {
       
 	TCollection_AsciiString aNmx("x0");
-	char* name= aNmx.ToCString();
+	Standard_CString name= aNmx.ToCString();
 	//
 	Handle (Geom_CartesianPoint) aGCP=
 	Handle (Geom_CartesianPoint)::DownCast(aGG);
@@ -209,7 +210,7 @@ static void MakeShapeForFullOutput(const TCollection_AsciiString & aBaseName,
 {
   TCollection_AsciiString aNum(aIndex);
   TCollection_AsciiString aName = aBaseName + aNum;
-  char * name = aName.ToCString();
+  Standard_CString name = aName.ToCString();
 
   TopoDS_Compound cmp;
   BRep_Builder BB;
@@ -226,7 +227,7 @@ static void MakeShapeForFullOutput(const TCollection_AsciiString & aBaseName,
 }
                                    
 
-Standard_Integer bopargcheck (Draw_Interpretor& di, Standard_Integer n,  char** a )
+Standard_Integer bopargcheck (Draw_Interpretor& di, Standard_Integer n,  const char** a )
 {
   if (n<2) {
     di << "\n";
