@@ -75,21 +75,21 @@ static
   void PrintState (Draw_Interpretor& aDI,
 		   const TopAbs_State& aState);
 
-static  Standard_Integer bhaspc      (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer baddve      (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bisclosed   (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bexplode    (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bupdateedge (Draw_Interpretor& , Standard_Integer , char**);
-static  Standard_Integer bremovesim  (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bopsetdisp  (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bfaceprepare(Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer brefine     (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bclassify   (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer b2dclassify (Draw_Interpretor& , Standard_Integer , char** );
+static  Standard_Integer bhaspc      (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer baddve      (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bisclosed   (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bexplode    (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bupdateedge (Draw_Interpretor& , Standard_Integer , const char**);
+static  Standard_Integer bremovesim  (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bopsetdisp  (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bfaceprepare(Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer brefine     (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bclassify   (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer b2dclassify (Draw_Interpretor& , Standard_Integer , const char** );
 
 //modified by NIZNHY-PKV Mon May 29 11:44:24 2006f
-static  Standard_Integer bhole       (Draw_Interpretor& , Standard_Integer , char** );
-static  Standard_Integer bxhole      (Draw_Interpretor& , Standard_Integer , char** );
+static  Standard_Integer bhole       (Draw_Interpretor& , Standard_Integer , const char** );
+static  Standard_Integer bxhole      (Draw_Interpretor& , Standard_Integer , const char** );
 //modified by NIZNHY-PKV Mon May 29 11:44:28 2006t
 
 //=======================================================================
@@ -102,7 +102,7 @@ static  Standard_Integer bxhole      (Draw_Interpretor& , Standard_Integer , cha
   if (done) return;
   done = Standard_True;
   // Chapter's name
-  char* g = "CCR commands";
+  const char* g = "CCR commands";
   //
   // Whether Edge has PCurve on Face
   theCommands.Add("bhaspc"       , "Use >bhaspc Edge Face"    , __FILE__, bhaspc      , g);
@@ -133,7 +133,7 @@ static  Standard_Integer bxhole      (Draw_Interpretor& , Standard_Integer , cha
 //=======================================================================
 Standard_Integer  brefine (Draw_Interpretor& di,
 			   Standard_Integer n, 
-			   char** a)
+			   const char** a)
 {
   if (n<2) {
     di << " Use >brefine Shape1\n";
@@ -190,7 +190,7 @@ Standard_Integer  brefine (Draw_Interpretor& di,
 //function : bfaceprepare
 //purpose  : 
 //=======================================================================
-Standard_Integer  bfaceprepare(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer  bfaceprepare(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<2) {
     di << " Use bfaceprepare> F1\n";
@@ -246,21 +246,21 @@ Standard_Integer  bfaceprepare(Draw_Interpretor& di, Standard_Integer n, char**
 //function : bopsetdisp
 //purpose  : 
 //=======================================================================
-Standard_Integer bopsetdisp (Draw_Interpretor& di, Standard_Integer , char** )
+Standard_Integer bopsetdisp (Draw_Interpretor& di, Standard_Integer , const char** )
 {
   Standard_Integer aFlag;
   
   char* xr=getenv("MDISP");
   if (xr==NULL) {
-    aFlag=putenv("MDISP=yes");
+    aFlag=putenv((char*)"MDISP=yes");
     di << " MDISP=yes. Return code=" << aFlag << "\n";
   }
   else if (!strcmp (xr, "yes")) {
-    aFlag=putenv("MDISP=no");
+    aFlag=putenv((char*)"MDISP=no");
     di << " MDISP=no. Return code=" << aFlag << "\n";
   }
   else {
-    aFlag=putenv("MDISP=yes");
+    aFlag=putenv((char*)"MDISP=yes");
     di << " MDISP=yes. Return code=" << aFlag << "\n";
   }
   
@@ -271,7 +271,7 @@ Standard_Integer bopsetdisp (Draw_Interpretor& di, Standard_Integer , char** )
 //function : bremovesim
 //purpose  : 
 //=======================================================================
-Standard_Integer bremovesim (Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer bremovesim (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<2) {
     di << " Use bremovesim> Face\n";
@@ -303,7 +303,7 @@ Standard_Integer bremovesim (Draw_Interpretor& di, Standard_Integer n, char** a)
 //function : bupdateedge
 //purpose  : 
 //=======================================================================
-Standard_Integer bupdateedge (Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer bupdateedge (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<3) {
     di << " Use bupdateedge> Edge Face\n";
@@ -338,7 +338,7 @@ Standard_Integer bupdateedge (Draw_Interpretor& di, Standard_Integer n, char** a
 //function : bisclosed
 //purpose  : 
 //=======================================================================
-Standard_Integer bisclosed (Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer bisclosed (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<3) {
     di << " Use bisclosed> Edge Face\n";
@@ -376,7 +376,7 @@ Standard_Integer bisclosed (Draw_Interpretor& di, Standard_Integer n, char** a)
 //function : bhaspc
 //purpose  : 
 //=======================================================================
-Standard_Integer bhaspc (Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer bhaspc (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<3) {
     di << " Use bhaspc> Edge Face [do]\n";
@@ -421,7 +421,7 @@ Standard_Integer bhaspc (Draw_Interpretor& di, Standard_Integer n, char** a)
 //function : baddve
 //purpose  : 
 //=======================================================================
-Standard_Integer baddve (Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer baddve (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n<6) {
     di << " Use baddve> E V1 V2 p1 p2\n";
@@ -520,7 +520,7 @@ Handle(Geom2d_Curve) CurveOnSurface(const TopoDS_Edge& E,
 //=======================================================================
 static Standard_Integer bexplode(Draw_Interpretor& di,
 				 Standard_Integer n, 
-				 char** a)
+				 const char** a)
 {
   if (n <= 1) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -608,7 +608,7 @@ static Standard_Integer bexplode(Draw_Interpretor& di,
 //=======================================================================
 Standard_Integer bclassify (Draw_Interpretor& aDI,
 			    Standard_Integer n, 
-			    char** a)
+			    const char** a)
 {
   char sbf[512];	
   
@@ -658,7 +658,7 @@ Standard_Integer bclassify (Draw_Interpretor& aDI,
 //=======================================================================
 Standard_Integer b2dclassify (Draw_Interpretor& aDI,
 			      Standard_Integer n, 
-			      char** a)
+			      const char** a)
 {
   char sbf[512];	
   
@@ -745,7 +745,7 @@ void PrintState (Draw_Interpretor& aDI,
 //=======================================================================
 Standard_Integer bhole (Draw_Interpretor& aDI,
 			Standard_Integer n, 
-			char** a)
+			const char** a)
 {
   char sbf[512];	
   
@@ -792,7 +792,8 @@ Standard_Integer bhole (Draw_Interpretor& aDI,
 //=======================================================================
 class X_Chr {
  public:
-  X_Chr::X_Chr() {
+//  X_Chr::X_Chr() {
+  X_Chr() {
     Reset();
   }
   void Reset() {
@@ -811,7 +812,7 @@ class X_Chr {
     myTime=myTime+aTime;
     ++myCnt;
   }
-  void Show(char *pComment) {
+  void Show(const char *pComment) {
     printf("  Tps: %7.2lf\tCnt: %d\tfor %s\n", myTime, myCnt, pComment);
   }
   
@@ -829,7 +830,7 @@ class X_Chr {
 //=======================================================================
 Standard_Integer bxhole (Draw_Interpretor& aDI,
 			 Standard_Integer n, 
-			 char** a)
+			 const char** a)
 {
   char sbf[512];	
   Standard_Integer aNbIter;
