@@ -196,7 +196,7 @@
 	// modified by NIZHNY-MKK  Thu Aug 26 17:37:09 2004.END
 
 	for (i=1; i<=aNbCPrts; i++) {
-	  const IntTools_CommonPrt& aCPart=aCPrts(i);
+	  const IntTools_CommonPrt& aCPart=aCPrts.Value(i);
 	  //
 	  anIndexIn=0;
 	  //
@@ -223,10 +223,40 @@
 	      TopoDS_Vertex aNewVertex;
 	      BOPTools_Tools::MakeNewVertex(aE, aT, aF,aNewVertex);
 	      //
-	      //decide to add pave or not.begin
 	      Standard_Boolean isonpave1, isonpave2;
 	      Standard_Real aTolToDecide;
 	      aTolToDecide=5.e-8;
+
+	      // modified by NIZHNY-IFV  Feb 15   2007
+	      // for occ11565
+	      //Check that whole edge belongs face
+	      isonpave1 = (Abs(anewSR.First() - aRFirst) < aTolToDecide);
+	      isonpave2 = (Abs(anewSR.Last()  - aRLast)  < aTolToDecide);
+	      //++
+	      if(isonpave1 && isonpave2) {
+		//Seems whole edge belongs face
+		
+		Standard_Boolean aCoinsideFlag = 
+		  BOPTools_Tools::IsBlockInOnFace(aPB, aF, myContext);
+		if (aCoinsideFlag) {
+		//
+		  // Add Interference to the Pool
+		  
+		  IntTools_CommonPrt aCP = aCPart;
+		  aCP.SetType(TopAbs_EDGE);
+		  BOPTools_ESInterference anInterf (nE, nF, aCP);
+		  anIndexIn=aEFs.Append(anInterf);
+		  myIntrPool->AddInterference (nE, nF, BooleanOperations_EdgeSurface, anIndexIn);
+		  //
+		  BOPTools_CommonBlock aCB(aPB, nF);
+	      
+		  aLCB.Append(aCB);
+		  break;
+		}
+	      }
+	      // modified by NIZHNY-IFV  Feb 15   2007. end
+	      //
+	      //decide to add pave or not.begin
 	      isonpave1  = (Abs(anewSR.First() - aT) < aTolToDecide);
 	      isonpave2  = (Abs(anewSR.Last()  - aT) < aTolToDecide);
 
