@@ -873,8 +873,8 @@ static Standard_Integer RejectBuildingEdge(const IntTools_Curve& theC,
   //
   aTolR3D=aFFi.TolR3D();
   //
-  const TopoDS_Face& aF1=TopoDS::Face(myDS->GetShape(nF1));
-  const TopoDS_Face& aF2=TopoDS::Face(myDS->GetShape(nF2));
+  TopoDS_Face aF1=TopoDS::Face(myDS->GetShape(nF1));
+  TopoDS_Face aF2=TopoDS::Face(myDS->GetShape(nF2));
   //
   bVF=myContext.IsValidPointForFaces (aP1, aF1, aF2, aTolR3D);
   //
@@ -978,8 +978,8 @@ static Standard_Integer RejectBuildingEdge(const IntTools_Curve& theC,
   //
   aTolR3D=aFFi.TolR3D();
   //
-  const TopoDS_Face& aF1=TopoDS::Face(myDS->GetShape(nF1));
-  const TopoDS_Face& aF2=TopoDS::Face(myDS->GetShape(nF2));
+  TopoDS_Face aF1=TopoDS::Face(myDS->GetShape(nF1));
+  TopoDS_Face aF2=TopoDS::Face(myDS->GetShape(nF2));
   //
   bVF=myContext.IsValidPointForFaces (aP1, aF1, aF2, aTolR3D);
   //
@@ -1215,8 +1215,8 @@ static Standard_Integer RejectBuildingEdge(const IntTools_Curve& theC,
     nF2=aFFi.Index2();
     //
     Standard_Real aTF = 1.e-7;
-    const TopoDS_Face& aF1=TopoDS::Face(myDS->GetShape(nF1));
-    const TopoDS_Face& aF2=TopoDS::Face(myDS->GetShape(nF2));
+    TopoDS_Face aF1=TopoDS::Face(myDS->GetShape(nF1));
+    TopoDS_Face aF2=TopoDS::Face(myDS->GetShape(nF2));
     Standard_Boolean isModT = ModifFFTol(aF1,aF2,aTF);
     Standard_Real aTolFF = (isModT) ? Max(aTF,aFFi.TolR3D()) : aFFi.TolR3D();
     BOPTools_ListOfPaveBlock aFFPBL;
