@@ -353,14 +353,12 @@ static
     BOPTools_Tools2D::MakePCurveOfType(aProjCurvAgain, aC2D);
     aTolR = aProjCurvAgain.GetTolerance();
     //
-    //modified by NIZNHY-PKV Mon Apr  3 19:27:25 2006f
     if (aC2D.IsNull()) { 
       Standard_Real aTR=0.0001;
       ProjLib_ProjectedCurve aProj3(aBAHS, aBAHC, aTR);// 3
       BOPTools_Tools2D::MakePCurveOfType(aProj3, aC2D);
       aTolR = aProj3.GetTolerance();
     }
-    //modified by NIZNHY-PKV Mon Apr  3 19:27:27 2006t
   }
   TolReached2d=aTolR;
   
@@ -395,8 +393,10 @@ static
 					     Handle(Geom2d_Curve)& aC2DA)
 {
   Standard_Boolean mincond, maxcond, decalu, decalv;
+  Standard_Integer k, iCnt;
   Standard_Real UMin, UMax, VMin, VMax, aT, u2, v2, du, dv, aDelta;
-  
+  Standard_Real aUPeriod, aUP2, aUP1, aUNew, aDif, aUx;
+  //
   aDelta=Precision::PConfusion();
   
   BRepAdaptor_Surface aBAS(aF, Standard_False);
@@ -413,28 +413,49 @@ static
  
   du = 0.;
   if (aBAS.IsUPeriodic()) {
-
-    Standard_Real UPeriod, anUNew;
-
-    UPeriod=aBAS.UPeriod(); 
-
+    aUPeriod=aBAS.UPeriod(); 
     mincond = (u2 < UMin-aDelta);
     maxcond = (u2 > UMax+aDelta); 
     
     decalu = mincond || maxcond;
     if (decalu) {
-      du = ( mincond ) ? UPeriod : -UPeriod;
+      //modified by NIZNHY-PKV Mon Mar 25 16:44:46 2008f
+      //du = ( mincond ) ? UPeriod : -UPeriod;
+      //
+      iCnt=1;
+      aUP2=aUPeriod+aUPeriod+aDelta;
+      aUP1=aUPeriod+aDelta;
+      //
+      if (u2 > aUP2) {
+	for(k=1; 1; ++k) {
+	  aUx=u2-k*aUPeriod;
+	  if (aUx < aUP1) {
+	    iCnt=k;
+	    break;
+	  }
+	}
+      }
+      else if (u2 < -aUP2) {
+	for(k=1; 1; ++k) {
+	  aUx=u2+k*aUPeriod;
+	  if (aUx > -aUP1) {
+	    iCnt=k;
+	    break;
+	  }
+	}
+      }
+      du = ( mincond ) ? aUPeriod : -aUPeriod;
+      du=iCnt*du;
+      //modified by NIZNHY-PKV Mon Mar 25 16:44:49 2008t
     }
     //
-    anUNew=u2+du;
-    if (anUNew<(UMin-aDelta)
-	|| 
-	anUNew>(UMax+aDelta)) {
+    aUNew=u2+du;
+    if (aUNew<(UMin-aDelta) || 
+	aUNew>(UMax+aDelta)) {
       // So previous correction was wrong.
       // Try to be closer to UMin or UMax.
       du=0.;
       if (u2>UMax){
-	Standard_Real aDif;
 	aDif=u2-UMax;
 	if (aDif < 4.e-7) {
 	  du=-aDif;
