@@ -40,6 +40,9 @@
 
 #include <Geom_Curve.hxx>
 #include <Geom_Surface.hxx>
+#include <Geom_BSplineSurface.hxx>
+#include <Geom_BezierSurface.hxx>
+
 #include <GeomAdaptor_Surface.hxx>
 
 #include <IntTools_Tools.hxx>
@@ -52,6 +55,7 @@
 #include <Bnd_Box.hxx>
 
 
+
 static
   void PointNearE (const TopoDS_Edge& aE,
 		   const TopoDS_Face& aF,
@@ -223,7 +227,6 @@ static Standard_Boolean CheckKeepArguments(const TopoDS_Face& F1,
   return aFlag;
 }
 
-
 //=======================================================================
 //function : DoSplitSEAMOnFace
 //purpose  : 
@@ -231,47 +234,81 @@ static Standard_Boolean CheckKeepArguments(const TopoDS_Face& F1,
   void BOPTools_Tools3D::DoSplitSEAMOnFace (const TopoDS_Edge& aSplit,
 					    const TopoDS_Face& aF)
 {
+  Standard_Boolean bIsUPeriodic, bIsLeft;
   Standard_Real aTol, a, b, anUPeriod, aT, anU, dU=1.e-7, anU1;
-  Standard_Boolean bIsUPeriodic;
-  BRep_Builder BB;
+  Standard_Real aScPr;
   gp_Pnt2d aP2D;
   gp_Vec2d aVec2D;
-
-  TopoDS_Edge aSp=aSplit;
+  Handle(Geom2d_Curve) aTmpC1, aTmpC2;
+  Handle(Geom2d_Curve) C2D1;
+  Handle(Geom2d_Line) aLD1;
+  Handle(Geom_Surface) aS;
+  BRep_Builder BB;
+  TopoDS_Edge aSp;
+  //
+  aSp=aSplit;
   aSp.Orientation(TopAbs_FORWARD);
-
+  
   aTol=BRep_Tool::Tolerance(aSp);
 
-  Handle(Geom_Surface) aS=BRep_Tool::Surface(aF);
+  aS=BRep_Tool::Surface(aF);
   bIsUPeriodic=aS->IsUPeriodic();
-  if (!bIsUPeriodic) {
-    return;
+  
+  anUPeriod=0.;
+  if (bIsUPeriodic) {
+    anUPeriod=aS->UPeriod();
+  }
+  else {
+    //modified by NIZNHY-PKV Fri Jul 11 09:54:43 2008f
+    Standard_Boolean bIsUClosed;
+    Standard_Real aUmin, aUmax, aVmin, aVmax;
+    Handle(Geom_BSplineSurface) aBS;
+    Handle(Geom_BezierSurface) aBZ;
+    //
+    bIsUClosed=Standard_False;
+    aBS=Handle(Geom_BSplineSurface)::DownCast(aS);
+    aBZ=Handle(Geom_BezierSurface) ::DownCast(aS);
+    //
+    if (!aBS.IsNull()) {
+      bIsUClosed=aBS->IsUClosed();
+      aBS->Bounds(aUmin, aUmax, aVmin, aVmax);
+    }
+    else if (!aBZ.IsNull()) {
+      bIsUClosed=aBZ->IsUClosed();
+      aBZ->Bounds(aUmin, aUmax, aVmin, aVmax);
+    }
+    if (!bIsUClosed) {
+      return;
+    }
+    //
+    anUPeriod=aUmax-aUmin;
+    //modified by NIZNHY-PKV Fri Jul 11 09:54:49 2008t
   }
-  anUPeriod=aS->UPeriod();
-
-  Handle(Geom2d_Curve)C2D1=BRep_Tool::CurveOnSurface(aSp, aF, a, b);
   //
-  Handle(Geom2d_Line) aLD1=Handle(Geom2d_Line)::DownCast(C2D1);
+  C2D1=BRep_Tool::CurveOnSurface(aSp, aF, a, b);
+  //modified by NIZNHY-PKV Fri Jul 11 09:55:10 2008f
+  /*
+  aLD1=Handle(Geom2d_Line)::DownCast(C2D1);
   if (aLD1.IsNull()) {
     return;
   }
-
+  */
+  //modified by NIZNHY-PKV Fri Jul 11 09:55:14 2008t
+  //
   aT=BOPTools_Tools2D::IntermediatePoint(a, b);
   C2D1->D1(aT, aP2D, aVec2D);
   gp_Dir2d aDir2D1(aVec2D);
   
   //
   gp_Dir2d aDOY(0.,1.);
-  Standard_Real aScPr=aDir2D1*aDOY;
+  aScPr=aDir2D1*aDOY;
   //
   //
-  Standard_Boolean bIsLeft;
   anU=aP2D.X();
   if (fabs (anU) < dU) {
     bIsLeft=Standard_True;
     anU1=anU+anUPeriod;
   }
-  
   else if (fabs (anU-anUPeriod) < dU) {
     bIsLeft=Standard_False;
     anU1=anU-anUPeriod;
@@ -280,7 +317,7 @@ static Standard_Boolean CheckKeepArguments(const TopoDS_Face& F1,
     return;
   }
   //
-  Handle(Geom2d_Curve) aTmpC1, aTmpC2;
+  
   
   aTmpC1=Handle(Geom2d_Curve)::DownCast(C2D1->Copy());
   Handle(Geom2d_TrimmedCurve) aC1 = new Geom2d_TrimmedCurve(aTmpC1, a, b);
@@ -308,8 +345,6 @@ static Standard_Boolean CheckKeepArguments(const TopoDS_Face& F1,
   }
   //
 }
-
-// modified by NIZHNY-MKK  Mon Feb 17 15:08:40 2003.BEGIN
 //=======================================================================
 //function : DoSplitSEAMOnFace
 //purpose  : 
@@ -340,7 +375,6 @@ Standard_Boolean BOPTools_Tools3D::DoSplitSEAMOnFace(const TopoDS_Edge& theSplit
   Handle(Geom2d_Curve) C2D2 = BRep_Tool::CurveOnSurface(aSeamF, theFace, a, b);
   Handle(Geom2d_Curve) C2D3 = BRep_Tool::CurveOnSurface(aSeamR, theFace, a, b);
   //
-
   Handle(Geom2d_TrimmedCurve) atr = Handle(Geom2d_TrimmedCurve)::DownCast(C2D1);
   Handle(Geom2d_Line) aLD1;
 
@@ -435,8 +469,6 @@ Standard_Boolean BOPTools_Tools3D::DoSplitSEAMOnFace(const TopoDS_Edge& theSplit
   }
   return Standard_False;
 }
-// modified by NIZHNY-MKK  Mon Feb 17 15:08:43 2003.END
-
 //=======================================================================
 //function :IsSplitToReverse1
 //purpose  : 
