@@ -4,7 +4,10 @@
 //		<pkv@irinox>
 
 #include <BOPTools_Tools3D.ixx>
+#include <math.h>
 
+#include <gp.hxx>
+#include <gp_Cylinder.hxx>
 #include <gp_Pnt2d.hxx>
 #include <gp_Vec2d.hxx>
 #include <gp_Dir2d.hxx>
@@ -17,8 +20,8 @@
 #include <Geom_Surface.hxx>
 
 #include <GeomAdaptor_Surface.hxx>
-
 #include <GeomAPI_ProjectPointOnSurf.hxx>
+
 #include <BRepTools.hxx>
 #include <BRepClass3d_SolidClassifier.hxx>
 
@@ -31,10 +34,8 @@
 #include <TopTools_ListOfShape.hxx>
 
 #include <BOPTools_Tools2D.hxx>
-#include <gp.hxx>
 
-// Peter KURNEV
-// p-kurnev@opencascade.com
+
 //=======================================================================
 //function : GetApproxNormalToFaceOnEdge
 //purpose  : 
@@ -74,15 +75,19 @@
 					gp_Pnt2d& aPx2DNear,
 					gp_Pnt& aPxNear)
 {
-  Standard_Real aFirst, aLast;
-
-  Handle(Geom2d_Curve) aC2D= BRep_Tool::CurveOnSurface (aE, aF, aFirst, aLast);
-  
+  Standard_Real aFirst, aLast, aETol, aFTol, transVal;
+  GeomAbs_SurfaceType aTS;
+  Handle(Geom2d_Curve) aC2D;
+  Handle(Geom_Surface) aS;
+  //
+  aC2D= BRep_Tool::CurveOnSurface (aE, aF, aFirst, aLast);
   if (aC2D.IsNull()) {
     aPx2DNear.SetCoord (99., 99);
     return;
   }
-  
+  //
+  aS=BRep_Tool::Surface(aF);
+  //
   gp_Pnt2d aPx2D;
   gp_Vec2d aVx2D;
   aC2D->D1 (aT, aPx2D, aVx2D);
@@ -98,17 +103,40 @@
   if (aF.Orientation()==TopAbs_REVERSED) {
     aDP.Reverse();
   }
-
-  //-- EJG
-  Standard_Real aETol = BRep_Tool::Tolerance(aE);
-  Standard_Real aFTol = BRep_Tool::Tolerance(aF);
-  if( (aETol > 1.e-5 && aFTol > 1.e-5) && aDt2D > 9.e-5 ) {
-    Handle(Geom_Surface) gsf = BRep_Tool::Surface(aF);
-    GeomAdaptor_Surface asf(gsf);
-    //PKV-103-D7
-    if( asf.GetType() != GeomAbs_Sphere ) {
+  //
+  aETol = BRep_Tool::Tolerance(aE);
+  aFTol = BRep_Tool::Tolerance(aF);
+  //modified by NIZNHY-PKV Fri Mar 28 15:09:30 2008f
+  // pkv NPAL19220
+  GeomAdaptor_Surface aGAS(aS);
+  aTS=aGAS.GetType();
+  if (aTS==GeomAbs_BSplineSurface) {
+    if (aETol > 1.e-5) {
+      aFTol=aETol;
+    }
+  }
+  //modified by NIZNHY-PKV Fri Mar 28 15:09:43 2008t
+  if( aETol > 1.e-5 && aFTol > 1.e-5 ) {
+    //modified by NIZNHY-PKV Fri Mar 28 15:09:52 2008f
+    //GeomAdaptor_Surface aGAS(aS);
+    //aTS=aGAS.GetType();
+    //modified by NIZNHY-PKV Fri Mar 28 15:10:01 2008t
+    //pkv/103/D7
+    if(aTS!=GeomAbs_Sphere) {
       gp_Vec2d transVec( aDP );
-      Standard_Real transVal = aDt2D + aETol + aFTol;
+      transVal = aDt2D + aETol + aFTol;
+      if (aTS==GeomAbs_Cylinder) {// pkv/909/F8
+	Standard_Real aR, dT;
+	//
+	gp_Cylinder aCyl=aGAS.Cylinder();
+	aR=aCyl.Radius();
+	dT=1.-transVal/aR;
+	dT=acos(dT);
+	transVal=dT;
+      }
+      //
+      transVec.Multiply(transVal);
+      //
       aPx2DNear = aPx2D.Translated( transVec );
     }
     else {
@@ -118,10 +146,7 @@
   else {
     aPx2DNear.SetCoord (aPx2D.X()+aDt2D*aDP.X(), aPx2D.Y()+aDt2D*aDP.Y());
   }
-  //aPx2DNear.SetCoord (aPx2D.X()+aDt2D*aDP.X(), aPx2D.Y()+aDt2D*aDP.Y());
-  //-- EJG
-
-  Handle(Geom_Surface) aS=BRep_Tool::Surface(aF);
+  //
   aS->D0(aPx2DNear.X(), aPx2DNear.Y(), aPxNear);
 }
 
