@@ -266,62 +266,97 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
   }
 
   myCstat = BRepCheck_NoError;
-
-  TopExp_Explorer exp,ede;
-  TopTools_MapOfShape mapS;
+  //
+  Standard_Integer index, aNbF;
+  TopExp_Explorer exp, ede;
+  TopTools_MapOfShape mapS, aMEToAvoid;
   myMapEF.Clear();
-
+  
 
   // Checks if the oriented faces of the shell give a "closed" shell,
-  // i-e if each oriented edge on oriented faces is found 2 times...
-  for (exp.Init(myShape,TopAbs_FACE); exp.More(); exp.Next()) {
-    if (IsOriented(exp.Current())) {
-      if (!mapS.Add(exp.Current())) {
+  // i-e if each oriented edge on oriented faces is found 2 times.
+  //
+  //modified by NIZNHY-PKV Mon Jun  4 13:59:21 2007f
+  exp.Init(myShape,TopAbs_FACE);
+  for (; exp.More(); exp.Next()) {
+    const TopoDS_Shape& aF=exp.Current();
+    if (IsOriented(aF)) {
+      ede.Init(exp.Current(),TopAbs_EDGE);
+      for (; ede.More(); ede.Next()) {
+	const TopoDS_Shape& aE=ede.Current();
+	if (!IsOriented(aE)) {
+	  aMEToAvoid.Add(aE);
+	}
+      }
+    }
+  }
+  //modified by NIZNHY-PKV Mon Jun  4 13:59:23 2007t
+  //
+  exp.Init(myShape,TopAbs_FACE);
+  for (; exp.More(); exp.Next()) {
+    const TopoDS_Shape& aF=exp.Current();
+    if (IsOriented(aF)) {
+      if (!mapS.Add(aF)) {
 	myCstat = BRepCheck_RedundantFace;
 	if (Update) {
 	  BRepCheck::Add(myMap(myShape),myCstat);
 	}
 	return myCstat;
       }
-      for (ede.Init(exp.Current(),TopAbs_EDGE); ede.More(); ede.Next()) {
-	if (IsOriented(ede.Current())) {
-	  Standard_Integer index = myMapEF.FindIndex(ede.Current());
-	  if (index == 0) {
+      //
+      ede.Init(exp.Current(),TopAbs_EDGE);
+      for (; ede.More(); ede.Next()) {
+	const TopoDS_Shape& aE=ede.Current();
+	//modified by NIZNHY-PKV Mon Jun  4 14:07:57 2007f
+	//if (IsOriented(aE)) {
+	if (!aMEToAvoid.Contains(aE)) {
+	  //modified by NIZNHY-PKV Mon Jun  4 14:08:01 2007
+	  index = myMapEF.FindIndex(aE);
+	  if (!index) {
 	    TopTools_ListOfShape thelist;
-	    index = myMapEF.Add(ede.Current(), thelist);
+	    index = myMapEF.Add(aE, thelist);
 	  }
-	  myMapEF(index).Append(exp.Current());
+	  myMapEF(index).Append(aF);
 	}
       }
     }
   }
-
+  //
   myNbori = mapS.Extent();
   if (myNbori >= 2) {
     mapS.Clear();
     // Search for the first oriented face
-    for (exp.Init(myShape,TopAbs_FACE);exp.More(); exp.Next()) {
-      if (IsOriented(exp.Current())) {
+    TopoDS_Shape aF;
+    exp.Init(myShape, TopAbs_FACE);
+    for (;exp.More(); exp.Next()) {
+      aF=exp.Current();
+      if (IsOriented(aF)) {
 	break;
       }
     }
-    Propagate(myMapEF,exp.Current(),mapS);
+    //
+    Propagate(myMapEF, aF, mapS);
   }
-
-  if (myNbori != mapS.Extent()) {
+  //
+  //
+  aNbF=mapS.Extent();
+  if (myNbori != aNbF) {
     myCstat = BRepCheck_NotConnected;
     if (Update) {
       BRepCheck::Add(myMap(myShape),myCstat);
     }
     return myCstat;
   }
-
-  Standard_Integer i,Nbedges = myMapEF.Extent();
-  for (i = 1; i<=Nbedges; i++) {
-    Standard_Integer nboc = myMapEF(i).Extent();
+  //
+  //
+  Standard_Integer i, Nbedges, nboc, nbSet;
+  //
+  Nbedges = myMapEF.Extent();
+  for (i = 1; i<=Nbedges; ++i) {
+    nboc = myMapEF(i).Extent();
     if (nboc == 0 || nboc >= 3) {
       TopTools_ListOfShape theSet;
-      Standard_Integer nbSet=NbConnectedSet(theSet);
+      nbSet=NbConnectedSet(theSet);
       // Si on a plus de une bulle ferme on considre le shell invalide
       // cela correspond aux critres d'un solide (pas ceux d'un shell)
       if (nbSet>1) {
