@@ -458,7 +458,7 @@ static void PERFORM_C0(TopoDS_Edge S1,
 	  E      = S2;
 	  Eother = S1;
 	}
-      Standard_Real aFirst, aLast, epsP, Udeb, Ufin;
+      Standard_Real aFirst, aLast, epsP = Precision::PConfusion(), Udeb, Ufin;
       Handle(Geom_Curve) pCurv = BRep_Tool::Curve(E, aFirst, aLast);
       
       Standard_Real aFOther, aLOther;
@@ -982,8 +982,9 @@ void BRepExtrema_DistanceSS::Perform(const TopoDS_Edge& S1, const TopoDS_Edge& S
      BRepExtrema_SeqOfSolution seqSol1;
      BRepExtrema_SeqOfSolution seqSol2;
 	
-     if (SeqSolution1.Length() > 0 && SeqSolution2.Length() > 0)
+     if (SeqSolution1.Length() > 0 && SeqSolution2.Length() > 0) {
        MIN_SOLUTION(SeqSolution1, SeqSolution2, myDstRef, myEps, seqSol1, seqSol2);
+     }
      
      if (!seqSol1.IsEmpty() && !seqSol2.IsEmpty())
        {
