@@ -310,8 +310,17 @@ void BRepFill_OffsetWire::Init(const TopoDS_Face&     Spine,
   //------------------------------------------------------------------
   // decoupe du spine pour les lieux bissecteurs.
   //------------------------------------------------------------------
+//  Modified by Sergey KHROMOV - Tue Nov 26 17:39:03 2002 Begin
+  static BRepMAT2d_Explorer Exp;
+
+  Exp.Perform(mySpine);
+
+//  TopoDS_Face anOldSpine = mySpine;
+
+  mySpine = TopoDS::Face(Exp.ModifiedShape(mySpine));
   PrepareSpine  ();
 
+//  Modified by Sergey KHROMOV - Tue Nov 26 17:39:03 2002 End
   TopoDS_Shape aShape;
   BRepFill_DataMapOfOrientedShapeListOfShape aMap;
   Standard_Boolean Done;
@@ -323,7 +332,9 @@ void BRepFill_OffsetWire::Init(const TopoDS_Face&     Spine,
   // et des Liens Topologie -> elements de base de la carte.
   //-----------------------------------------------------
   
-  static BRepMAT2d_Explorer Exp;
+//  Modified by Sergey KHROMOV - Tue Nov 26 17:39:03 2002 Begin
+//   static BRepMAT2d_Explorer Exp;
+//  Modified by Sergey KHROMOV - Tue Nov 26 17:39:03 2002 End
   Exp.Perform(myWorkSpine);
   myBilo.Compute(Exp,1,MAT_Left);
   myLink.Perform(Exp,myBilo);
