@@ -72,13 +72,13 @@ static Standard_Boolean Project(const Handle(Geom2d_Curve)& C,
       
       Standard_Real d = RealLast();
       for (i = 1; i <= n; i++) {
-	if (extrema.IsMin(i)) {
-	  Standard_Real dd = extrema.Value(i);
+	//OCC16852:if (extrema.IsMin(i)) {
+	  const Standard_Real dd = extrema.Value(i);
 	  if (dd < d) {
 	    d = dd;
 	    p = extrema.Point(i).Parameter();
 	  }
-	}
+	//OCC16852:}
       }
     }
     else
