@@ -1203,8 +1203,8 @@ static void ExtentEdge(const TopoDS_Edge& E,TopoDS_Edge& NE, const Standard_Real
 	      Adaptor3d_CurveOnSurface ConS( HC2d, HSurf );
 	      Standard_Real /*max_deviation,*/ average_deviation;
 	      GeomAbs_Shape Continuity = GeomAbs_C1;
-	      Standard_Real MaxDegree = 14;
-	      Standard_Real MaxSegment = evaluateMaxSegment(ConS);
+	      Standard_Integer MaxDegree = 14;
+	      Standard_Integer MaxSegment = evaluateMaxSegment(ConS);
 	      GeomLib::BuildCurve3d(Precision::Confusion(),
 				    ConS, FirstParOnPC, LastParOnPC,
 				    C3d, max_deviation, average_deviation,
