@@ -58,7 +58,7 @@ Standard_IMPORT Draw_Viewer dout;
 // addpcurve
 //=======================================================================
 
-static Standard_Integer addpcurve(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer addpcurve(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if(n < 4) return 1;
   TopoDS_Shape E = DBRep::Get(a[1]);
@@ -80,7 +80,7 @@ static Standard_Integer addpcurve(Draw_Interpretor& , Standard_Integer n, char**
 // transform
 //=======================================================================
 
-static Standard_Integer transform(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer transform(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n <= 1) return 1;
 
@@ -161,7 +161,7 @@ static Standard_Integer transform(Draw_Interpretor& di,Standard_Integer n,char**
 // gtransform
 //=======================================================================
 
-static Standard_Integer deform(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer deform(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n <= 1) return 1;
   
@@ -200,7 +200,7 @@ static Standard_Integer deform(Draw_Interpretor& di,Standard_Integer n,char** a)
 // tcopy
 //=======================================================================
 
-static Standard_Integer tcopy(Draw_Interpretor& ,Standard_Integer n,char** a)
+static Standard_Integer tcopy(Draw_Interpretor& ,Standard_Integer n,const char** a)
 {
   if (n < 3) return 1;
   if ((n-1)%2 != 0) return 1;
@@ -217,7 +217,7 @@ static Standard_Integer tcopy(Draw_Interpretor& ,Standard_Integer n,char** a)
 // NurbsConvert
 //=======================================================================
 
-static Standard_Integer nurbsconvert(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer nurbsconvert(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n < 3) return 1;
   if ((n-1)%2 != 0) return 1;
@@ -247,7 +247,7 @@ static Standard_Integer nurbsconvert(Draw_Interpretor& di,Standard_Integer n,cha
 // make a 3D edge curve
 //=======================================================================
 
-static Standard_Integer mkedgecurve (Draw_Interpretor& ,Standard_Integer n,char** a)
+static Standard_Integer mkedgecurve (Draw_Interpretor& ,Standard_Integer n,const char** a)
 {
 
   Standard_Boolean CurveDone ;
@@ -269,7 +269,7 @@ static Standard_Integer mkedgecurve (Draw_Interpretor& ,Standard_Integer n,char*
 // sameparameter
 //=======================================================================
 
-static Standard_Integer sameparameter(Draw_Interpretor& ,Standard_Integer n,char** a)
+static Standard_Integer sameparameter(Draw_Interpretor& ,Standard_Integer n,const char** a)
 {
   if (n < 2) return 1;
   Standard_Real tol = 1.e-7;
@@ -287,7 +287,7 @@ static Standard_Integer sameparameter(Draw_Interpretor& ,Standard_Integer n,char
 //function : updatetol
 //purpose  : 
 //=======================================================================
-static Standard_Integer updatetol(Draw_Interpretor& ,Standard_Integer n,char** a)
+static Standard_Integer updatetol(Draw_Interpretor& ,Standard_Integer n,const char** a)
 {
   if (n < 2) return 1;
 
@@ -305,7 +305,7 @@ static Standard_Integer updatetol(Draw_Interpretor& ,Standard_Integer n,char** a
 //function : OrienSolid
 //purpose  : 
 //=======================================================================
-static Standard_Integer orientsolid(Draw_Interpretor& ,Standard_Integer n,char** a)
+static Standard_Integer orientsolid(Draw_Interpretor& ,Standard_Integer n,const char** a)
 {
   if (n < 2) return 1;
 
@@ -324,7 +324,7 @@ static Standard_Integer orientsolid(Draw_Interpretor& ,Standard_Integer n,char**
 //function : boundingstr
 //purpose  : 
 //=======================================================================
-static Standard_Integer boundingstr(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer boundingstr(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n < 2) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -349,7 +349,7 @@ static Standard_Integer boundingstr(Draw_Interpretor& di,Standard_Integer n,char
 //function : bounding
 //purpose  : 
 //=======================================================================
-static Standard_Integer bounding(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer bounding(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n < 2) return 1;
   Standard_Real axmin,aymin,azmin,axmax,aymax,azmax;
@@ -380,7 +380,7 @@ static Standard_Integer bounding(Draw_Interpretor& di,Standard_Integer n,char**
 //function : findplane
 //purpose  : 
 //=======================================================================
-static Standard_Integer findplane(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer findplane(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -400,7 +400,7 @@ static Standard_Integer findplane(Draw_Interpretor& di,Standard_Integer n,char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer precision(Draw_Interpretor& di,Standard_Integer n,char** a)
+static Standard_Integer precision(Draw_Interpretor& di,Standard_Integer n,const char** a)
 {
   n--;
 
@@ -422,12 +422,12 @@ static Standard_Integer precision(Draw_Interpretor& di,Standard_Integer n,char**
 #include <IntCurvesFace_ShapeIntersector.hxx>
 #include <gp_Lin.hxx>
 
-static Standard_Integer reperageshape(Draw_Interpretor& di, Standard_Integer narg , char** a) 
+static Standard_Integer reperageshape(Draw_Interpretor& di, Standard_Integer narg , const char** a) 
 {
   Standard_Integer details=0;
   if(narg<2) return 1;
   if(narg==3) details=1;
-  char *id1 = a[1];
+  const char *id1 = a[1];
   TopoDS_Shape TheShape1 = DBRep::Get(id1);
   
   //cout << "Pick positions with button "<<endl;
@@ -505,7 +505,7 @@ static Standard_Integer reperageshape(Draw_Interpretor& di, Standard_Integer nar
 
 
 static Standard_Integer maxtolerance(Draw_Interpretor& theCommands, 
-				     Standard_Integer n, char** a) { 
+				     Standard_Integer n, const char** a) { 
   if(n<2) return(1);
   TopoDS_Shape TheShape = DBRep::Get(a[1]);
   if(TheShape.IsNull()) return(1);
@@ -569,7 +569,7 @@ static Standard_Integer maxtolerance(Draw_Interpretor& theCommands,
 }
 
 
-static Standard_Integer vecdc(Draw_Interpretor& di,Standard_Integer ,char** ) {
+static Standard_Integer vecdc(Draw_Interpretor& di,Standard_Integer ,const char** ) {
   //cout << "Pick positions with button "<<endl;
   di << "Pick positions with button "<< "\n";
 
@@ -645,7 +645,7 @@ static Standard_Integer vecdc(Draw_Interpretor& di,Standard_Integer ,char** ) {
 //=======================================================================
 
 #include <TopTools_SequenceOfShape.hxx>
- static Standard_Integer nproject(Draw_Interpretor& di, Standard_Integer n, char** a)
+ static Standard_Integer nproject(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if ( n < 4) return 1;
   TopoDS_Shape InpShape;
@@ -720,7 +720,7 @@ static Standard_Integer vecdc(Draw_Interpretor& di,Standard_Integer ,char** ) {
 //           exploration d un wire 
 //==========================================================================
 static Standard_Integer wexplo (Draw_Interpretor&, 
-				Standard_Integer argc, char** argv)
+				Standard_Integer argc, const char** argv)
 { 
   char name[100];
   if (argc < 2) return 1;
@@ -758,7 +758,7 @@ void  BRepTest::BasicCommands(Draw_Interpretor& theCommands)
 
   DBRep::BasicCommands(theCommands);
 
-  char* g = "TOPOLOGY Basic shape commands";
+  const char* g = "TOPOLOGY Basic shape commands";
 
   theCommands.Add("addpcurve",
 		  "addpcurve edge 2dcurve face [tol (default 1.e-7)]",
