@@ -50,7 +50,8 @@
 #include <BRep_Tool.hxx>
 
 #include <TopOpeBRepTool_PurgeInternalEdges.hxx>
-#include <TopOpeBRepTool_FuseEdges.hxx>
+//#include <TopOpeBRepTool_FuseEdges.hxx>
+#include <BRepLib_FuseEdges.hxx>
 
 #include <TopTools_HSequenceOfShape.hxx>
 #include <BRep_Builder.hxx>
@@ -70,7 +71,7 @@
 #endif
 
 static char* checkfaultyname = NULL;
-Standard_EXPORT void BRepTest_CheckCommands_SetFaultyName(char* name)
+Standard_EXPORT void BRepTest_CheckCommands_SetFaultyName(const char* name)
 {
   if (checkfaultyname != NULL) {
     free(checkfaultyname);
@@ -97,13 +98,13 @@ Standard_IMPORT Standard_Integer BRepCheck_Trace(const Standard_Integer phase);
 //function : FindNamed
 //=======================================================================
 static Standard_Boolean FindNamed(const TopoDS_Shape& S,
-				  Standard_CString& Name)
+				  char*& Name)
 {
   for (Standard_Integer i = 1 ;i <= lfaulty.Length(); i++) {
     Handle(DBRep_DrawableShape) DS = 
       Handle(DBRep_DrawableShape)::DownCast(lfaulty(i));
     if (DS->Shape().IsSame(S)) {
-      Name = DS->Name();
+      Name = (char*)DS->Name();
       return Standard_True;
     }
   }
@@ -156,7 +157,7 @@ static void PrintSub(Standard_OStream& OS,
 	    Name = (char*)malloc(18*sizeof(char));
 	    sprintf(Name,"%s%d",checkfaultyname,nbfaulty);
 	    DBRep::Set(Name,sub);
-	    lfaulty.Append(Draw::Get(Name));
+	    lfaulty.Append(Draw::Get((Standard_CString&)Name));
 	  }
 	  OS << "Shape " << Name << " ";
 	  if (!FindNamed(S,Name)) {
@@ -164,7 +165,7 @@ static void PrintSub(Standard_OStream& OS,
 	    Name = (char*)malloc(18*sizeof(char));
 	    sprintf(Name,"%s%d",checkfaultyname,nbfaulty);
 	    DBRep::Set(Name,S);
-	    lfaulty.Append(Draw::Get(Name));
+	    lfaulty.Append(Draw::Get((Standard_CString&)Name));
 	  }
 	  OS << " on shape " << Name << " :\n";
 	  for (;itl.More(); itl.Next()) {
@@ -200,7 +201,7 @@ static void Print(Standard_OStream& OS,
 	Name = (char*)malloc(18*sizeof(char));
 	sprintf(Name,"%s%d",checkfaultyname,nbfaulty);
 	DBRep::Set(Name,S);
-	lfaulty.Append(Draw::Get(Name));
+	lfaulty.Append(Draw::Get((Standard_CString&)Name));
       }
       OS << "On Shape " << Name << " :\n";
 	
@@ -241,7 +242,7 @@ static void Print(Standard_OStream& OS,
 //purpose  : 
 //=======================================================================
 static Standard_Integer computetolerance(Draw_Interpretor& di,
-					 Standard_Integer narg, char** a)
+					 Standard_Integer narg, const char** a)
 {
   if (narg < 2) {
     //cout << "Usage: computetolerance shape" << endl;
@@ -284,7 +285,7 @@ static Standard_Integer computetolerance(Draw_Interpretor& di,
 //purpose  : Checks the closure of a section line
 //=======================================================================
 static Standard_Integer checksection(Draw_Interpretor& di,
-				     Standard_Integer narg, char** a)
+				     Standard_Integer narg, const char** a)
 {
   if (narg < 2) {
     return 1;
@@ -319,9 +320,9 @@ static Standard_Integer checksection(Draw_Interpretor& di,
 //purpose  : Checks the differences beetween a result and his arguments
 //=======================================================================
 static Standard_Integer checkdiff(Draw_Interpretor& di,
-				  Standard_Integer narg, char** a)
+				  Standard_Integer narg, const char** a)
 {
-  char* syntaxe = "checkdiff arg1 [arg2..argn] result [closedSolid (0/1)] [geomCtrl (1/0)]";
+  const char* syntaxe = "checkdiff arg1 [arg2..argn] result [closedSolid (0/1)] [geomCtrl (1/0)]";
   if (narg < 3) {
     if (narg==2) {
       Standard_Integer bcrtrace=atoi(a[narg-1]);
@@ -392,7 +393,7 @@ static Standard_Integer checkdiff(Draw_Interpretor& di,
 //=======================================================================
 
 // static Standard_Integer CHK(Draw_Interpretor& theCommands,
-// 			    Standard_Integer narg, char** a)
+// 			    Standard_Integer narg, const char** a)
 // {
 //   if (narg < 2) {
 //     return 1;
@@ -897,7 +898,7 @@ void StructuralDump(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer checkshape(Draw_Interpretor& theCommands,
-				   Standard_Integer narg, char** a)
+				   Standard_Integer narg, const char** a)
 {
   if (narg == 1) {
     //cout << endl;
@@ -1036,7 +1037,7 @@ static void InitEpsSurf(Standard_Real& epsnl,Standard_Real& epsdis, Standard_Rea
   maxlen = 10000 ;
 }
 
-static Standard_Integer shapeG1continuity (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer shapeG1continuity (Draw_Interpretor& di, Standard_Integer n, const char** a)
 
 { Standard_Real epsnl,epsC0, epsC1, epsC2, epsG1,percent,maxlen;
   Standard_Integer nbeval;  
@@ -1160,7 +1161,7 @@ static Standard_Integer shapeG1continuity (Draw_Interpretor& di, Standard_Intege
   return 0;
 }
 /*****************************************************************************/
-static Standard_Integer shapeG0continuity (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer shapeG0continuity (Draw_Interpretor& di, Standard_Integer n, const char** a)
 
 { Standard_Real epsnl,epsC0, epsC1, epsC2, epsG1,percent,maxlen; 
   Standard_Integer nbeval;
@@ -1281,7 +1282,7 @@ static Standard_Integer shapeG0continuity (Draw_Interpretor& di, Standard_Intege
   return 0;
 }
 /*****************************************************************************************/
-static Standard_Integer shapeG2continuity (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer shapeG2continuity (Draw_Interpretor& di, Standard_Integer n, const char** a)
 
 { Standard_Real epsnl,epsC0, epsC1, epsC2, epsG1, percent,maxlen;
   Standard_Boolean ISG2=Standard_True;
@@ -1423,7 +1424,7 @@ static Standard_Integer shapeG2continuity (Draw_Interpretor& di, Standard_Intege
 //purpose  : 
 //=======================================================================
 static Standard_Integer clintedge(Draw_Interpretor& di,
-					 Standard_Integer narg, char** a)
+					 Standard_Integer narg, const char** a)
 {
   char newname[255];
 
@@ -1467,7 +1468,7 @@ static Standard_Integer clintedge(Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 static Standard_Integer facintedge(Draw_Interpretor& di,
-					 Standard_Integer narg, char** a)
+					 Standard_Integer narg, const char** a)
 {
   char newname[255];
 
@@ -1505,7 +1506,7 @@ static Standard_Integer facintedge(Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 static Standard_Integer fuseedge(Draw_Interpretor& di,
-					 Standard_Integer narg, char** a)
+					 Standard_Integer narg, const char** a)
 {
   char newname[255];
 
@@ -1517,7 +1518,9 @@ static Standard_Integer fuseedge(Draw_Interpretor& di,
   TopoDS_Shape S = DBRep::Get(a[1]);
 
   TopTools_DataMapOfIntegerListOfShape mymap;
-  TopOpeBRepTool_FuseEdges myfusealgo(S);
+  //TopOpeBRepTool_FuseEdges myfusealgo(S);
+  BRepLib_FuseEdges myfusealgo(S);
+  myfusealgo.SetConcatBSpl();
   Standard_Integer nbvertices;
   nbvertices = myfusealgo.NbVertices();
 
@@ -1550,7 +1553,7 @@ static Standard_Integer fuseedge(Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 static Standard_Integer listfuseedge(Draw_Interpretor& di,
-					 Standard_Integer narg, char** a)
+					 Standard_Integer narg, const char** a)
 {
   char newname[255];
 
@@ -1562,7 +1565,7 @@ static Standard_Integer listfuseedge(Draw_Interpretor& di,
   TopoDS_Shape S = DBRep::Get(a[1]);
 
   TopTools_DataMapOfIntegerListOfShape mymap;
-  TopOpeBRepTool_FuseEdges myfusealgo(S);
+  BRepLib_FuseEdges myfusealgo(S);
   myfusealgo.Edges(mymap);
 
   Standard_Integer i;
@@ -1606,7 +1609,7 @@ void BRepTest::CheckCommands(Draw_Interpretor& theCommands)
   BRepTest_CheckCommands_SetFaultyName("faulty_");
   DBRep::BasicCommands(theCommands);
 
-  char* g = "TOPOLOGY Check commands";
+  const char* g = "TOPOLOGY Check commands";
 
 //  Modified by skv - Tue Apr 27 13:35:35 2004 Begin
   theCommands.Add("checkshape", 
