@@ -67,7 +67,7 @@ Standard_IMPORT Draw_Viewer dout;
 // vertex
 //=======================================================================
 
-static Standard_Integer vertex(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer vertex(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   if (n >= 5) {
@@ -90,7 +90,7 @@ static Standard_Integer vertex(Draw_Interpretor& , Standard_Integer n, char** a)
 // range
 //=======================================================================
 
-static Standard_Integer range(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer range(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   TopoDS_Shape aLocalShape(DBRep::Get(a[1],TopAbs_EDGE));
@@ -116,7 +116,7 @@ static Standard_Integer range(Draw_Interpretor& , Standard_Integer n, char** a)
 // trim
 //=======================================================================
 
-static Standard_Integer trim(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer trim(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape e = DBRep::Get(a[1]);
@@ -164,7 +164,7 @@ static Standard_Integer trim(Draw_Interpretor& di, Standard_Integer n, char** a)
 // polyline
 //=======================================================================
 
-static Standard_Integer polyline(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polyline(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 8) return 1;
   if (((n-2) % 3) != 0) return 1;
@@ -183,7 +183,7 @@ static Standard_Integer polyline(Draw_Interpretor& , Standard_Integer n, char**
 // polyvertex
 //=======================================================================
 
-static Standard_Integer polyvertex(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polyvertex(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   Standard_Integer i;
@@ -202,7 +202,7 @@ static Standard_Integer polyvertex(Draw_Interpretor& , Standard_Integer n, char*
 // wire
 //=======================================================================
 
-static Standard_Integer wire(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer wire(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   Standard_Integer i;
@@ -230,7 +230,7 @@ static Standard_Integer wire(Draw_Interpretor& di, Standard_Integer n, char** a)
 // mkedge
 //=======================================================================
 
-static Standard_Integer mkedge(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer mkedge(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -305,7 +305,7 @@ Standard_IMPORT Draw_Color DrawTrSurf_CurveColor(const Draw_Color col);
 Standard_IMPORT void DBRep_WriteColorOrientation ();
 Standard_IMPORT Draw_Color DBRep_ColorOrientation (const TopAbs_Orientation Or);
 
-static Standard_Integer mkcurve(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer mkcurve(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -345,7 +345,7 @@ static Standard_Integer mkcurve(Draw_Interpretor& di, Standard_Integer n, char**
 //=======================================================================
 
 static Standard_Integer mkpoint(Draw_Interpretor& , 
-				Standard_Integer n, char** a)
+				Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -365,7 +365,7 @@ static Standard_Integer mkpoint(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer mk2dcurve(Draw_Interpretor& di, 
-				  Standard_Integer na, char** a)
+				  Standard_Integer na, const char** a)
 {
   if (na < 3) return 1;
 
@@ -405,7 +405,7 @@ static Standard_Integer mk2dcurve(Draw_Interpretor& di,
 // edge
 //=======================================================================
 
-static Standard_Integer edge(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer edge(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   TopoDS_Shape V1 = DBRep::Get(a[2],TopAbs_VERTEX);
@@ -421,7 +421,7 @@ static Standard_Integer edge(Draw_Interpretor& , Standard_Integer n, char** a)
 // isoedge
 //=======================================================================
 
-static Standard_Integer isoedge(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer isoedge(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
 
@@ -469,7 +469,7 @@ static Standard_Integer isoedge(Draw_Interpretor& , Standard_Integer n, char** a
 // transfert
 //=======================================================================
 
-static Standard_Integer transfert(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer transfert(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -489,7 +489,7 @@ static Standard_Integer transfert(Draw_Interpretor& , Standard_Integer n, char**
 
 static Standard_Integer profile(Draw_Interpretor& di,
 				Standard_Integer n,
-				char** a)
+				const char** a)
 {
   // this command build a profile
   // from a moving point
@@ -894,7 +894,7 @@ static Standard_Integer profile(Draw_Interpretor& di,
 
 static Standard_Integer bsplineprof(Draw_Interpretor& di,
 				    Standard_Integer n,
-				    char** a)
+				    const char** a)
 {
   // this command build a profile
   // from a moving point
@@ -1143,7 +1143,7 @@ static Standard_Integer bsplineprof(Draw_Interpretor& di,
 
 static Standard_Integer profile2d(Draw_Interpretor& di, 
 				  Standard_Integer n, 
-				  char** a)
+				  const char** a)
 {
   // this command build a profile with 2d curves.
   // from a moving point
@@ -1441,14 +1441,15 @@ static Standard_Integer profile2d(Draw_Interpretor& di,
       }
     }
   }
-  name = "CurX";
-  Draw::Set(name, x);
-  name = "CurY";
-  Draw::Set(name, y);
-  name = "CurDX";
-  Draw::Set(name, dx);
-  name = "CurDY";
-  Draw::Set(name, dy);
+  const char* aName;
+  aName = "CurX";
+  Draw::Set(aName, x);
+  aName = "CurY";
+  Draw::Set(aName, y);
+  aName = "CurDX";
+  Draw::Set(aName, dx);
+  aName = "CurDY";
+  Draw::Set(aName, dy);
 
   return 0;
 
@@ -1465,7 +1466,7 @@ static Standard_Integer profile2d(Draw_Interpretor& di,
 //=======================================================================
 
 Standard_Integer mkoffset(Draw_Interpretor& di, 
-			  Standard_Integer n, char** a)
+			  Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
   char name[100];
@@ -1521,15 +1522,15 @@ Standard_Integer mkoffset(Draw_Interpretor& di,
 //=======================================================================
 
 Standard_Integer pickface(Draw_Interpretor& di, 
-			  Standard_Integer , char** )
+			  Standard_Integer , const char** )
 {
-  char* name = new char[100];
-  sprintf(name,".");
+  Standard_CString pick_name=".";
   
-  TopoDS_Shape S = DBRep::Get(name,TopAbs_FACE);
+  TopoDS_Shape S = DBRep::Get(pick_name,TopAbs_FACE);
   if (S.IsNull()) return 1;
   
-  sprintf(name,"PickedFace %s",name);
+  char* name = new char[100];
+  sprintf(name,"PickedFace %s",pick_name);
   DBRep::Set(name,S);
   di.AppendElement(name);
   return 0;
@@ -1537,7 +1538,7 @@ Standard_Integer pickface(Draw_Interpretor& di,
 
 
 Standard_Integer edgeintersector(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -1629,7 +1630,7 @@ Standard_Integer edgeintersector(Draw_Interpretor& di,
 //           changing the geometry
 //=======================================================================
 
-static Standard_Integer concatwire(Draw_Interpretor&, Standard_Integer n, char** c)
+static Standard_Integer concatwire(Draw_Interpretor&, Standard_Integer n, const char** c)
 { GeomAbs_Shape Option=GeomAbs_C1;
 
   if ( n < 3 ) return 1;                               
@@ -1657,7 +1658,7 @@ static Standard_Integer concatwire(Draw_Interpretor&, Standard_Integer n, char**
 //=======================================================================
 
 Standard_Integer  build3d(Draw_Interpretor& di, 
-			  Standard_Integer n, char** a)
+			  Standard_Integer n, const char** a)
 {
 
   if ( (n <2) || (n>3) ) {
@@ -1693,7 +1694,7 @@ void  BRepTest::CurveCommands(Draw_Interpretor& theCommands)
   DBRep::BasicCommands(theCommands);
   GeometryTest::CurveCommands(theCommands);
 
-  char* g = "TOPOLOGY Curve topology commands";
+  const char* g = "TOPOLOGY Curve topology commands";
 
   theCommands.Add("vertex",
 		  "vertex name [x y z / p edge]",__FILE__,
