@@ -116,7 +116,7 @@ static void Print(Draw_Interpretor& di,
 }
 
 static Standard_Integer Loc(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<6) return 1;
   TopoDS_Shape S = DBRep::Get(a[2]);
@@ -202,7 +202,7 @@ static Standard_Integer Loc(Draw_Interpretor& theCommands,
 
 
 static Standard_Integer HOLE1(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
   if (narg<10 || narg == 11) return 1;
   TopoDS_Shape S = DBRep::Get(a[2]);
@@ -236,7 +236,7 @@ static Standard_Integer HOLE1(Draw_Interpretor& theCommands,
 }
 
 static Standard_Integer HOLE2(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
   if (narg<10) return 1;
   TopoDS_Shape S = DBRep::Get(a[2]);
@@ -262,7 +262,7 @@ static Standard_Integer HOLE2(Draw_Interpretor& theCommands,
 }
 
 static Standard_Integer HOLE3(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
   if (narg<10) return 1;
   TopoDS_Shape S = DBRep::Get(a[2]);
@@ -288,7 +288,7 @@ static Standard_Integer HOLE3(Draw_Interpretor& theCommands,
 
 
 static Standard_Integer HOLE4(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
   if (narg<11) return 1;
   TopoDS_Shape S = DBRep::Get(a[2]);
@@ -314,7 +314,7 @@ static Standard_Integer HOLE4(Draw_Interpretor& theCommands,
 }
 
 static Standard_Integer CONTROL(Draw_Interpretor& theCommands,
-				Standard_Integer narg, char** a)
+				Standard_Integer narg, const char** a)
 {
   if (narg >= 2) {
     WithControl = strcmp("0",a[1]);
@@ -335,7 +335,7 @@ static Standard_Integer CONTROL(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer PRW(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<9) return 1;
   TopoDS_Shape S = DBRep::Get(a[3]);
@@ -396,7 +396,7 @@ static Standard_Integer PRW(Draw_Interpretor& theCommands,
     else {
       if (a[i][1] == '\0')
 	return 1;
-      char* Temp = a[i]+1;
+      const char* Temp = a[i]+1;
       aLocalShape = DBRep::Get(Temp,TopAbs_WIRE);
       wir = TopoDS::Wire(aLocalShape);
 //      wir = TopoDS::Wire(DBRep::Get(Temp,TopAbs_WIRE));
@@ -509,7 +509,7 @@ static Standard_Integer PRW(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer PRF(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<8) return 1;
   TopoDS_Shape S = DBRep::Get(a[3]);
@@ -674,7 +674,7 @@ static Standard_Integer PRF(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer SPLS(Draw_Interpretor& ,
-			     Standard_Integer narg, char** a)
+			     Standard_Integer narg, const char** a)
 {
   Standard_Integer newnarg ;
 
@@ -717,7 +717,7 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
 	  if (a[i][1] == '\0')
 	    return 1;
 	  pick = (a[i][1] == '.');
-	  char* Temp = a[i]+1;
+	  const char* Temp = a[i]+1;
 	  W = DBRep::Get(Temp,TopAbs_SHAPE,Standard_False);
 	  rever = Standard_True;
 	}
@@ -786,7 +786,7 @@ static Standard_Integer SPLS(Draw_Interpretor& ,
 //=======================================================================
 
 Standard_Integer offsetshape(Draw_Interpretor& ,
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
 
   //OSD_Chronometer Clock;
@@ -846,7 +846,7 @@ static Standard_Boolean      TheInter     = Standard_False;
 static GeomAbs_JoinType      TheJoin      = GeomAbs_Arc;
 
 Standard_Integer offsetparameter(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if ( n == 1 ) { 
     //cout << " OffsetParameter Tol Inter(c/p) JoinType(a/i)" << endl;
@@ -902,7 +902,7 @@ Standard_Integer offsetparameter(Draw_Interpretor& di,
 //=======================================================================
 
 Standard_Integer offsetload(Draw_Interpretor& ,
-			    Standard_Integer n, char** a)
+			    Standard_Integer n, const char** a)
 {
   if ( n < 2) return 1;
   TopoDS_Shape  S  = DBRep::Get(a[1]);
@@ -934,7 +934,7 @@ Standard_Integer offsetload(Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-Standard_Integer offsetonface(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer offsetonface(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if ( n < 3) return 1;
 
@@ -955,7 +955,7 @@ Standard_Integer offsetonface(Draw_Interpretor&, Standard_Integer n, char** a)
 //=======================================================================
 
 Standard_Integer offsetperform(Draw_Interpretor&,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if ( n < 2) return 1;
 
@@ -974,7 +974,7 @@ Standard_Integer offsetperform(Draw_Interpretor&,
 //=======================================================================
 
 static Standard_Integer Debou(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
   Standard_Integer i ;
   Standard_Integer newnarg ;
@@ -1037,7 +1037,7 @@ static Standard_Integer Debou(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer ROW(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<13) return 1;
   TopoDS_Shape S = DBRep::Get(a[3]);
@@ -1100,7 +1100,7 @@ static Standard_Integer ROW(Draw_Interpretor& theCommands,
     else {
       if (a[i][1] == '\0')
 	return 1;
-      char* Temp = a[i]+1;
+      const char* Temp = a[i]+1;
       aLocalShape = DBRep::Get(Temp,TopAbs_WIRE);
       wir = TopoDS::Wire(aLocalShape);
 //      wir = TopoDS::Wire(DBRep::Get(Temp,TopAbs_WIRE));
@@ -1198,7 +1198,7 @@ static Standard_Integer ROW(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer ROF(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<12) return 1;
   TopoDS_Shape S = DBRep::Get(a[3]);
@@ -1348,7 +1348,7 @@ static Standard_Integer ROF(Draw_Interpretor& theCommands,
 //=======================================================================
 
 static Standard_Integer GLU(Draw_Interpretor& ,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg<6 || narg%2 != 0) return 1;
   TopoDS_Shape Sne = DBRep::Get(a[2]);
@@ -1412,7 +1412,7 @@ static Standard_Integer GLU(Draw_Interpretor& ,
 }
 
 static Standard_Integer DEFIN(Draw_Interpretor& theCommands,
-			      Standard_Integer narg, char** a)
+			      Standard_Integer narg, const char** a)
 {
 
   if (strcasecmp(a[0],"FEATPRISM") &&
@@ -1574,7 +1574,7 @@ static Standard_Integer DEFIN(Draw_Interpretor& theCommands,
 
 
 static Standard_Integer ADD(Draw_Interpretor& ,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   Standard_Integer i ;
   if (narg < 4 || narg%2 != 0) {
@@ -1649,7 +1649,7 @@ static Standard_Integer ADD(Draw_Interpretor& ,
 
 
 static Standard_Integer PERF(Draw_Interpretor& theCommands,
-			    Standard_Integer narg, char** a)
+			    Standard_Integer narg, const char** a)
 {
   if (narg < 3) {
     return 1;
@@ -1987,7 +1987,7 @@ static Standard_Integer PERF(Draw_Interpretor& theCommands,
 
 
 static Standard_Integer BOSS(Draw_Interpretor& theCommands,
-			     Standard_Integer narg, char** a)
+			     Standard_Integer narg, const char** a)
 {
   if (strcasecmp(a[0],"ENDEDGES") && strcasecmp(a[0],"FILLET")
       && strcasecmp(a[0],"BOSSAGE")) {
@@ -2155,7 +2155,7 @@ void BRepTest::FeatureCommands (Draw_Interpretor& theCommands)
 
   DBRep::BasicCommands(theCommands);
 
-  char* g = "TOPOLOGY Feature commands";
+  const char* g = "TOPOLOGY Feature commands";
 
   theCommands.Add("localope", 
 		  " Performs a local top. operation : localope result shape tool F/C (fuse/cut) face [face...]",
