@@ -52,7 +52,7 @@ static BRepOffsetAPI_MakePipeShell* Sweep= 0;
 // prism
 //=======================================================================
 
-static Standard_Integer prism(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer prism(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
 
@@ -89,7 +89,7 @@ static Standard_Integer prism(Draw_Interpretor& , Standard_Integer n, char** a)
 //=======================================================================
 
 static Standard_Integer revol(Draw_Interpretor& ,
-			      Standard_Integer n, char** a)
+			      Standard_Integer n, const char** a)
 {
   if (n < 10) return 1; 
 
@@ -117,7 +117,7 @@ static Standard_Integer revol(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer pipe(Draw_Interpretor& ,
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
   if ( n < 4) return 1;
 
@@ -136,7 +136,7 @@ static Standard_Integer pipe(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer geompipe(Draw_Interpretor& ,
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
   TopoDS_Shape Spine = DBRep::Get(a[2],TopAbs_EDGE);
   if ( Spine.IsNull()) return 1;
@@ -176,7 +176,7 @@ static Standard_Integer geompipe(Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-Standard_Integer evolved(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer evolved(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if ( n == 1) {
     //cout << " 1) evolved result base profil : "<< endl;
@@ -232,7 +232,7 @@ Standard_Integer evolved(Draw_Interpretor& di, Standard_Integer n, char** a)
 //=======================================================================
 
 static Standard_Integer pruled(Draw_Interpretor& ,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if ( n != 4) return 1;
 
@@ -275,7 +275,7 @@ static Standard_Integer pruled(Draw_Interpretor& ,
 //purpose  : Create a surface between generating wires
 //=======================================================================
 
-Standard_Integer gener(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer gener(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if ( n < 4) return 1;
 
@@ -307,7 +307,7 @@ Standard_Integer gener(Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer thrusections(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer thrusections(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n<6) return 1;
 
@@ -380,7 +380,7 @@ Standard_Integer thrusections(Draw_Interpretor&, Standard_Integer n, char** a)
 //  mksweep
 //=======================================================================
 static Standard_Integer mksweep(Draw_Interpretor& ,
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
   if ( n != 2) return 1;
   TopoDS_Shape Spine = DBRep::Get(a[1],TopAbs_WIRE);
@@ -397,7 +397,7 @@ static Standard_Integer mksweep(Draw_Interpretor& ,
 //  setsweep
 //=======================================================================
 static Standard_Integer setsweep(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if ( n == 1) {
     //cout << "setsweep options [arg1 [arg2 [...]]] : options are :" << endl;
@@ -502,7 +502,7 @@ static Standard_Integer setsweep(Draw_Interpretor& di,
 //  addsweep
 //=======================================================================
 static Standard_Integer addsweep(Draw_Interpretor& di,
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
   if ( n == 1) {
     //cout << "addsweep wire/vertex [Vertex] [-T] [-R] [u0 v0 u1 v1 [...[uN vN]]] : options are :" << endl;
@@ -600,7 +600,7 @@ static Standard_Integer addsweep(Draw_Interpretor& di,
 //  deletesweep
 //=======================================================================
 static Standard_Integer deletesweep(Draw_Interpretor& di,
-				    Standard_Integer n, char** a)
+				    Standard_Integer n, const char** a)
 {
   if ( n != 2) {
     return 1;
@@ -624,7 +624,7 @@ static Standard_Integer deletesweep(Draw_Interpretor& di,
 //  buildsweep
 //=======================================================================
 static Standard_Integer buildsweep(Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 {
   if ( n == 1) {
     //cout << "build sweep result [-M/-C/-R] [-S] [tol] : options are" << endl;
@@ -712,7 +712,7 @@ static Standard_Integer buildsweep(Draw_Interpretor& di,
 //  simulsweep
 //=======================================================================
 static Standard_Integer simulsweep(Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 {
   if ( (n!=3) && (n!=4) ) return 1;
   
@@ -769,7 +769,7 @@ void  BRepTest::SweepCommands(Draw_Interpretor& theCommands)
 
   DBRep::BasicCommands(theCommands);
 
-  char* g = "Sweep commands";
+  const char* g = "Sweep commands";
   
   theCommands.Add("prism",
 		  "prism result base dx dy dz [Copy | Inf | Seminf]",
