@@ -22,6 +22,9 @@
 #include <BRep_ListIteratorOfListOfCurveRepresentation.hxx>
 #include <BRep_TEdge.hxx>
 #include <TColgp_SequenceOfPnt2d.hxx>
+#include <TColStd_SequenceOfReal.hxx>
+#include <TColGeom2d_SequenceOfCurve.hxx>
+#include <TopTools_SequenceOfShape.hxx>
 #include <Precision.hxx>
 
 #include <Poly_Triangulation.hxx>
@@ -34,6 +37,8 @@
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
 
+#include <errno.h>
+
 //=======================================================================
 //function : UVBounds
 //purpose  : 
@@ -371,40 +376,56 @@ void  BRepTools::UpdateFaceUVPoints(const TopoDS_Face& F)
   // First edge loop, store the vertices in a Map with their 2d points
 
   BRepTools_MapOfVertexPnt2d theVertices;
-  TopExp_Explorer expE,expV;
+  TopoDS_Iterator expE,expV;
+  TopoDS_Iterator EdgeIt,VertIt;
+  TColStd_SequenceOfReal aFSeq, aLSeq;
+  TColGeom2d_SequenceOfCurve aCSeq;
+  TopTools_SequenceOfShape aShSeq;
   gp_Pnt2d P;
   Standard_Integer i;
   // a 3d tolerance for UV !!
   Standard_Real tolerance = BRep_Tool::Tolerance(F);
   TColgp_SequenceOfPnt2d emptySequence;
   
-  for (expE.Init(F,TopAbs_EDGE); expE.More(); expE.Next()) {
+  for (expE.Initialize(F); expE.More(); expE.Next()) {
+    if(expE.Value().ShapeType() != TopAbs_WIRE)
+      continue;
     
-    const TopoDS_Edge& E = TopoDS::Edge(expE.Current());
-    Standard_Real f,l;
-    const Handle(Geom2d_Curve) C = BRep_Tool::CurveOnSurface(E,F,f,l);
-    if (C.IsNull()) continue;
+    EdgeIt.Initialize(expE.Value());
+    for( ; EdgeIt.More(); EdgeIt.Next())
+    {
+      const TopoDS_Edge& E = TopoDS::Edge(EdgeIt.Value());
+      Standard_Real f,l;
+      Handle(Geom2d_Curve) C = BRep_Tool::CurveOnSurface(E,F,f,l);
 
-    for (expV.Init(E.Oriented(TopAbs_FORWARD),TopAbs_VERTEX); 
-         expV.More(); expV.Next()) {
-      
-      const TopoDS_Vertex& V = TopoDS::Vertex(expV.Current());
+      aFSeq.Append(f);
+      aLSeq.Append(l);
+      aCSeq.Append(C);
+      aShSeq.Append(E);
 
-      TopAbs_Orientation Vori = V.Orientation();
-      if ( Vori == TopAbs_INTERNAL ) {
-        continue;
+      if (C.IsNull()) continue;
+
+      for (expV.Initialize(E.Oriented(TopAbs_FORWARD)); 
+           expV.More(); expV.Next()) {
+        
+        const TopoDS_Vertex& V = TopoDS::Vertex(expV.Value());
+        
+        TopAbs_Orientation Vori = V.Orientation();
+        if ( Vori == TopAbs_INTERNAL ) {
+          continue;
+        }
+        
+        Standard_Real p = BRep_Tool::Parameter(V,E,F);
+        C->D0(p,P);
+        if (!theVertices.IsBound(V)) 
+          theVertices.Bind(V,emptySequence);
+        TColgp_SequenceOfPnt2d& S = theVertices(V);
+        for (i = 1; i <= S.Length(); i++) {
+          if (P.Distance(S(i)) < tolerance) break;
+        }
+        if (i > S.Length())
+          S.Append(P);
       }
-
-      Standard_Real p = BRep_Tool::Parameter(V,E,F);
-      C->D0(p,P);
-      if (!theVertices.IsBound(V)) 
-        theVertices.Bind(V,emptySequence);
-      TColgp_SequenceOfPnt2d& S = theVertices(V);
-      for (i = 1; i <= S.Length(); i++) {
-        if (P.Distance(S(i)) < tolerance) break;
-      }
-      if (i > S.Length())
-        S.Append(P);
     }
   }
  
@@ -412,11 +433,10 @@ void  BRepTools::UpdateFaceUVPoints(const TopoDS_Face& F)
   TopoDS_Vertex Vf,Vl;
   gp_Pnt2d Pf,Pl;
 
-  for (expE.Init(F,TopAbs_EDGE); expE.More(); expE.Next()) {
-    
-    const TopoDS_Edge& E = TopoDS::Edge(expE.Current());
-    Standard_Real f,l;
-    const Handle(Geom2d_Curve) C = BRep_Tool::CurveOnSurface(E,F,f,l);
+  for(Standard_Integer j = 1; j <= aShSeq.Length(); j++)
+  {
+    const TopoDS_Edge& E = TopoDS::Edge(aShSeq.Value(j));
+    const Handle(Geom2d_Curve)& C = aCSeq.Value(j);
     if (C.IsNull()) continue;
     
     TopExp::Vertices(E,Vf,Vl);
@@ -431,7 +451,7 @@ void  BRepTools::UpdateFaceUVPoints(const TopoDS_Face& F)
       if (seqf.Length() == 1) 
         Pf = seqf(1);
       else {
-        C->D0(f,Pf);
+        C->D0(aFSeq.Value(j),Pf);
         for (i = 1; i <= seqf.Length(); i++) {
           if (Pf.Distance(seqf(i)) <= tolerance) {
             Pf = seqf(i);
@@ -451,7 +471,7 @@ void  BRepTools::UpdateFaceUVPoints(const TopoDS_Face& F)
       if (seql.Length() == 1) 
         Pl = seql(1);
       else {
-        C->D0(l,Pl);
+        C->D0(aLSeq.Value(j),Pl);
         for (i = 1; i <= seql.Length(); i++) {
           if (Pl.Distance(seql(i)) <= tolerance) {
             Pl = seql(i);
@@ -595,9 +615,11 @@ void BRepTools_Write (const TopoDS_Shape& S,
 //purpose  : 
 //=======================================================================
 
-void  BRepTools::Write(const TopoDS_Shape& Sh, Standard_OStream& S)
+void  BRepTools::Write(const TopoDS_Shape& Sh, Standard_OStream& S,
+                       const Handle(Message_ProgressIndicator)& PR)
 {
   BRepTools_ShapeSet SS;
+  SS.SetProgress(PR);
   SS.Add(Sh);
   SS.Write(S);
   SS.Write(Sh,S);
@@ -611,24 +633,24 @@ void  BRepTools::Write(const TopoDS_Shape& Sh, Standard_OStream& S)
 
 void  BRepTools::Read(TopoDS_Shape& Sh, 
                       istream& S, 
-                      const BRep_Builder& B)
+                      const BRep_Builder& B,
+                      const Handle(Message_ProgressIndicator)& PR)
 {
   BRepTools_ShapeSet SS(B);
+  SS.SetProgress(PR);
   SS.Read(S);
   SS.Read(Sh,S);
 }
 
-
-
 //=======================================================================
 //function : Write
 //purpose  : 
 //=======================================================================
 
 Standard_Boolean  BRepTools::Write(const TopoDS_Shape& Sh, 
-                                   const Standard_CString File)
+                                   const Standard_CString File,
+                                   const Handle(Message_ProgressIndicator)& PR)
 {
-  
   ofstream os;
   //  if (!fic.open(File,output)) return Standard_False;
   os.open(File, ios::out);
@@ -639,6 +661,7 @@ Standard_Boolean  BRepTools::Write(const TopoDS_Shape& Sh,
     return isGood;
   
   BRepTools_ShapeSet SS;
+  SS.SetProgress(PR);
   SS.Add(Sh);
   
   os << "DBRep_DrawableShape\n";  // for easy Draw read
@@ -648,13 +671,17 @@ Standard_Boolean  BRepTools::Write(const TopoDS_Shape& Sh,
     SS.Write(Sh,os);
   os.flush();
   isGood = os.good();
+
+  errno = 0;
   os.close();
-  isGood = os.good() && isGood;
- 
+#ifdef DEB
+  cout<<"!!!"<<strerror(errno)<<endl;
+#endif
+  isGood = os.good() && isGood && !errno;
+
   return isGood;
 }
 
-
 //=======================================================================
 //function : Read
 //purpose  : 
@@ -662,14 +689,15 @@ Standard_Boolean  BRepTools::Write(const TopoDS_Shape& Sh,
 
 Standard_Boolean BRepTools::Read(TopoDS_Shape& Sh, 
                                  const Standard_CString File,
-                                 const BRep_Builder& B)
+                                 const BRep_Builder& B,
+                                 const Handle(Message_ProgressIndicator)& PR)
 {
   filebuf fic;
   istream in(&fic);
-  //  if (!fic.open(File,input)) return Standard_False;
   if (!fic.open(File, ios::in)) return Standard_False;
 
   BRepTools_ShapeSet SS(B);
+  SS.SetProgress(PR);
   SS.Read(in);
   if(!SS.NbShapes()) return Standard_False;
   SS.Read(Sh,in);
@@ -772,3 +800,6 @@ Standard_Boolean BRepTools::IsReallyClosed(const TopoDS_Edge& E,
   }
   return nbocc == 2;
 }
+
+
+
