@@ -6,6 +6,7 @@
 #include <TopoDS_Shell.hxx>
 #include <TopoDS_Solid.hxx>
 #include <TopoDS_Compound.hxx>
+#include <TopoDS_Face.hxx>
 #include <TopoDS_Iterator.hxx>
 #include <TopExp_Explorer.hxx>
 #include <BRep_Builder.hxx>
@@ -19,6 +20,7 @@
 #include <TopLoc_Location.hxx>
 #include <BRep_ListOfCurveRepresentation.hxx>
 #include <BRep_GCurve.hxx>
+#include <BRep_Tool.hxx>
 #include <BRep_ListIteratorOfListOfCurveRepresentation.hxx>
 #include <TopoDS_Edge.hxx>
 
@@ -386,7 +388,6 @@ TopoDS_Shape BRepTools_ReShape::Apply (const TopoDS_Shape& shape,
       return C;
     else return S;
   }
-
   cout<<"BRepTools_ReShape::Apply NOT YET IMPLEMENTED"<<endl;
   return shape;
 }
@@ -512,6 +513,15 @@ TopoDS_Shape BRepTools_ReShape::Apply (const TopoDS_Shape& shape,
     //BRepTools_Edge sbe;
     CopyRanges ( TopoDS::Edge ( result ), TopoDS::Edge ( shape ),0,1 );
   }
+
+  if (st == TopAbs_FACE)  {
+    TopoDS_Face face = TopoDS::Face ( shape );
+    if( BRep_Tool::NaturalRestriction( face ) ) {
+      BRep_Builder aB;
+      aB.NaturalRestriction( TopoDS::Face (  result ), Standard_True );
+    }
+  }
+
   result.Orientation(orien);
   myStatus = locStatus;
   Replace ( shape, result );
