@@ -40,6 +40,8 @@
 #include <Poly_Triangulation.hxx>
 #include <Poly_PolygonOnTriangulation.hxx>
 
+#include <Message_ProgressIndicator.hxx>
+#include <Message_ProgressSentry.hxx>
 
 #ifdef MacOS
 #define strcasecmp(p,q) strcmp(p,q)
@@ -231,14 +233,65 @@ void  BRepTools_ShapeSet::DumpGeometry(Standard_OStream& OS)const
 //purpose  : 
 //=======================================================================
 
-void  BRepTools_ShapeSet::WriteGeometry(Standard_OStream& OS)const 
+void  BRepTools_ShapeSet::WriteGeometry(Standard_OStream& OS)
 {
+  //OCC19559
+  myCurves2d.SetProgress(GetProgress());
+  myCurves.SetProgress(GetProgress());
+  mySurfaces.SetProgress(GetProgress());
+
+  if ( !GetProgress().IsNull()) {
+    if(GetProgress()->UserBreak() ) return;
+    GetProgress()->NewScope ( 15, "2D Curves" );
+  }
   myCurves2d.Write(OS);
+  
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 15, "3D Curves" );
+  }
   myCurves.Write(OS);
+  
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+  
+    GetProgress()->NewScope ( 10, "3D Polygons" );
+  }
   WritePolygon3D(OS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+
+    GetProgress()->NewScope ( 10, "Polygons On Triangulation" );
+  }
   WritePolygonOnTriangulation(OS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 10, "Surfaces" );
+  }
   mySurfaces.Write(OS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 15, "Triangulations" );
+  }
   WriteTriangulation(OS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+  }
 }
 
 
@@ -249,12 +302,63 @@ void  BRepTools_ShapeSet::WriteGeometry(Standard_OStream& OS)const
 
 void  BRepTools_ShapeSet::ReadGeometry(Standard_IStream& IS)
 {
+  //OCC19559
+  myCurves2d.SetProgress(GetProgress());
+  myCurves.SetProgress(GetProgress());
+  mySurfaces.SetProgress(GetProgress());
+
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->NewScope ( 15, "2D Curves" );
+  }
   myCurves2d.Read(IS);
+
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 15, "3D Curves" );
+  }
   myCurves.Read(IS);
+
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 10, "3D Polygons" );
+  }
   ReadPolygon3D(IS);
+  if ( !GetProgress().IsNull() ) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+
+    GetProgress()->NewScope ( 10, "Polygons On Triangulation" );
+  }
   ReadPolygonOnTriangulation(IS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+    
+    GetProgress()->NewScope ( 10, "Surfaces" );
+  }
   mySurfaces.Read(IS);
+  if ( !GetProgress().IsNull() ) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+
+    GetProgress()->NewScope ( 15, "Triangulations" );
+  }
   ReadTriangulation(IS);
+  if ( !GetProgress().IsNull()) {
+    if( GetProgress()->UserBreak() ) return;
+    GetProgress()->EndScope();
+    GetProgress()->Show();
+  }
 }
 
 //=======================================================================
@@ -923,7 +1027,8 @@ void  BRepTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
           case 5 :   // -5- Polygon3D                            
             IS >> c >> l;
 //szy-02.05.2004            myBuilder.UpdateEdge(E,Handle(Poly_Polygon3D)::DownCast(myPolygons3D(c)));
-	    myBuilder.UpdateEdge(E,Handle(Poly_Polygon3D)::DownCast(myPolygons3D(c)), Locations().Location(l));
+			if (c > 0 && c <= myPolygons3D.Extent())
+	          myBuilder.UpdateEdge(E,Handle(Poly_Polygon3D)::DownCast(myPolygons3D(c)), Locations().Location(l));
             break;
 
           case 6 :
@@ -935,17 +1040,22 @@ void  BRepTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
             }
             IS >> t >> l;
             if (closed) {
-              myBuilder.UpdateEdge
-                (E, Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt)),
-                 Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt2)),
-                 Handle(Poly_Triangulation)::DownCast(myTriangulations(t)),
-                 Locations().Location(l));
+		      if (t > 0 && t <= myTriangulations.Extent() &&
+				  pt > 0 && pt <= myNodes.Extent() &&
+				  pt2 > 0 && pt2 <= myNodes.Extent())
+                myBuilder.UpdateEdge
+                  (E, Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt)),
+                   Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt2)),
+                   Handle(Poly_Triangulation)::DownCast(myTriangulations(t)),
+                   Locations().Location(l));
             }
             else {
-              myBuilder.UpdateEdge
-                (E,Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt)),
-                 Handle(Poly_Triangulation)::DownCast(myTriangulations(t)),
-                 Locations().Location(l));
+		      if (t > 0 && t <= myTriangulations.Extent() &&
+				  pt > 0 && pt <= myNodes.Extent())
+                myBuilder.UpdateEdge
+                  (E,Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(pt)),
+                   Handle(Poly_Triangulation)::DownCast(myTriangulations(t)),
+                   Locations().Location(l));
             }
             // range
             
@@ -1001,8 +1111,9 @@ void  BRepTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
     if (string[0] == '2') {
       // cas triangulation
       s = atoi ( &string[2] );
-      myBuilder.UpdateFace(TopoDS::Face(S),
-                           Handle(Poly_Triangulation)::DownCast(myTriangulations(s)));
+	  if (s > 0 && s <= myTriangulations.Extent())
+        myBuilder.UpdateFace(TopoDS::Face(S),
+                             Handle(Poly_Triangulation)::DownCast(myTriangulations(s)));
     }
 //    else IS.seekg(pos);
     }
@@ -1088,6 +1199,9 @@ void BRepTools_ShapeSet::WritePolygonOnTriangulation(Standard_OStream&      OS,
                                                      const Standard_Boolean Compact)const
 {
   Standard_Integer i, j, nbpOntri = myNodes.Extent();
+
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Polygons On Triangulation", 0, nbpOntri, 1);
   if (Compact)
     OS << "PolygonOnTriangulations " << nbpOntri << endl;
   else {
@@ -1099,7 +1213,10 @@ void BRepTools_ShapeSet::WritePolygonOnTriangulation(Standard_OStream&      OS,
   Handle(Poly_PolygonOnTriangulation) Poly;
   Handle(TColStd_HArray1OfReal) Param;
 
-  for (i=1; i<=nbpOntri; i++) {
+  for (i=1; i<=nbpOntri && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     Poly = Handle(Poly_PolygonOnTriangulation)::DownCast(myNodes(i));
     const TColStd_Array1OfInteger& Nodes = Poly->Nodes();
     if (!Compact) {
@@ -1130,7 +1247,6 @@ void BRepTools_ShapeSet::WritePolygonOnTriangulation(Standard_OStream&      OS,
     }
     else OS <<"0 \n";
   }
-
 }
 
 //=======================================================================
@@ -1153,41 +1269,47 @@ void BRepTools_ShapeSet::ReadPolygonOnTriangulation(Standard_IStream& IS)
   char buffer[255];
   IS >> buffer;
   if (strstr(buffer,"PolygonOnTriangulations") == NULL) return;
-    Standard_Integer i, j, val, nbpol = 0, nbnodes =0;
-    Standard_Integer hasparameters;
-    Standard_Real par;
-    Handle(TColStd_HArray1OfReal) Param;
-    Handle(Poly_PolygonOnTriangulation) Poly;
-    IS >> nbpol;
-    for (i=1; i<=nbpol; i++) {
-      IS >> nbnodes;
-      TColStd_Array1OfInteger Nodes(1, nbnodes);
-      for (j = 1; j <= nbnodes; j++) {
-        IS >> val;
-        Nodes(j) = val;
-      }
-      IS >> buffer;
+  Standard_Integer i, j, val, nbpol = 0, nbnodes =0;
+  Standard_Integer hasparameters;
+  Standard_Real par;
+  Handle(TColStd_HArray1OfReal) Param;
+  Handle(Poly_PolygonOnTriangulation) Poly;
+  IS >> nbpol;
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Polygons On Triangulation", 0, nbpol, 1);
+  for (i=1; i<=nbpol&& PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
+    IS >> nbnodes;
+    TColStd_Array1OfInteger Nodes(1, nbnodes);
+    for (j = 1; j <= nbnodes; j++) {
+      IS >> val;
+      Nodes(j) = val;
+    }
+    IS >> buffer;
 //      if (!strcasecmp(buffer, "p")) {
-        Standard_Real def;
-        IS >> def;
-        IS >> hasparameters;
-        if (hasparameters) {
-          TColStd_Array1OfReal Param1(1, nbnodes);
-          for (j = 1; j <= nbnodes; j++) {
-            IS >> par;
-            Param1(j) = par;
-          }
-          Poly = new Poly_PolygonOnTriangulation(Nodes, Param1);
+      Standard_Real def;
+      IS >> def;
+      IS >> hasparameters;
+      if (hasparameters) {
+        TColStd_Array1OfReal Param1(1, nbnodes);
+        for (j = 1; j <= nbnodes; j++) {
+          IS >> par;
+          Param1(j) = par;
         }
-        else Poly = new Poly_PolygonOnTriangulation(Nodes);
-        Poly->Deflection(def);
+        Poly = new Poly_PolygonOnTriangulation(Nodes, Param1);
+      }
+      else Poly = new Poly_PolygonOnTriangulation(Nodes);
+      Poly->Deflection(def);
 //      }
 //      else {
 //      IS.seekg(ppp);
 //      Poly = new Poly_PolygonOnTriangulation(Nodes);
 //      }
-      myNodes.Add(Poly);
-    }
+    myNodes.Add(Poly);
+  }
 //  }
 //  else IS.seekg(pos);
 }
@@ -1203,6 +1325,10 @@ void BRepTools_ShapeSet::WritePolygon3D(Standard_OStream&      OS,
                                         const Standard_Boolean Compact)const
 {
   Standard_Integer i, j, nbpol = myPolygons3D.Extent();
+  
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "3D Poligons", 0, nbpol, 1);
+
   if (Compact)
     OS << "Polygon3D " << nbpol << endl;
   else {
@@ -1212,7 +1338,10 @@ void BRepTools_ShapeSet::WritePolygon3D(Standard_OStream&      OS,
   }
   
   Handle(Poly_Polygon3D) P;
-  for (i = 1; i <= nbpol; i++) {
+  for (i = 1; i <= nbpol && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     P = Handle(Poly_Polygon3D)::DownCast(myPolygons3D(i));
     if (Compact) {
       OS << P->NbNodes() << " ";
@@ -1282,28 +1411,34 @@ void BRepTools_ShapeSet::ReadPolygon3D(Standard_IStream& IS)
 
   IS >> buffer;
   if (strstr(buffer,"Polygon3D") == NULL) return;
-    Handle(Poly_Polygon3D) P;
-    IS >> nbpol;
-    for (i=1; i<=nbpol; i++) {
-      IS >> nbnodes;
-      IS >> hasparameters;
-      TColgp_Array1OfPnt Nodes(1, nbnodes);
-      IS >> d;
-      for (j = 1; j <= nbnodes; j++) {
-        IS >> x >> y >> z;
-        Nodes(j).SetCoord(x,y,z);
-      }
-      if (hasparameters) {
-        TColStd_Array1OfReal Param(1,nbnodes);
-        for (p = 1; p <= nbnodes; p++) {
-          IS >> Param(p);
-        }
-        P = new Poly_Polygon3D(Nodes, Param);
-      }
-      else P = new Poly_Polygon3D(Nodes);
-      P->Deflection(d);
-      myPolygons3D.Add(P);
+  Handle(Poly_Polygon3D) P;
+  IS >> nbpol;
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "3D Polygons", 0, nbpol, 1);
+  for (i=1; i<=nbpol && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
+    IS >> nbnodes;
+    IS >> hasparameters;
+    TColgp_Array1OfPnt Nodes(1, nbnodes);
+    IS >> d;
+    for (j = 1; j <= nbnodes; j++) {
+      IS >> x >> y >> z;
+      Nodes(j).SetCoord(x,y,z);
     }
+    if (hasparameters) {
+      TColStd_Array1OfReal Param(1,nbnodes);
+      for (p = 1; p <= nbnodes; p++) {
+        IS >> Param(p);
+      }
+      P = new Poly_Polygon3D(Nodes, Param);
+    }
+    else P = new Poly_Polygon3D(Nodes);
+    P->Deflection(d);
+    myPolygons3D.Add(P);
+  }
 }
 
 
@@ -1318,6 +1453,10 @@ void BRepTools_ShapeSet::WriteTriangulation(Standard_OStream&      OS,
 {
   Standard_Integer i, j, nbNodes, nbtri = myTriangulations.Extent();
   Standard_Integer nbTriangles = 0, n1, n2, n3;
+  
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Triangulations", 0, nbtri, 1);
+
   if (Compact)
     OS << "Triangulations " << nbtri << endl;
   else {
@@ -1327,7 +1466,10 @@ void BRepTools_ShapeSet::WriteTriangulation(Standard_OStream&      OS,
   }
   
   Handle(Poly_Triangulation) T;
-  for (i = 1; i <= nbtri; i++) {
+  for (i = 1; i <= nbtri && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     T = Handle(Poly_Triangulation)::DownCast(myTriangulations(i));
     if (Compact) {
       OS << T->NbNodes() << " " << T->NbTriangles() << " ";
@@ -1394,7 +1536,6 @@ void BRepTools_ShapeSet::WriteTriangulation(Standard_OStream&      OS,
     }
     OS << "\n";
   }
-
 }
 
 //=======================================================================
@@ -1425,43 +1566,49 @@ void BRepTools_ShapeSet::ReadTriangulation(Standard_IStream& IS)
   Handle(Poly_Triangulation) T;
 
   IS >> buffer;
-  if (strstr(buffer,"Triangulations") != NULL) {
-    IS >> nbtri;
-    for (i=1; i<=nbtri; i++) {
-      IS >> nbNodes >> nbTriangles >> hasUV;
-      IS >> d;
+  if (strstr(buffer,"Triangulations") == NULL) return;
 
-      TColgp_Array1OfPnt Nodes(1, nbNodes);
-      TColgp_Array1OfPnt2d UVNodes(1, nbNodes);
+  IS >> nbtri;
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Triangulations", 0, nbtri, 1);
+  for (i=1; i<=nbtri && PS.More();i++, PS.Next()) {
+    if ( !progress.IsNull() )  
+      progress->Show();
 
-      for (j = 1; j <= nbNodes; j++) {
-        IS >> x >> y >> z;
-        Nodes(j).SetCoord(x,y,z);
-      }
+    IS >> nbNodes >> nbTriangles >> hasUV;
+    IS >> d;
 
-      if (hasUV) {
-        for (j = 1; j <= nbNodes; j++) {
-          IS >> x >> y;
-          UVNodes(j).SetCoord(x,y);
-        }
-      }
-      
-      
-      // read the triangles
-      Standard_Integer n1,n2,n3;
-      Poly_Array1OfTriangle Triangles(1, nbTriangles);
-      for (j = 1; j <= nbTriangles; j++) {
-        IS >> n1 >> n2 >> n3;
-        Triangles(j).Set(n1,n2,n3);
-      }
-      
-      if (hasUV) T =  new Poly_Triangulation(Nodes,UVNodes,Triangles);
-      else T = new Poly_Triangulation(Nodes,Triangles);
-      
-      T->Deflection(d);
-      
-      myTriangulations.Add(T);
+    TColgp_Array1OfPnt Nodes(1, nbNodes);
+    TColgp_Array1OfPnt2d UVNodes(1, nbNodes);
+
+    for (j = 1; j <= nbNodes; j++) {
+      IS >> x >> y >> z;
+      Nodes(j).SetCoord(x,y,z);
     }
+
+    if (hasUV) {
+      for (j = 1; j <= nbNodes; j++) {
+        IS >> x >> y;
+        UVNodes(j).SetCoord(x,y);
+      }
+    }
+      
+    // read the triangles
+    Standard_Integer n1,n2,n3;
+    Poly_Array1OfTriangle Triangles(1, nbTriangles);
+    for (j = 1; j <= nbTriangles; j++) {
+      IS >> n1 >> n2 >> n3;
+      Triangles(j).Set(n1,n2,n3);
+    }
+      
+    if (hasUV) T =  new Poly_Triangulation(Nodes,UVNodes,Triangles);
+    else T = new Poly_Triangulation(Nodes,Triangles);
+      
+    T->Deflection(d);
+      
+    myTriangulations.Add(T);
   }
 }
 
+
