@@ -7,6 +7,9 @@
 #include <BinMDF_ADriverTable.hxx>
 #include <CDM_MessageDriver.hxx>
 #include <BinMFunction_FunctionDriver.hxx>
+#include <BinMFunction_GraphNodeDriver.hxx>
+#include <BinMFunction_ScopeDriver.hxx>
+
 //=======================================================================
 //function : AddDrivers
 //purpose  : 
@@ -16,4 +19,6 @@ void BinMFunction::AddDrivers (const Handle(BinMDF_ADriverTable)& theDriverTable
 			       const Handle(CDM_MessageDriver)&   theMsgDriver)
 {
   theDriverTable->AddDriver (new BinMFunction_FunctionDriver  (theMsgDriver) );
+  theDriverTable->AddDriver (new BinMFunction_GraphNodeDriver (theMsgDriver) );
+  theDriverTable->AddDriver (new BinMFunction_ScopeDriver     (theMsgDriver) );
 }
