@@ -13,7 +13,18 @@
 #define BP_EXTCHARSIZE     ((Standard_Integer)sizeof(Standard_ExtCharacter))
 #define BP_REALSIZE        ((Standard_Integer)sizeof(Standard_Real))
 #define BP_SHORTREALSIZE   ((Standard_Integer)sizeof(Standard_ShortReal))
-#define BP_UUIDSIZE        ((Standard_Integer)sizeof(Standard_UUID))
+#define BP_UUIDSIZE        ((Standard_Integer)sizeof(BinObjMgt_UUID))
+
+// We define a GUID structure that is different from Standard_UUID because
+// the latter contains a 'unsigned long' member that has variables size
+// (4 or 8 bits) thus making the persistent files non-portable.
+// This structure below ensures the portability.
+typedef struct {
+  unsigned int   Data1 ;        // 4-bytes long on all OS
+  unsigned short Data2 ;        // 2-bytes long on all OS
+  unsigned short Data3 ;        // 2-bytes long on all OS
+  unsigned char  Data4[8] ;     // 8-bytes long on all OS
+} BinObjMgt_UUID ;
 
 //=======================================================================
 //function : BinObjMgt_Persistent
@@ -186,6 +197,22 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutCharacter
   return *this;
 }
 
+//=======================================================================
+//function : PutByte
+//purpose  : 
+//=======================================================================
+
+BinObjMgt_Persistent& BinObjMgt_Persistent::PutByte
+  (const Standard_Byte theValue)
+{
+  alignOffset (1);
+  prepareForPut (1);
+  Standard_Byte *aData = (Standard_Byte*) myData(myIndex) + myOffset;
+  *aData = theValue;
+  myOffset++;
+  return *this;
+}
+
 //=======================================================================
 //function : PutExtCharacter
 //purpose  : 
@@ -292,7 +319,7 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutCString
   alignOffset (1);
   Standard_Integer aSize = strlen (theValue) + 1;
   prepareForPut (aSize);
-  putArray (theValue, aSize);
+  putArray ((void* const)theValue, aSize);
   return *this;
 }
 
@@ -307,7 +334,7 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutAsciiString
   alignOffset (BP_INTSIZE, Standard_True);
   Standard_Integer aSize = theValue.Length() + 1;
   prepareForPut (aSize);
-  putArray (theValue.ToCString(), aSize);
+  putArray ((void* const)theValue.ToCString(), aSize);
   return *this;
 }
 
@@ -326,7 +353,7 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutExtendedString
   Standard_Integer aStartIndex = myIndex;
   Standard_Integer aStartOffset = myOffset;
 #endif
-  putArray (theValue.ToExtString(), aSize);
+  putArray ((void* const)theValue.ToExtString(), aSize);
 #if DO_INVERSE
   inverseExtCharData (aStartIndex, aStartOffset, aSize - BP_EXTCHARSIZE);
 #endif
@@ -383,11 +410,23 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutGUID
 {
   alignOffset (BP_INTSIZE, Standard_True);
   prepareForPut (BP_UUIDSIZE);
-  Standard_UUID anUUID = theValue.ToUUID();
+  const Standard_UUID aStandardUUID = theValue.ToUUID();
+  BinObjMgt_UUID anUUID;
+  anUUID.Data1 = (unsigned int)   aStandardUUID.Data1;
+  anUUID.Data2 = (unsigned short) aStandardUUID.Data2;
+  anUUID.Data3 = (unsigned short) aStandardUUID.Data3;
+  anUUID.Data4[0] = aStandardUUID.Data4[0];
+  anUUID.Data4[1] = aStandardUUID.Data4[1];
+  anUUID.Data4[2] = aStandardUUID.Data4[2];
+  anUUID.Data4[3] = aStandardUUID.Data4[3];
+  anUUID.Data4[4] = aStandardUUID.Data4[4];
+  anUUID.Data4[5] = aStandardUUID.Data4[5];
+  anUUID.Data4[6] = aStandardUUID.Data4[6];
+  anUUID.Data4[7] = aStandardUUID.Data4[7];
 #if DO_INVERSE
-  anUUID.Data1 = (unsigned long) InverseLong ((unsigned long) anUUID.Data1);
-  anUUID.Data2 = (unsigned short) InverseExtChar ((unsigned short) anUUID.Data2);
-  anUUID.Data3 = (unsigned short) InverseExtChar ((unsigned short) anUUID.Data3);
+  anUUID.Data1 = (unsigned int)   InverseInt     (anUUID.Data1);
+  anUUID.Data2 = (unsigned short) InverseExtChar (anUUID.Data2);
+  anUUID.Data3 = (unsigned short) InverseExtChar (anUUID.Data3);
 #endif
   putArray (&anUUID, BP_UUIDSIZE);
   return *this;
@@ -399,7 +438,22 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutGUID
 //=======================================================================
 
 BinObjMgt_Persistent& BinObjMgt_Persistent::PutCharArray
-  (const BinObjMgt_PChar& theArray,
+  (const BinObjMgt_PChar  theArray,
+   const Standard_Integer theLength)
+{
+  alignOffset (1);
+  prepareForPut (theLength);
+  putArray (theArray, theLength);
+  return *this;
+}
+
+//=======================================================================
+//function : PutByteArray
+//purpose  : Put C array of byte, theLength is the number of elements
+//=======================================================================
+
+BinObjMgt_Persistent& BinObjMgt_Persistent::PutByteArray
+  (const BinObjMgt_PByte  theArray,
    const Standard_Integer theLength)
 {
   alignOffset (1);
@@ -414,8 +468,8 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutCharArray
 //=======================================================================
 
 BinObjMgt_Persistent& BinObjMgt_Persistent::PutExtCharArray
-  (const BinObjMgt_PExtChar& theArray,
-   const Standard_Integer theLength)
+  (const BinObjMgt_PExtChar theArray,
+   const Standard_Integer   theLength)
 {
   alignOffset (BP_EXTCHARSIZE, Standard_True);
   Standard_Integer aSize = theLength * BP_EXTCHARSIZE;
@@ -437,8 +491,8 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutExtCharArray
 //=======================================================================
 
 BinObjMgt_Persistent& BinObjMgt_Persistent::PutIntArray
-  (const BinObjMgt_PInteger& theArray,
-   const Standard_Integer theLength)
+  (const BinObjMgt_PInteger theArray,
+   const Standard_Integer   theLength)
 {
   alignOffset (BP_INTSIZE, Standard_True);
   Standard_Integer aSize = theLength * BP_INTSIZE;
@@ -460,7 +514,7 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutIntArray
 //=======================================================================
 
 BinObjMgt_Persistent& BinObjMgt_Persistent::PutRealArray
-  (const BinObjMgt_PReal& theArray,
+  (const BinObjMgt_PReal  theArray,
    const Standard_Integer theLength)
 {
   alignOffset (BP_INTSIZE, Standard_True);
@@ -477,6 +531,29 @@ BinObjMgt_Persistent& BinObjMgt_Persistent::PutRealArray
   return *this;
 }
 
+//=======================================================================
+//function : PutShortRealArray
+//purpose  : Put C array of float, theLength is the number of elements
+//=======================================================================
+
+BinObjMgt_Persistent& BinObjMgt_Persistent::PutShortRealArray
+  (const BinObjMgt_PShortReal theArray,
+   const Standard_Integer     theLength)
+{
+  alignOffset (BP_INTSIZE, Standard_True);
+  Standard_Integer aSize = theLength * BP_SHORTREALSIZE;
+  prepareForPut (aSize);
+#if DO_INVERSE
+  Standard_Integer aStartIndex = myIndex;
+  Standard_Integer aStartOffset = myOffset;
+#endif
+  putArray (theArray, aSize);
+#if DO_INVERSE
+  inverseShortRealData (aStartIndex, aStartOffset, aSize);
+#endif
+  return *this;
+}
+
 //=======================================================================
 //function : GetCharacter
 //purpose  : 
@@ -493,6 +570,22 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetCharacter
   return *this;
 }
 
+//=======================================================================
+//function : GetByte
+//purpose  : 
+//=======================================================================
+
+const BinObjMgt_Persistent& BinObjMgt_Persistent::GetByte
+  (Standard_Byte& theValue) const
+{
+  alignOffset (1);
+  if (noMoreData (1)) return *this;
+  Standard_Byte *aData = (Standard_Byte*) myData(myIndex) + myOffset;
+  theValue = *aData;
+  ((BinObjMgt_Persistent*)this)->myOffset++;
+  return *this;
+}
+
 //=======================================================================
 //function : GetExtCharacter
 //purpose  : 
@@ -675,7 +768,7 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetExtendedString
     Standard::Free (aString);
   }
 #if DO_INVERSE
-  Standard_ExtString aString = theValue.ToExtString();
+  Standard_PExtCharacter aString = (Standard_PExtCharacter)theValue.ToExtString();
   for (Standard_Integer i=0; i < theValue.Length(); i++)
     aString[i] = InverseExtChar (aString[i]);
 #endif
@@ -737,15 +830,19 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetGUID
   (Standard_GUID& theValue) const
 {
   alignOffset (BP_INTSIZE);
-  if (noMoreData (BP_UUIDSIZE)) return *this;
-  Standard_UUID anUUID;
+  if (noMoreData (BP_UUIDSIZE))
+    return *this;
+  BinObjMgt_UUID anUUID;
   getArray (&anUUID, BP_UUIDSIZE);
 #if DO_INVERSE
-  anUUID.Data1 = (unsigned long) InverseLong ((unsigned long) anUUID.Data1);
-  anUUID.Data2 = (unsigned short) InverseExtChar ((unsigned short) anUUID.Data2);
-  anUUID.Data3 = (unsigned short) InverseExtChar ((unsigned short) anUUID.Data3);
+  anUUID.Data1 = (unsigned int)   InverseInt     (anUUID.Data1);
+  anUUID.Data2 = (unsigned short) InverseExtChar (anUUID.Data2);
+  anUUID.Data3 = (unsigned short) InverseExtChar (anUUID.Data3);
 #endif
-  theValue = Standard_GUID (anUUID);
+  theValue = Standard_GUID (anUUID.Data1, anUUID.Data2, anUUID.Data3,
+                            ((anUUID.Data4[0] << 8) | (anUUID.Data4[1])),
+                            anUUID.Data4[2], anUUID.Data4[3], anUUID.Data4[4],
+                            anUUID.Data4[5], anUUID.Data4[6], anUUID.Data4[7]);
   return *this;
 }
 
@@ -757,7 +854,24 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetGUID
 //=======================================================================
 
 const BinObjMgt_Persistent& BinObjMgt_Persistent::GetCharArray
-  (const BinObjMgt_PChar& theArray,
+  (const BinObjMgt_PChar  theArray,
+   const Standard_Integer theLength) const
+{
+  alignOffset (1);
+  if (noMoreData (theLength)) return *this;
+  getArray (theArray, theLength);
+  return *this;
+}
+
+//=======================================================================
+//function : GetByteArray
+//purpose  : Get C array of unsigned chars, theLength is the number of elements;
+//           theArray must point to a 
+//           space enough to place theLength elements
+//=======================================================================
+
+const BinObjMgt_Persistent& BinObjMgt_Persistent::GetByteArray
+  (const BinObjMgt_PByte  theArray,
    const Standard_Integer theLength) const
 {
   alignOffset (1);
@@ -774,8 +888,8 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetCharArray
 //=======================================================================
 
 const BinObjMgt_Persistent& BinObjMgt_Persistent::GetExtCharArray
-  (const BinObjMgt_PExtChar& theArray,
-   const Standard_Integer theLength) const
+  (const BinObjMgt_PExtChar theArray,
+   const Standard_Integer   theLength) const
 {
   alignOffset (BP_EXTCHARSIZE, Standard_True);
   Standard_Integer aSize = theLength * BP_EXTCHARSIZE;
@@ -796,8 +910,8 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetExtCharArray
 //=======================================================================
 
 const BinObjMgt_Persistent& BinObjMgt_Persistent::GetIntArray
-  (const BinObjMgt_PInteger& theArray,
-   const Standard_Integer theLength) const
+  (const BinObjMgt_PInteger theArray,
+   const Standard_Integer   theLength) const
 {
   alignOffset (BP_INTSIZE, Standard_True);
   Standard_Integer aSize = theLength * BP_INTSIZE;
@@ -818,7 +932,7 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetIntArray
 //=======================================================================
 
 const BinObjMgt_Persistent& BinObjMgt_Persistent::GetRealArray
-  (const BinObjMgt_PReal& theArray,
+  (const BinObjMgt_PReal  theArray,
    const Standard_Integer theLength) const
 {
   alignOffset (BP_INTSIZE, Standard_True);
@@ -832,6 +946,28 @@ const BinObjMgt_Persistent& BinObjMgt_Persistent::GetRealArray
   return *this;
 }
 
+//=======================================================================
+//function : GetShortRealArray
+//purpose  : Get C array of float, theLength is the number of elements;
+//           theArray must point to a 
+//           space enough to place theLength elements
+//=======================================================================
+
+const BinObjMgt_Persistent& BinObjMgt_Persistent::GetShortRealArray
+  (const BinObjMgt_PShortReal theArray,
+   const Standard_Integer     theLength) const
+{
+  alignOffset (BP_INTSIZE, Standard_True);
+  Standard_Integer aSize = theLength * BP_SHORTREALSIZE;
+  if (noMoreData (aSize)) return *this;
+  getArray (theArray, aSize);
+#if DO_INVERSE
+  for (Standard_Integer i=0; i < theLength; i++)
+    theArray[i] = InverseShortReal (theArray[i]);
+#endif
+  return *this;
+}
+
 //=======================================================================
 //function : putArray
 //purpose  : Puts theSize bytes from theArray
@@ -975,3 +1111,31 @@ void BinObjMgt_Persistent::inverseRealData
     }
   }
 }
+
+//=======================================================================
+//function : inverseShortRealData
+//purpose  : Inverses bytes in the data addressed by the given values
+//=======================================================================
+
+void BinObjMgt_Persistent::inverseShortRealData
+  (const Standard_Integer theIndex,
+   const Standard_Integer theOffset,
+   const Standard_Integer theSize)
+{
+  Standard_Integer anIndex = theIndex;
+  Standard_Integer anOffset = theOffset;
+  Standard_Integer aLen = theSize;
+  while (aLen > 0) {
+    Standard_Integer aLenInPiece = Min (aLen, BP_PIECESIZE - anOffset);
+    Standard_ShortReal *aData =
+      (Standard_ShortReal *) ((char *)myData(anIndex) + anOffset);
+    for (Standard_Integer i=0; i < aLenInPiece / BP_INTSIZE; i++)
+      aData[i] = InverseShortReal (aData[i]);
+    aLen -= aLenInPiece;
+    anOffset += aLenInPiece;
+    if (anOffset >= BP_PIECESIZE) {
+      anIndex++;
+      anOffset = 0;
+    }
+  }
+}
