@@ -38,9 +38,10 @@
 #include <BinTools_CurveSet.hxx>
 #include <BinTools_SurfaceSet.hxx>
 #include <string.h>
-
+//#define MDTV_DEB 1
 const char* Version_1  = "Open CASCADE Topology V1 (c)";
 const char* Version_2  = "Open CASCADE Topology V2 (c)";
+const char* Version_3  = "Open CASCADE Topology V3 (c)";
 //=======================================================================
 //function : operator << (gp_Pnt)
 //purpose  : 
@@ -59,7 +60,7 @@ static Standard_OStream& operator <<(Standard_OStream& OS, const gp_Pnt P)
 //=======================================================================
 
 BinTools_ShapeSet::BinTools_ShapeSet(const Standard_Boolean isWithTriangles)
-     :myWithTriangles(isWithTriangles), myFormatNb(2)
+     :myWithTriangles(isWithTriangles), myFormatNb(3)
 {}
 
 //=======================================================================
@@ -295,7 +296,9 @@ void  BinTools_ShapeSet::Write(Standard_OStream& OS)const
 {
 
   // write the copyright
-  if (myFormatNb == 2)
+  if (myFormatNb == 3)
+    OS << "\n" << Version_3 << endl;
+  else if (myFormatNb == 2)
     OS << "\n" << Version_2 << endl;
   else
     OS << "\n" << Version_1 << endl;
@@ -371,13 +374,15 @@ void  BinTools_ShapeSet::Read(Standard_IStream& IS)
     for (Standard_Integer lv = (strlen(vers)- 1); lv > 1 && (vers[lv] == '\r' || vers[lv] == '\n') ;lv--) 
       vers[lv] = '\0';
     
-  } while ( ! IS.fail() && strcmp(vers,Version_1) && strcmp(vers,Version_2) );
+  } while ( ! IS.fail() && strcmp(vers,Version_1) && strcmp(vers,Version_2) &&
+	   strcmp(vers,Version_3));
   if (IS.fail()) {
     cout << "BinTools_ShapeSet::Read: File was not written with this version of the topology"<<endl;
      return;
   }
 
-  if (strcmp(vers,Version_2) == 0) SetFormatNb(2);
+  if (strcmp(vers,Version_3) == 0) SetFormatNb(3);
+  else  if (strcmp(vers,Version_2) == 0) SetFormatNb(2);    
   else SetFormatNb(1);
 
   //-----------------------------------------
@@ -438,7 +443,7 @@ void  BinTools_ShapeSet::Read(Standard_IStream& IS)
 
     S.Free(aFree);
     S.Modified(aMod);
-     if (myFormatNb == 2)
+     if (myFormatNb >= 2)
        S.Checked(aChecked);
      else
        S.Checked   (Standard_False);     // force check at reading.. 
@@ -534,27 +539,40 @@ void  BinTools_ShapeSet::WriteGeometry(const TopoDS_Shape& S,
       BinTools::PutReal(OS, BRep_Tool::Tolerance(V));
       gp_Pnt p = BRep_Tool::Pnt(V);
       OS << p;
-
+#ifdef MDTV_DEB
+      Standard_Integer aPos;
+#endif
       Handle(BRep_TVertex) TV = Handle(BRep_TVertex)::DownCast(S.TShape());
       BRep_ListIteratorOfListOfPointRepresentation itrp(TV->Points());
       while (itrp.More()) {
 	const Handle(BRep_PointRepresentation)& PR = itrp.Value();
-
-	BinTools::PutReal(OS, PR->Parameter());
+//	BinTools::PutReal(OS, PR->Parameter());
 	if (PR->IsPointOnCurve()) {
+#ifdef MDTV_DEB
+	  aPos = OS.tellp();
+#endif
 	  OS << (Standard_Byte)1; // 1
+	  BinTools::PutReal(OS, PR->Parameter());
 	  BinTools::PutInteger(OS, myCurves.Index(PR->Curve()));
 	}
 
 	else if (PR->IsPointOnCurveOnSurface()) {
+#ifdef MDTV_DEB
+	  aPos = OS.tellp();
+#endif
 	  OS << (Standard_Byte)2;// 2
+	  BinTools::PutReal(OS, PR->Parameter());
 	  BinTools::PutInteger(OS, myCurves2d.Index(PR->PCurve()));
 	  BinTools::PutInteger(OS, mySurfaces.Index(PR->Surface()));
 	}
 
 	else if (PR->IsPointOnSurface()) {
+#ifdef MDTV_DEB
+	  aPos = OS.tellp();
+#endif
 	  OS << (Standard_Byte)3;// 3
 	  BinTools::PutReal(OS, PR->Parameter2());
+	  BinTools::PutReal(OS, PR->Parameter());
 	  BinTools::PutInteger(OS, mySurfaces.Index(PR->Surface()));
 	}
 	BinTools::PutInteger(OS, Locations().Index(PR->Location()));
@@ -615,7 +633,7 @@ void  BinTools_ShapeSet::WriteGeometry(const TopoDS_Shape& S,
 	  BinTools::PutReal(OS, last);
 
         // Write UV Points for higher performance
-	  if (FormatNb() == 2)
+	  if (FormatNb() >= 2)
 	    {
 	      gp_Pnt2d Pf,Pl;
 	      if (CR->IsCurveOnClosedSurface()) {
@@ -762,20 +780,34 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 
 	BRep_ListOfPointRepresentation& lpr = TV->ChangePoints();
 	TopLoc_Location L;
-
+	Standard_Boolean aNewF = (myFormatNb > 2) ? Standard_True : Standard_False;
+#ifdef MDTV_DEB
+	gp_Pnt aPnt = gp_Pnt(X,Y,Z);
+#endif
 	do {
-//	aPos = IS.tellg();      
-//	cout << "\nPOS = " << aPos <<endl;
-
-	  val = (Standard_Integer)IS.get();//case {0|1|2|3}
-	  if (val > 0 && val <= 3) 
-	    BinTools::GetReal(IS, p1); 
-	  
+	  if(aNewF) {
+	    val = (Standard_Integer)IS.get();//case {0|1|2|3}
+	    if (val > 0 && val <= 3) 
+	      BinTools::GetReal(IS, p1); 
+	  } else {
+	    Standard_Integer aPos = IS.tellg();
+	    BinTools::GetReal(IS, p1); 	    
+	    val = (Standard_Integer)IS.get();//case {0|1|2|3}
+#ifdef MDTV_DEB
+	    cout << "\nVal = " << val <<endl;   
+#endif	  
+	    if(val != 1 && val !=2 && val !=3){
+	      IS.seekg(aPos);
+	      val = (Standard_Integer)IS.get();
+	      if (val > 0 && val <= 3) 
+		BinTools::GetReal(IS, p1);
+	    }
+	  }
 	  Handle(BRep_PointRepresentation) PR;
 	  switch (val) {
 	  case 0 :
 	    break;
-
+	    
 	  case 1 :
 	    {
 	      BinTools::GetInteger(IS, c);
@@ -788,7 +820,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	      PR = POC;
 	    }
 	    break;
-
+	    
 	  case 2 :
 	    {
 	      BinTools::GetInteger(IS, pc);
@@ -796,7 +828,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	      if (myCurves2d.Curve2d(pc).IsNull() ||
 		  mySurfaces.Surface(s).IsNull())
 		break;
-
+	      
 	      Handle(BRep_PointOnCurveOnSurface) POC =
 		new BRep_PointOnCurveOnSurface(p1,
 					       myCurves2d.Curve2d(pc),
@@ -805,7 +837,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	      PR = POC;
 	    }
 	    break;
-
+	    
 	  case 3 :
 	    {
 	      BinTools::GetReal(IS, p2);
@@ -820,14 +852,14 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	      PR = POC;
 	    }
 	    break;
-
+	    
 	  default:
 	    {
 	      aMsg << "BinTools_SurfaceSet::ReadGeometry: UnExpected BRep_PointRepresentation = "<< val <<endl;
 	      Standard_Failure::Raise(aMsg);
-	    }
+	      }
 	  }
-
+	  
 	  if (val > 0) {
 	    BinTools::GetInteger(IS, l);//Locations index
 	    
@@ -914,7 +946,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	    BinTools::GetReal(IS, last);
 
             // read UV Points // for XML Persistence higher performance
-            if (FormatNb() == 2)
+            if (FormatNb() >= 2)
             {
 	      BinTools::GetReal(IS, PfX);
 	      BinTools::GetReal(IS, PfY);
@@ -930,7 +962,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
 	      break;
 	    
             if (closed) {
-              if (FormatNb() == 2)
+              if (FormatNb() >= 2)
                 myBuilder.UpdateEdge(E,myCurves2d.Curve2d(pc),
                                      myCurves2d.Curve2d(pc2),
                                      mySurfaces.Surface(s),
@@ -951,7 +983,7 @@ void  BinTools_ShapeSet::ReadGeometry(const TopAbs_ShapeEnum T,
             }
             else
             {
-              if (FormatNb() == 2)
+              if (FormatNb() >= 2)
                 myBuilder.UpdateEdge(E,myCurves2d.Curve2d(pc),
                                      mySurfaces.Surface(s),
                                      Locations().Location(l),tol,
