@@ -507,17 +507,40 @@ void Bnd_Box::Add (const Bnd_Box& Other)
   if (IsWhole()) return;
   else if (Other.IsVoid()) return; 
   else if (Other.IsWhole()) SetWhole();
-  else {
-    Bnd_Box Brother = Other;
-    Standard_Real x,y,z,X,Y,Z;
-    Brother.Get(x,y,z,X,Y,Z);
-    Update(x,y,z,X,Y,Z);
-    if (Brother.IsOpenXmin()) OpenXmin();
-    if (Brother.IsOpenXmax()) OpenXmax();
-    if (Brother.IsOpenYmin()) OpenYmin();
-    if (Brother.IsOpenYmax()) OpenYmax();
-    if (Brother.IsOpenZmin()) OpenZmin();
-    if (Brother.IsOpenZmax()) OpenZmax();
+  else if (IsVoid()) (*this) = Other;
+  else
+  {
+    if ( ! IsOpenXmin() )
+    {
+      if (Other.IsOpenXmin()) OpenXmin();
+      else if (Xmin > Other.Xmin) Xmin = Other.Xmin;
+    }
+    if ( ! IsOpenXmax() )
+    {
+      if (Other.IsOpenXmax()) OpenXmax();
+      else if (Xmax < Other.Xmax) Xmax = Other.Xmax;
+    }
+    if ( ! IsOpenYmin() )
+    {
+      if (Other.IsOpenYmin()) OpenYmin();
+      else if (Ymin > Other.Ymin) Ymin = Other.Ymin;
+    }
+    if ( ! IsOpenYmax() )
+    {
+      if (Other.IsOpenYmax()) OpenYmax();
+      else if (Ymax < Other.Ymax) Ymax = Other.Ymax;
+    }
+    if ( ! IsOpenZmin() )
+    {
+      if (Other.IsOpenZmin()) OpenZmin();
+      else if (Zmin > Other.Zmin) Zmin = Other.Zmin;
+    }
+    if ( ! IsOpenZmax() )
+    {
+      if (Other.IsOpenZmax()) OpenZmax();
+      else if (Zmax < Other.Zmax) Zmax = Other.Zmax;
+    }
+    Gap = Max (Gap, Other.Gap);
   }
 }
 
