@@ -159,7 +159,7 @@ void CGM_Driver::BeginFile (const Handle(PlotMgt_Plotter)& aPlotter,
   }
 
   // Open the CGM metafile
-  cgmo = OPEN_FILE (myFileName.ToCString(), TypeOfCgm + 1);
+  cgmo = OPEN_FILE ((Standard_PCharacter)myFileName.ToCString(), TypeOfCgm + 1);
   if (!cgmo) {
 #ifdef IMP020701
     char error[1024];
@@ -253,7 +253,7 @@ void CGM_Driver::BeginDraw ()
 }
 
 //=============================================================
-void CGM_Driver::EndDraw (const Standard_Boolean dontFlush)
+void CGM_Driver::EndDraw (const Standard_Boolean )//dontFlush)
 {
   // Close the current picture
   WriteData (ENDPIC, ptablong, ptabreal, ptabchar);
