@@ -128,9 +128,9 @@ static Standard_Boolean ToricRotule(const BRepAdaptor_Surface& fac,
   gp_Dir ds2 = s2.Plane().Position().Direction();
   if ( Abs(df.Dot(ds1)) >= tolesp || Abs(df.Dot(ds2)) >= tolesp ) 
     return Standard_False;
-  Standard_Real rad1 = sp1->Radius();
-  Standard_Real rad2 = sp2->Radius();
-  if(Abs(rad1 - rad2) >= tolesp) return Standard_False;
+  Standard_Real r1 = sp1->Radius();
+  Standard_Real r2 = sp2->Radius();
+  if(Abs(r1 - r2) >= tolesp) return Standard_False;
   return Standard_True;
 }
 
