@@ -34,6 +34,7 @@
 #include <GProp_GProps.hxx>
 #include <BRepGProp.hxx>
 #include <TColStd_Array1OfReal.hxx>
+#include <Draw_ProgressIndicator.hxx>
 
 // memory management
 #include <Standard.hxx>
@@ -110,7 +111,7 @@ static Standard_Boolean withHid = Standard_False;
 //=======================================================================
 
 static Standard_Integer isos (Draw_Interpretor& di,
-			      Standard_Integer NbArg, char **Arg)
+			      Standard_Integer NbArg, const char **Arg)
 {
   NbArg-- ;
   
@@ -157,7 +158,7 @@ static Standard_Integer isos (Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer hlr (Draw_Interpretor& di,
-			     Standard_Integer n, char **a)
+			     Standard_Integer n, const char **a)
 {
   if (n <= 1) {
     if (withHLR) {
@@ -284,7 +285,7 @@ static Standard_Integer hlr (Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer dispor (Draw_Interpretor& ,
-				Standard_Integer n, char** a)
+				Standard_Integer n, const char** a)
 {
   Standard_Boolean d = !strcasecmp(a[0],"vori");
 
@@ -311,7 +312,7 @@ static Standard_Integer dispor (Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer discretisation(Draw_Interpretor& di,
-				       Standard_Integer n, char** a)
+				       Standard_Integer n, const char** a)
 {
   if (n <= 1)
     di << "Current number of points : "<<discret<<"\n";
@@ -327,7 +328,7 @@ static Standard_Integer discretisation(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer triangles(Draw_Interpretor& , 
-				  Standard_Integer n, char** a)
+				  Standard_Integer n, const char** a)
 {
   if (n < 1) return 1;
 
@@ -361,7 +362,7 @@ static Standard_Integer triangles(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer tclean(Draw_Interpretor& , 
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n < 1) return 1;
   
@@ -377,7 +378,7 @@ static Standard_Integer tclean(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer polygons(Draw_Interpretor& , 
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n < 1)  return 1;
 
@@ -412,7 +413,7 @@ static Standard_Integer polygons(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer compound(Draw_Interpretor& ,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   BRep_Builder B;
@@ -431,7 +432,7 @@ static Standard_Integer compound(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer emptycopy(Draw_Interpretor& ,
-				  Standard_Integer n, char** a)
+				  Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   TopoDS_Shape S = DBRep::Get(a[(n == 2) ? 1 : 2]);
@@ -446,7 +447,7 @@ static Standard_Integer emptycopy(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer add(Draw_Interpretor& ,
-			    Standard_Integer n, char** a)
+			    Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   BRep_Builder B;
@@ -464,7 +465,7 @@ static Standard_Integer add(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer explode(Draw_Interpretor& di,
-				Standard_Integer n, char** a)
+				Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -537,12 +538,12 @@ static Standard_Integer explode(Draw_Interpretor& di,
     M.Add(S);
     TopExp_Explorer ex(S,typ);
     for (; ex.More(); ex.Next()) {
-      const TopoDS_Shape& S = ex.Current();
-      Standard_Boolean added = M.Add(S);
+      const TopoDS_Shape& Sx = ex.Current();
+      Standard_Boolean added = M.Add(Sx);
       if (added) {
 	i++;
 	sprintf(p,"%d",i);
-	DBRep::Set(newname,S);
+	DBRep::Set(newname,Sx);
 	di.AppendElement(newname);
       }
     }
@@ -555,7 +556,7 @@ static Standard_Integer explode(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer nexplode(Draw_Interpretor& di, 
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 { 
   if (n <= 2) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -648,7 +649,7 @@ static Standard_Integer nexplode(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer exwire(Draw_Interpretor& ,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -676,7 +677,7 @@ static Standard_Integer exwire(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer invert(Draw_Interpretor& ,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -700,7 +701,7 @@ static Standard_Integer invert(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer orientation(Draw_Interpretor& ,
-				    Standard_Integer n, char** a)
+				    Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   Standard_Integer cas = 0;
@@ -763,7 +764,7 @@ static Standard_Integer orientation(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer numshapes(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -790,7 +791,7 @@ static Standard_Integer numshapes(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer nbshapes(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -811,11 +812,116 @@ static Standard_Integer nbshapes(Draw_Interpretor& di,
   return 0;
 }
 
+//=======================================================================
+// 
+//=======================================================================
+
+static Standard_Integer countshapes(Draw_Interpretor& di,
+                                    Standard_Integer n, const char** a)
+{
+  if (n < 2) return 1;
+
+  Standard_Integer i;
+  TopExp_Explorer ex;
+  for (i = 1; i < n; i++) {
+    TopoDS_Shape Sh = DBRep::Get(a[i]);
+    Standard_Integer nbElem = 0;
+    if (!Sh.IsNull()) {
+      di <<"Number of shapes in "<<a[i]<<"\n";
+      TopTools_MapOfShape M;
+
+      for (ex.Init (Sh,TopAbs_VERTEX); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " VERTEX     : " << nbElem << "\n";
+      nbElem = 0;
+    
+      for (ex.Init (Sh,TopAbs_EDGE); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " EDGE       : " << nbElem << "\n";
+      nbElem = 0;
+
+      for (ex.Init (Sh,TopAbs_WIRE); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " WIRE       : " << nbElem << "\n";
+      nbElem = 0;
+
+      for (ex.Init (Sh,TopAbs_FACE); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " FACE       : " << nbElem << "\n";
+      nbElem = 0;
+
+      for (ex.Init (Sh,TopAbs_SHELL); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " SHELL      : " << nbElem << "\n";
+      nbElem = 0;
+
+      for (ex.Init (Sh,TopAbs_SOLID); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " SOLID      : " << nbElem << "\n";
+      nbElem = 0;
+
+      for (ex.Init (Sh,TopAbs_COMPSOLID); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " COMPSOLID  : " << nbElem << "\n";
+      nbElem = 0;
+      
+      for (ex.Init (Sh,TopAbs_COMPOUND); ex.More(); ex.Next()) {
+        const TopoDS_Shape& S = ex.Current();
+        Standard_Boolean added = M.Add(S);
+        if (added) {
+          nbElem++;
+        }
+      }
+      di << " COMPOUND   : " << nbElem << "\n";
+      nbElem = 0;
+
+      di << " SHAPE      : " << M.Extent() << "\n";
+      di << "\n" ;
+    }
+}
+
+  return 0;
+}
 
 //=======================================================================
 //memory management
 //=======================================================================
-static Standard_Integer purgemmgt(Draw_Interpretor&, Standard_Integer ,char**) {
+static Standard_Integer purgemmgt(Draw_Interpretor&, Standard_Integer , const char**) {
   Standard::Purge();
   return 0;
 }
@@ -826,7 +932,7 @@ static Standard_Integer purgemmgt(Draw_Interpretor&, Standard_Integer ,char**) {
 //=======================================================================
 
 static Standard_Integer check(Draw_Interpretor& ,
-			      Standard_Integer n, char** a)
+			      Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -851,7 +957,7 @@ static Standard_Integer check(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer normals(Draw_Interpretor& di,
-				Standard_Integer n, char** a)
+				Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   Standard_Real l = 1.;
@@ -920,10 +1026,8 @@ static Standard_Integer normals(Draw_Interpretor& di,
 //function : Set
 //purpose  : 
 //=======================================================================
-
 void  DBRep::Set(const Standard_CString Name, const TopoDS_Shape& S)
 {
-  char* name = Name;
   Handle(DBRep_DrawableShape) D =
     new DBRep_DrawableShape(S,
 			    Draw_vert,
@@ -936,15 +1040,12 @@ void  DBRep::Set(const Standard_CString Name, const TopoDS_Shape& S)
   D->DisplayTriangulation(disptriangles);
   D->DisplayPolygons(disppolygons);
   D->DisplayHLR(withHLR,withRg1,withRgN,withHid,anglHLR);
-  Draw::Set(name,D);
+  Draw::Set(Name,D);
 }
-
-
 //=======================================================================
 //function : Get
 //purpose  : 
 //=======================================================================
-
 TopoDS_Shape  DBRep::Get(Standard_CString& name,
 			 const TopAbs_ShapeEnum typ,
 			 const Standard_Boolean complain)
@@ -980,6 +1081,35 @@ TopoDS_Shape  DBRep::Get(Standard_CString& name,
   return S;
 }
 
+static Standard_Integer XProgress (Draw_Interpretor& di, Standard_Integer argc, const char **argv)
+{
+  for ( Standard_Integer i=1; i < argc; i++ ) {
+    Standard_Boolean turn = Standard_True;
+    if ( argv[i][0] == '-' ) turn = Standard_False;
+    else if ( argv[i][0] != '+' ) continue;
+    if ( argv[i][1] == 't' ) Draw_ProgressIndicator::DefaultTextMode() = turn;
+    else if ( argv[i][1] == 'g' ) Draw_ProgressIndicator::DefaultGraphMode() = turn;
+    else if ( ! strcmp ( argv[i], "-stop" ) && i+1 < argc ) {
+      Draw_ProgressIndicator::StopIndicator() = atol(argv[++i]);
+      return 0;
+    }
+  }
+  di << "Progress Indicator defaults: text mode is ";
+  if ( Draw_ProgressIndicator::DefaultTextMode() ) {
+    di<<"ON";
+  } else {
+    di<<"OFF";
+  }
+  di<<", graphical mode is ";
+  if ( Draw_ProgressIndicator::DefaultGraphMode() ) {
+    di<<"ON";
+  } else {
+    di<<"OFF";
+  }
+  di<< "\n";
+  return 0;
+}
+
 //=======================================================================
 //function : BasicCommands
 //purpose  : 
@@ -992,7 +1122,7 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
   done = Standard_True;
   Draw::Commands(theCommands);
 
-  char* g = "Basic shape commands";
+  const char* g = "Basic shape commands";
 
   theCommands.Add("isos","isos [name1 ...] [nbisos]",__FILE__,isos,g);
   theCommands.Add("hlr" ,"[no]hlr, rg1, rgn, hid, ang",__FILE__,hlr ,g);
@@ -1017,11 +1147,16 @@ void  DBRep::BasicCommands(Draw_Interpretor& theCommands)
   theCommands.Add("normals","normals s (length = 10), disp normals",__FILE__,normals,g);
   theCommands.Add("nbshapes","nbshapes s; size of shape",__FILE__,nbshapes,g);
   theCommands.Add("numshapes","numshapes s; size of shape",__FILE__,numshapes,g);
+  theCommands.Add("countshapes","countshapes s; count of shape",__FILE__,countshapes,g);
+
 //  theCommands.Add("dumpmmgt",
 //		  "dump le contenu du gestionnaire de memoire",__FILE__,dumpmmgt,g);
   theCommands.Add("purgemmgt",
 		  "rend la memoire libre du gestionnaire de memoire au systeme",
 		  __FILE__,purgemmgt,g);
+  
+  // Add command for DRAW-specific ProgressIndicator
+  theCommands.Add ( "XProgress","XProgress [+|-t] [+|-g]: switch on/off textual and graphical mode of Progress Indicator",XProgress,"DE: General");
 }
 
 //=======================================================================
@@ -1080,8 +1215,12 @@ static void ssave(const Handle(Draw_Drawable3D)&d, ostream& OS)
     N = Handle(DBRep_DrawableShape)::DownCast(d);
   BRep_Builder B;
   BRepTools_ShapeSet S(B);
+  if(!Draw::GetProgressBar().IsNull())
+    S.SetProgress(Draw::GetProgressBar());
   S.Add(N->Shape());
   S.Write(OS);
+  if(!Draw::GetProgressBar().IsNull() && Draw::GetProgressBar()->UserBreak())
+    return;
   S.Write(N->Shape(),OS);
 }
 
@@ -1089,11 +1228,15 @@ static Handle(Draw_Drawable3D) srestore (istream& IS)
 {
   BRep_Builder B;
   BRepTools_ShapeSet S(B);
+  if(!Draw::GetProgressBar().IsNull())
+    S.SetProgress(Draw::GetProgressBar());
   S.Read(IS);
+  Handle(DBRep_DrawableShape) N;
+  if(!Draw::GetProgressBar().IsNull() && Draw::GetProgressBar()->UserBreak())
+    return N;
   TopoDS_Shape theShape;
-  S.Read(theShape,IS);
-  Handle(DBRep_DrawableShape) N = 
-    new DBRep_DrawableShape(theShape,
+  S.Read(theShape,IS );
+  N = new DBRep_DrawableShape(theShape,
 			    Draw_vert,
 			    Draw_jaune,
 			    Draw_rouge,
@@ -1104,6 +1247,7 @@ static Handle(Draw_Drawable3D) srestore (istream& IS)
   N->DisplayTriangulation(disptriangles);
   N->DisplayPolygons(disppolygons);
   N->DisplayHLR(withHLR,withRg1,withRgN,withHid,anglHLR);
+  
   return N;
 }
 
@@ -1112,7 +1256,6 @@ static Draw_SaveAndRestore ssr("DBRep_DrawableShape",
 			       stest,ssave,srestore);
 
 
-
 void dumps (const TopoDS_Shape& S)
 {
  BRepTools::Dump(S,cout);
