@@ -35,7 +35,7 @@
 
 static Standard_Integer DDataStd_SetNode (Draw_Interpretor& di, 
 					  Standard_Integer  n, 
-					  char**            a)
+					  const char**            a)
 {
   Handle(TDF_Data) DF;
   if (!DDF::GetDF(a[1],DF)) return 1;
@@ -67,7 +67,7 @@ static Standard_Integer DDataStd_SetNode (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_AppendNode (Draw_Interpretor& di, 
 					     Standard_Integer  n, 
-					     char**            a)
+					     const char**            a)
 {
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -113,7 +113,7 @@ static Standard_Integer DDataStd_AppendNode (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_PrependNode (Draw_Interpretor& di, 
 					     Standard_Integer  n, 
-					     char**            a)
+					     const char**            a)
 {
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -159,7 +159,7 @@ static Standard_Integer DDataStd_PrependNode (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_RootNode (Draw_Interpretor& di, 
 					   Standard_Integer  n, 
-					   char**            a)
+					   const char**            a)
 {
   if (n >= 3) {
     Handle(TDF_Data) DF;
@@ -193,7 +193,7 @@ static Standard_Integer DDataStd_RootNode (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_InsertNodeBefore(Draw_Interpretor& di, 
 						  Standard_Integer  n, 
-						  char**            a)
+						  const char**            a)
 {
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -232,7 +232,7 @@ static Standard_Integer DDataStd_InsertNodeBefore(Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_InsertNodeAfter(Draw_Interpretor& di, 
 						 Standard_Integer  n, 
-						 char**            a)
+						 const char**            a)
 {  
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -268,7 +268,7 @@ static Standard_Integer DDataStd_InsertNodeAfter(Draw_Interpretor& di,
 //purpose  : DetachNode (DOC TreeNodeEntry [ID])
 //=======================================================================
 
-static Standard_Integer DDataStd_DetachNode (Draw_Interpretor& di,Standard_Integer n, char** a)
+static Standard_Integer DDataStd_DetachNode (Draw_Interpretor& di,Standard_Integer n, const char** a)
 {
   if (n >= 3) {   
     Handle(TDF_Data) DF;
@@ -306,7 +306,7 @@ static Standard_Integer DDataStd_DetachNode (Draw_Interpretor& di,Standard_Integ
 
 static Standard_Integer DDataStd_TreeBrowse (Draw_Interpretor& di, 
 						 Standard_Integer  n, 
-						 char**            a)
+						 const char**            a)
 {
   if (n<3) return 1;
   
@@ -317,7 +317,7 @@ static Standard_Integer DDataStd_TreeBrowse (Draw_Interpretor& di,
   TDF_Tool::Label(DF,a[2],lab);
 
   Handle(DDataStd_TreeBrowser) NewTreeNode = new DDataStd_TreeBrowser (lab);
-  Standard_CString name = new char[50];
+  char *name = new char[50];
   if (n == 4) sprintf(name,"treebrowser_%s",a[3]);
   else        sprintf(name,"treebrowser_%s",a[1]);
 
@@ -338,7 +338,7 @@ static Standard_Integer DDataStd_TreeBrowse (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_OpenNode (Draw_Interpretor& di, 
 					   Standard_Integer  n, 
-					   char**            a)
+					   const char**            a)
 {
   if (n < 2) return 1;
   
@@ -373,7 +373,7 @@ static Standard_CString PrintLabel(const TDF_Label& L)
 
 static Standard_Integer DDataStd_ChildNodeIterate (Draw_Interpretor& di, 
 						   Standard_Integer  n, 
-						   char**            a)
+						   const char**            a)
 {
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -421,7 +421,7 @@ static TDataStd_ChildNodeIterator cni;
 
 static Standard_Integer DDataStd_InitChildNodeIterator (Draw_Interpretor& di, 
 							Standard_Integer  n, 
-							char**            a)
+							const char**            a)
 {
   if (n >= 4) {
     Handle(TDF_Data) DF;
@@ -456,7 +456,7 @@ static Standard_Integer DDataStd_InitChildNodeIterator (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_ChildNodeMore (Draw_Interpretor& di, 
 						Standard_Integer  /*n*/, 
-						char**            /*a*/)
+						const char**            /*a*/)
 {
   if (cni.More()) {
     //cout<<"TRUE"<<endl;
@@ -476,7 +476,7 @@ static Standard_Integer DDataStd_ChildNodeMore (Draw_Interpretor& di,
 
 static Standard_Integer DDataStd_ChildNodeNext (Draw_Interpretor& /*di*/, 
 						Standard_Integer  /*n*/, 
-						char**            /*a*/)
+						const char**            /*a*/)
 {
   cni.Next();
   return 0;
@@ -489,7 +489,7 @@ static Standard_Integer DDataStd_ChildNodeNext (Draw_Interpretor& /*di*/,
 
 static Standard_Integer DDataStd_ChildNodeNextBrother (Draw_Interpretor& /*di*/, 
 						       Standard_Integer  /*n*/, 
-						       char**            /*a*/)
+						       const char**            /*a*/)
 {
   cni.NextBrother();
   return 0;
@@ -502,7 +502,7 @@ static Standard_Integer DDataStd_ChildNodeNextBrother (Draw_Interpretor& /*di*/,
 
 static Standard_Integer DDataStd_ChildNodeValue (Draw_Interpretor& di, 
 						 Standard_Integer  /*n*/, 
-						 char**            /*a*/)
+						 const char**            /*a*/)
 {
   Standard_CString entry = PrintLabel(cni.Value()->Label());
   //cout<<entry<<endl;
@@ -521,7 +521,7 @@ void DDataStd::TreeCommands (Draw_Interpretor& theCommands)
   if (done) return;
   done = Standard_True;  
 
-  char* g = "DData : Standard Attribute Commands";
+  const char* g = "DData : Standard Attribute Commands";
 
   // SET
 
