@@ -42,6 +42,8 @@
 #include <TNaming_NamedShape.hxx>
 #include <TDataStd_Plane.hxx>
 #include <TDataStd_Point.hxx>
+#include <Standard_PCharacter.hxx>
+
 //#include <TSketchStd_Geometry.hxx>
 //#include <TSketchStd_Edge.hxx>
 
@@ -52,7 +54,7 @@
 
 static Standard_Integer DPrsStd_AISDisplay (Draw_Interpretor& di,
 					  Standard_Integer nb, 
-					  char** arg) 
+					  const char** arg) 
 {   
        
   Handle(TDocStd_Document) D;
@@ -82,7 +84,7 @@ static Standard_Integer DPrsStd_AISDisplay (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISRemove (Draw_Interpretor& di,
 					   Standard_Integer nb, 
-					   char** arg) 
+					   const char** arg) 
 {   
    if (nb == 3) {     
      Handle(TDocStd_Document) D;
@@ -107,7 +109,7 @@ static Standard_Integer DPrsStd_AISRemove (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISErase (Draw_Interpretor& di,
 					Standard_Integer nb, 
-					char** arg) 
+					const char** arg) 
 {   
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -131,7 +133,7 @@ static Standard_Integer DPrsStd_AISErase (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISUpdate (Draw_Interpretor& di,
 					 Standard_Integer nb, 
-					 char** arg) 
+					 const char** arg) 
 {   
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -156,7 +158,7 @@ static Standard_Integer DPrsStd_AISUpdate (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISSet (Draw_Interpretor& di,
 					Standard_Integer nb, 
-					char** arg) 
+					const char** arg) 
 {   
   if (nb == 4) {        
     Handle(TDocStd_Document) D;
@@ -192,7 +194,9 @@ static Standard_Integer DPrsStd_AISSet (Draw_Interpretor& di,
     cout << "\n";
 #endif
     Standard_Character resS[37];
-    guid.ToCString(resS);
+    Standard_PCharacter presS;
+    presS=resS;
+    guid.ToCString(presS);
     di<<resS;
     return 0; 
   }
@@ -207,7 +211,7 @@ static Standard_Integer DPrsStd_AISSet (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISDriver (Draw_Interpretor& di,
 					   Standard_Integer nb, 
-					   char** arg) 
+					   const char** arg) 
 {   
   if (nb >= 3) {     
     Handle(TDocStd_Document) D;
@@ -221,7 +225,9 @@ static Standard_Integer DPrsStd_AISDriver (Draw_Interpretor& di,
       if( nb == 3 ) {
 	guid = prs->GetDriverGUID();
 	Standard_Character str[37];
-	guid.ToCString( str );
+	Standard_PCharacter pstr;
+	pstr=str;
+	guid.ToCString( pstr );
 	di << str ;
 	return 0; 
       }
@@ -249,7 +255,11 @@ static Standard_Integer DPrsStd_AISDriver (Draw_Interpretor& di,
 
         prs->SetDriverGUID(guid);
 	Standard_Character resS[37];
-	guid.ToCString( resS );
+	Standard_PCharacter presS;
+	//modified by NIZNHY-PKV Tue Apr 22 16:15:02 2008f
+	presS=resS;
+	//modified by NIZNHY-PKV Tue Apr 22 16:15:05 2008t
+	guid.ToCString( presS );
 	di << resS ;
         return 0;
       }
@@ -266,7 +276,7 @@ static Standard_Integer DPrsStd_AISDriver (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISUnset (Draw_Interpretor& di,
 					  Standard_Integer nb, 
-					  char** arg) 
+					  const char** arg) 
 {   
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -289,7 +299,7 @@ static Standard_Integer DPrsStd_AISUnset (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISTransparency (Draw_Interpretor& di,
 						 Standard_Integer nb, 
-						 char** arg) 
+						 const char** arg) 
 {
   if (nb >= 3 ) {     
     Handle(TDocStd_Document) D;
@@ -330,7 +340,7 @@ static Standard_Integer DPrsStd_AISTransparency (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISDefaultTransparency (Draw_Interpretor& di,
 							Standard_Integer nb, 
-							char** arg) 
+							const char** arg) 
 {   
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -356,7 +366,7 @@ static Standard_Integer DPrsStd_AISDefaultTransparency (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISColor (Draw_Interpretor& di,
 					  Standard_Integer nb, 
-					  char** arg) 
+					  const char** arg) 
 {
   if (nb >= 3) {     
     Handle(TDocStd_Document) D;
@@ -396,7 +406,7 @@ static Standard_Integer DPrsStd_AISColor (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISDefaultColor (Draw_Interpretor& di,
 						 Standard_Integer nb, 
-						 char** arg) 
+						 const char** arg) 
 {
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -425,7 +435,7 @@ static Standard_Integer DPrsStd_AISDefaultColor (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISMaterial (Draw_Interpretor& di,
 					     Standard_Integer nb, 
-					     char** arg) 
+					     const char** arg) 
 {
   if (nb >= 3) {     
     Handle(TDocStd_Document) D;
@@ -466,7 +476,7 @@ static Standard_Integer DPrsStd_AISMaterial (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISDefaultMaterial (Draw_Interpretor& di,
 						    Standard_Integer nb, 
-						    char** arg) 
+						    const char** arg) 
 {
   if (nb == 3) {     
     Handle(TDocStd_Document) D;
@@ -496,7 +506,7 @@ static Standard_Integer DPrsStd_AISDefaultMaterial (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISHasOwnColor (Draw_Interpretor& di,
 					        Standard_Integer nb, 
-					        char** arg) 
+					        const char** arg) 
 {
   if (nb >= 3) {     
     if (nb > 3)
@@ -530,7 +540,7 @@ static Standard_Integer DPrsStd_AISHasOwnColor (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISHasOwnMaterial (Draw_Interpretor& di,
 					           Standard_Integer nb, 
-					           char** arg) 
+					           const char** arg) 
 {
   if (nb >= 3) {     
     if (nb > 3)
@@ -564,7 +574,7 @@ static Standard_Integer DPrsStd_AISHasOwnMaterial (Draw_Interpretor& di,
 
 static Standard_Integer DPrsStd_AISHasOwnTransparency (Draw_Interpretor& di,
 					               Standard_Integer nb, 
-					               char** arg) 
+					               const char** arg) 
 {
   if (nb >= 3) {     
     if (nb > 3)
@@ -601,7 +611,7 @@ void DPrsStd::AISPresentationCommands (Draw_Interpretor& theCommands)
   static Standard_Boolean done = Standard_False;
   if (done) return;
   done = Standard_True;
-  char* g = "DPrsStd : standard presentation commands" ;  
+  const char* g = "DPrsStd : standard presentation commands" ;  
  
   // standard commands working on AISPresentation
 
