@@ -85,7 +85,7 @@ static void SetTitle(const Standard_Integer id)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer zoom(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer zoom(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   // one argument -> All Views
   // two argument -> First is the view
@@ -121,7 +121,7 @@ static Standard_Integer zoom(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer wzoom(Draw_Interpretor& di, Standard_Integer, char**)
+static Standard_Integer wzoom(Draw_Interpretor& di, Standard_Integer, const char**)
 {
   Standard_Integer id1,X1,Y1,b;
   Standard_Integer X2,Y2;
@@ -205,7 +205,7 @@ static Standard_Integer wzoom(Draw_Interpretor& di, Standard_Integer, char**)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer wclick(Draw_Interpretor& di, Standard_Integer, char**)
+static Standard_Integer wclick(Draw_Interpretor& di, Standard_Integer, const char**)
 {
   Standard_Integer id1,X1,Y1,b;
   dout.Flush();
@@ -219,7 +219,7 @@ static Standard_Integer wclick(Draw_Interpretor& di, Standard_Integer, char**)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer view(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer view(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (Draw_Batch) return 1;
 
@@ -278,7 +278,7 @@ static Standard_Integer view(Draw_Interpretor& di, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer delview(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer delview(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n == 1) {
     for (Standard_Integer id = 0; id < MAXVIEW; id++)
@@ -300,7 +300,7 @@ static Standard_Integer delview(Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer fit(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer fit(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Boolean f2d = !strcasecmp(a[0],"2dfit");
   if (n == 1) {
@@ -344,7 +344,7 @@ static Standard_Integer fit(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer focal(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer focal(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer start = 0;
   Standard_Integer end = MAXVIEW-1;
@@ -373,7 +373,7 @@ static Standard_Integer focal(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer setfocal(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer setfocal(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n == 1) {
     for (Standard_Integer id = 0; id < MAXVIEW; id++) {
@@ -397,8 +397,8 @@ static Standard_Integer setfocal(Draw_Interpretor& di, Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-//static Standard_Integer magnify(Draw_Interpretor& di, Standard_Integer n, char** a)
-static Standard_Integer magnify(Draw_Interpretor& , Standard_Integer n, char** a)
+//static Standard_Integer magnify(Draw_Interpretor& di, Standard_Integer n, const char** a)
+static Standard_Integer magnify(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer start = 0;
   Standard_Integer end = MAXVIEW-1;
@@ -408,7 +408,7 @@ static Standard_Integer magnify(Draw_Interpretor& , Standard_Integer n, char** a
     start = end = anid;
   }
   Standard_Boolean v2d = (a[0][0] == '2');   // 2dmu, 2dmd
-  char* com = a[0];
+  const char* com = a[0];
   if (v2d) com += 2;
   Standard_Real dz = 1.;
   if (!strcasecmp(com,"mu"))      // mu, 2dmu
@@ -428,7 +428,7 @@ static Standard_Integer magnify(Draw_Interpretor& , Standard_Integer n, char** a
   return 0;
 }
 
-Standard_EXPORT Standard_Integer Draw_magnify(Draw_Interpretor& di, Standard_Integer n, char** a) 
+Standard_EXPORT Standard_Integer Draw_magnify(Draw_Interpretor& di, Standard_Integer n, const char** a) 
 {
   return magnify(di,n,a);
 }
@@ -438,7 +438,7 @@ Standard_EXPORT Standard_Integer Draw_magnify(Draw_Interpretor& di, Standard_Int
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer rotate(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer rotate(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer start = 0;
   Standard_Integer end = MAXVIEW-1;
@@ -482,7 +482,7 @@ static Standard_Integer rotate(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer panning(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer panning(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer start = 0;
   Standard_Integer end = MAXVIEW-1;
@@ -496,7 +496,7 @@ static Standard_Integer panning(Draw_Interpretor& , Standard_Integer n, char** a
   Standard_Integer X,Y,W,H;
 
   Standard_Boolean v2d = (a[0][0] == '2');     // pu2d, pd2d, pr2d, pl2d
-  char* com = a[0];
+  const char* com = a[0];
   if (v2d) com += 2;
 
   if (!strcasecmp(com,"pu"))    // pu , 2dpu
@@ -526,7 +526,7 @@ static Standard_Integer panning(Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer ptv(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer ptv(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Real X,Y,Z;
   Standard_Integer start = 0;
@@ -565,7 +565,7 @@ static Standard_Integer ptv(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer dptv(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer dptv(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Real DX,DY,DZ;
   Standard_Integer start = 0;
@@ -603,7 +603,7 @@ static Standard_Integer dptv(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer color(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer color(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) {
     Draw_BlackBackGround = !Draw_BlackBackGround;
@@ -631,7 +631,7 @@ static Standard_Integer color(Draw_Interpretor& di, Standard_Integer n, char** a
 //=======================================================================
 
 static Standard_Integer hardcopy(Draw_Interpretor& ,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   // Inch = 25.40001969 mm.
   // 28.4 pixels / mm.
@@ -643,7 +643,7 @@ static Standard_Integer hardcopy(Draw_Interpretor& ,
   Standard_Real dy  = 210 * Sqrt(2.);
 
   Standard_Integer iview = 1;
-  char* file = "a4.ps";
+  const char* file = "a4.ps";
   if (n >= 2) {
     file = a[1];
     if (n >= 3) {
@@ -757,7 +757,7 @@ static Standard_Integer hardcopy(Draw_Interpretor& ,
 }
 
 static Standard_Integer dfont(Draw_Interpretor& di,
-			      Standard_Integer n, char** a)
+			      Standard_Integer n, const char** a)
 {
   if        ( n == 1 ) {
     strcpy(Draw_fontname, Draw_fontnamedefault);
@@ -777,7 +777,7 @@ static Standard_Integer dfont(Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer hcolor(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer hcolor(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) {
     di << "code de couleur (Draw.cxx) : " << "\n" ;
@@ -799,7 +799,7 @@ static Standard_Integer hcolor(Draw_Interpretor& di, Standard_Integer n, char**
 
 extern void Draw_RepaintNowIfNecessary();
 
-static Standard_Integer xwd(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer xwd(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -807,7 +807,7 @@ static Standard_Integer xwd(Draw_Interpretor& , Standard_Integer n, char** a)
   Draw_RepaintNowIfNecessary();
 
   Standard_Integer id = 1;
-  char* file = a[1];
+  const char* file = a[1];
   if (n > 2) {
     id  = atoi(a[1]);
     file = a[2];
@@ -823,7 +823,7 @@ static Standard_Integer xwd(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : Creation/Suppression d'une grille.
 //=======================================================================
 
-static Standard_Integer grid (Draw_Interpretor& , Standard_Integer NbArg, char **Arg)
+static Standard_Integer grid (Draw_Interpretor& , Standard_Integer NbArg, const char **Arg)
 {
   Standard_Real StepX, StepY, StepZ ;
   
@@ -853,10 +853,10 @@ static Standard_Integer grid (Draw_Interpretor& , Standard_Integer NbArg, char *
   }
 
 #ifdef HPUX
-  char *temp = "grid";
+  const char *temp = "grid";
 #else
   char temp1[] = "grid";
-  char *temp = temp1;
+  const char *temp = temp1;
 #endif
   Handle (Draw_Grid) Grille = Handle(Draw_Grid)::DownCast (Draw::Get(temp)) ;
 
@@ -871,7 +871,7 @@ static Standard_Integer grid (Draw_Interpretor& , Standard_Integer NbArg, char *
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer dflush (Draw_Interpretor& , Standard_Integer, char **)
+static Standard_Integer dflush (Draw_Interpretor& , Standard_Integer, const char **)
 {
   dout.Flush();
   return 0;
@@ -882,7 +882,7 @@ static Standard_Integer dflush (Draw_Interpretor& , Standard_Integer, char **)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer dtext(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer dtext(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   gp_Pnt P;
   Standard_Boolean is3d;
@@ -925,7 +925,7 @@ void Draw::GraphicCommands(Draw_Interpretor& theCommands)
   if (Done) return;
   Done = Standard_True;
 
-  char* g =  "DRAW Graphic Commands";
+  const char* g =  "DRAW Graphic Commands";
   theCommands.Add("wclick","wait for a mouse click",
 		  __FILE__,wclick,g);
   theCommands.Add("zoom","zoom [view-id] z, or zoom z for all 3d views",
