@@ -27,6 +27,8 @@
 #include <Draw_Drawable3D.hxx>
 #include <Draw_SequenceOfDrawable3D.hxx>
 #include <Draw_VMap.hxx>
+#include <Draw_ProgressIndicator.hxx>
+
 #ifdef WNT
 //#define strcasecmp strcmp Already defined
 Standard_IMPORT Draw_Viewer dout;
@@ -36,6 +38,7 @@ Standard_IMPORT Draw_Viewer dout;
 #endif
 
 #include <tcl.h>
+#include <errno.h>
 
 
 Standard_Boolean Draw_ParseFailed;
@@ -62,7 +65,7 @@ static Standard_Integer p_id;
 static Standard_Integer p_X;
 static Standard_Integer p_Y;
 static Standard_Integer p_b;
-static char* p_Name = "";
+static const char* p_Name = "";
 
 
 static Draw_SaveAndRestore* Draw_First = NULL;
@@ -73,7 +76,7 @@ static Draw_SaveAndRestore* Draw_First = NULL;
 //=======================================================================
 
 Draw_SaveAndRestore::Draw_SaveAndRestore
-  (char* name,
+  (const char* name,
    Standard_Boolean (*test)(const Handle(Draw_Drawable3D)&),
   void (*save)(const Handle(Draw_Drawable3D)&, ostream&),
   Handle(Draw_Drawable3D) (*restore) (istream&),
@@ -147,12 +150,12 @@ static Draw_SaveAndRestore numsr("Draw_Number",
 // save
 //=======================================================================
 
-static Standard_Integer save(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer save(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 2) return 1;
 
 
-  char* name = a[2];
+  const char* name = a[2];
   filebuf fic;
   ostream os(&fic);
   os.precision(15);
@@ -165,12 +168,18 @@ static Standard_Integer save(Draw_Interpretor& di, Standard_Integer n, char** a)
   if (!D.IsNull()) {
     // find a tool
     Draw_SaveAndRestore* tool = Draw_First;
+    Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
+    progress->SetScale ( 0, 100, 1 );
+    progress->NewScope(100,"Writing");
+    progress->Show();
+
     while (tool) {
       if (tool->Test(D)) break;
       tool = tool->Next();
     }
     if (tool) {
       os << tool->Name() << "\n";
+      Draw::SetProgressBar(progress);
       tool->Save(D,os);
       os << "\n";
     }
@@ -178,9 +187,25 @@ static Standard_Integer save(Draw_Interpretor& di, Standard_Integer n, char** a)
       di << "No method for saving " << a[1];
       return 1;
     }
+    Draw::SetProgressBar( 0 );
+    progress->EndScope();
+    progress->Show();
   }
   
   os << "0\n\n";
+
+  Standard_Boolean res = Standard_False;
+
+  errno = 0;
+  fic.close();
+
+  res = os.good() && !errno;
+  if( !res )
+  {
+    di<<"File has not been written";
+    return 1;
+  }
+
   di << a[1];
   return 0;
 }
@@ -189,13 +214,13 @@ static Standard_Integer save(Draw_Interpretor& di, Standard_Integer n, char** a)
 // read
 //=======================================================================
 
-static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
 
   if (n <= 2) return 1;
 
-  char* fname = a[1];
-  char* name  = a[2];
+  const char* fname = a[1];
+  const char* name  = a[2];
   
   filebuf fic;
   istream in(&fic);
@@ -208,9 +233,14 @@ static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, char**
   in >> typ;
   if (!in.fail()) {
     // search a tool
+    Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
+    progress->NewScope(100,"Reading");
+    progress->Show();
+
     Draw_SaveAndRestore* tool = Draw_First;
     while (tool) {
       if (!strcmp(typ,tool->Name())) break;
+      Draw::SetProgressBar(progress);
       tool = tool->Next();
     }
     if (tool) {
@@ -221,6 +251,9 @@ static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, char**
       di << "Cannot restore a  " << typ;
       return 1;
     }
+    Draw::SetProgressBar( 0 );
+    progress->EndScope();
+    progress->Show();
   }
   
   di << name;
@@ -231,7 +264,7 @@ static Standard_Integer restore(Draw_Interpretor& di, Standard_Integer n, char**
 // display
 //=======================================================================
 
-static Standard_Integer display(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer display(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   else {
@@ -252,7 +285,7 @@ static Standard_Integer display(Draw_Interpretor& di, Standard_Integer n, char**
 // erase, clear, donly
 //=======================================================================
 
-static Standard_Integer erase(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer erase(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   static Standard_Boolean draw_erase_mute = Standard_False;
   if (n == 2) {
@@ -328,7 +361,7 @@ static Standard_Integer erase(Draw_Interpretor& di, Standard_Integer n, char** a
       if (!D.IsNull()) {
 	if (D->Visible()) {
 	    dout.RemoveDrawable(D);
-	    if (!draw_erase_mute) di << a[i] << " ";
+	    if (!draw_erase_mute) di << D->Name() << " ";
 	  }
       }
     }
@@ -348,7 +381,7 @@ static Standard_Integer erase(Draw_Interpretor& di, Standard_Integer n, char** a
 // draw
 //=======================================================================
 
-static Standard_Integer draw(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer draw(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   Standard_Integer id = atoi(a[1]);
@@ -372,7 +405,7 @@ static Standard_Integer draw(Draw_Interpretor& , Standard_Integer n, char** a)
 // protect, unprotect
 //=======================================================================
 
-static Standard_Integer protect(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer protect(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   Standard_Boolean prot = *a[0] != 'u';
@@ -390,7 +423,7 @@ static Standard_Integer protect(Draw_Interpretor& di, Standard_Integer n, char**
 // autodisplay
 //=======================================================================
 
-static Standard_Integer autodisplay(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer autodisplay(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 1)
     autodisp = !autodisp;
@@ -410,7 +443,7 @@ static Standard_Integer autodisplay(Draw_Interpretor& di, Standard_Integer n, ch
 // whatis
 //=======================================================================
 
-static Standard_Integer whatis(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer whatis(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 1) return 1;
   for (Standard_Integer i = 1; i < n; i++) {
@@ -427,7 +460,7 @@ static Standard_Integer whatis(Draw_Interpretor& di, Standard_Integer n, char**
 // value
 //=======================================================================
 
-static Standard_Integer value(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer value(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n != 2) return 1;
   di << atof(a[1]);
@@ -436,16 +469,28 @@ static Standard_Integer value(Draw_Interpretor& di, Standard_Integer n, char** a
 }
 
 //=======================================================================
-// dname
+//function : dname
+//purpose  : 
 //=======================================================================
-
-static Standard_Integer dname(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer dname(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
-  if (n <= 1) return 1;
-  for (Standard_Integer i = 1; i < n; i++) {
-    Handle(Draw_Drawable3D) D = Draw::Get(a[i]);
-    if (!D.IsNull()) 
-      di << a[i];
+  if (n <= 1) {
+    return 1;
+  }
+  //
+  Standard_PCharacter pC;
+  Standard_Integer i;
+  Handle(Draw_Drawable3D) aD;
+  //
+  for (i = 1; i < n; ++i) {
+    aD = Draw::Get(a[i]);
+    if (!aD.IsNull()) {
+      //modified by NIZNHY-PKV Tue Jun 10 10:18:13 2008f
+      //di << a[i];
+      pC=(Standard_PCharacter)aD->Name();
+      di << pC;
+      //modified by NIZNHY-PKV Tue Jun 10 10:18:18 2008t
+    }
   }
   return 0;
 }
@@ -455,7 +500,7 @@ static Standard_Integer dname(Draw_Interpretor& di, Standard_Integer n, char** a
 //=======================================================================
 
 
-static Standard_Integer dump(Draw_Interpretor& DI, Standard_Integer n, char** a)
+static Standard_Integer dump(Draw_Interpretor& DI, Standard_Integer n, const char** a)
 {
   if(n < 2) return 1;
   Standard_Integer i;
@@ -477,7 +522,7 @@ static Standard_Integer dump(Draw_Interpretor& DI, Standard_Integer n, char** a)
 // copy
 //=======================================================================
 
-static Standard_Integer copy(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer copy(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   Standard_Boolean cop = !strcasecmp(a[0],"copy");
@@ -504,7 +549,7 @@ static Standard_Integer copy(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer repaintall(Draw_Interpretor& , Standard_Integer , char** )
+static Standard_Integer repaintall(Draw_Interpretor& , Standard_Integer , const char** )
 {
   if (repaint2d) dout.Repaint2D();
   repaint2d = Standard_False;
@@ -519,7 +564,7 @@ static Standard_Integer repaintall(Draw_Interpretor& , Standard_Integer , char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer set(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer set(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   Standard_Integer i = 1;
@@ -538,7 +583,7 @@ static Standard_Integer set(Draw_Interpretor& di, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer isdraw(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer isdraw(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n != 2) return 1;
   Handle(Draw_Drawable3D) D = Draw::Get(a[1],Standard_False);
@@ -554,7 +599,7 @@ static Standard_Integer isdraw(Draw_Interpretor& di, Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-Standard_Integer isprot(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer isprot(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n != 2) return 1;
   Handle(Draw_Drawable3D) D = Draw::Get(a[1],Standard_False);
@@ -575,7 +620,7 @@ Standard_Integer isprot(Draw_Interpretor& di, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer pick(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer pick(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
   Standard_Integer id;
@@ -603,7 +648,7 @@ static Standard_Integer pick(Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer lastrep(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer lastrep(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -637,9 +682,8 @@ static Standard_Integer lastrep(Draw_Interpretor& di, Standard_Integer n, char**
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void  Draw::Set(Standard_CString& name, 
-		const Handle(Draw_Drawable3D)& D)
+void Draw::Set(const Standard_CString name, 
+	       const Handle(Draw_Drawable3D)& D)
 {
  Draw::Set(name,D,autodisp);
 }
@@ -664,7 +708,7 @@ static char* tracevar(ClientData CD, Tcl_Interp*, char*, char*, Standard_Integer
   if (D.IsNull())
     return NULL;
   if (D->Protected())
-    return "variable is protected";
+    return (char*) "variable is protected";
   else {
     if (D->Visible()) {
       dout.RemoveDrawable(D);
@@ -682,11 +726,14 @@ static char* tracevar(ClientData CD, Tcl_Interp*, char*, char*, Standard_Integer
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void  Draw::Set(Standard_CString& name, 
-		const Handle(Draw_Drawable3D)& D,
-		const Standard_Boolean displ)
+void Draw::Set(const Standard_CString name, 
+	       const Handle(Draw_Drawable3D)& D,
+	       const Standard_Boolean displ)
 {
+  Standard_PCharacter pName;
+  //
+  pName=(Standard_PCharacter)name;
+  //
   if ((name[0] == '.') && (name[1] == '\0')) {
     if (!D.IsNull()) {
       dout.RemoveDrawable(D);
@@ -694,7 +741,8 @@ void  Draw::Set(Standard_CString& name,
     }
   }
   else {
-    Tcl_UnsetVar(theCommands.Interp(),name,0);
+    
+    Tcl_UnsetVar(theCommands.Interp(),pName,0);
     if (!D.IsNull()) {
       Standard_Integer ival = theVariables.Extent() + 1;
       theVariables.Bind(ival,D);
@@ -702,11 +750,11 @@ void  Draw::Set(Standard_CString& name,
 #if ((TCL_MAJOR_VERSION > 8) || ((TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION >= 4))) && !defined(USE_NON_CONST)
       D->Name((const Standard_CString)Tcl_SetVar(theCommands.Interp(),name,name,0));
 #else
-      D->Name(Tcl_SetVar(theCommands.Interp(),name,name,0));
+      D->Name(Tcl_SetVar(theCommands.Interp(),pName,pName,0));
 #endif
     
       // set the trace function
-      Tcl_TraceVar(theCommands.Interp(),name,TCL_TRACE_UNSETS,
+      Tcl_TraceVar(theCommands.Interp(),pName,TCL_TRACE_UNSETS,
 		   tracevar,(ClientData)ival);
       
       if (displ) {
@@ -718,39 +766,37 @@ void  Draw::Set(Standard_CString& name,
     }
   }
 }
-
 //=======================================================================
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void  Draw::Set(Standard_CString& Name, const Standard_Real val)
+void Draw::Set(const Standard_CString Name, const Standard_Real val)
 {
   if ((Name[0] == '.') && (Name[1] == '\0')) return;
-  Handle(Draw_Drawable3D) D = Draw::Get(Name,Standard_False);
+  Standard_CString aName = Name;
+  Handle(Draw_Drawable3D) D = Draw::Get(aName,Standard_False);
   Handle(Draw_Number) N;
   if (!D.IsNull()) {
     N = Handle(Draw_Number)::DownCast(D);
   }
   if (N.IsNull()) {
     N = new Draw_Number(val);
-    Draw::Set(Name,N,Standard_False);
+    Draw::Set(aName,N,Standard_False);
   }
   else
     N->Value(val);
 }
-
-
 //=======================================================================
 //function : Get
 //purpose  : 
 //=======================================================================
-
-
-Handle(Draw_Drawable3D)  Draw::Get(Standard_CString& name, 
-				   const Standard_Boolean )
-//				   const Standard_Boolean complain)
+Handle(Draw_Drawable3D) Draw::Get(Standard_CString& name, 
+			          const Standard_Boolean )
 {
+  Standard_PCharacter pName;
+  //
+  pName=(Standard_PCharacter)name;
+  //
   Standard_Boolean pick = ((name[0] == '.') && (name[1] == '\0'));
   Handle(Draw_Drawable3D) D;
   if (pick) {
@@ -758,8 +804,10 @@ Handle(Draw_Drawable3D)  Draw::Get(Standard_CString& name,
     dout.Select(p_id,p_X,p_Y,p_b);
     dout.Pick(p_id,p_X,p_Y,5,D,0);
     if (!D.IsNull()) {
-      if (D->Name())
+      if (D->Name()) {
 	name = p_Name = D->Name();
+	//p_Name = (char *)D->Name();
+      }
     }
   }
   else {
@@ -772,7 +820,9 @@ Handle(Draw_Drawable3D)  Draw::Get(Standard_CString& name,
       D = Handle(Draw_Drawable3D)::DownCast(theVariables((long)index));
 #else
     Standard_Integer index = (Standard_Integer) 
-      Tcl_VarTraceInfo(theCommands.Interp(),name,TCL_TRACE_UNSETS,
+      Tcl_VarTraceInfo(theCommands.Interp(),
+		       pName,
+		       TCL_TRACE_UNSETS,
 		       tracevar, NULL);
     if (index != 0)
       D = Handle(Draw_Drawable3D)::DownCast(theVariables(index));
@@ -782,7 +832,6 @@ Handle(Draw_Drawable3D)  Draw::Get(Standard_CString& name,
       cout <<name<<" does not exist"<<endl;
 #endif
   }
-  
   return D;
 }
 
@@ -790,13 +839,14 @@ Handle(Draw_Drawable3D)  Draw::Get(Standard_CString& name,
 //function : Get
 //purpose  : 
 //=======================================================================
-
-
-Standard_Boolean  Draw::Get(Standard_CString& name, 
-			    Standard_Real& val)
+Standard_Boolean Draw::Get(const Standard_CString name, 
+			   Standard_Real& val)
 {
-  if ((name[0] == '.') && (name[1] == '\0')) return Standard_False;
-  Handle(Draw_Drawable3D) D = Draw::Get(name,(Standard_Boolean)Standard_False);
+  if ((name[0] == '.') && (name[1] == '\0')) {
+    return Standard_False;
+  }
+  Standard_CString aName = name;
+  Handle(Draw_Drawable3D) D = Draw::Get(aName,Standard_False);
   if (!D.IsNull()) {
     Handle(Draw_Number) N = Handle(Draw_Number)::DownCast(D);
     if (!N.IsNull()) {
@@ -811,7 +861,6 @@ Standard_Boolean  Draw::Get(Standard_CString& name,
 //function : LastPick
 //purpose  : 
 //=======================================================================
-
 void  Draw::LastPick(Standard_Integer& view, 
 		     Standard_Integer& X, 
 		     Standard_Integer& Y, 
@@ -822,13 +871,10 @@ void  Draw::LastPick(Standard_Integer& view,
   Y = p_Y;
   button = p_b;
 }
-
-
 //=======================================================================
 //function : Repaint
 //purpose  : 
 //=======================================================================
-
 void  Draw::Repaint()
 {
   repaint2d = Standard_True;
@@ -840,8 +886,8 @@ void  Draw::Repaint()
 //purpose  : 
 //=======================================================================
 
-//static Standard_Integer trigo (Draw_Interpretor& di, Standard_Integer n, char** a)
-static Standard_Integer trigo (Draw_Interpretor& di, Standard_Integer , char** a)
+//static Standard_Integer trigo (Draw_Interpretor& di, Standard_Integer n, const char** a)
+static Standard_Integer trigo (Draw_Interpretor& di, Standard_Integer , const char** a)
 {
 
   Standard_Real x = atof(a[1]);
@@ -928,7 +974,7 @@ static Standard_Real ParseValue(char*& name)
 	
 	if (Numeric(*name))   // numeric litteral
 	  x = atof(name);
-	else if (!Draw::Get(name,x)) {  // variable
+	else if (!Draw::Get((Standard_CString) name,x)) {  // variable
 	  
 	  // search for a function ...
 	  *p = c;
@@ -1059,7 +1105,10 @@ static Standard_Real Parse(char*& name)
     }
   }
 }
-
+//=======================================================================
+//function : Atof
+//purpose  : 
+//=======================================================================
 Standard_Real Draw::Atof(const Standard_CString name)
 {
   // copy the string
@@ -1077,17 +1126,19 @@ Standard_Integer Draw::Atoi(const Standard_CString name)
 {
   return (Standard_Integer ) Draw::Atof(name);
 }
-
-
 //=======================================================================
-// set a TCL var
+//function : Set
+//purpose  : set a TCL var
 //=======================================================================
-
-void Draw::Set(Standard_CString& Name, const Standard_CString val)
+void Draw::Set(const Standard_CString Name, const Standard_CString val)
 {
-  Tcl_SetVar(theCommands.Interp(),Name,val,0);
+  Standard_PCharacter pName, pVal;
+  //
+  pName=(Standard_PCharacter)Name;
+  pVal=(Standard_PCharacter)val;
+  //
+  Tcl_SetVar(theCommands.Interp(), pName, pVal, 0);
 }
-
 //=======================================================================
 // Command management
 // refresh the screen
@@ -1120,7 +1171,6 @@ extern void (*Draw_AfterCommand)(Standard_Integer);
 //function : Commands
 //purpose  : 
 //=======================================================================
-
 void  Draw::VariableCommands(Draw_Interpretor& theCommands)
 {
   static Standard_Boolean Done = Standard_False;
@@ -1133,7 +1183,7 @@ void  Draw::VariableCommands(Draw_Interpretor& theCommands)
 
   //  set up some variables
 
-  char* n;
+  const char* n;
   Handle(Draw_Axis3D) theAxes3d = new Draw_Axis3D(gp_Pnt(0,0,0),Draw_bleu,20);
   n = "axes";
   Draw::Set(n,theAxes3d);
@@ -1162,7 +1212,7 @@ void  Draw::VariableCommands(Draw_Interpretor& theCommands)
   theGrid->Protected(Standard_True);
   
 
-  char* g;
+  const char* g;
 
   g = "DRAW Numeric functions";
 
