@@ -74,7 +74,7 @@ class Draw_View : public Draw_Window {
   
   Draw_View(Standard_Integer i, 
 	    Draw_Viewer* v,
-	    char *w);
+	    const char *w);
   
   void WExpose();
   
@@ -149,9 +149,9 @@ Draw_View::Draw_View(Standard_Integer i, Draw_Viewer* v,
 // Portage WNT
 
 #ifdef WNT
-Draw_View::Draw_View(Standard_Integer i, Draw_Viewer* v, char* w) 
+Draw_View::Draw_View(Standard_Integer i, Draw_Viewer* v, const char* w) 
 #else
-Draw_View::Draw_View(Standard_Integer i, Draw_Viewer* v, char* w) :
+Draw_View::Draw_View(Standard_Integer i, Draw_Viewer* v, const char* w) :
      Draw_Window(w), id(i), viewer(v)
 #endif
 {
@@ -350,7 +350,7 @@ Draw_Viewer::Draw_Viewer()
 //purpose  : 
 //=======================================================================
 
-Standard_Boolean Draw_Viewer::DefineColor (const Standard_Integer i, char* colname)
+Standard_Boolean Draw_Viewer::DefineColor (const Standard_Integer i, const char* colname)
 {
   if (Draw_Batch) return 1;
   return Draw_Window::DefineColor(i,colname);
@@ -421,7 +421,7 @@ void Draw_Viewer::MakeView(const Standard_Integer id,
 
 void Draw_Viewer::MakeView    (const Standard_Integer id,
 			       const char*  typ,
-			       char*  window)
+			       const char*  window)
 {
   if (Draw_Batch) return;
   if (id < MAXVIEW) {
@@ -1519,7 +1519,7 @@ void Draw_Display::DrawString(const gp_Pnt2d& ppt,
     {
       int X =   (int) ( pt.X() + moveX + curview->dX);
       int Y =   (int) (-pt.Y() + moveY - curview->dY);
-      curview->DrawString(X,Y,S);
+      curview->DrawString(X,Y,(char *)S);
       if (Draw_Bounds) {
 	if (pt.X() + moveX > xmax) xmax = pt.X();
 	if (pt.X() + moveX < xmin) xmin = pt.X();
