@@ -14,6 +14,11 @@
 //
 // Robert Boehne 30 May 2000 : Dec Osf
 
+// include windows.h first to have all definitions available
+#ifdef WNT
+#include <windows.h>
+#endif
+
 #include <Standard_ErrorHandler.hxx>
 
 #include <tcl.h>
@@ -234,7 +239,7 @@ Draw_Window::Draw_Window(Window mother) :
 //purpose  : 
 //=======================================================================
 
-Draw_Window::Draw_Window (char* title,
+Draw_Window::Draw_Window (const char* title,
 			  Standard_Integer X, Standard_Integer Y,
 			  Standard_Integer DX, Standard_Integer DY) :
        base(*new Base_Window()),
@@ -256,7 +261,7 @@ Draw_Window::Draw_Window (char* title,
 //purpose  : 
 //=======================================================================
 
-Draw_Window::Draw_Window ( char* window ) :
+Draw_Window::Draw_Window (const char* window ) :
        base(*new Base_Window()),
        win(0),
        next(firstWindow),
@@ -500,7 +505,7 @@ Standard_Integer Draw_Window::WidthWin() const
 //purpose  : 
 //=======================================================================
 
-void Draw_Window::SetTitle(char* title)
+void Draw_Window::SetTitle(const char* title)
 {
   XStoreName(Draw_WindowDisplay, win,title);
 }
@@ -521,7 +526,7 @@ char* Draw_Window::GetTitle()
 //function :DefineColor 
 //purpose  : 
 //=======================================================================
-Standard_Boolean Draw_Window::DefineColor(const Standard_Integer i, char* colorName)
+Standard_Boolean Draw_Window::DefineColor(const Standard_Integer i, const char* colorName)
 {
   XColor color;
 
@@ -2358,7 +2363,7 @@ void DrawWindow::SelectNoWait(HANDLE& hWnd, int& x, int& y, int& button)
 }
 
 
-Standard_Boolean DrawWindow::DefineColor (const Standard_Integer, char*)
+Standard_Boolean DrawWindow::DefineColor (const Standard_Integer, const char*)
  {
  	return Standard_True;
  };
