@@ -70,6 +70,10 @@ Standard_EXPORT Draw_Color DrawTrSurf_CurveColor(const Draw_Color col)
   return c;
 }
 
+//=======================================================================
+//function : GetDrawable
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_Drawable) GetDrawable(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -79,6 +83,10 @@ static Handle(DrawTrSurf_Drawable) GetDrawable(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetSurface
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_Surface) GetSurface(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -88,6 +96,10 @@ static Handle(DrawTrSurf_Surface) GetSurface(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetBezierSurface
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BezierSurface) GetBezierSurface(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -97,6 +109,10 @@ static Handle(DrawTrSurf_BezierSurface) GetBezierSurface(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetBSplineSurface
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BSplineSurface) GetBSplineSurface(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -107,6 +123,10 @@ static Handle(DrawTrSurf_BSplineSurface) GetBSplineSurface(Standard_CString& Nam
 }
 
 #ifdef DEB
+//=======================================================================
+//function : GetCurve
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_Curve) GetCurve(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -117,6 +137,10 @@ static Handle(DrawTrSurf_Curve) GetCurve(Standard_CString& Name)
 }
 #endif
 
+//=======================================================================
+//function : GetBezierCurve
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BezierCurve) GetBezierCurve(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -126,6 +150,10 @@ static Handle(DrawTrSurf_BezierCurve) GetBezierCurve(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetBSplineCurve
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BSplineCurve) GetBSplineCurve(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -135,6 +163,10 @@ static Handle(DrawTrSurf_BSplineCurve) GetBSplineCurve(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetBezierCurve2d
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BezierCurve2d) GetBezierCurve2d(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -144,6 +176,10 @@ static Handle(DrawTrSurf_BezierCurve2d) GetBezierCurve2d(Standard_CString& Name)
   return Dr;
 }
 
+//=======================================================================
+//function : GetBSplineCurve2d
+//purpose  : 
+//=======================================================================
 static Handle(DrawTrSurf_BSplineCurve2d) GetBSplineCurve2d(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -158,8 +194,7 @@ static Handle(DrawTrSurf_BSplineCurve2d) GetBSplineCurve2d(Standard_CString& Nam
 //function : nbiso
 //purpose  : 
 //=======================================================================
-
-static Standard_Integer nbiso (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer nbiso (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) {
     if (n == 3) {
@@ -187,7 +222,7 @@ static Standard_Integer nbiso (Draw_Interpretor& di, Standard_Integer n, char**
 
 static Standard_Integer drawpoles(Draw_Interpretor&, 
 				  Standard_Integer n,
-				  char** a)
+				  const char** a)
 {
   if ( n == 1) {
     if ( !strcmp(a[0],"shpoles")) {
@@ -310,7 +345,7 @@ static Standard_Integer drawpoles(Draw_Interpretor&,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer draw (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer draw (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n <= 2) {
 	if (!strcmp(a[0],"dmode")) {
@@ -367,7 +402,7 @@ static Standard_Integer draw (Draw_Interpretor& di, Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer transform (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer transform (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
   gp_Trsf T;
@@ -442,7 +477,7 @@ static Standard_Integer transform (Draw_Interpretor& di, Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer d2transform (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer d2transform (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   gp_Trsf2d T;
@@ -509,8 +544,7 @@ static Standard_Integer d2transform (Draw_Interpretor& di, Standard_Integer n, c
 //function : Set
 //purpose  : point
 //=======================================================================
-
-void  DrawTrSurf::Set(Standard_CString& Name, 
+void  DrawTrSurf::Set(const Standard_CString Name, 
 		      const gp_Pnt& P)
 {
   Handle(DrawTrSurf_Point) DP = new DrawTrSurf_Point(P,PntShape,PntColor);
@@ -521,8 +555,7 @@ void  DrawTrSurf::Set(Standard_CString& Name,
 //function : Set
 //purpose  : point
 //=======================================================================
-
-void  DrawTrSurf::Set(Standard_CString& Name, 
+void  DrawTrSurf::Set(const Standard_CString Name, 
 		      const gp_Pnt2d& P)
 {
   Handle(DrawTrSurf_Point) DP = new DrawTrSurf_Point(P,PntShape,PntColor);
@@ -533,8 +566,7 @@ void  DrawTrSurf::Set(Standard_CString& Name,
 //function : Set
 //purpose  : Geometry from Geom
 //=======================================================================
-
-void  DrawTrSurf::Set(Standard_CString& Name, 
+void  DrawTrSurf::Set(const Standard_CString Name, 
 		      const Handle(Geom_Geometry)& G)
 {
   Handle(DrawTrSurf_Drawable) D;
@@ -631,8 +663,7 @@ void  DrawTrSurf::Set(Standard_CString& Name,
 //function : Set
 //purpose  : Curve from Geom2d
 //=======================================================================
-
-void  DrawTrSurf::Set(Standard_CString& Name, 
+void  DrawTrSurf::Set(const Standard_CString Name, 
 		      const Handle(Geom2d_Curve)& C)
 {
   Handle(DrawTrSurf_Drawable) D;
@@ -675,21 +706,17 @@ void  DrawTrSurf::Set(Standard_CString& Name,
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void DrawTrSurf::Set(Standard_CString& Name, 
+void DrawTrSurf::Set(const Standard_CString Name, 
 		     const Handle(Poly_Triangulation)& T)
 {
   Handle(DrawTrSurf_Triangulation) D = new DrawTrSurf_Triangulation(T);
   Draw::Set(Name,D);
 }
-
-
 //=======================================================================
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void DrawTrSurf::Set(Standard_CString& Name, 
+void DrawTrSurf::Set(const Standard_CString Name, 
 		     const Handle(Poly_Polygon3D)& P)
 {
   Handle(DrawTrSurf_Polygon3D) D = new DrawTrSurf_Polygon3D(P);
@@ -700,8 +727,7 @@ void DrawTrSurf::Set(Standard_CString& Name,
 //function : Set
 //purpose  : 
 //=======================================================================
-
-void DrawTrSurf::Set(Standard_CString& Name, 
+void DrawTrSurf::Set(const Standard_CString Name, 
 		     const Handle(Poly_Polygon2D)& P)
 {
   Handle(DrawTrSurf_Polygon2D) D = new DrawTrSurf_Polygon2D(P);
@@ -712,7 +738,6 @@ void DrawTrSurf::Set(Standard_CString& Name,
 //function : Get
 //purpose  : 
 //=======================================================================
-
 Handle(Geom_Geometry)  DrawTrSurf::Get(Standard_CString& Name)
 {
   Handle(Draw_Drawable3D) D = Draw::Get(Name);
@@ -735,7 +760,6 @@ Handle(Geom_Geometry)  DrawTrSurf::Get(Standard_CString& Name)
 //function : GetPoint
 //purpose  : 
 //=======================================================================
-
 Standard_Boolean DrawTrSurf::GetPoint(Standard_CString& Name,
 				      gp_Pnt& P)
 {
@@ -755,7 +779,6 @@ Standard_Boolean DrawTrSurf::GetPoint(Standard_CString& Name,
 //function : GetPoint2d
 //purpose  : 
 //=======================================================================
-
 Standard_Boolean DrawTrSurf::GetPoint2d(Standard_CString& Name,
 					gp_Pnt2d& P)
 {
@@ -775,7 +798,6 @@ Standard_Boolean DrawTrSurf::GetPoint2d(Standard_CString& Name,
 //function : GetCurve
 //purpose  : 
 //=======================================================================
-
 Handle(Geom_Curve)  DrawTrSurf::GetCurve(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Curve) D = 
@@ -791,9 +813,7 @@ Handle(Geom_Curve)  DrawTrSurf::GetCurve(Standard_CString& Name)
 //function : GetBezierCurve
 //purpose  : 
 //=======================================================================
-
-Handle(Geom_BezierCurve)  DrawTrSurf::GetBezierCurve
-       (Standard_CString& Name)
+Handle(Geom_BezierCurve)  DrawTrSurf::GetBezierCurve(Standard_CString& Name)
 {
   Handle(DrawTrSurf_BezierCurve) D = 
     Handle(DrawTrSurf_BezierCurve)::DownCast(Draw::Get(Name));
@@ -808,9 +828,7 @@ Handle(Geom_BezierCurve)  DrawTrSurf::GetBezierCurve
 //function : GetBSplineCurve
 //purpose  : 
 //=======================================================================
-
-Handle(Geom_BSplineCurve)  DrawTrSurf::GetBSplineCurve
-       (Standard_CString& Name)
+Handle(Geom_BSplineCurve)  DrawTrSurf::GetBSplineCurve(Standard_CString& Name)
 {
   Handle(DrawTrSurf_BSplineCurve) D = 
     Handle(DrawTrSurf_BSplineCurve)::DownCast(Draw::Get(Name));
@@ -819,13 +837,10 @@ Handle(Geom_BSplineCurve)  DrawTrSurf::GetBSplineCurve
   else
     return Handle(Geom_BSplineCurve)::DownCast(D->GetCurve());
 }
-
-
 //=======================================================================
 //function : GetCurve2d
 //purpose  : 
 //=======================================================================
-
 Handle(Geom2d_Curve)  DrawTrSurf::GetCurve2d(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Curve2d) D = 
@@ -835,15 +850,11 @@ Handle(Geom2d_Curve)  DrawTrSurf::GetCurve2d(Standard_CString& Name)
   else
     return D->GetCurve();
 }
-
-
 //=======================================================================
 //function : GetBezierCurve2d
 //purpose  : 
 //=======================================================================
-
-Handle(Geom2d_BezierCurve)  DrawTrSurf::GetBezierCurve2d
-       (Standard_CString& Name)
+Handle(Geom2d_BezierCurve)  DrawTrSurf::GetBezierCurve2d(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Curve2d) D = 
     Handle(DrawTrSurf_Curve2d)::DownCast(Draw::Get(Name));
@@ -852,13 +863,10 @@ Handle(Geom2d_BezierCurve)  DrawTrSurf::GetBezierCurve2d
   else
     return Handle(Geom2d_BezierCurve)::DownCast(D->GetCurve());
 }
-
-
 //=======================================================================
 //function : GetBSplineCurve2d
 //purpose  : 
 //=======================================================================
-
 Handle(Geom2d_BSplineCurve)  DrawTrSurf::GetBSplineCurve2d
        (Standard_CString& Name)
 {
@@ -869,13 +877,10 @@ Handle(Geom2d_BSplineCurve)  DrawTrSurf::GetBSplineCurve2d
   else
     return Handle(Geom2d_BSplineCurve)::DownCast(D->GetCurve());
 }
-
-
 //=======================================================================
 //function : GetSurface
 //purpose  : 
 //=======================================================================
-
 Handle(Geom_Surface)  DrawTrSurf::GetSurface
        (Standard_CString& Name)
 {
@@ -886,13 +891,10 @@ Handle(Geom_Surface)  DrawTrSurf::GetSurface
   else
     return D->GetSurface();
 }
-
-
 //=======================================================================
 //function : GetBezierSurface
 //purpose  : 
 //=======================================================================
-
 Handle(Geom_BezierSurface)  DrawTrSurf::GetBezierSurface
        (Standard_CString& Name)
 {
@@ -903,13 +905,10 @@ Handle(Geom_BezierSurface)  DrawTrSurf::GetBezierSurface
   else
     return Handle(Geom_BezierSurface)::DownCast(D->GetSurface());
 }
-
-
 //=======================================================================
 //function : GetBSplineSurface
 //purpose  : 
 //=======================================================================
-
 Handle(Geom_BSplineSurface) DrawTrSurf::GetBSplineSurface
        (Standard_CString& Name)
 {
@@ -920,12 +919,10 @@ Handle(Geom_BSplineSurface) DrawTrSurf::GetBSplineSurface
   else
     return Handle(Geom_BSplineSurface)::DownCast(D->GetSurface());
 }
-
 //=======================================================================
 //function : GetTriangulation
 //purpose  : 
 //=======================================================================
-
 Handle(Poly_Triangulation) DrawTrSurf::GetTriangulation(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Triangulation) D =
@@ -935,14 +932,10 @@ Handle(Poly_Triangulation) DrawTrSurf::GetTriangulation(Standard_CString& Name)
   else
     return D->Triangulation();
 }
-
-
-
 //=======================================================================
 //function : GetPolygon3D
 //purpose  : 
 //=======================================================================
-
 Handle(Poly_Polygon3D) DrawTrSurf::GetPolygon3D(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Polygon3D) D =
@@ -952,12 +945,10 @@ Handle(Poly_Polygon3D) DrawTrSurf::GetPolygon3D(Standard_CString& Name)
   else
     return D->Polygon3D();
 }
-
 //=======================================================================
 //function : GetPolygon2D
 //purpose  : 
 //=======================================================================
-
 Handle(Poly_Polygon2D) DrawTrSurf::GetPolygon2D(Standard_CString& Name)
 {
   Handle(DrawTrSurf_Polygon2D) D =
@@ -967,13 +958,11 @@ Handle(Poly_Polygon2D) DrawTrSurf::GetPolygon2D(Standard_CString& Name)
   else
     return D->Polygon2D();
 }
-
 //=======================================================================
 //function : setcurvcolor
 //purpose  : 
 //=======================================================================
-
-static Standard_Integer setcurvcolor(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer setcurvcolor(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Draw_Color col,savecol;
 
@@ -1043,7 +1032,7 @@ static Standard_Integer setcurvcolor(Draw_Interpretor& di, Standard_Integer n, c
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer changecurvcolor(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer changecurvcolor(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Draw_Color col,savecol;
 
@@ -1105,7 +1094,7 @@ void  DrawTrSurf::BasicCommands(Draw_Interpretor& theCommands)
   if (done) return;
   done = Standard_True;
 
-  char* g;
+  const char* g;
   g = "geometric display commands";
   
   theCommands.Add("nbiso",
