@@ -5,6 +5,7 @@
 
 #include <Storage_StreamModeError.hxx>
 #include <Storage_StreamUnknownTypeError.hxx>
+#include <Standard_PCharacter.hxx>
 
 // Propagate the improvement (BUC60808) on all platforms
 // #ifdef WNT
@@ -512,10 +513,12 @@ Storage_BaseDriver& FSD_CmpFile::PutReal(const Standard_Real aValue)
 {
 #ifdef BUC60808
   char realbuffer[100];
-
+  Standard_PCharacter pChar;
+  //
+  pChar=realbuffer;
   realbuffer[0] = '\0';
-  //if (OSD::RealToCString(aValue,realbuffer)) {
-  if (myRealConv.RealToCString(aValue,realbuffer)) {
+  //
+  if (myRealConv.RealToCString(aValue,pChar)) {
     myStream << realbuffer << " ";
   }
   else {
@@ -542,10 +545,12 @@ Storage_BaseDriver& FSD_CmpFile::PutShortReal(const Standard_ShortReal aValue)
 {
 #ifdef BUC60808
   char realbuffer[100];
-
+  Standard_PCharacter pStr;
+  //
+  pStr=realbuffer;
   realbuffer[0] = '\0';
-  // if (OSD::RealToCString(aValue,realbuffer)) {
-  if (myRealConv.RealToCString(aValue,realbuffer)) {
+  //
+  if (myRealConv.RealToCString(aValue,pStr)) {
     myStream << realbuffer << " ";
   }
   else {
