@@ -882,17 +882,20 @@ Standard_Real GeomAdaptor_Surface::UResolution
     Handle(Geom_ToroidalSurface)& S = 
       *((Handle(Geom_ToroidalSurface)*)&mySurface);
     Standard_Real R = S->MajorRadius() + S->MinorRadius();
-    Res = R3d/(2*R);
+    if(R>Precision::Confusion())
+      Res = R3d/(2*R);
   }
   else if (mySurfaceType == GeomAbs_Sphere) {
     Handle(Geom_SphericalSurface)& S = 
       *((Handle(Geom_SphericalSurface)*)&mySurface);
-    Res = R3d/(2*S->Radius());
+    if(S->Radius()>Precision::Confusion())
+      Res = R3d/(2*S->Radius());
   }
   else if (mySurfaceType == GeomAbs_Cylinder) {
     Handle(Geom_CylindricalSurface)& S =
       *((Handle(Geom_CylindricalSurface)*)&mySurface);
-    Res = R3d/(2*S->Radius());
+    if(S->Radius()>Precision::Confusion())
+      Res = R3d/(2*S->Radius());
   }
   else if (mySurfaceType == GeomAbs_Cone) {
     Standard_Real res=0;
@@ -908,8 +911,13 @@ Standard_Real GeomAdaptor_Surface::UResolution
       Standard_Real Rayon1 = (*((Handle(Geom_Circle)*)&C))->Radius();
       C = S->VIso(myVFirst);
       Standard_Real Rayon2 = (*((Handle(Geom_Circle)*)&C))->Radius();
-      if ( Rayon1 > Rayon2) res = R3d / Rayon1;
-      else                  res = R3d / Rayon2;
+      if ( Rayon1 > Rayon2) {
+	if(Rayon1>Precision::Confusion())
+	  res = R3d / Rayon1;
+      } else {
+	if(Rayon2>Precision::Confusion())
+	  res = R3d / Rayon2;
+      }
     }
     return res;
   }  
@@ -964,12 +972,14 @@ Standard_Real GeomAdaptor_Surface::VResolution
   else if (mySurfaceType == GeomAbs_Torus) {
     Handle(Geom_ToroidalSurface)& S = 
       *((Handle(Geom_ToroidalSurface)*)&mySurface);
-    Res = R3d/(2*S->MinorRadius());
+    if(S->MinorRadius()>Precision::Confusion())
+      Res = R3d/(2*S->MinorRadius());
   }
   else if (mySurfaceType == GeomAbs_Sphere) {
     Handle(Geom_SphericalSurface)& S =
       *((Handle(Geom_SphericalSurface)*)&mySurface);
-    Res = R3d/(2*S->Radius());
+    if(S->Radius()>Precision::Confusion())
+      Res = R3d/(2*S->Radius());
   }
   else if (mySurfaceType == GeomAbs_BezierSurface){
     Standard_Real Ures,Vres;
