@@ -480,7 +480,7 @@ void GeomLib::EvalMaxParametricDistance(const Adaptor3d_Curve& ACurve,
     max_squared = Max(max_squared,local_distance_squared) ;
   }
   if (max_squared > 0.0e0) {
-    MaxDistance = Sqrt(max_squared) ;
+    MaxDistance = sqrt(max_squared) ;
   }
   else {
     MaxDistance = 0.0e0 ;
@@ -556,7 +556,7 @@ void GeomLib::EvalMaxDistanceAlongParameter(const Adaptor3d_Curve& ACurve,
     max_squared = Max(max_squared,local_distance_squared) ;
   }
   if (max_squared > tolerance_squared) {
-    MaxDistance = Sqrt(max_squared) ;
+    MaxDistance = sqrt(max_squared) ;
   }
   else {
     MaxDistance = Tolerance ;
@@ -1895,9 +1895,9 @@ void GeomLib::Inertia(const TColgp_Array1OfPnt& Points,
   XDir.SetCoord(V3(1),V3(2),V3(3));
   YDir.SetCoord(V2(1),V2(2),V2(3));
 
-  Zgap = Sqrt(Abs(J.Value(m1)));
-  Ygap = Sqrt(Abs(J.Value(m2)));
-  Xgap = Sqrt(Abs(J.Value(m3)));
+  Zgap = sqrt(Abs(J.Value(m1)));
+  Ygap = sqrt(Abs(J.Value(m2)));
+  Xgap = sqrt(Abs(J.Value(m3)));
 }
 //=======================================================================
 //function : AxeOfInertia
@@ -2297,3 +2297,159 @@ void GeomLib::CancelDenominatorDerivative(Handle(Geom_BSplineSurface)         &
    }
  }
 }
+
+//=======================================================================
+//function : NormEstim
+//purpose  : 
+//=======================================================================
+
+Standard_Integer GeomLib::NormEstim(const Handle(Geom_Surface)& S, 
+				    const gp_Pnt2d& UV, 
+				    const Standard_Real Tol, gp_Dir& N) 
+{
+  gp_Vec DU, DV;
+  gp_Pnt DummyPnt;
+  Standard_Real aTol2 = Square(Tol);
+
+  S->D1(UV.X(), UV.Y(), DummyPnt, DU, DV);
+
+  Standard_Real MDU = DU.SquareMagnitude(), MDV = DV.SquareMagnitude();
+
+  Standard_Real h, sign;
+  Standard_Boolean AlongV;
+  Handle(Geom_Curve) Iso;
+  Standard_Real t, first, last, bid1, bid2;
+  gp_Vec Tang;
+
+  if(MDU >= aTol2 && MDV >= aTol2) {
+    gp_Vec Norm = DU^DV;
+    Standard_Real Magn = Norm.SquareMagnitude();
+    if(Magn < aTol2) return 3;
+
+    Magn = sqrt(Magn);
+    N.SetXYZ(Norm.XYZ()/Magn);
+
+    return 0;
+  }
+  else if(MDU < aTol2 && MDV >= aTol2) {
+    AlongV = Standard_True;
+    Iso = S->UIso(UV.X());
+    t = UV.Y();
+    S->Bounds(bid1, bid2, first, last);
+  }
+  else if(MDU >= aTol2 && MDV < aTol2) {
+    AlongV = Standard_False;
+    Iso = S->VIso(UV.Y());
+    t = UV.X();
+    S->Bounds(first, last, bid1, bid2);
+  }
+  else {
+    return 3;
+  }
+
+  Standard_Real L = .001;
+
+  if(Precision::IsInfinite(Abs(first))) first = t - 1.;
+  if(Precision::IsInfinite(Abs(last)))  last  = t + 1.;
+  
+  if(last - t >= t - first) {
+    sign = 1.;
+  }
+  else {
+    sign = -1.;
+  }
+
+  Standard_Real hmax = .01*(last - first);
+  if(AlongV) {
+    h = Min(L/sqrt(MDV), hmax);
+    S->D1(UV.X(), UV.Y() + sign*h, DummyPnt, DU, DV);
+  }
+  else {
+    h = Min(L/sqrt(MDU), hmax);
+    S->D1(UV.X() + sign*h, UV.Y(), DummyPnt, DU, DV);
+  }
+
+  gp_Vec DD;
+
+  gp_Vec NAux = DU^DV;
+  Standard_Real h1 = h;
+  while(NAux.SquareMagnitude() < aTol2) {
+    h1 += h;
+    if(AlongV) {
+      Standard_Real v = UV.Y() + sign*h1;
+
+      if(v < first || v > last) return 3;
+
+      S->D1(UV.X(), v, DummyPnt, DU, DV);
+    }
+    else {
+      Standard_Real v = UV.X() + sign*h1;
+
+      if(v < first || v > last) return 3;
+
+      S->D1(v, UV.Y(), DummyPnt, DU, DV);
+
+    }
+    NAux = DU^DV;
+  }
+
+
+  Iso->D2(t, DummyPnt, Tang, DD);
+
+  if(DD.SquareMagnitude() >= aTol2) {
+    gp_Vec NV = DD * (Tang * Tang) - Tang * (Tang * DD);
+    Standard_Real MagnNV = NV.SquareMagnitude();
+    if(MagnNV < aTol2) return 3;
+
+    MagnNV = sqrt(MagnNV);
+    N.SetXYZ(NV.XYZ()/MagnNV);
+
+    Standard_Real par = .5*(bid2-bid1);
+
+    if(AlongV) {
+      Iso = S->UIso(par);
+    }
+    else {
+      Iso = S->VIso(par);
+    }
+
+    Iso->D2(t, DummyPnt, Tang, DD);
+
+    gp_Vec N1V = DD * (Tang * Tang) - Tang * (Tang * DD);
+    Standard_Real MagnN1V = N1V.SquareMagnitude();
+    if(MagnN1V < aTol2) return 3;
+
+    MagnN1V = sqrt(MagnN1V);
+    gp_Dir N1(N1V.XYZ()/MagnN1V);
+
+    Standard_Integer res = 1;
+
+    if(N*N1 < 1. - Tol) res = 2;
+
+    if(N*NAux <= 0.) N.Reverse();
+
+    return res;
+  }
+  else {
+    //Seems to be conical singular point
+    
+    if(AlongV) {
+      NAux = DU^Tang;
+    }
+    else {
+      NAux = Tang^DV;
+    }
+
+    sign = NAux.Magnitude();
+
+    if(sign < Tol) return 3;
+
+    N = NAux;
+
+    return 2;
+   
+  }
+
+}
+ 
+
