@@ -29,6 +29,7 @@
 #include <TColgp_Array1OfPnt2d.hxx>
 #include <Standard_Failure.hxx>
 #include <Standard_ErrorHandler.hxx>
+#include <Message_ProgressSentry.hxx>
 
 #define LINE      1
 #define CIRCLE    2
@@ -81,6 +82,9 @@ Standard_Integer  GeomTools_Curve2dSet::Add(const Handle(Geom2d_Curve)& S)
 Handle(Geom2d_Curve)  GeomTools_Curve2dSet::Curve2d
        (const Standard_Integer I)const 
 {
+  if (I <= 0 || I > myMap.Extent())
+     return Handle(Geom2d_Curve)();
+
   return  Handle(Geom2d_Curve)::DownCast(myMap(I));
 }
 
@@ -486,7 +490,13 @@ void  GeomTools_Curve2dSet::Write(Standard_OStream& OS)const
 
   Standard_Integer i, nbsurf = myMap.Extent();
   OS << "Curve2ds "<< nbsurf << "\n";
-  for (i = 1; i <= nbsurf; i++) {
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "2D Curves", 0, nbsurf, 1);
+
+  for (i = 1; i <= nbsurf && PS.More(); i++, PS.Next()) {
+    if ( !myProgress.IsNull() ) 
+      progress->Show();
     PrintCurve2d(Handle(Geom2d_Curve)::DownCast(myMap(i)),OS,Standard_True);
   }
 
@@ -501,7 +511,7 @@ void  GeomTools_Curve2dSet::Write(Standard_OStream& OS)const
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt2d& P)
 {
-  Standard_Real X,Y;
+  Standard_Real X=0.,Y=0.;
   IS >> X >> Y;
   P.SetCoord(X,Y);
   return IS;
@@ -514,7 +524,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt2d& P)
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir2d& D)
 {
-  Standard_Real X,Y;
+  Standard_Real X=0.,Y=0.;
   IS >> X >> Y;
   D.SetCoord(X,Y);
   return IS;
@@ -529,8 +539,8 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir2d& D)
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_Line)& L)
 {
-  gp_Pnt2d P;
-  gp_Dir2d AX;
+  gp_Pnt2d P(0.,0.);
+  gp_Dir2d AX(1.,0.);
   IS >> P >> AX;
   L = new Geom2d_Line(P,AX);
   return IS;
@@ -544,9 +554,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_Circle)& C)
 {
-  gp_Pnt2d P;
-  gp_Dir2d AX,AY;
-  Standard_Real R;
+  gp_Pnt2d P(0.,0.);
+  gp_Dir2d AX(1.,0.),AY(1.,0.);
+  Standard_Real R=0.;
   IS >> P >> AX >> AY >> R;
   C = new Geom2d_Circle(gp_Ax22d(P,AX,AY),R);
   return IS;
@@ -560,9 +570,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_Ellipse)& E)
 {
-  gp_Pnt2d P;
-  gp_Dir2d AX,AY;
-  Standard_Real R1,R2;
+  gp_Pnt2d P(0.,0.);
+  gp_Dir2d AX(1.,0.),AY(1.,0.);
+  Standard_Real R1=0.,R2=0.;
   IS >> P >> AX >> AY >> R1 >> R2;
   E = new Geom2d_Ellipse(gp_Ax22d(P,AX,AY),R1,R2);
   return IS;
@@ -576,9 +586,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_Parabola)& C)
 {
-  gp_Pnt2d P;
-  gp_Dir2d AX,AY;
-  Standard_Real R1;
+  gp_Pnt2d P(0.,0.);
+  gp_Dir2d AX(1.,0.),AY(1.,0.);
+  Standard_Real R1=0.;
   IS >> P >> AX >> AY >> R1;
   C = new Geom2d_Parabola(gp_Ax22d(P,AX,AY),R1);
   return IS;
@@ -592,9 +602,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_Hyperbola)& H)
 {
-  gp_Pnt2d P;
-  gp_Dir2d AX,AY;
-  Standard_Real R1,R2;
+  gp_Pnt2d P(0.,0.);
+  gp_Dir2d AX(1.,0.),AY(1.,0.);
+  Standard_Real R1=0.,R2=0.;
   IS >> P >> AX >> AY >> R1 >> R2;
   H = new Geom2d_Hyperbola(gp_Ax22d(P,AX,AY),R1,R2);
   return IS;
@@ -608,11 +618,11 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_BezierCurve)& B)
 {
-  Standard_Boolean rational;
+  Standard_Boolean rational=Standard_False;
   IS >> rational;
 
   // poles and weights
-  Standard_Integer i,degree;
+  Standard_Integer i=0,degree=0;
   IS >> degree;
 
   TColgp_Array1OfPnt2d poles(1,degree+1);
@@ -640,17 +650,16 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_BSplineCurve)& B)
 {
-
-  Standard_Boolean rational,periodic;
+  Standard_Boolean rational=Standard_False,periodic=Standard_False;
   IS >> rational >> periodic;
 
   // poles and weights
-  Standard_Integer i,degree,nbpoles,nbknots;
+  Standard_Integer i=0,degree=0,nbpoles=0,nbknots=0;
   IS >> degree >> nbpoles >> nbknots;
 
   TColgp_Array1OfPnt2d poles(1,nbpoles);
   TColStd_Array1OfReal weights(1,nbpoles);
-  
+
   for (i = 1; i <= nbpoles; i++) {
     IS >> poles(i);
     if (rational)
@@ -680,7 +689,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_TrimmedCurve)& C)
 {
-  Standard_Real p1,p2;
+  Standard_Real p1=0.,p2=0.;
   IS >> p1 >> p2;
   Handle(Geom2d_Curve) BC;
   GeomTools_Curve2dSet::ReadCurve2d(IS,BC);
@@ -696,7 +705,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom2d_OffsetCurve)& C)
 {
-  Standard_Real p;
+  Standard_Real p=0.;
   IS >> p;
   Handle(Geom2d_Curve) BC;
   GeomTools_Curve2dSet::ReadCurve2d(IS,BC);
@@ -826,12 +835,39 @@ void  GeomTools_Curve2dSet::Read(Standard_IStream& IS)
   }
 
   Handle(Geom2d_Curve) C;
-  Standard_Integer i, nbsurf;
-  IS >> nbsurf;
-  for (i = 1; i <= nbsurf; i++) {
+  Standard_Integer i, nbcurve;
+  IS >> nbcurve;
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "2D Curves", 0, nbcurve, 1);
+
+  for (i = 1; i <= nbcurve && PS.More(); i++, PS.Next()) {
+    if ( !myProgress.IsNull() ) 
+      progress->Show();
+    
     GeomTools_Curve2dSet::ReadCurve2d(IS,C);
     myMap.Add(C);
   }
 }
 
+//=======================================================================
+//function : GetProgress
+//purpose  : 
+//=======================================================================
+
+Handle(Message_ProgressIndicator) GeomTools_Curve2dSet::GetProgress() const
+{
+  return myProgress;
+}
+
+//=======================================================================
+//function : SetProgress
+//purpose  : 
+//=======================================================================
+
+void GeomTools_Curve2dSet::SetProgress(const Handle(Message_ProgressIndicator)& PR)
+{
+  myProgress = PR;
+}
+
 
