@@ -29,6 +29,7 @@
 #include <TColgp_Array1OfPnt.hxx>
 #include <Standard_Failure.hxx>
 #include <Standard_ErrorHandler.hxx>
+#include <Message_ProgressSentry.hxx>
 
 #define LINE      1
 #define CIRCLE    2
@@ -80,12 +81,9 @@ Standard_Integer  GeomTools_CurveSet::Add(const Handle(Geom_Curve)& C)
 Handle(Geom_Curve)  GeomTools_CurveSet::Curve
        (const Standard_Integer I)const 
 {
-  if  (I == 0) {
-	Handle(Geom_Curve) dummy;
-	return dummy;
-  }
-  else
-    return Handle(Geom_Curve)::DownCast(myMap(I));
+  if (I <= 0 || I > myMap.Extent())
+	return Handle(Geom_Curve)();
+  return Handle(Geom_Curve)::DownCast(myMap(I));
 }
 
 
@@ -507,9 +505,16 @@ void  GeomTools_CurveSet::Write(Standard_OStream& OS)const
 {
   int  prec = OS.precision(17);
 
-  Standard_Integer i, nbsurf = myMap.Extent();
-  OS << "Curves "<< nbsurf << "\n";
-  for (i = 1; i <= nbsurf; i++) {
+  Standard_Integer i, nbcurve = myMap.Extent();
+  OS << "Curves "<< nbcurve << "\n";
+    //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "3D Curves", 0, nbcurve, 1);
+
+  for (i = 1; i <= nbcurve && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     PrintCurve(Handle(Geom_Curve)::DownCast(myMap(i)),OS,Standard_True);
   }
 
@@ -524,7 +529,7 @@ void  GeomTools_CurveSet::Write(Standard_OStream& OS)const
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt& P)
 {
-  Standard_Real X,Y,Z;
+  Standard_Real X=0.,Y=0.,Z=0.;
   IS >> X >> Y >> Z;
   P.SetCoord(X,Y,Z);
   return IS;
@@ -537,7 +542,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt& P)
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir& D)
 {
-  Standard_Real X,Y,Z;
+  Standard_Real X=0.,Y=0.,Z=0.;
   IS >> X >> Y >> Z;
   D.SetCoord(X,Y,Z);
   return IS;
@@ -552,8 +557,8 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir& D)
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_Line)& L)
 {
-  gp_Pnt P;
-  gp_Dir AX;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir AX(1.,0.,0.);
   IS >> P >> AX;
   L = new Geom_Line(P,AX);
   return IS;
@@ -567,9 +572,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_Circle)& C)
 {
-  gp_Pnt P;
-  gp_Dir A,AX,AY;
-  Standard_Real R;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir A(1.,0.,0.),AX(1.,0.,0.),AY(1.,0.,0.);
+  Standard_Real R=0.;
   IS >> P >> A >> AX >> AY >> R;
   C = new Geom_Circle(gp_Ax2(P,A,AX),R);
   return IS;
@@ -583,9 +588,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_Ellipse)& E)
 {
-  gp_Pnt P;
-  gp_Dir A,AX,AY;
-  Standard_Real R1,R2;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir A(1.,0.,0.),AX(1.,0.,0.),AY(1.,0.,0.);
+  Standard_Real R1=0.,R2=0.;
   IS >> P >> A >> AX >> AY >> R1 >> R2;
   E = new Geom_Ellipse(gp_Ax2(P,A,AX),R1,R2);
   return IS;
@@ -599,9 +604,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_Parabola)& C)
 {
-  gp_Pnt P;
-  gp_Dir A,AX,AY;
-  Standard_Real R1;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir A(1.,0.,0.),AX(1.,0.,0.),AY(1.,0.,0.);
+  Standard_Real R1=0.;
   IS >> P >> A >> AX >> AY >> R1;
   C = new Geom_Parabola(gp_Ax2(P,A,AX),R1);
   return IS;
@@ -615,9 +620,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_Hyperbola)& H)
 {
-  gp_Pnt P;
-  gp_Dir A,AX,AY;
-  Standard_Real R1,R2;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir A(1.,0.,0.),AX(1.,0.,0.),AY(1.,0.,0.);
+  Standard_Real R1=0.,R2=0.;
   IS >> P >> A >> AX >> AY >> R1 >> R2;
   H = new Geom_Hyperbola(gp_Ax2(P,A,AX),R1,R2);
   return IS;
@@ -631,11 +636,11 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_BezierCurve)& B)
 {
-  Standard_Boolean rational;
+  Standard_Boolean rational=Standard_False;
   IS >> rational;
 
   // poles and weights
-  Standard_Integer i,degree;
+  Standard_Integer i=0,degree=0;
   IS >> degree;
 
   TColgp_Array1OfPnt poles(1,degree+1);
@@ -664,11 +669,11 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_BSplineCurve)& B)
 {
 
-  Standard_Boolean rational,periodic;
+  Standard_Boolean rational=Standard_False,periodic=Standard_False;
   IS >> rational >> periodic;
 
   // poles and weights
-  Standard_Integer i,degree,nbpoles,nbknots;
+  Standard_Integer i=0,degree=0,nbpoles=0,nbknots=0;
   IS >> degree >> nbpoles >> nbknots;
 
   TColgp_Array1OfPnt poles(1,nbpoles);
@@ -703,7 +708,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_TrimmedCurve)& C)
 {
-  Standard_Real p1,p2;
+  Standard_Real p1=0.,p2=0.;
   IS >> p1 >> p2;
   Handle(Geom_Curve) BC;
   GeomTools_CurveSet::ReadCurve(IS,BC);
@@ -719,9 +724,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_OffsetCurve)& C)
 {
-  Standard_Real p;
+  Standard_Real p=0.;
   IS >> p;
-  gp_Dir D;
+  gp_Dir D(1.,0.,0.);
   IS >> D;
   Handle(Geom_Curve) BC;
   GeomTools_CurveSet::ReadCurve(IS,BC);
@@ -852,10 +857,36 @@ void  GeomTools_CurveSet::Read(Standard_IStream& IS)
   Handle(Geom_Curve) C;
   Standard_Integer i, nbcurve;
   IS >> nbcurve;
-  for (i = 1; i <= nbcurve; i++) {
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "3D Curves", 0, nbcurve, 1);
+  for (i = 1; i <= nbcurve && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     GeomTools_CurveSet::ReadCurve(IS,C);
     myMap.Add(C);
   }
 }
 
+//=======================================================================
+//function : GetProgress
+//purpose  : 
+//=======================================================================
+
+Handle(Message_ProgressIndicator) GeomTools_CurveSet::GetProgress() const
+{
+  return myProgress;
+}
+
+//=======================================================================
+//function : SetProgress
+//purpose  : 
+//=======================================================================
+
+void GeomTools_CurveSet::SetProgress(const Handle(Message_ProgressIndicator)& PR)
+{
+  myProgress = PR;
+}
+
 
