@@ -34,6 +34,7 @@
 #include <TColgp_Array2OfPnt.hxx>
 #include <Standard_Failure.hxx>
 #include <Standard_ErrorHandler.hxx>
+#include <Message_ProgressSentry.hxx>
 
 #define PLANE           1
 #define CYLINDER        2
@@ -87,7 +88,9 @@ Standard_Integer  GeomTools_SurfaceSet::Add(const Handle(Geom_Surface)& S)
 Handle(Geom_Surface)  GeomTools_SurfaceSet::Surface
        (const Standard_Integer I)const 
 {
-  return  Handle(Geom_Surface)::DownCast(myMap(I));
+  if (I <= 0 || I > myMap.Extent())
+    return Handle(Geom_Surface)();
+  return Handle(Geom_Surface)::DownCast(myMap(I));
 }
 
 
@@ -624,7 +627,14 @@ void  GeomTools_SurfaceSet::Write(Standard_OStream& OS)const
 
   Standard_Integer i, nbsurf = myMap.Extent();
   OS << "Surfaces "<< nbsurf << "\n";
-  for (i = 1; i <= nbsurf; i++) {
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Surfaces", 0, nbsurf, 1);
+
+  for (i = 1; i <= nbsurf && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     PrintSurface(Handle(Geom_Surface)::DownCast(myMap(i)),OS,Standard_True);
   }
 
@@ -639,7 +649,7 @@ void  GeomTools_SurfaceSet::Write(Standard_OStream& OS)const
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt& P)
 {
-  Standard_Real X,Y,Z;
+  Standard_Real X=0.,Y=0.,Z=0.;
   IS >> X >> Y >> Z;
   P.SetCoord(X,Y,Z);
   return IS;
@@ -652,7 +662,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Pnt& P)
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir& D)
 {
-  Standard_Real X,Y,Z;
+  Standard_Real X=0.,Y=0.,Z=0.;
   IS >> X >> Y >> Z;
   D.SetCoord(X,Y,Z);
   return IS;
@@ -665,8 +675,8 @@ static Standard_IStream& operator>>(Standard_IStream& IS, gp_Dir& D)
 
 static Standard_IStream& operator>>(Standard_IStream& IS, gp_Ax3& A3)
 {
-  gp_Pnt P;
-  gp_Dir A,AX,AY;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir A(1.,0.,0.),AX(1.,0.,0.),AY(1.,0.,0.);
   IS >> P >> A >> AX >> AY;
   gp_Ax3 ax3(P,A,AX);
   if (AY.DotCross(A,AX) < 0)
@@ -699,7 +709,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_CylindricalSurface)& S)
 {
   gp_Ax3 A;
-  Standard_Real R;
+  Standard_Real R=0.;
   IS >> A  >> R;
   S = new Geom_CylindricalSurface(A,R);
   return IS;
@@ -714,7 +724,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_ConicalSurface)& S)
 {
   gp_Ax3 A;
-  Standard_Real R,Ang;
+  Standard_Real R=0.,Ang=0.;
   IS >> A >> R >> Ang;
   S = new Geom_ConicalSurface(A,Ang,R);
   return IS;
@@ -729,7 +739,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_SphericalSurface)& S)
 {
   gp_Ax3 A;
-  Standard_Real R;
+  Standard_Real R=0.;
   IS >> A >> R;
   S = new Geom_SphericalSurface(A,R);
   return IS;
@@ -744,7 +754,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_ToroidalSurface)& S)
 {
   gp_Ax3 A;
-  Standard_Real R1,R2;
+  Standard_Real R1=0.,R2=0.;
   IS >> A >> R1 >> R2;
   S = new Geom_ToroidalSurface(A,R1,R2);
   return IS;
@@ -758,7 +768,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_SurfaceOfLinearExtrusion)& S)
 {
-  gp_Dir D;
+  gp_Dir D(1.,0.,0.);
   Handle(Geom_Curve) C;
   IS >> D;
   GeomTools_CurveSet::ReadCurve(IS,C);
@@ -774,8 +784,8 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_SurfaceOfRevolution)& S)
 {
-  gp_Pnt P;
-  gp_Dir D;
+  gp_Pnt P(0.,0.,0.);
+  gp_Dir D(1.,0.,0.);
   Handle(Geom_Curve) C;
   IS >> P >> D;
   GeomTools_CurveSet::ReadCurve(IS,C);
@@ -791,9 +801,9 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_BezierSurface)& S)
 {
-  Standard_Boolean urational, vrational;
+  Standard_Boolean urational=Standard_False, vrational=Standard_False;
   IS >> urational >> vrational;
-  Standard_Integer udegree, vdegree;
+  Standard_Integer udegree=0, vdegree=0;
   IS >> udegree >> vdegree;
   TColgp_Array2OfPnt poles(1,udegree+1,1,vdegree+1);
   TColStd_Array2OfReal weights(1,udegree+1,1,vdegree+1);
@@ -822,10 +832,11 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_BSplineSurface)& S)
 {
-  Standard_Boolean urational, vrational, uperiodic, vperiodic;
+  Standard_Boolean urational=Standard_False, vrational=Standard_False,
+                   uperiodic=Standard_False, vperiodic=Standard_False;
   IS >> urational >> vrational;
   IS >> uperiodic >> vperiodic;
-  Standard_Integer udegree, vdegree,nbupoles,nbvpoles,nbuknots,nbvknots;
+  Standard_Integer udegree=0, vdegree=0,nbupoles=0,nbvpoles=0,nbuknots=0,nbvknots=0;
   IS >> udegree >> vdegree;
   IS >> nbupoles >> nbvpoles;
   IS >> nbuknots >> nbvknots;
@@ -871,7 +882,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_RectangularTrimmedSurface)& S)
 {
-  Standard_Real U1,U2,V1,V2;
+  Standard_Real U1=0.,U2=0.,V1=0.,V2=0.;
   IS >> U1 >> U2 >> V1 >> V2;
   Handle(Geom_Surface) BS;
   GeomTools_SurfaceSet::ReadSurface(IS,BS);
@@ -887,7 +898,7 @@ static Standard_IStream& operator>>(Standard_IStream& IS,
 static Standard_IStream& operator>>(Standard_IStream& IS,
 				    Handle(Geom_OffsetSurface)& S)
 {
-  Standard_Real O;
+  Standard_Real O=0.;
   IS >> O;
   Handle(Geom_Surface) BS;
   GeomTools_SurfaceSet::ReadSurface(IS,BS);
@@ -1036,10 +1047,37 @@ void  GeomTools_SurfaceSet::Read(Standard_IStream& IS)
   Handle(Geom_Surface) S;
   Standard_Integer i, nbsurf;
   IS >> nbsurf;
-  for (i = 1; i <= nbsurf; i++) {
+  //OCC19559
+  Handle(Message_ProgressIndicator) progress = GetProgress();
+  Message_ProgressSentry PS(progress, "Surfaces", 0, nbsurf, 1);
+  for (i = 1; i <= nbsurf && PS.More(); i++, PS.Next()) {
+    if ( !progress.IsNull() ) 
+      progress->Show();
+
     GeomTools_SurfaceSet::ReadSurface(IS,S);
     myMap.Add(S);
   }
 }
 
+//=======================================================================
+//function : GetProgress
+//purpose  : 
+//=======================================================================
+
+Handle(Message_ProgressIndicator) GeomTools_SurfaceSet::GetProgress() const
+{
+  return myProgress;
+}
+
+//=======================================================================
+//function : SetProgress
+//purpose  : 
+//=======================================================================
+
+void GeomTools_SurfaceSet::SetProgress(const Handle(Message_ProgressIndicator)& PR)
+{
+  myProgress = PR;
+}
+
+
 
