@@ -109,6 +109,15 @@
 #include <DrawTrSurf_BSplineSurface.hxx>
 #include <TColStd_HArray1OfReal.hxx>
 
+//epa test
+#include <BRepBuilderAPI_MakeEdge.hxx>
+#include <AIS_Shape.hxx>
+#include <TopoDS_Edge.hxx>
+#include <GeomLProp_CLProps.hxx>
+#include <GCPnts_AbscissaPoint.hxx>
+#include <GCPnts_UniformAbscissa.hxx>
+#include <DBRep.hxx>
+
 #ifdef WNT
 Standard_IMPORT Draw_Viewer dout;
 #endif
@@ -118,7 +127,7 @@ Standard_IMPORT Draw_Viewer dout;
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer polelaw (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polelaw (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer k,
   jj,
@@ -176,7 +185,7 @@ static Standard_Integer polelaw (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer to2d (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer to2d (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -205,7 +214,7 @@ static Standard_Integer to2d (Draw_Interpretor& , Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer to3d (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer to3d (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -234,7 +243,7 @@ static Standard_Integer to3d (Draw_Interpretor& , Standard_Integer n, char** a)
 //=======================================================================
 
 
-static Standard_Integer gproject(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer gproject(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   
   char newname[1024];
@@ -374,7 +383,7 @@ return 0;
 //=======================================================================
 
 static Standard_Integer project (Draw_Interpretor& di, 
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if ( n == 1) {
     
@@ -465,7 +474,7 @@ static Standard_Integer project (Draw_Interpretor& di,
 //=======================================================================
 
 Standard_Integer projonplane(Draw_Interpretor& di, 
-			     Standard_Integer n, char** a)
+			     Standard_Integer n, const char** a)
 {
   if ( n < 4 ) return 1;
 
@@ -509,7 +518,7 @@ Standard_Integer projonplane(Draw_Interpretor& di,
 //=======================================================================
 
 static void solution(const Handle(GccInt_Bisec)& Bis,
-		     char* name,
+		     const char* name,
 		     const Standard_Integer i)
 {
   char solname[200];
@@ -517,7 +526,7 @@ static void solution(const Handle(GccInt_Bisec)& Bis,
     sprintf(solname,"%s",name);
   else
     sprintf(solname,"%s_%d",name,i);
-  char* temp = solname; // pour portage WNT
+  const char* temp = solname; // pour portage WNT
 
   switch ( Bis->ArcType()) {
   case GccInt_Lin:
@@ -542,7 +551,7 @@ static void solution(const Handle(GccInt_Bisec)& Bis,
 }
 
 static Standard_Integer bisec (Draw_Interpretor& di, 
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   
@@ -567,7 +576,7 @@ static Standard_Integer bisec (Draw_Interpretor& di,
 	  NbSol = Bis.NbSolutions();
 	  for ( i = 1; i <= NbSol; i++) {
 	    sprintf(solname,"%s_%d",a[1],i);
-	    char* temp = solname; // pour portage WNT
+	    const char* temp = solname; // pour portage WNT
 	    DrawTrSurf::Set(temp,new Geom2d_Line(Bis.ThisSolution(i)));
 	  }
 	}
@@ -739,7 +748,7 @@ static Standard_Integer bisec (Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer movelaw (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer movelaw (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Integer dimension,
   ii,
@@ -814,7 +823,7 @@ static Standard_Integer movelaw (Draw_Interpretor& di, Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer crvpoints (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer crvpoints (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Integer i, nbp;
   Standard_Real defl;
@@ -894,13 +903,153 @@ static Standard_Integer crvpoints (Draw_Interpretor& di, Standard_Integer n, cha
   return 0;
 } 
 
+//=======================================================================
+//function : uniformAbscissa
+//purpose  : epa test (TATA-06-002 (Problem with GCPnts_UniformAbscissa class)
+//=======================================================================
+static Standard_Integer uniformAbscissa (Draw_Interpretor& di, Standard_Integer n, const char** a)
+{
+  if( n != 3 )
+    return 1;
+  
+  /*Handle(Geom_BSplineCurve) ellip;
+  ellip = DrawTrSurf::GetBSplineCurve(a[1]);
+  if (ellip.IsNull())
+  {
+    di << " BSpline is NULL  "<<"\n";     
+    return 1;
+  }*/
+
+  Handle(Geom_Curve) ellip;
+  ellip = DrawTrSurf::GetCurve(a[1]);
+  if (ellip.IsNull())
+  {
+    di << " Curve is NULL  "<<"\n";     
+    return 1;
+  }
+
+  Standard_Integer nocp;
+  nocp = atoi(a[2]);
+  if(nocp < 2)
+    return 1;
+
+
+  //test nbPoints for Geom_Ellipse
+
+  try
+  {
+    GeomLProp_CLProps Prop(ellip,2,Precision::Intersection());
+    Prop.SetCurve(ellip);
+
+    GeomAdaptor_Curve GAC(ellip);
+    di<<"Type Of curve: "<<GAC.GetType()<<"\n";
+    Standard_Real Tol = Precision::Confusion();
+    Standard_Real L;
+
+    L = GCPnts_AbscissaPoint::Length(GAC, GAC.FirstParameter(), GAC.LastParameter(), Tol);
+    di<<"Ellipse length = "<<L<<"\n";
+    Standard_Real Abscissa = L/(nocp-1);
+    di << " CUR : Abscissa " << Abscissa << "\n";
+
+    GCPnts_UniformAbscissa myAlgo(GAC, Abscissa, ellip->FirstParameter(), ellip->LastParameter());
+    if ( myAlgo.IsDone() )
+    {
+      di << " CasCurve  - nbpoints " << myAlgo.NbPoints() << "\n";
+      for(Standard_Integer i = 1; i<= myAlgo.NbPoints(); i++ )
+        di << i <<" points = " << myAlgo.Parameter( i ) << "\n";
+    }
+  }
+
+  catch (Standard_Failure )
+  {
+    di << " Standard Failure  " <<"\n";
+  }
+  return 0;
+}
+
+//=======================================================================
+//function : EllipsUniformAbscissa
+//purpose  : epa test (TATA-06-002 (Problem with GCPnts_UniformAbscissa class)
+//=======================================================================
+static Standard_Integer EllipsUniformAbscissa (Draw_Interpretor& di, Standard_Integer n, const char** a)
+{
+  if( n != 4 )
+    return 1;  
+  
+  Standard_Real R1;
+  R1 = atof(a[1]);
+  Standard_Real R2;
+  R2 = atof(a[2]);
+
+  Standard_Integer nocp;
+  nocp = atoi(a[3]);
+  if(nocp < 2)
+    return 1;
+  
+  //test nbPoints for Geom_Ellipse
+  Handle_Geom_Ellipse ellip;
+
+
+  try
+  {
+    gp_Pnt location;
+    location = gp_Pnt( 0.0, 0.0, 0.0);
+    gp_Dir main_direction(0.0, 0.0, 1.0);
+
+    gp_Dir x_direction(1.0, 0.0, 0.0);
+    gp_Ax2 mainaxis( location, main_direction);
+
+    mainaxis.SetXDirection(x_direction);
+    ellip = new Geom_Ellipse(mainaxis,R1, R2);
+
+    BRepBuilderAPI_MakeEdge curve_edge(ellip);
+    TopoDS_Edge edge_curve = curve_edge.Edge();
+
+    DBRep::Set("Ellipse",edge_curve);
+  }
+  
+  catch(Standard_Failure)
+  {
+    di << " Standard Failure  "<<"\n";     
+  }
+
+  try
+  {
+    GeomLProp_CLProps Prop(ellip,2,Precision::Intersection());
+    Prop.SetCurve(ellip);
+
+    GeomAdaptor_Curve GAC(ellip);
+    di<<"Type Of curve: "<<GAC.GetType()<<"\n";
+    Standard_Real Tol = Precision::Confusion();
+    Standard_Real L;
+
+    L = GCPnts_AbscissaPoint::Length(GAC, GAC.FirstParameter(), GAC.LastParameter(), Tol);
+    di<<"Ellipse length = "<<L<<"\n";
+    Standard_Real Abscissa = L/(nocp-1);
+    di << " CUR : Abscissa " << Abscissa << "\n";
+
+    GCPnts_UniformAbscissa myAlgo(GAC, Abscissa, ellip->FirstParameter(), ellip->LastParameter());
+    if ( myAlgo.IsDone() )
+    {
+      di << " CasCurve  - nbpoints " << myAlgo.NbPoints() << "\n";
+      for(Standard_Integer i = 1; i<= myAlgo.NbPoints(); i++ )
+        di << i <<" points = " << myAlgo.Parameter( i ) << "\n";
+    }
+  }
+
+  catch (Standard_Failure )
+  {
+    di << " Standard Failure  " <<"\n";
+  }
+  return 0;
+}
 
 //=======================================================================
 //function : mypoints
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer mypoints (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer mypoints (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Integer i, nbp;
   Standard_Real defl;
@@ -1050,7 +1199,7 @@ static Standard_Integer mypoints (Draw_Interpretor& di, Standard_Integer n, char
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer surfpoints (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer surfpoints (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Integer i, nbp;
   Standard_Real defl;
@@ -1114,7 +1263,7 @@ static Standard_Integer surfpoints (Draw_Interpretor& di, Standard_Integer n, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   
   if (n < 4) return 1;
@@ -1152,7 +1301,7 @@ static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n,
         for (Standard_Integer i=1; i<=nblines; i++) {
           sprintf(newname,"%s_%d",a[1],i);
           Result = Inters.Line(i);
-          char* temp = newname; // pour portage WNT
+          const char* temp = newname; // pour portage WNT
           DrawTrSurf::Set(temp,Result);
         }
       }
@@ -1210,7 +1359,7 @@ static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n,
         for (Standard_Integer i=1; i<=nblines; i++) {
           sprintf(newname,"%s_%d",a[1],i);
           Result = Inters.Line(i);
-          char* temp = newname;
+          const char* temp = newname;
           DrawTrSurf::Set(temp,Result);
         }
       }
@@ -1227,7 +1376,7 @@ static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n,
           if (nblines > 1) sprintf(newname,"%s_b_%d",a[1],i);
           else             sprintf(newname,"%s_b",a[1]);
           Result = Inters.Boundary(i);
-          char* temp = newname;
+          const char* temp = newname;
           DrawTrSurf::Set(temp,Result);
         }
       }
@@ -1255,13 +1404,13 @@ static Standard_Integer intersection (Draw_Interpretor& di, Standard_Integer n,
       for (i = 1; i <= nblines; i++, Compt++) {
 	sprintf(newname,"%s_%d",a[1],Compt);
 	Result = Inters.Segment(i);
-	char* temp = newname; // pour portage WNT
+	const char* temp = newname; // pour portage WNT
 	DrawTrSurf::Set(temp,Result);
       }
       for (i = 1; i <= nbpoints; i++, Compt++) {
 	sprintf(newname,"%s_%d",a[1],i);
 	Point = Inters.Point(i);
-	char* temp = newname; // pour portage WNT
+	const char* temp = newname; // pour portage WNT
 	DrawTrSurf::Set(temp,Point);
       }
     }
@@ -1294,7 +1443,7 @@ void  GeometryTest::CurveCommands(Draw_Interpretor& theCommands)
   
   DrawTrSurf::BasicCommands(theCommands);
   
-  char* g;
+  const char* g;
   
   g = "GEOMETRY curves creation";
 
@@ -1352,6 +1501,16 @@ void  GeometryTest::CurveCommands(Draw_Interpretor& theCommands)
 		  "crvpoints result curv deflection",
 		  __FILE__,
 		  crvpoints,g);
+  
+  theCommands.Add("uniformAbscissa",
+		  "uniformAbscissa Curve nbPnt",
+		  __FILE__,
+                  uniformAbscissa,g);
+
+  theCommands.Add("uniformAbscissaEl",
+		  "uniformAbscissaEl maxR minR nbPnt",
+		  __FILE__,  EllipsUniformAbscissa,g);
+
   theCommands.Add("mypoints",
 		  "mypoints result curv deflection",
 		  __FILE__,
@@ -1362,3 +1521,4 @@ void  GeometryTest::CurveCommands(Draw_Interpretor& theCommands)
 		  surfpoints,g);
 
 }
+
