@@ -317,7 +317,7 @@ static void PointsByFile(Handle(AppDef_HArray1OfMultiPointConstraint)& MPC,
 
 
 //==================================================================================
-static Standard_Integer smoothing (Draw_Interpretor& di,Standard_Integer n, char** a)
+static Standard_Integer smoothing (Draw_Interpretor& di,Standard_Integer n, const char** a)
 //==================================================================================
 //  Tolerance < 0 lissage "filtre"
 //  Tolerance > 0 lissage avec respect de l'erreur max
@@ -372,7 +372,7 @@ static Standard_Integer smoothing (Draw_Interpretor& di,Standard_Integer n, char
     if (n > ific) {
       // lecture du fichier.
     // nbpoints, 2d ou 3d, puis valeurs.
-      char* nomfic = a[ific];
+      const char* nomfic = a[ific];
       ifstream iFile(nomfic, ios::in);
       if (!iFile) { 
 	di << a[ific] <<"do not exist !" << "\n";
@@ -492,7 +492,7 @@ static Standard_Integer smoothing (Draw_Interpretor& di,Standard_Integer n, char
 //=============================================================================
 static Standard_Integer smoothingbybezier (Draw_Interpretor& di,
 					   Standard_Integer n, 
-					   char** a)
+					   const char** a)
 //============================================================================
 {
   Standard_Real Tolerance=0;
@@ -548,7 +548,7 @@ static Standard_Integer smoothingbybezier (Draw_Interpretor& di,
     else {
       // lecture du fichier.
       // nbpoints, 2d ou 3d, puis valeurs.
-      char* nomfic = a[5];
+      const char* nomfic = a[5];
       ifstream iFile(nomfic, ios::in);
       if (!iFile) { 
 	di << a[6] <<"do not exist !" << "\n";
@@ -736,7 +736,7 @@ void  GeomliteTest::ApproxCommands(Draw_Interpretor& theCommands)
 
   DrawTrSurf::BasicCommands(theCommands);
 
-  char* g;
+  const char* g;
   // constrained constructs
   g = "GEOMETRY Constraints";
 
