@@ -104,7 +104,7 @@ Standard_IMPORT Draw_Viewer dout;
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer anacurve (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer anacurve (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -261,7 +261,7 @@ static Standard_Integer anacurve (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer polecurve (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polecurve (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer k,i;
 
@@ -345,7 +345,7 @@ static Standard_Integer polecurve (Draw_Interpretor& , Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer polecurve2d (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polecurve2d (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer k,i;
 
@@ -429,7 +429,7 @@ static Standard_Integer polecurve2d (Draw_Interpretor& , Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer reverse (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer reverse (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -455,7 +455,7 @@ static Standard_Integer reverse (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cmovepole (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer cmovepole (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -513,7 +513,7 @@ static Standard_Integer cmovepole (Draw_Interpretor& , Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cmovetangent (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer cmovetangent (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Integer dimension,
   condition,
@@ -619,7 +619,7 @@ static Standard_Integer cmovetangent (Draw_Interpretor& di, Standard_Integer n,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cmovepoint (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer cmovepoint (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -675,7 +675,7 @@ static Standard_Integer cmovepoint (Draw_Interpretor& , Standard_Integer n, char
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cinsertknot (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer cinsertknot (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -721,7 +721,7 @@ static Standard_Integer cinsertknot (Draw_Interpretor& , Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer csetknot (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer csetknot (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -756,7 +756,7 @@ static Standard_Integer csetknot (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cremknot (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer cremknot (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -790,7 +790,7 @@ static Standard_Integer cremknot (Draw_Interpretor& di, Standard_Integer n, char
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer increasedegree (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer increasedegree (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -821,7 +821,7 @@ static Standard_Integer increasedegree (Draw_Interpretor& , Standard_Integer n,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer removepole (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer removepole (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -849,7 +849,7 @@ static Standard_Integer removepole (Draw_Interpretor& di, Standard_Integer n, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer insertpole (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer insertpole (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
 
@@ -885,7 +885,7 @@ static Standard_Integer insertpole (Draw_Interpretor& di, Standard_Integer n, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer cfindp (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer cfindp (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
 
@@ -934,7 +934,7 @@ static Standard_Integer cfindp (Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer csetperiodic (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer csetperiodic (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -966,7 +966,7 @@ static Standard_Integer csetperiodic (Draw_Interpretor& , Standard_Integer n, ch
 //=======================================================================
 
 static Standard_Integer value (Draw_Interpretor& ,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -1018,7 +1018,7 @@ static Standard_Integer value (Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer value2d (Draw_Interpretor& , 
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -1065,7 +1065,7 @@ static Standard_Integer value2d (Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer segment (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer segment (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -1097,7 +1097,7 @@ static Standard_Integer segment (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer setorigin (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer setorigin (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -1121,7 +1121,7 @@ static Standard_Integer setorigin (Draw_Interpretor& , Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer point(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer point(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   if (n >= 5) {
@@ -1142,7 +1142,7 @@ static Standard_Integer point(Draw_Interpretor& , Standard_Integer n, char** a)
 //=======================================================================
 
 static Standard_Integer coord(Draw_Interpretor&,
-			      Standard_Integer n, char** a) 
+			      Standard_Integer n, const char** a) 
 {
   if ( n == 4) {
     gp_Pnt2d P;
@@ -1168,7 +1168,7 @@ static Standard_Integer coord(Draw_Interpretor&,
 //purpose  : 
 //=======================================================================
 static Standard_Integer minmaxcurandinf(Draw_Interpretor& di, 
-				   Standard_Integer argc, char** argv)
+				   Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1;
 
@@ -1215,7 +1215,7 @@ static Standard_Integer minmaxcurandinf(Draw_Interpretor& di,
 //purpose  :  affiche le peigne de courbure
 //=======================================================================
 static Standard_Integer shcurvature(Draw_Interpretor&, 
-				   Standard_Integer argc, char** argv)
+				   Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1;
 
@@ -1240,7 +1240,7 @@ static Standard_Integer shcurvature(Draw_Interpretor&,
 //purpose  :  efface le peigne de courbure
 //=======================================================================
 static Standard_Integer clcurvature(Draw_Interpretor&, 
-				   Standard_Integer argc, char** argv)
+				   Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1; 
    Handle(DrawTrSurf_Curve2d) C2d =  Handle(DrawTrSurf_Curve2d)
@@ -1264,7 +1264,7 @@ static Standard_Integer clcurvature(Draw_Interpretor&,
 //purpose  :  definit le rayon de courbure maximum a afficher
 //=======================================================================
 static Standard_Integer radiusmax(Draw_Interpretor&, 
-				  Standard_Integer argc, char** argv)
+				  Standard_Integer argc, const char** argv)
 {
   if (argc < 3) return 1; 
   Standard_Real Radius = atof(argv[2]);
@@ -1289,7 +1289,7 @@ static Standard_Integer radiusmax(Draw_Interpretor&,
 //purpose  :  definit le ratio du rayon de courbure a afficher
 //=======================================================================
 static Standard_Integer radiusratio(Draw_Interpretor&, 
-				  Standard_Integer argc, char** argv)
+				  Standard_Integer argc, const char** argv)
 {
   if (argc < 3) return 1;
   Standard_Real Ratio = atof(argv[2]);
@@ -1314,7 +1314,7 @@ static Standard_Integer radiusratio(Draw_Interpretor&,
 //purpose  : 
 //=======================================================================
 static Standard_Integer localprop(Draw_Interpretor& di, 
-				  Standard_Integer argc, char** argv)
+				  Standard_Integer argc, const char** argv)
 {
   if (argc < 3) return 1;
 
@@ -1391,7 +1391,7 @@ static Standard_Integer localprop(Draw_Interpretor& di,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer rawcont(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer rawcont(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -1449,7 +1449,7 @@ static Standard_Integer rawcont(Draw_Interpretor& di, Standard_Integer n, char**
 //function : approxcurveonsurf
 //purpose  : 
 //=======================================================================
-static Standard_Integer approxcurveonsurf(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer approxcurveonsurf(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   Standard_Real Tol = 1.e-7;              // Tolerance (default 0.1mm) 
   GeomAbs_Shape Continuity = GeomAbs_C1;  // Continuity order : 0, 1 or 2 (default 1)
@@ -1496,7 +1496,7 @@ static Standard_Integer approxcurveonsurf(Draw_Interpretor& di, Standard_Integer
 //function : approxcurve
 //purpose  : 
 //=======================================================================
-static Standard_Integer approxcurve(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer approxcurve(Draw_Interpretor& di, Standard_Integer n, const char** a)
 { 
   Standard_Real Tol = 1.e-7;              // Tolerance (default 0.1mm) 
   GeomAbs_Shape Continuity = GeomAbs_C1;  // Continuity order : 0, 1 or 2 (default 1)
@@ -1664,7 +1664,7 @@ static Standard_Integer approxcurve(Draw_Interpretor& di, Standard_Integer n, ch
 //=======================================================================
 
 static Standard_Integer splitc1(Draw_Interpretor& di,
-				   Standard_Integer n, char** c)
+				   Standard_Integer n, const char** c)
 
 {Standard_Real      tolerance=1.0e-5,
    angular_tolerance = 1.0e-4 ;
@@ -1723,7 +1723,7 @@ static Standard_Integer splitc1(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer splitc12d(Draw_Interpretor& di,
-				     Standard_Integer n, char** c)
+				     Standard_Integer n, const char** c)
 
 {Standard_Real      tolerance=1.0e-5,
    angular_tolerance = 1.0e-4 ;
@@ -1778,7 +1778,7 @@ static Standard_Integer splitc12d(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer canceldenom(Draw_Interpretor& ,
-				     Standard_Integer n, char** c)
+				     Standard_Integer n, const char** c)
 
 {Standard_Integer    uoption,voption;
  Standard_Boolean    udirection=Standard_False;
@@ -1802,7 +1802,7 @@ static Standard_Integer canceldenom(Draw_Interpretor& ,
 //=======================================================================
 
 static Standard_Integer length(Draw_Interpretor& di,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n<2) return 1;
   Handle(Geom_Curve) GC = DrawTrSurf::GetCurve(a[1]);
@@ -1843,7 +1843,7 @@ void  GeomliteTest::CurveCommands(Draw_Interpretor& theCommands)
   
   DrawTrSurf::BasicCommands(theCommands);
   
-  char* g;
+  const char* g;
   
   
   // analytic curves
