@@ -92,7 +92,7 @@ Standard_IMPORT Draw_Viewer dout;
 //=======================================================================
 static Standard_Integer surface_radius (Draw_Interpretor& di,
 					Standard_Integer n, 
-					char** a)
+					const char** a)
 {
   Standard_Integer report_curvature = 0 ;
   Standard_Real UParameter,VParameter,radius,tolerance = 1.0e-7 ;
@@ -149,7 +149,7 @@ static Standard_Integer surface_radius (Draw_Interpretor& di,
 
 static Standard_Integer anasurface (Draw_Interpretor& ,
 				    Standard_Integer  n, 
-				    char** a)
+				    const char** a)
 {
   if (n < 2) return 1;
   gp_Ax3 loc;
@@ -230,7 +230,7 @@ static Standard_Integer anasurface (Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer polesurface (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer polesurface (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   Standard_Integer k,j,i;
 
@@ -345,7 +345,7 @@ static Standard_Integer polesurface (Draw_Interpretor& , Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer algosurface (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer algosurface (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -387,7 +387,7 @@ static Standard_Integer algosurface (Draw_Interpretor& , Standard_Integer n, cha
 //=======================================================================
 
 static Standard_Integer trimming (Draw_Interpretor& , 
-				  Standard_Integer n, char** a)
+				  Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -456,7 +456,7 @@ static Standard_Integer trimming (Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer converting(Draw_Interpretor& , Standard_Integer n, char ** a)
+static Standard_Integer converting(Draw_Interpretor& , Standard_Integer n, const char ** a)
 {
   if ( n < 3) return 1;
 
@@ -519,7 +519,7 @@ static Standard_Integer converting(Draw_Interpretor& , Standard_Integer n, char
 //=======================================================================
 
 static Standard_Integer tobezier(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if ( n < 3) return 1;
   Standard_Integer i,j,NbU,NbV,NbArc;
@@ -630,7 +630,7 @@ static Standard_Integer tobezier(Draw_Interpretor& di,
 //=======================================================================
 
 static Standard_Integer convbz(Draw_Interpretor& di,
-				 Standard_Integer n, char** a)
+				 Standard_Integer n, const char** a)
 {
   if ( n < 4) return 1;
 
@@ -714,7 +714,7 @@ static Standard_Integer convbz(Draw_Interpretor& di,
 //=======================================================================
 
 
-static Standard_Integer approxsurf(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer approxsurf(Draw_Interpretor& di, Standard_Integer n, const char** a)
 { 
 // " Tolerance (par defaut 0.1mm) " 
   Standard_Real Tol = 1.e-4;
@@ -766,7 +766,7 @@ static Standard_Integer approxsurf(Draw_Interpretor& di, Standard_Integer n, cha
 //=======================================================================
 
 static Standard_Integer offseting (Draw_Interpretor& ,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -813,7 +813,7 @@ static Standard_Integer offseting (Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer sreverse (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer sreverse (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -838,7 +838,7 @@ static Standard_Integer sreverse (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer iso (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer iso (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
 
@@ -863,7 +863,7 @@ static Standard_Integer iso (Draw_Interpretor& , Standard_Integer n, char** a)
 //=======================================================================
 
 static Standard_Integer value (Draw_Interpretor& ,
-			       Standard_Integer n, char** a)
+			       Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
 
@@ -922,7 +922,7 @@ static Standard_Integer value (Draw_Interpretor& ,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer movepole (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer movepole (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
   Standard_Boolean BSpline = Standard_False;
@@ -1006,7 +1006,7 @@ static Standard_Integer movepole (Draw_Interpretor& , Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer movepoint (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer movepoint (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 7) return 1;
 
@@ -1055,7 +1055,7 @@ static Standard_Integer movepoint (Draw_Interpretor& , Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer insertknot (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer insertknot (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -1106,7 +1106,7 @@ static Standard_Integer insertknot (Draw_Interpretor& , Standard_Integer n, char
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer incdegree (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer incdegree (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -1170,7 +1170,7 @@ static Standard_Integer incdegree (Draw_Interpretor& di, Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer rempole (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer rempole (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -1227,7 +1227,7 @@ static Standard_Integer rempole (Draw_Interpretor& di, Standard_Integer n, char*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer sfindp (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer sfindp (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 7) return 1;
   Standard_Boolean BSpline = Standard_False;
@@ -1272,7 +1272,7 @@ static Standard_Integer sfindp (Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer ssetperiodic (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer ssetperiodic (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -1326,7 +1326,7 @@ static Standard_Integer ssetperiodic (Draw_Interpretor& , Standard_Integer n, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer exchuv (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer exchuv (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
 
@@ -1355,7 +1355,7 @@ static Standard_Integer exchuv (Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer segsur (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer segsur (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 6) return 1;
 
@@ -1381,7 +1381,7 @@ static Standard_Integer segsur (Draw_Interpretor& , Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer setuvorigin (Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer setuvorigin (Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -1407,7 +1407,7 @@ static Standard_Integer setuvorigin (Draw_Interpretor& , Standard_Integer n, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer parameters (Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer parameters (Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if(n == 8)
     { 
@@ -1468,7 +1468,7 @@ static Standard_Integer parameters (Draw_Interpretor& di, Standard_Integer n, ch
 //purpose  : 
 //=======================================================================
 
-Standard_Integer bounds(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer bounds(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   Standard_Real U1, U2, V1, V2;
   if ( n == 4) {  // compute on a curve or a 2d curve
@@ -1514,7 +1514,7 @@ void  GeomliteTest::SurfaceCommands(Draw_Interpretor& theCommands)
 
   DrawTrSurf::BasicCommands(theCommands);
 
-  char* g;
+  const char* g;
   // analytic surfaces
   g = "GEOMETRY surfaces creation";
 
