@@ -34,6 +34,7 @@
 #include <Graphic2d_Primitive.pxx>
 #include <Standard_Type.hxx>
 #include <Aspect_Units.hxx>
+#include <Precision.hxx>
 
 #define MAXPOINTS 1023
 
@@ -188,10 +189,10 @@ void Graphic2d_Drawer::SetValues (const Standard_Real XF,
 
         myXF    = Standard_ShortReal(XF);
         myYF    = Standard_ShortReal(YF);
-        mySF    = Standard_ShortReal(SF);
+        mySF    = Standard_ShortReal(SF>Precision::Confusion()?SF:Precision::Confusion());
         myXT    = Standard_ShortReal(XT);
         myYT    = Standard_ShortReal(YT);
-        myST    = Standard_ShortReal(ST);
+        myST    = Standard_ShortReal(ST>Precision::Confusion()?ST:Precision::Confusion());
         myZF    = Standard_ShortReal(ZF);
 
 }
