@@ -9,7 +9,8 @@
 #include <Interface_Check.hxx>
 #include <Interface_CheckIterator.hxx>
 #include <Interface_GeneralLib.hxx>
-#include <Interface_TraceFile.hxx>
+#include <Message_Messenger.hxx>
+#include <Message.hxx>
 #include <stdio.h>
 
 //#define MISOPOINT
@@ -107,7 +108,7 @@
    const Handle(Interface_Protocol)& protocol,
    Interface_CopyTool& TC)
 {
-  if (Interface_TraceFile::DefLevel() > 0) Interface_TraceFile::Def() <<
+  Message::DefaultMessenger() <<
     "** WorkSession : Copying split data before sending"<<endl;
   const Interface_Graph& G = eval.Graph();
   Interface_CheckIterator checks;
@@ -137,8 +138,7 @@
   (const Handle(IFSelect_WorkLibrary)& WL,
    const Handle(Interface_Protocol)& protocol)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  if (Interface_TraceFile::DefLevel() > 0) sout <<
+  Message::DefaultMessenger() <<
     "** WorkSession : Sending split data already copied"<<endl;
   Standard_Integer nb = NbFiles();
   Interface_CheckIterator checks;
@@ -158,7 +158,8 @@
       if (!res) {
 	char mess[100];  sprintf(mess,"Split Send (WriteFile) abandon on file n0.%d",i);
 	checks.CCheck(0)->AddFail (mess);
-	sout<<"  **  Sending File n0."<<i<<" has failed, abandon  **"<<endl;
+	Message::DefaultMessenger() << 
+	  "  **  Sending File n0."<<i<<" has failed, abandon  **"<<endl;
 	return checks;
       }
       AddSentFile (FileName(i).ToCString());
@@ -190,8 +191,7 @@
   const Interface_Graph& G = eval.Graph();
   Interface_CheckIterator checks;
   Standard_Integer i = 0;
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  if (Interface_TraceFile::DefLevel() > 0) sout <<
+  Message::DefaultMessenger() <<
     "** WorkSession : Copying then sending split data"<<endl;
   theshareout = eval.ShareOut();
   theremain = new TColStd_HArray1OfInteger(0,G.Size()); theremain->Init(0);
@@ -217,7 +217,8 @@
     if (!res) {
       char mess[100];  sprintf(mess,"Split Send (WriteFile) abandon on file n0.%d",i);
       checks.CCheck(0)->AddFail (mess);
-      sout<<"  **  Sending File "<<filename<<" has failed, abandon  **"<<endl;
+      Message::DefaultMessenger() <<
+	"  **  Sending File "<<filename<<" has failed, abandon  **"<<endl;
       checks.SetName ("X-STEP WorkSession : Split Send (only Write)");
       return checks;
     }
@@ -238,7 +239,7 @@
 {
   Interface_CheckIterator checks;
   checks.SetName ("X-STEP WorkSession : Send All");
-  if (Interface_TraceFile::DefLevel() > 0) Interface_TraceFile::Def() <<
+  Message::DefaultMessenger() <<
     "** WorkSession : Sending all data"<<endl;
   Handle(Interface_InterfaceModel)  model = G.Model();
   if (model.IsNull() || protocol.IsNull() || WL.IsNull()) return checks;
@@ -259,8 +260,8 @@
   checks.Merge(checklst);
   if (!res) checks.CCheck(0)->AddFail ("SendAll (WriteFile) has failed");
 //  if (!checks.IsEmpty(Standard_False)) {
-//    Standard_OStream& sout = Interface_TraceFile::Def();
-//    sout<<"  **    SendAll has produced Check Messages :    **"<<endl;
+//    Message::DefaultMessenger() <<
+//      "  **    SendAll has produced Check Messages :    **"<<endl;
 //    checks.Print (sout,model,Standard_False);
 //  }
   return checks;
@@ -278,7 +279,7 @@
 {
   Interface_CheckIterator checks;
   checks.SetName ("X-STEP WorkSession : Send Selected");
-  if (Interface_TraceFile::DefLevel() > 0) Interface_TraceFile::Def() <<
+  Message::DefaultMessenger() <<
     "** WorkSession : Sending selected data"<<endl;
   Handle(Interface_InterfaceModel)  original = G.Model();
   if (original.IsNull() || protocol.IsNull() || WL.IsNull()) return checks;
@@ -313,8 +314,8 @@
   checks.Merge(checklst);
   if (!res) checks.CCheck(0)->AddFail ("SendSelected (WriteFile) has failed");
 //  if (!checks.IsEmpty(Standard_False)) {
-//    Standard_OStream& sout = Interface_TraceFile::Def();
-//    sout<<"  **    SendSelected has produced Check Messages :    **"<<endl;
+//    Message::DefaultMessenger() <<
+//      "  **    SendSelected has produced Check Messages :    **"<<endl;
 //    checks.Print (sout,original,Standard_False);
 //  }
   return checks;
@@ -383,8 +384,8 @@
 
 //    Faut-il enregistrer les erreurs dans newmod ? bonne question
 //    if (!checks.IsEmpty(Standard_False)) {
-//      Standard_OStream& sout = Interface_TraceFile::Def();
-//      sout<<" Messages on Copied Model n0 "<<numod<<", Dispatch Rank "<<dispnum<<endl;
+//      Message::DefaultMessenger() <<
+//        " Messages on Copied Model n0 "<<numod<<", Dispatch Rank "<<dispnum<<endl;
 //      checks.Print(sout,newmod,Standard_False);
 //    }
   }
