@@ -8,6 +8,8 @@
 #include <TColStd_HSequenceOfAsciiString.hxx>
 
 #include <Interface_Macros.hxx>
+#include <Message_Messenger.hxx>
+#include <Message.hxx>
 
 #include <stdio.h>
 
@@ -305,7 +307,7 @@ static TCollection_AsciiString nulword;
     }
     counter->AddWithGraph (list,thesession->Graph());
   }
-  counter->PrintList(cout,thesession->Model(),mode);
+  counter->PrintList(Message::DefaultMessenger(),thesession->Model(),mode);
   return IFSelect_RetVoid;
 }
 
