@@ -7,7 +7,7 @@
 #include <IGESData_BasicEditor.hxx>
 #include <Interface_Static.hxx>
 #include <Interface_Macros.hxx>
-#include <MoniTool_Msg.hxx>
+#include <Message_Msg.hxx>
 
 #include <stdio.h>
 
@@ -53,7 +53,7 @@ void IGESData_IGESModel::ClearHeader ()
 //=======================================================================
 
 void IGESData_IGESModel::DumpHeader
-  (Standard_OStream& S, const Standard_Integer ) const
+  (const Handle(Message_Messenger)& S, const Standard_Integer ) const
 {
   Standard_Integer ns = thestart->Length();
   S<<"****    Dump of IGES Model , Start and Global Sections   ****"<<endl;
@@ -323,21 +323,21 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
 {
   // MGE 23/07/98
   // =====================================
-  //MoniTool_Msg Msg40 ("XSTEP_40");
-  //MoniTool_Msg Msg41 ("XSTEP_41");
-  //MoniTool_Msg Msg42 ("XSTEP_42");
-  //MoniTool_Msg Msg43 ("XSTEP_43");
-  //MoniTool_Msg Msg44 ("XSTEP_44");
-  //MoniTool_Msg Msg45 ("XSTEP_45");
-  //MoniTool_Msg Msg46 ("XSTEP_46");
-  //MoniTool_Msg Msg47 ("XSTEP_47");
-  //MoniTool_Msg Msg48 ("XSTEP_48");
-  //MoniTool_Msg Msg50 ("XSTEP_50");
-  //MoniTool_Msg Msg51 ("XSTEP_51");
-  //MoniTool_Msg Msg52 ("XSTEP_52");
-  //MoniTool_Msg Msg53 ("XSTEP_53");
-  //MoniTool_Msg Msg54 ("XSTEP_54");
-  //MoniTool_Msg Msg55 ("XSTEP_55");
+  //Message_Msg Msg40 ("XSTEP_40");
+  //Message_Msg Msg41 ("XSTEP_41");
+  //Message_Msg Msg42 ("XSTEP_42");
+  //Message_Msg Msg43 ("XSTEP_43");
+  //Message_Msg Msg44 ("XSTEP_44");
+  //Message_Msg Msg45 ("XSTEP_45");
+  //Message_Msg Msg46 ("XSTEP_46");
+  //Message_Msg Msg47 ("XSTEP_47");
+  //Message_Msg Msg48 ("XSTEP_48");
+  //Message_Msg Msg50 ("XSTEP_50");
+  //Message_Msg Msg51 ("XSTEP_51");
+  //Message_Msg Msg52 ("XSTEP_52");
+  //Message_Msg Msg53 ("XSTEP_53");
+  //Message_Msg Msg54 ("XSTEP_54");
+  //Message_Msg Msg55 ("XSTEP_55");
   // =====================================
 
   char del[2];
@@ -345,7 +345,7 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
   del[1] = theheader.EndMark();
   // Sending of message : Parameter Delimiter Character and Record Delimiter Character must be different.
   if (del[0] == del[1]) {
-    MoniTool_Msg Msg40 ("XSTEP_40");
+    Message_Msg Msg40 ("XSTEP_40");
     ach->SendFail(Msg40);
   }
   for (int i = 0; i <= 1; i ++) {
@@ -354,43 +354,43 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
 	del [i] == 72 || del[i] >= 127) {
         // Sending of message : Parameter Delimiter Character is incorrect.
       if (i == 0) {
-        MoniTool_Msg Msg41 ("XSTEP_41");
+        Message_Msg Msg41 ("XSTEP_41");
         ach->SendFail(Msg41);
       }
       // Sending of message : Character Record Delimiter parameter is incorrect.
       else {
-        MoniTool_Msg Msg42 ("XSTEP_42");
+        Message_Msg Msg42 ("XSTEP_42");
         ach->SendFail (Msg42);
       }
     }
   }
   // Sending of message : Single Precision Magnitude parameter is incorrect. 
   if (theheader.MaxPower10Single() <= 0) {
-    MoniTool_Msg Msg43 ("XSTEP_43");
+    Message_Msg Msg43 ("XSTEP_43");
     ach->SendFail(Msg43);
   }
 
   // Sending of message : Precision Significance parameter is incorrect.
   if (theheader.MaxDigitsSingle()  <= 0) {
-    MoniTool_Msg Msg44 ("XSTEP_44");
+    Message_Msg Msg44 ("XSTEP_44");
     ach->SendFail(Msg44);
   }
 
   // Sending of messages : Double Precision Magnitude parameter is incorrect.
   if (theheader.MaxPower10Double() <= 0) {
-    MoniTool_Msg Msg45 ("XSTEP_45");
+    Message_Msg Msg45 ("XSTEP_45");
     ach->SendFail(Msg45);
   }
 
   // Sending of message : Double Precision Significance parameter is incorrect.
   if (theheader.MaxDigitsDouble()  <= 0) {
-    MoniTool_Msg Msg46 ("XSTEP_46");
+    Message_Msg Msg46 ("XSTEP_46");
     ach->SendFail(Msg46);
   }
 
   // Sending of message : Model Space Scale parameter is incorrect.
   if (theheader.Scale() <= 0.) {
-    MoniTool_Msg Msg47 ("XSTEP_47");
+    Message_Msg Msg47 ("XSTEP_47");
     ach->SendFail(Msg47);
   }
 
@@ -398,7 +398,7 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
 
   // Sending of message : Unit Flag parameter is incorrect.
   if (unf  < 1 || unf > 11) {
-    MoniTool_Msg Msg48 ("XSTEP_48");
+    Message_Msg Msg48 ("XSTEP_48");
     ach->SendFail(Msg48);
   }
 
@@ -406,7 +406,7 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
   if (theheader.UnitName().IsNull()) {
     // Sending of message : Unit Name parameter is undefined.
     if (unf == 3) {
-      MoniTool_Msg Msg50 ("XSTEP_50");
+      Message_Msg Msg50 ("XSTEP_50");
       ach->SendFail(Msg50);
     }
   }
@@ -425,12 +425,12 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
       case  9 : unok = !strcmp(unm,"UM");   break;
       case 10 : unok = !strcmp(unm,"CM");   break;
       case 11 : unok = !strcmp(unm,"UIN");  break;
-      default : MoniTool_Msg Msg48 ("XSTEP_48"); ach->SendFail(Msg48);
+      default : Message_Msg Msg48 ("XSTEP_48"); ach->SendFail(Msg48);
 	break;
     }
     // Sending of message : Flag parameter doesn`t correspond to the Unit Name parameter.
     if (!unok) {
-      MoniTool_Msg Msg51 ("XSTEP_51");
+      Message_Msg Msg51 ("XSTEP_51");
       ach->SendFail(Msg51);
     }
   }
@@ -438,7 +438,7 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
   IGESData_VerifyDate (theheader.Date(),ach,"Creation Date");
   // Sending of message : Minimum Resolution parameter is incorrect.
   if (theheader.Resolution() <= 0.) {
-    MoniTool_Msg Msg52 ("XSTEP_52");
+    Message_Msg Msg52 ("XSTEP_52");
     ach->SendFail(Msg52);
   }
   // ..  comment verifier les coordonnees max ?
@@ -446,14 +446,14 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
   // Sending of message : Version Flag parameter is incorrect.
   if (theheader.IGESVersion() < 1 ||
       theheader.IGESVersion() > IGESData_BasicEditor::IGESVersionMax()) {
-    MoniTool_Msg Msg53 ("XSTEP_53");
+    Message_Msg Msg53 ("XSTEP_53");
     ach->SendWarning(Msg53);
   }
 
   // Sending of message : Drafting Standard Flag parameter is incorrect.
   if (theheader.DraftingStandard() < 0 ||
       theheader.DraftingStandard() > IGESData_BasicEditor::DraftingMax()) {
-    MoniTool_Msg Msg54 ("XSTEP_54");
+    Message_Msg Msg54 ("XSTEP_54");
     ach->SendWarning(Msg54);
   }
 
@@ -461,7 +461,7 @@ void  IGESData_IGESModel::VerifyCheck (Handle(Interface_Check)& ach) const
   if (theheader.IGESVersion() >= 9) {
     // Sending of message : Last change Date parameter is undefined.
     if (!theheader.HasLastChangeDate()) {
-      MoniTool_Msg Msg55 ("XSTEP_55");
+      Message_Msg Msg55 ("XSTEP_55");
       ach->SendWarning(Msg55);
     }
     else IGESData_VerifyDate (theheader.LastChangeDate(),ach,"Last Change Date");
@@ -475,7 +475,7 @@ void IGESData_VerifyDate(const Handle(TCollection_HAsciiString)& str,
 {
   // MGE 23/07/98
   // =====================================
-  MoniTool_Msg Msg57 ("XSTEP_57");
+  Message_Msg Msg57 ("XSTEP_57");
   // =====================================
 
   //  Attention c est du Hollerith
@@ -484,9 +484,9 @@ void IGESData_VerifyDate(const Handle(TCollection_HAsciiString)& str,
 
   Handle(TCollection_HAsciiString) stdvar = str;
   if (strcmp(mess,"Last Change Date")==0)
-    Msg57.AddInteger(25);
+    Msg57.Arg(25);
   else
-    Msg57.AddInteger(18);
+    Msg57.Arg(18);
   if (((stdvar->Length() != 13) && (stdvar->Length() != 15)) || !stdvar->IsRealValue()) ach->SendFail(Msg57); 
   //smh#13 For short year date
   else if ((stdvar->Value(3) > '1' || 
@@ -543,7 +543,7 @@ void  IGESData_IGESModel::ClearLabels ()
 //=======================================================================
 
 void  IGESData_IGESModel::PrintLabel
-  (const Handle(Standard_Transient)& ent, Standard_OStream& S) const
+  (const Handle(Standard_Transient)& ent, const Handle(Message_Messenger)& S) const
 { 
   DeclareAndCast(IGESData_IGESEntity,igesent,ent);
   if (igesent.IsNull()) S<<"Null";
@@ -561,7 +561,7 @@ void  IGESData_IGESModel::PrintLabel
 //=======================================================================
 
 void  IGESData_IGESModel::PrintToLog
-  (const Handle(Standard_Transient)& ent, Standard_OStream& S) const
+  (const Handle(Standard_Transient)& ent, const Handle(Message_Messenger)& S) const
 {
   DeclareAndCast(IGESData_IGESEntity,igesent,ent);
   if (!igesent.IsNull()) {
@@ -581,7 +581,7 @@ void  IGESData_IGESModel::PrintToLog
 //=======================================================================
 
 void  IGESData_IGESModel::PrintInfo
-  (const Handle(Standard_Transient)& ent, Standard_OStream& S) const
+  (const Handle(Standard_Transient)& ent, const Handle(Message_Messenger)& S) const
 {
   DeclareAndCast(IGESData_IGESEntity,igesent,ent);
   if (igesent.IsNull()) S<<"(NOT IGES)";
@@ -589,8 +589,7 @@ void  IGESData_IGESModel::PrintInfo
     Standard_Integer num = Number(ent);
     if (num == 0) S<<"??";
     else  {
-      S<<(2*num-1) << "type";
-      Type(ent)->Print(S);
+      S<<(2*num-1) << "type " << Type(ent)->Name();
     }
   }
 }
