@@ -9,7 +9,7 @@
 #include <IGESData_Status.hxx>
  
 // MGE 03/08/98
-#include <MoniTool_Msg.hxx>
+#include <Message_Msg.hxx>
 
 static Standard_Integer testconv = -1;  // cf parametre de session
 
@@ -25,7 +25,7 @@ IGESData_ParamReader::IGESData_ParamReader(const Handle(Interface_ParamList)& li
                                            const Handle(Interface_Check)& ach,
                                            const Standard_Integer base,
                                            const Standard_Integer nbpar,
-                                           const Standard_Integer num)
+                                           const Standard_Integer /*num*/)
 {
   Clear();
   theparams = list;  thecheck = ach;  thelast = Standard_True;
@@ -430,7 +430,7 @@ Standard_Boolean IGESData_ParamReader::ReadInteger
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadBoolean
-  (const IGESData_ParamCursor& PC, const MoniTool_Msg& amsg,
+  (const IGESData_ParamCursor& PC, const Message_Msg& amsg,
    Standard_Boolean& val, const Standard_Boolean exact)
 {
   if (!PrepareRead(PC,Standard_False)) return Standard_False;
@@ -539,7 +539,7 @@ Standard_Boolean IGESData_ParamReader::ReadReal
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadXY
-  (const IGESData_ParamCursor& PC,MoniTool_Msg& amsg, gp_XY& val)
+  (const IGESData_ParamCursor& PC,Message_Msg& /*amsg*/, gp_XY& val)
 {
   if (!PrepareRead(PC,Standard_False,2)) return Standard_False;
   Standard_Real X,Y;
@@ -577,7 +577,7 @@ Standard_Boolean IGESData_ParamReader::ReadXY
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadXYZ
-  (const IGESData_ParamCursor& PC,MoniTool_Msg& amsg, gp_XYZ& val)
+  (const IGESData_ParamCursor& PC,Message_Msg& /*amsg*/, gp_XYZ& val)
 {
   if (!PrepareRead(PC,Standard_False,3)) return Standard_False;
   Standard_Real X,Y,Z;
@@ -617,7 +617,7 @@ Standard_Boolean IGESData_ParamReader::ReadXYZ
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadText
-  (const IGESData_ParamCursor& PC, const MoniTool_Msg& amsg  ,
+  (const IGESData_ParamCursor& PC, const Message_Msg& amsg,
    Handle(TCollection_HAsciiString)& val)
 {
   if (!PrepareRead(PC,Standard_False)) return Standard_False;
@@ -701,8 +701,8 @@ Standard_Boolean IGESData_ParamReader::ReadEntity (const Handle(IGESData_IGESRea
     val.Nullify();
     if (!canbenul) {
       aStatus = IGESData_ReferenceError;
-     // MoniTool_Msg Msg216 ("IGESP_216");
-     // amsg.AddString(amsg.Value());
+     // Message_Msg Msg216 ("IGESP_216");
+     // amsg.Arg(amsg.Value());
      // SendFail (amsg);
 
       thelast = Standard_True;
@@ -717,8 +717,8 @@ Standard_Boolean IGESData_ParamReader::ReadEntity (const Handle(IGESData_IGESRea
       val.Nullify();
       if (!canbenul) {
 	aStatus = IGESData_EntityError;
-	// MoniTool_Msg Msg217 ("IGES_217");
-        //amsg.AddString(Msg217.Value());
+	// Message_Msg Msg217 ("IGES_217");
+        //amsg.Arg(Msg217.Value());
         //SendFail (amsg);
         thelast = Standard_True;
       }
@@ -788,8 +788,8 @@ Standard_Boolean IGESData_ParamReader::ReadEntity (const Handle(IGESData_IGESRea
   if (val.IsNull()) return res;
   if (!val->IsKind(type)) {
     aStatus = IGESData_TypeError;
-    // MoniTool_Msg Msg218 ("IGES_218");
-    //amsg.AddString(Msg218.Value());
+    // Message_Msg Msg218 ("IGES_218");
+    //amsg.Arg(Msg218.Value());
     //SendFail(amsg);
     thelast = Standard_True;
     val.Nullify();
@@ -831,7 +831,7 @@ Standard_Boolean IGESData_ParamReader::ReadEntity
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadInts
-  (const IGESData_ParamCursor& PC, const MoniTool_Msg& amsg ,
+  (const IGESData_ParamCursor& PC, const Message_Msg& amsg ,
    Handle(TColStd_HArray1OfInteger)& val,  const Standard_Integer index)
 {
   if (!PrepareRead(PC,Standard_True)) return Standard_False;
@@ -893,7 +893,7 @@ Standard_Boolean IGESData_ParamReader::ReadInts
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadReals
-  (const IGESData_ParamCursor& PC,MoniTool_Msg& amsg ,
+  (const IGESData_ParamCursor& PC,Message_Msg& /*amsg*/,
    Handle(TColStd_HArray1OfReal)& val,  const Standard_Integer index)
 {
   if (!PrepareRead(PC,Standard_True)) return Standard_False;
@@ -941,7 +941,7 @@ Standard_Boolean IGESData_ParamReader::ReadReals
 //=======================================================================
 
 Standard_Boolean IGESData_ParamReader::ReadTexts
-  (const IGESData_ParamCursor& PC, const MoniTool_Msg& amsg  ,
+  (const IGESData_ParamCursor& PC, const Message_Msg& amsg  ,
    Handle(Interface_HArray1OfHAsciiString)& val,  const Standard_Integer index)
 {
   if (!PrepareRead(PC,Standard_True)) return Standard_False;
@@ -1034,7 +1034,7 @@ Standard_Boolean IGESData_ParamReader::ReadTexts
 
 Standard_Boolean IGESData_ParamReader::ReadEnts
   (const Handle(IGESData_IGESReaderData)& IR,
-   const IGESData_ParamCursor& PC, const MoniTool_Msg& amsg  ,
+   const IGESData_ParamCursor& PC, const Message_Msg& amsg  ,
    Handle(IGESData_HArray1OfIGESEntity)& val,  const Standard_Integer index)
 {
   if (!PrepareRead(PC,Standard_True)) return Standard_False;
@@ -1133,7 +1133,7 @@ Standard_Boolean IGESData_ParamReader::ReadEnts
 
 Standard_Boolean IGESData_ParamReader::ReadEntList
   (const Handle(IGESData_IGESReaderData)& IR,
-   const IGESData_ParamCursor& PC, MoniTool_Msg& amsg,
+   const IGESData_ParamCursor& PC, Message_Msg& amsg,
    Interface_EntityList& val, const Standard_Boolean ord)
 {
 
@@ -1145,19 +1145,23 @@ Standard_Boolean IGESData_ParamReader::ReadEntList
     if (!ReadingEntityNumber(i,nval)) return Standard_False;
     if (nval < 0) 
       {
-        MoniTool_Msg Msg219 ("XSTEP_219");
-        amsg.AddString(Msg219.Value());
+        Message_Msg Msg219 ("XSTEP_219");
+        amsg.Arg(Msg219.Value());
         SendWarning(amsg);
       }
     if (nval <= 0) continue;
     DeclareAndCast(IGESData_IGESEntity,anent,IR->BoundEntity(nval));
     if (anent.IsNull()) 
-       { 
-         MoniTool_Msg Msg216 ("XSTEP_216");
-         amsg.AddString(Msg216.Value());
-         SendWarning(amsg);
-       }   
-    else if (IR->DirType(nval).Type() == 0) {MoniTool_Msg Msg217 ("XSTEP_217"); SendWarning(Msg217.Value());}
+    { 
+      Message_Msg Msg216 ("XSTEP_216");
+      amsg.Arg(Msg216.Value());
+      SendWarning(amsg);
+    }   
+    else if (IR->DirType(nval).Type() == 0)
+    {
+      Message_Msg Msg217 ("XSTEP_217");
+      SendWarning(TCollection_AsciiString(Msg217.Value()).ToCString());
+    }
     else if (ord) val.Append (anent);
     else          val.Add    (anent);
   }
@@ -1384,7 +1388,7 @@ Standard_Boolean IGESData_ParamReader::ReadingEntityNumber
 //purpose  : 
 //=======================================================================
 
-void IGESData_ParamReader::SendFail (const MoniTool_Msg& amsg)
+void IGESData_ParamReader::SendFail (const Message_Msg& amsg)
 {
   thecheck->SendFail (amsg);
   thelast = Standard_False;
@@ -1396,7 +1400,7 @@ void IGESData_ParamReader::SendFail (const MoniTool_Msg& amsg)
 //purpose  : 
 //=======================================================================
 
-void IGESData_ParamReader::SendWarning (const MoniTool_Msg& amsg)
+void IGESData_ParamReader::SendWarning (const Message_Msg& amsg)
 {
   thecheck->SendWarning (amsg);
   thelast = Standard_False;
