@@ -17,7 +17,7 @@
 #include <Interface_Macros.hxx>
 
 // MGE 31/07/98
-#include <MoniTool_Msg.hxx>
+#include <Message_Msg.hxx>
 
 
 //=======================================================================
@@ -42,11 +42,11 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
   // MGE 31/07/98
   // Building of messages
   //========================================
-  MoniTool_Msg Msg100("XSTEP_100");
-  MoniTool_Msg Msg101("XSTEP_101");
-  MoniTool_Msg Msg102("XSTEP_102");
-  MoniTool_Msg Msg103("XSTEP_103");
-  MoniTool_Msg Msg159("XSTEP_159");
+  Message_Msg Msg100("XSTEP_100");
+  Message_Msg Msg101("XSTEP_101");
+  Message_Msg Msg102("XSTEP_102");
+  Message_Msg Msg103("XSTEP_103");
+  Message_Msg Msg159("XSTEP_159");
   //========================================
 
   Standard_Integer I, J;
@@ -66,7 +66,7 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
   Standard_Boolean FlagindexV = PR.ReadInteger(PR.Current(), anIndexV);
 
   if (!FlagindexU || !FlagindexV){ 
-    MoniTool_Msg Msg97("XSTEP_97");
+    Message_Msg Msg97("XSTEP_97");
     PR.SendFail(Msg97);
   }
 
@@ -75,7 +75,7 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
   Standard_Boolean FlagdegV  =  PR.ReadInteger(PR.Current(), aDegV);
 
   if (!FlagdegU || !FlagdegV){ 
-    MoniTool_Msg Msg98("XSTEP_98");
+    Message_Msg Msg98("XSTEP_98");
     PR.SendFail(Msg98);
   }
   //szv#4:S4163:12Mar99 `st=` not needed
@@ -126,7 +126,7 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
       allPoles   = new TColgp_HArray2OfXYZ   (0, anIndexU, 0, anIndexV);
 
       Standard_Boolean BadWeigth = Standard_False;
-      MoniTool_Msg Msg105("XSTEP_105");
+      Message_Msg Msg105("XSTEP_105");
 
       for (J = 0; J <= anIndexV; J ++) {
 	for (I = 0; I <= anIndexU; I ++) {
@@ -139,7 +139,7 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
             allWeights->SetValue(I, J, tempVal);
           }
 	  else{
-	    MoniTool_Msg Msg104("XSTEP_104");
+	    Message_Msg Msg104("XSTEP_104");
 	    PR.SendFail(Msg104);
 	  }
         }
@@ -168,12 +168,12 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
   PR.ReadReal(PR.Current(), Msg107, aVmax);
 */
   if (!PR.ReadReal(PR.Current(), aUmin) || !PR.ReadReal(PR.Current(), aVmin)){
-    MoniTool_Msg Msg106("XSTEP_106");
+    Message_Msg Msg106("XSTEP_106");
     PR.SendFail(Msg106);
   }
 
   if (!PR.ReadReal(PR.Current(), aUmax) || !PR.ReadReal(PR.Current(), aVmax)){
-    MoniTool_Msg Msg107("XSTEP_107");
+    Message_Msg Msg107("XSTEP_107");
     PR.SendFail(Msg107);
   }
 /*
@@ -200,7 +200,7 @@ void IGESGeom_ToolBSplineSurface::ReadOwnParams
   }
   if (pbfin > 0) PR.SendWarning(Msg159);
   if (pbfin < 0){
-    MoniTool_Msg Msg158("XSTEP_158");
+    Message_Msg Msg158("XSTEP_158");
     PR.SendFail(Msg158);
   }
   DirChecker(ent).CheckTypeAndForm(PR.CCheck(),ent);
@@ -360,9 +360,9 @@ void IGESGeom_ToolBSplineSurface::OwnCheck(const Handle(IGESGeom_BSplineSurface)
   // MGE 31/07/98
   // Building of messages
   //========================================
-  //MoniTool_Msg Msg104("XSTEP_104");
-  //MoniTool_Msg Msg160("XSTEP_160");
-  //MoniTool_Msg Msg161("XSTEP_161");
+  //Message_Msg Msg104("XSTEP_104");
+  //Message_Msg Msg160("XSTEP_160");
+  //Message_Msg Msg161("XSTEP_161");
   //========================================
 
 
@@ -407,13 +407,13 @@ void IGESGeom_ToolBSplineSurface::OwnCheck(const Handle(IGESGeom_BSplineSurface)
   Standard_Integer I,J;
 
   if (ent->NbKnotsU() != (indU + ent->DegreeU() +2)) {
-    MoniTool_Msg Msg160("XSTEP_160");
-    Msg160.AddInteger(indU + ent->DegreeU() +2);
+    Message_Msg Msg160("XSTEP_160");
+    Msg160.Arg(indU + ent->DegreeU() +2);
     ach->SendFail(Msg160);
   }
   if (ent->NbKnotsV() != (indV + ent->DegreeV() +2)) {
-    MoniTool_Msg Msg161("XSTEP_161");
-    Msg161.AddInteger(indV + ent->DegreeV() +2);
+    Message_Msg Msg161("XSTEP_161");
+    Msg161.Arg(indV + ent->DegreeV() +2);
     ach->SendFail(Msg161);
   }
 
@@ -422,7 +422,7 @@ void IGESGeom_ToolBSplineSurface::OwnCheck(const Handle(IGESGeom_BSplineSurface)
       Flag &= (ent->Weight(I,J) > 0);
 
   if (!Flag) {
-    MoniTool_Msg Msg104("XSTEP_104");
+    Message_Msg Msg104("XSTEP_104");
     ach->SendFail(Msg104);
   }
 
@@ -448,7 +448,7 @@ void IGESGeom_ToolBSplineSurface::OwnCheck(const Handle(IGESGeom_BSplineSurface)
 
 void IGESGeom_ToolBSplineSurface::OwnDump(const Handle(IGESGeom_BSplineSurface)& ent,
                                           const IGESData_IGESDumper& /* dumper */,
-                                          Standard_OStream& S,
+                                          const Handle(Message_Messenger)& S,
                                           const Standard_Integer level)  const
 {
   S << "BSplineSurface from IGESGeom" << endl << endl;
