@@ -3,11 +3,8 @@
 #include <IGESData_BasicEditor.hxx>
 #include <Interface_Check.hxx>
 
-#include <Interface_TraceFile.hxx>
 #include <Interface_Macros.hxx>
 
-
-
     IGESSelect_ComputeStatus::IGESSelect_ComputeStatus ()
     : IGESSelect_ModelModifier (Standard_False)    {  }
 
@@ -16,7 +13,6 @@
    const Handle(IGESData_IGESModel)& target,
    Interface_CopyTool& ) const
 {
-//  Standard_OStream& sout = Interface_TraceFile::Def();
   DeclareAndCast(IGESData_Protocol,protocol,ctx.Protocol());
   if (protocol.IsNull()) {
     ctx.CCheck()->AddFail("IGES Compute Status, Protocol incorrect");
