@@ -82,8 +82,9 @@
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
 // S3767
-#include <MoniTool_Msg.hxx>  
+#include <Message_Msg.hxx>  
 #include <ShapeConstruct_Curve.hxx>
+#include <gp_Hypr.hxx>
 
 //=======================================================================
 //function : CheckBSplineCurve
@@ -106,7 +107,7 @@ static Standard_Boolean checkBSplineCurve(IGESToBRep_BasicCurve*               t
       if(CWeights.Value(i) > aMaxValue) aMaxValue = CWeights.Value(i);    
     }
     if(aMaxValue - aMinValue > 1000) {
-      MoniTool_Msg msg1374("IGES_1374"); // WARNING - Difference between weights is too big.
+      Message_Msg msg1374("IGES_1374"); // WARNING - Difference between weights is too big.
       theCurve->SendWarning(theBSplineCurve, msg1374);
     }
   }
@@ -116,7 +117,7 @@ static Standard_Boolean checkBSplineCurve(IGESToBRep_BasicCurve*               t
   //check whether knots are in ascending order.
   for (Standard_Integer i = CKnots.Lower(); i < CKnots.Upper(); i++) 
     if(CKnots.Value (i+1) < CKnots.Value (i)) { 
-      MoniTool_Msg msg1373("IGES_1373"); // FAIL - Knots are not in ascending order 
+      Message_Msg msg1373("IGES_1373"); // FAIL - Knots are not in ascending order 
       theCurve->SendFail(theBSplineCurve, msg1373);
       aResult = Standard_False;
     }
@@ -178,7 +179,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBasicCurve
 { 
   Handle(Geom_Curve) res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -241,7 +242,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dBasicCurve
 { 
   Handle(Geom2d_Curve) res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -303,13 +304,13 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferConicArc
 { 
   Handle(Geom_Curve) res;
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st, msg1005);
     return res;
   }
   // If the Conic is closed, the start and end points will be ignored.
   if (!st->ComputedFormNumber()) {
-    MoniTool_Msg msg1155("IGES_1155");
+    Message_Msg msg1155("IGES_1155");
     SendFail(st, msg1155);
 //    AddFail(st, "Coefficients do not define correctly a conic.");
     return res;
@@ -366,7 +367,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferConicArc
         t2 = ElCLib::Parameter(circ, endPoint);
 	if (t1 > t2 && (t1 - t2) > Precision::Confusion()) t2 += 2.*PI;
 	if (Abs(t1 - t2) <= Precision::Confusion())  { // t1 = t2
-	  MoniTool_Msg msg1160("IGES_1160");
+	  Message_Msg msg1160("IGES_1160");
 	  SendWarning(st, msg1160);      
 	}
 	else
@@ -395,7 +396,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferConicArc
     t1 = ElCLib::Parameter(parab, startPoint);
     t2 = ElCLib::Parameter(parab, endPoint);
     if (Abs(t1 - t2) <= Precision::Confusion()) { // t1 = t2
-      MoniTool_Msg msg1160("IGES_1160");
+      Message_Msg msg1160("IGES_1160");
       SendWarning(st, msg1160);      
       //AddWarning(st, "The trim of the parabola is not correct.");
     }
@@ -423,7 +424,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferConicArc
       t2 = ElCLib::Parameter(elips, endPoint);
       if (t2 < t1 && (t1 -t2) > Precision::Confusion()) t2 += 2.*PI;
       if (Abs(t1 - t2) <= Precision::Confusion()) { // t1 = t2   
-	MoniTool_Msg msg1160("IGES_1160");
+	Message_Msg msg1160("IGES_1160");
 	SendWarning(st, msg1160);  
 	//AddWarning(st, "The trim of the ellipse is not correct, the result will be a ellipse.");
       }
@@ -431,17 +432,18 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferConicArc
 	res = new Geom_TrimmedCurve(res, t1, t2);
     }
   }
-  else {                                            // This is a hyperbola.
-    gp_Hypr   hyper(frame, majorRadius, minorRadius);
+  else {
+      
+    gp_Hypr hpr(frame, majorRadius, minorRadius);
     
-    t1 = ElCLib::Parameter(hyper, startPoint);
-    t2 = ElCLib::Parameter(hyper, endPoint);
+    t1 = ElCLib::Parameter(hpr, startPoint);
+    t2 = ElCLib::Parameter(hpr, endPoint);
       
     res = new Geom_Hyperbola(frame, majorRadius, minorRadius);
     
     //pdn taking PConfusion for parameters.
     if (Abs(t1 - t2) <= Precision::PConfusion()) { // t1 = t2   
-	MoniTool_Msg msg1160("IGES_1160");
+	Message_Msg msg1160("IGES_1160");
 	SendWarning(st, msg1160);  
       }
     else if (t1 > t2)
@@ -464,13 +466,13 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dConicArc
 { 
   Handle(Geom2d_Curve) res;
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st, msg1005);
     return res;
   }
 
  if (!st->ComputedFormNumber()) {
-    MoniTool_Msg msg1155("IGES_1155");
+    Message_Msg msg1155("IGES_1155");
     SendFail(st, msg1155);
     return res;
   }
@@ -538,7 +540,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dConicArc
 	
 	if (t2 < t1 && (t1 -t2) > Precision::PConfusion()) t2 += 2.*PI;
 	if (Abs(t1 - t2) <= Precision::PConfusion()) { // t1 = t2
-	  MoniTool_Msg msg1160("IGES_1160");
+	  Message_Msg msg1160("IGES_1160");
 	  SendWarning(st, msg1160); 
 	}
 	else 
@@ -569,7 +571,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dConicArc
     t1  = ElCLib::Parameter(parab, startPoint);
     t2  = ElCLib::Parameter(parab, endPoint);
     if (Abs(t1 - t2) <= Precision::PConfusion())  { // t1 = t2   
-	MoniTool_Msg msg1160("IGES_1160");
+	Message_Msg msg1160("IGES_1160");
 	SendWarning(st, msg1160);  
       }  
     else if (t1 > t2)
@@ -600,7 +602,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dConicArc
       t2  = ElCLib::Parameter(elips, endPoint);
       if (t2 < t1 && (t1 - t2) > Precision::PConfusion()) t2 += 2.*PI;
       if (Abs(t1 - t2) <= Precision::PConfusion())  { // t1 = t2   
-	MoniTool_Msg msg1160("IGES_1160");
+	Message_Msg msg1160("IGES_1160");
 	SendWarning(st, msg1160);  
       }
       else   
@@ -614,13 +616,13 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dConicArc
     if (st->TransformedAxis().IsOpposite (st->Axis(), GetEpsilon()))
       res->Reverse();
 
-    gp_Hypr2d hyper = Handle(Geom2d_Hyperbola)::DownCast(res)->Hypr2d();//#45 rln (frame, majorRadius, minorRadius);
+    gp_Hypr2d hpr = Handle(Geom2d_Hyperbola)::DownCast(res)->Hypr2d();//#45 rln (frame, majorRadius, minorRadius);
    
-    t1 = ElCLib::Parameter(hyper, startPoint);
-    t2 = ElCLib::Parameter(hyper, endPoint);
+    t1 = ElCLib::Parameter(hpr, startPoint);
+    t2 = ElCLib::Parameter(hpr, endPoint);
     
     if (Abs(t1 - t2) <= Precision::PConfusion())   { // t1 = t2   
-	MoniTool_Msg msg1160("IGES_1160");
+	Message_Msg msg1160("IGES_1160");
 	SendWarning(st, msg1160);  
       }
     else if (t1 > t2)
@@ -643,7 +645,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferCircularArc
 { 
   Handle(Geom_Curve) res;
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st,msg1005);
     return res;
   }
@@ -712,7 +714,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dCircularArc
 { 
   Handle(Geom2d_Curve) res;	
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st,msg1005);
     return res;
   }
@@ -723,7 +725,7 @@ Handle(Geom2d_Curve) IGESToBRep_BasicCurve::Transfer2dCircularArc
   SetEpsilon(1.E-03);
   if (!st->TransformedAxis().IsParallel /*#45 rln 23.11.98 IsEqual*/(st->Axis(), GetEpsilon())) {
     SetModeTransfer(Standard_True);          // Only not to use Trsf
-    MoniTool_Msg msg1165("IGES_1165");
+    Message_Msg msg1165("IGES_1165");
     SendWarning(st, msg1165); //"The Trsf is not compatible with a transfer2d, it will not applied."
   }
 
@@ -786,7 +788,7 @@ Handle(Geom_BSplineCurve) IGESToBRep_BasicCurve::TransferSplineCurve
 { 
   Handle(Geom_BSplineCurve) resconv;
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st,msg1005);
     return resconv;
   }
@@ -798,23 +800,23 @@ Handle(Geom_BSplineCurve) IGESToBRep_BasicCurve::TransferSplineCurve
   
   switch (result) {
   case 5 : {
-    MoniTool_Msg msg246("XSTEP_246");
+    Message_Msg msg246("XSTEP_246");
     SendFail(st, msg246);
     // less than on segment (no result produced)
     return resconv;
   }
   case 4 : {
-    MoniTool_Msg msg1170("IGES_1170");
+    Message_Msg msg1170("IGES_1170");
     SendFail(st, msg1170);
     // Polynomial equation is not correct ( no result produced
     return resconv;}
   case 3 :{
-    MoniTool_Msg msg1175("IGES_1175");
+    Message_Msg msg1175("IGES_1175");
     SendFail(st, msg1175);
     // Error during creation of control points ( no result produced)
     return resconv;}
   case 2 :{
-    MoniTool_Msg msg1180("IGES_1180");
+    Message_Msg msg1180("IGES_1180");
    SendFail(st, msg1180);
     //SplineType not processed (allowed : max 3) (no result produced)
     return resconv;}
@@ -840,7 +842,7 @@ Handle(Geom2d_BSplineCurve) IGESToBRep_BasicCurve::Transfer2dSplineCurve
 { 
   Handle(Geom2d_BSplineCurve) res;
   if (st.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(st, msg1005);
     return res;
   }
@@ -888,7 +890,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
   Handle(Geom_Curve) res;
   
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start,msg1005);
     return res;
   }
@@ -896,7 +898,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
   Standard_Integer  Degree = start->Degree();
 
   if (Degree<=0 || Degree>Geom_BSplineCurve::MaxDegree()) { 
-    MoniTool_Msg msg1190("IGES_1190");
+    Message_Msg msg1190("IGES_1190");
     SendFail(start, msg1190);
     // Improper degree either lower or equal to 0 or upper to MaxDegree
       return res;
@@ -910,7 +912,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
   Standard_Integer  newNbPoles = NbPoles;
   
   if (NbPoles<2) {
-    MoniTool_Msg msg1195("IGES_1195");
+    Message_Msg msg1195("IGES_1195");
     SendFail(start, msg1195);
     // Transfer aborted for a BSpline Curve : Number of poles lower than 2
     return res;
@@ -972,11 +974,11 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
     Standard_Integer aMult = TempMult.Value(i);
     Standard_Integer maxMult = ( i==1 || i == KnotIndex ? Degree + 1 : Degree );
     if (aMult > maxMult) {
-    MoniTool_Msg msg1200("IGES_1200");//#61 rln 05.01.99
+    Message_Msg msg1200("IGES_1200");//#61 rln 05.01.99
     const Standard_CString vide ("");
-    msg1200.AddString(vide);
-    msg1200.AddString(vide);
-    msg1200.AddString(vide);
+    msg1200.Arg(vide);
+    msg1200.Arg(vide);
+    msg1200.Arg(vide);
     SendWarning(start, msg1200);//Multiplicity > Degree (or Degree+1 at end); corrected
       for ( DelIndex = OldSumOfMult + 1; aMult > maxMult; DelIndex++, aMult-- ) {
 	newNbPoles--;
@@ -1018,10 +1020,10 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
     
 
   if (! (SumOfMult  ==  newNbPoles + Degree + 1)) {
-    MoniTool_Msg msg1210("IGES_1210");
+    Message_Msg msg1210("IGES_1210");
     const Standard_CString vide ("");
-    msg1210.AddString(vide);
-    msg1210.AddString(vide);
+    msg1210.Arg(vide);
+    msg1210.Arg(vide);
     SendWarning(start, msg1210);
     //Sum of multiplicities not equal to the sum : Count of poles + Degree + 1
   }
@@ -1046,7 +1048,7 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
       //:39 by abv 15.12.97
       Standard_Real weight = start->Weight(i);
       if ( weight < Precision::PConfusion() ) {
-	MoniTool_Msg msg1215("IGES_1215");
+	Message_Msg msg1215("IGES_1215");
 	SendFail(start, msg1215);
         // Some weights are not positive
         return res;
@@ -1055,8 +1057,8 @@ Handle(Geom_Curve) IGESToBRep_BasicCurve::TransferBSplineCurve
 //:39      PoleWeight.SetValue(WeightIndex++, start->Weight(i));
     }
     if (polynomial) {
-      MoniTool_Msg msg1220("IGES_1220");
-      msg1220.AddString("curve");
+      Message_Msg msg1220("IGES_1220");
+      msg1220.Arg("curve");
       SendWarning(start, msg1220);
       // Rational curve is polynomial
     }
@@ -1138,7 +1140,7 @@ Handle(Geom2d_Curve)  IGESToBRep_BasicCurve::Transfer2dBSplineCurve
 { 
   Handle(Geom2d_Curve)  res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -1234,7 +1236,7 @@ Handle(Geom_Curve)  IGESToBRep_BasicCurve::TransferLine
 { 
   Handle(Geom_Curve)  res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -1262,7 +1264,7 @@ Handle(Geom_Curve)  IGESToBRep_BasicCurve::TransferLine
     res = new Geom_TrimmedCurve(Gline, t1, t2);
   }
   else {
-    MoniTool_Msg msg1225("IGES_1225");
+    Message_Msg msg1225("IGES_1225");
     SendFail(start, msg1225);
     // StartPoint and EndPoint of the line are the same Point
   }
@@ -1282,7 +1284,7 @@ Handle(Geom2d_Curve)  IGESToBRep_BasicCurve::Transfer2dLine
 { 
   Handle(Geom2d_Curve) res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -1314,7 +1316,7 @@ Handle(Geom2d_Curve)  IGESToBRep_BasicCurve::Transfer2dLine
   //added by rln 18/12/97 CSR# CTS18544 entity 25168 and 31273
   //generating fail the same as above
   else { 
-    MoniTool_Msg msg1225("IGES_1225");
+    Message_Msg msg1225("IGES_1225");
     SendFail(start, msg1225); // StartPoint and EndPoint of the 2d line are the same Point
   }
   return res;
@@ -1333,7 +1335,7 @@ Handle(Geom_Transformation)  IGESToBRep_BasicCurve::TransferTransformation
 { 
   Handle(Geom_Transformation) res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
@@ -1343,7 +1345,7 @@ Handle(Geom_Transformation)  IGESToBRep_BasicCurve::TransferTransformation
       (GetEpsilon(),start->Value(),resultat) )
     res = new Geom_Transformation(resultat);
   else {
-    MoniTool_Msg msg1036("IGES_1036");
+    Message_Msg msg1036("IGES_1036");
     SendFail(start, msg1036); // Transformation : not a similarity
   } 
   return res;
@@ -1363,21 +1365,21 @@ Handle(Geom_BSplineCurve)  IGESToBRep_BasicCurve::TransferCopiousData
 { 
   Handle(Geom_BSplineCurve)  res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
   
   Standard_Integer  FormNb = start->FormNumber();
   if (!(FormNb==11 || FormNb==12 || FormNb==63)) {
-    MoniTool_Msg msg1240("IGES_1240");
+    Message_Msg msg1240("IGES_1240");
     SendWarning( start, msg1240);
     // "Copious Data : Form number is different from 11, 12 or 63 so the vector treatement is skipped");
   }
 
   Standard_Integer  NbPoints = start->NbPoints();
   if (NbPoints < 2) {
-    MoniTool_Msg msg1195("IGES_1195");
+    Message_Msg msg1195("IGES_1195");
     SendFail(start, msg1195);  // Count of points lower than 2
     return res;
   }
@@ -1415,7 +1417,7 @@ Handle(Geom_BSplineCurve)  IGESToBRep_BasicCurve::TransferCopiousData
 
   // #1 pdn 7 May 1998  BUC50028 entity 6307
   if ( NbPoints == 1) {
-    MoniTool_Msg msg1235("IGES_1235");
+    Message_Msg msg1235("IGES_1235");
     SendFail(start, msg1235);
     // The curve degenerates to a point");
     return res;
@@ -1463,21 +1465,21 @@ Handle(Geom2d_BSplineCurve) IGESToBRep_BasicCurve::Transfer2dCopiousData(const H
 { 
   Handle(Geom2d_BSplineCurve)  res;
   if (start.IsNull()) {
-    MoniTool_Msg msg1005("IGES_1005");
+    Message_Msg msg1005("IGES_1005");
     SendFail(start, msg1005);
     return res;
   }
   
   Standard_Integer  FormNb = start->FormNumber();
   if (!(FormNb==11 || FormNb==12 || FormNb==63)) {
-    MoniTool_Msg msg1240("IGES_1240");
+    Message_Msg msg1240("IGES_1240");
     SendWarning( start, msg1240);
     // "Copious Data : Form number is different from 11, 12 or 63 so the vector treatement is skipped");
   }
   
   Standard_Integer  NbPoints = start->NbPoints();
   if (NbPoints < 2) {
-    MoniTool_Msg msg1195("IGES_1195");
+    Message_Msg msg1195("IGES_1195");
     SendFail(start, msg1195);  // Count of points lower than 2
     return res;
   }
@@ -1515,7 +1517,7 @@ Handle(Geom2d_BSplineCurve) IGESToBRep_BasicCurve::Transfer2dCopiousData(const H
   NbPoints = TempIndex - TempPole.Lower();
   //added by rln on 26/12/97 to avoid exception when creating Bspline from one point
   if (NbPoints == 1) {
-    MoniTool_Msg msg1235("IGES_1235");
+    Message_Msg msg1235("IGES_1235");
     SendFail(start, msg1235);
     // The curve degenerates to a point");
     return res;
