@@ -17,7 +17,7 @@
 #include <BRepTools_Modifier.hxx>
 
 #include <Message_Msg.hxx>
-#include <Message_TraceFile.hxx>
+#include <Message_Messenger.hxx>
 
 #include <IGESFile_Read.hxx>
 #include <IGESData_FileProtocol.hxx>
@@ -79,6 +79,7 @@ static Handle(IGESData_FileProtocol) protocol;
     protocol->Add(IGESSolid::Protocol());
   }
   theActor = new IGESToBRep_Actor;
+  theProc = new Transfer_TransientProcess;
 }
 
 
@@ -89,25 +90,28 @@ static Handle(IGESData_FileProtocol) protocol;
 
 Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
 { 
-  Handle(Message_TraceFile) TF = Message_TraceFile::Default();
+  if ( theProc.IsNull() )
+    theProc = new Transfer_TransientProcess;
+  Handle(Message_Messenger) TF = theProc->Messenger();
   
   // Message for Diagnostic file.
   Message_Msg msg2000("IGES_2000");   
-  msg2000.AddString(filename);
-  TF->SendEver (msg2000);
+  msg2000.Arg(filename);
+  TF->Send (msg2000, Message_Info);
   //Message_Msg msg2001("IGES_2001");   // Date
   Message_Msg msg2005("IGES_2005");
-  msg2005.AddInteger(Message_TraceFile::DefLevel());
-  TF->SendEver (msg2005);
+  msg2005.Arg(theProc->TraceLevel());
+  TF->Send (msg2005, Message_Info);
   /////////////////////////////////////////////////////////
   Handle(IGESData_IGESModel) model = new IGESData_IGESModel;
 
   OSD_Timer c; c.Reset(); c.Start();    
-  Standard_Integer StatusFile = IGESFile_Read(filename,model,protocol);
+  char *pfilename=(char *)filename;
+  Standard_Integer StatusFile = IGESFile_Read(pfilename,model,protocol);
   if (StatusFile != 0) {
     // Sending of message : IGES file opening error 
     Message_Msg Msg2("XSTEP_2");
-    TF->SendEver (Msg2);
+    TF->Send (Msg2, Message_Info);
     //Message_Msg Msg3("XSTEP_3");
     //Message_Msg Msg4("XSTEP_4");
     //Message_Msg Msg5("XSTEP_5");
@@ -119,31 +123,31 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
       case 2  : // Sending of message : No such file or directory
         {
           Message_Msg Msg3("XSTEP_3");
-          TF->SendEver (Msg3);
+          TF->Send (Msg3, Message_Info);
         }
 	break;
       case 12 : // Sending of message : Not enough space
         {
           Message_Msg Msg4("XSTEP_4");
-          TF->SendEver (Msg4);
+          TF->Send (Msg4, Message_Info);
         }
 	break;
       case 13 : // Sending of message : Permission Denied
         {
           Message_Msg Msg5("XSTEP_5");
-          TF->SendEver (Msg5);
+          TF->Send (Msg5, Message_Info);
         }
 	break;
       case 24 : // Sending of message : Too many open files
         {
           Message_Msg Msg6("XSTEP_6");
-          TF->SendEver (Msg6);
+          TF->Send (Msg6, Message_Info);
         }
 	break;
       default : // Sending of message : No determined
         {
           Message_Msg Msg7("XSTEP_7");
-          TF->SendEver (Msg7);
+          TF->Send (Msg7, Message_Info);
         }
 	break;
       }
@@ -164,10 +168,10 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
     nbFail += ach->NbFails();
   }
 // Messages nbWarn and nbFail;
-  Msg25.AddInteger(nbFail);
-  Msg26.AddInteger(nbWarn);
-  TF->SendEver (Msg25);
-  TF->SendEver (Msg26);
+  Msg25.Arg(nbFail);
+  Msg26.Arg(nbWarn);
+  TF->Send (Msg25, Message_Info);
+  TF->Send (Msg26, Message_Info);
   
   // Message fin de loading iGES file (elapsed time %s)
   char t[20];
@@ -182,8 +186,8 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
   else
     sprintf(t,"%.2fs",second);
   // Sending of message : End of Loading
-  Msg8.AddString(t);
-  TF->SendEver (Msg8);
+  Msg8.Arg(t);
+  TF->Send (Msg8, Message_Info);
   
   SetModel(model);
   return StatusFile;
@@ -199,7 +203,10 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
   theModel = model;
   theDone  = Standard_False;
   theShapes.Clear();
-  theProc = new Transfer_TransientProcess (theModel->NbEntities());
+  if ( theProc.IsNull() )
+    theProc = new Transfer_TransientProcess (theModel->NbEntities());
+  else 
+    theProc->Clear();
 }
 
 
@@ -254,7 +261,8 @@ Standard_Integer IGESToBRep_Reader::LoadFile (const Standard_CString filename)
 {
   Interface_CheckTool cht (theModel,protocol);
   Interface_CheckIterator chl = cht.CompleteCheckList();
-  if (withprint) cht.Print(chl,Message_TraceFile::Def() );
+  if (withprint && !theProc.IsNull()) 
+    cht.Print(chl, theProc->Messenger());
   return chl.IsEmpty(Standard_True);
 }
 
@@ -348,20 +356,21 @@ static void TrimTolerances (const TopoDS_Shape& shape,
 //function : TransferRoots
 //purpose  : Transfers all Roots Entities
 //=======================================================================
-    void  IGESToBRep_Reader::TransferRoots (const Standard_Boolean onlyvisible)
+void  IGESToBRep_Reader::TransferRoots (const Standard_Boolean onlyvisible)
 {
-  Handle(Message_TraceFile) TF = Message_TraceFile::Default();
+  if (theModel.IsNull() || theProc.IsNull()) return;
+
+  Handle(Message_Messenger) TF = theProc->Messenger();
   // Declaration of messages.
   Message_Msg msg2030("IGES_2030");
-  TF->SendEver (msg2030);
+  TF->Send (msg2030, Message_Info);
   Message_Msg msg2065("IGES_2065");
   OSD_Timer c; c.Reset(); c.Start();   // Initialisation du CHRONO
   theDone = Standard_False;
   theShapes.Clear();
-  if (theModel.IsNull()) return;
   
-  Standard_Integer level = Message_TraceFile::DefLevel();
-  theProc->SetErrorHandle(Standard_True,level);
+  Standard_Integer level = theProc->TraceLevel();
+  theProc->SetErrorHandle(Standard_True);
   theProc->SetRootManagement(Standard_True);
 //  PrepareTransfer();  -> protocol, actor
   theActor->SetModel(theModel);
@@ -378,19 +387,19 @@ static void TrimTolerances (const TopoDS_Shape& shape,
   
   Standard_Integer precisionMode = Interface_Static::IVal("read.precision.mode");
   Message_Msg msg2035("IGES_2035");
-  msg2035.AddInteger(precisionMode);
-  TF->SendEver (msg2035);
+  msg2035.Arg(precisionMode);
+  TF->Send (msg2035, Message_Info);
   if (precisionMode==1) {
     Message_Msg msg2040("IGES_2040");
-    msg2040.AddReal(Interface_Static::RVal("read.precision.val"));//#70 rln 03.03.99
-    TF->SendEver (msg2040);
+    msg2040.Arg(Interface_Static::RVal("read.precision.val"));//#70 rln 03.03.99
+    TF->Send (msg2040, Message_Info);
   }
   Message_Msg msg2045("IGES_2045");
-  msg2045.AddInteger(continuity);
-  TF->SendEver (msg2045);
+  msg2045.Arg(continuity);
+  TF->Send (msg2045, Message_Info);
   Message_Msg msg2050("IGES_2050");
-  msg2050.AddInteger(Interface_Static::IVal("read.surfacecurve.mode"));
-  TF->SendEver (msg2050);
+  msg2050.Arg(Interface_Static::IVal("read.surfacecurve.mode"));
+  TF->Send (msg2050, Message_Info);
 
   // sln 11.06.2002 OCC448
   Interface_Static::SetIVal("read.iges.onlyvisible",onlyvisible);
@@ -401,9 +410,9 @@ static void TrimTolerances (const TopoDS_Shape& shape,
     if ( SH.IsShared(ent) || ! theActor->Recognize (ent) ) continue;
     if (level > 0) {
       Message_Msg msg2070("IGES_2070");
-      msg2070.AddInteger(2*i-1);
-      msg2070.AddInteger(ent->TypeNumber());
-      TF->SendEver (msg2070);
+      msg2070.Arg(2*i-1);
+      msg2070.Arg(ent->TypeNumber());
+      TF->Send (msg2070, Message_Info);
     }
     // on ajoute un traitement pour ne prendre que les entites visibles
     if ( ! onlyvisible || ent->BlankStatus() == 0 ) {
@@ -416,12 +425,12 @@ static void TrimTolerances (const TopoDS_Shape& shape,
       } 
       catch(Standard_Failure) {
         Message_Msg msg1005("IGES_1005");
-        TF->SendEver (msg1005);
+        TF->Send (msg1005, Message_Info);
         continue;
       }
       if (shape.IsNull()) {
         Message_Msg msg2076("IGES_2076");
-        TF->SendEver (msg2076);
+        TF->Send (msg2076, Message_Info);
       }
       else {
         if (SBE.ShapeType(shape,Standard_True) != TopAbs_SHAPE) {
@@ -447,8 +456,8 @@ static void TrimTolerances (const TopoDS_Shape& shape,
   else
     sprintf(t,"%.2fs",second);
   // Sending of message : End of Loading
-  msg2065.AddString(t);
-  TF->SendEver (msg2065);
+  msg2065.Arg(t);
+  TF->Send (msg2065, Message_Info);
 }
 
 
@@ -458,22 +467,22 @@ static void TrimTolerances (const TopoDS_Shape& shape,
 //=======================================================================
 Standard_Boolean  IGESToBRep_Reader::Transfer(const Standard_Integer num)
 { 
-  Handle(Message_TraceFile) TF = Message_TraceFile::Default();
+  Handle(Message_Messenger) TF = theProc->Messenger();
   theDone = Standard_False;
   if (theModel.IsNull()) {
     Message_Msg msg2031("IGES_2031");
-    TF->SendEver (msg2031);
+    TF->Send (msg2031, Message_Info);
     return Standard_False;
   }
   if (num <= 0 || num > theModel->NbEntities()) {
     Message_Msg msg2032("IGES_2032");
-    msg2032.AddInteger(num);
-    TF->SendEver (msg2032);
+    msg2032.Arg(num);
+    TF->Send (msg2032, Message_Info);
     return Standard_False;
   }
   // declaration of messages
   Message_Msg msg2030("IGES_2030");
-  TF->SendEver (msg2030);
+  TF->Send (msg2030, Message_Info);
   Message_Msg msg2065("IGES_2065");
   OSD_Timer c; c.Reset(); c.Start();   // Initialisation du CHRONO
   
@@ -487,29 +496,29 @@ Standard_Boolean  IGESToBRep_Reader::Transfer(const Standard_Integer num)
   Standard_Real eps;
   Standard_Integer Ival = Interface_Static::IVal("read.precision.mode");
   Message_Msg msg2035("IGES_2035");
-  msg2035.AddInteger(Ival);
-  TF->SendEver (msg2035);
+  msg2035.Arg(Ival);
+  TF->Send (msg2035, Message_Info);
   if ( Ival == 0)
     eps = theModel->GlobalSection().Resolution();
   else {
     //mjm : modif du 19/12/97 pour prise en compte effective du parametre
     eps = Interface_Static::RVal("read.precision.val");
     Message_Msg msg2040("IGES_2040");
-    msg2040.AddReal(eps);//#70 rln 03.03.99
-    TF->SendEver (msg2040);
+    msg2040.Arg(eps);//#70 rln 03.03.99
+    TF->Send (msg2040, Message_Info);
     
   }
   Ival = Interface_Static::IVal("read.iges.bspline.approxd1.mode");
   CAS.SetModeApprox ( (Ival > 0) );
   Message_Msg msg2045("IGES_2045");
   Ival = Interface_Static::IVal("read.iges.bspline.continuity");
-  msg2045.AddInteger(Ival);
-  TF->SendEver (msg2045);
+  msg2045.Arg(Ival);
+  TF->Send (msg2045, Message_Info);
   CAS.SetContinuity(Ival);
   Message_Msg msg2050("IGES_2050");
   Ival = Interface_Static::IVal("read.surfacecurve.mode");
-  msg2050.AddInteger(Ival);
-  TF->SendEver (msg2050);
+  msg2050.Arg(Ival);
+  TF->Send (msg2050, Message_Info);
   CAS.SetSurfaceCurve (Ival);
 
   if (eps > 1.E-08) CAS.SetEpsGeom(eps);
@@ -525,7 +534,7 @@ Standard_Boolean  IGESToBRep_Reader::Transfer(const Standard_Integer num)
     } 
     catch(Standard_Failure) {
       Message_Msg msg1015("IGES_1015");
-      TF->SendEver (msg1015);
+      TF->Send (msg1015, Message_Info);
       exceptionRaised = Standard_True;
     }
   }
@@ -567,8 +576,8 @@ Standard_Boolean  IGESToBRep_Reader::Transfer(const Standard_Integer num)
   else
     sprintf(t,"%.2fs",second);
   // Sending of message : End of Loading
-  msg2065.AddString(t);
-  TF->SendEver (msg2065);
+  msg2065.Arg(t);
+  TF->Send (msg2065, Message_Info);
   return Standard_True;
 }
 
