@@ -90,7 +90,7 @@
 //#include <TColStd_HSequenceOfTransient.hxx>
 #include <ShapeBuild_Edge.hxx>
 #include <IGESToBRep_IGESBoundary.hxx>
-#include <MoniTool_Msg.hxx>
+#include <Message_Msg.hxx>
 #include <TCollection_HAsciiString.hxx>
 #include <IGESData_IGESModel.hxx>  
 #include <ShapeAlgo.hxx>
@@ -164,7 +164,7 @@ TopoDS_Vertex  IGESToBRep_TopoCurve::TransferPoint
 {
   TopoDS_Vertex  V1;
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005");
+    Message_Msg Msg1005("IGES_1005");
     SendFail(start, Msg1005); //"Point Transfer Error : Null IGESEntity"
     //AddFail(start, "Point Transfer Error : Null IGESEntity");
     return  V1;
@@ -206,7 +206,7 @@ TopoDS_Vertex  IGESToBRep_TopoCurve::Transfer2dPoint
 {
   TopoDS_Vertex V1;
   if (start.IsNull()) {
-     MoniTool_Msg Msg1005("IGES_1005");//"2D Point Transfer Error : Null IGESEntity"
+     Message_Msg Msg1005("IGES_1005");//"2D Point Transfer Error : Null IGESEntity"
      SendFail(start, Msg1005);
    // AddFail(start, "2D Point Transfer Error : Null IGESEntity");
     return  V1;
@@ -244,7 +244,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCompositeCurveGeneral(const Handle(I
   TopoDS_Shape  res;
 
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"CompositeCurve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"CompositeCurve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     // AddFail(start, "CompositeCurve Transfer Error : Null IGESEntity");
     return  res;
@@ -263,16 +263,16 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCompositeCurveGeneral(const Handle(I
     //added by rln 26/12/97 CSR# UKI60028 entity 3117
     if (i > 1 && IgesEnt == start->Curve (i-1)) {
 //      char mess[80];
-      MoniTool_Msg Msg1045("IGES_1045"); //"The entities of the CompositeCurve are the same: %d & %d"
-      Msg1045.AddInteger(i);
+      Message_Msg Msg1045("IGES_1045"); //"The entities of the CompositeCurve are the same: %d & %d"
+      Msg1045.Arg(i);
       SendWarning(start,Msg1045);
       //sprintf (mess, "The entities of the CompositeCurve are the same: %d & %d", i-1, i);
       //AddWarning (start, mess);
       continue;
     }
     if (IgesEnt.IsNull()) {
-      MoniTool_Msg Msg1040("IGES_1040");//"Curve%dd is a null object : number %d"
-      Msg1040.AddInteger(i); 
+      Message_Msg Msg1040("IGES_1040");//"Curve%dd is a null object : number %d"
+      Msg1040.Arg(i); 
       SendFail(start,Msg1040);
       return res;
     }
@@ -280,8 +280,8 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCompositeCurveGeneral(const Handle(I
     if (is2d && (IgesEnt->IsKind(STANDARD_TYPE(IGESGeom_Boundary)) ||
 		 IgesEnt->IsKind(STANDARD_TYPE(IGESGeom_CurveOnSurface)) ) ) {
       //AddWarning(start, "Entity cannot be built from a boundary.");
-      MoniTool_Msg Msg1040("IGES_1040");//"Entity cannot be built from a boundary."
-      Msg1040.AddInteger(i); 
+      Message_Msg Msg1040("IGES_1040");//"Entity cannot be built from a boundary."
+      Msg1040.Arg(i); 
       SendFail(start,Msg1040);
       return res;
     }
@@ -300,31 +300,31 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCompositeCurveGeneral(const Handle(I
 										    revsewd, revnextsewd);
 	if (isConnected) {
 	  if (revsewd) {
-	    MoniTool_Msg Msg1051("IGES_1051");   //"All curvAll curves %dd before rank %d have been to be reversed."
-	    Msg1051.AddInteger((is2d ? 2 : 3));
-	    Msg1051.AddInteger(i);
+	    Message_Msg Msg1051("IGES_1051");   //"All curvAll curves %dd before rank %d have been to be reversed."
+	    Msg1051.Arg((is2d ? 2 : 3));
+	    Msg1051.Arg(i);
 	    SendWarning(start,Msg1051);
 	  }
 	  if (revnextsewd) {
-	    MoniTool_Msg Msg1050("IGES_1050");   //"Curve %dd needs to be reversed : %d"
-	    Msg1050.AddInteger((is2d ? 2 : 3));
-	    Msg1050.AddInteger(i);
+	    Message_Msg Msg1050("IGES_1050");   //"Curve %dd needs to be reversed : %d"
+	    Msg1050.Arg((is2d ? 2 : 3));
+	    Msg1050.Arg(i);
 	    SendWarning(start,Msg1050);
 	    
 	    //  sprintf(mess, "Curve %dd needs to be reversed : %d", ( is2d ? 2 : 3 ), i);//:13
 	  //  AddWarning(start, mess);
 	  }
 	  if (distmin > precision) {
-	    MoniTool_Msg Msg1055("IGES_1055");   
-	    Msg1055.AddInteger((is2d ? 2 : 3));
-	    Msg1055.AddInteger(i);
+	    Message_Msg Msg1055("IGES_1055");   
+	    Msg1055.Arg((is2d ? 2 : 3));
+	    Msg1055.Arg(i);
 	    SendWarning(start,Msg1055);
 	  }
 	}
 	else {
-	  MoniTool_Msg Msg1060("IGES_1060");   //"Curves %dd are too much disconnected : %d & %d"
-	  Msg1060.AddInteger((is2d ? 2 : 3));
-	  Msg1060.AddInteger(i);
+	  Message_Msg Msg1060("IGES_1060");   //"Curves %dd are too much disconnected : %d & %d"
+	  Msg1060.Arg((is2d ? 2 : 3));
+	  Msg1060.Arg(i);
 	  SendFail(start,Msg1060);
 	  return res;
 	}
@@ -366,7 +366,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCompositeCurve
       res.Move(L);
     }
     else {
-      MoniTool_Msg Msg1035("IGES_1035");
+      Message_Msg Msg1035("IGES_1035");
       SendWarning(start,Msg1035);
     }
       //  AddWarning(start, "Transformation skipped (not a similarity)");
@@ -390,7 +390,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dCompositeCurve
   res = TransferCompositeCurveGeneral ( start, Standard_True, face, trans, uFact);
   // Message occur if needed in TransferCompositeCurveGeneral
   //if (start->HasTransf()) {
-  //  MoniTool_Msg Msg1036("IGES_1036"); //"The Trsf cannot be applied to the entity."
+  //  Message_Msg Msg1036("IGES_1036"); //"The Trsf cannot be applied to the entity."
   //  SendWarning(start,Msg1036);
   // AddWarning(start, "The Trsf cannot be applied to the entity.");
   //}
@@ -408,7 +408,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
   TopoDS_Shape  res;
   
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005");
+    Message_Msg Msg1005("IGES_1005");
     SendFail(start,Msg1005);
     //  AddFail(start, "CurveOnSurface Transfer Error : Null IGESEntity");
     return  res;
@@ -417,7 +417,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
   TopoDS_Face  face;
   Handle (IGESData_IGESEntity) igesSurface = start->Surface();
   if (igesSurface.IsNull() || !IGESToBRep::IsTopoSurface(igesSurface)) {
-    MoniTool_Msg Msg131("XSTEP_131");  //"BasicSurface Transfer Error : Null IGESEntity"
+    Message_Msg Msg131("XSTEP_131");  //"BasicSurface Transfer Error : Null IGESEntity"
     SendFail(start,Msg131);
     //AddFail(start, "BasicSurface Transfer Error : Null IGESEntity");
     return res;
@@ -450,7 +450,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
 	    if (IGESToBRep::IsTopoCurve(start->Curve3D())) {
 	      TopoDS_Shape  Sh = TransferTopoCurve(start->Curve3D());
 	      if (!Sh.IsNull()) {
-		MoniTool_Msg Msg1062("IGES_1062");
+		Message_Msg Msg1062("IGES_1062");
      //CurveOnSurface on Composite Surface case not implemented : 3D representation returned.
 		SendWarning(start,Msg1062);
 		res = Sh;
@@ -458,8 +458,8 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
 	    }
 	  }
 	  else {
-	    MoniTool_Msg Msg1061("IGES_1061"); 
-	    Msg1061.AddString("CurveOnSurface");
+	    Message_Msg Msg1061("IGES_1061"); 
+	    Msg1061.Arg("CurveOnSurface");
 	    SendFail(start,Msg1061);
 	  }
 	  return res;
@@ -472,7 +472,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
 	  if (IGESToBRep::IsTopoCurve(start->Curve3D())) {
 	    TopoDS_Shape  Sh = TransferTopoCurve(start->Curve3D());
 	    if (!Sh.IsNull()) {
-	      MoniTool_Msg Msg1062("IGES_1062"); //"Basis Surface Error : 3dCurve returned"
+	      Message_Msg Msg1062("IGES_1062"); //"Basis Surface Error : 3dCurve returned"
 	      SendWarning(start,Msg1062);
 	      //   AddWarning(start,"Basis Surface Error : 3dCurve returned");
 	      res = Sh;
@@ -480,8 +480,8 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferCurveOnSurface
 	  }
 	}
 	else {
-	  MoniTool_Msg Msg1061("IGES_1061"); 
-	  Msg1061.AddString("CurveOnSurface");
+	  Message_Msg Msg1061("IGES_1061"); 
+	  Msg1061.Arg("CurveOnSurface");
 	  SendFail(start,Msg1061);
 	}
 	//  AddFail(start, "Basis Surface Error.");
@@ -509,7 +509,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferCurveOnFace(TopoDS_Face&  face,
 {
   TopoDS_Shape  res;
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"CurveOnFace Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"CurveOnFace Transfer Error : Null IGESEntity"
     SendFail(start,Msg1005);
     return res;
   }
@@ -529,7 +529,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferCurveOnFace(TopoDS_Face&  face,
   IB->Check(Result, !isCurveOnSurf, okCurve3d, okCurve2d);
   Handle(ShapeExtend_WireData) sewd = IB->WireData();
   if (sewd->NbEdges() == 0) {
-      MoniTool_Msg Msg1095("IGES_1095");//"Both 2d and 3d representations are invalid"
+      Message_Msg Msg1095("IGES_1095");//"Both 2d and 3d representations are invalid"
       SendFail(start,Msg1095);
     return res;
   }
@@ -547,7 +547,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferCurveOnFace(TopoDS_Face&  face,
       mywire.Move(L);
     }
     else {
-      MoniTool_Msg Msg1035("IGES_1035"); //"Transformation skipped (not a similarity)"
+      Message_Msg Msg1035("IGES_1035"); //"Transformation skipped (not a similarity)"
       SendWarning(start,Msg1035);
     }
   }
@@ -572,13 +572,13 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
   TopoDS_Shape  res;
 
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"Offset Curve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"Offset Curve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //AddFail(start, "OffsetCurve Transfer Error : Null IGESEntity");
     return  res;
   }
   if (!start->OffsetType()==1) {
-    MoniTool_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
+    Message_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
     SendFail(start,Msg1100);
     //AddFail(start, "Offset distance flag different from 1 not treated");
     return  res;
@@ -598,7 +598,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
   while (BaseCrv->IsKind(STANDARD_TYPE(IGESGeom_OffsetCurve))) {
     DeclareAndCast(IGESGeom_OffsetCurve, OffCrv, BaseCrv);
     if (!OffCrv->OffsetType()==1) {
-       MoniTool_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
+       Message_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
        SendFail(start,Msg1100);
        return  res;
     }
@@ -608,7 +608,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
 
 
   if (!IGESToBRep::IsTopoCurve(BaseCrv)) {
-   MoniTool_Msg Msg110("XSTEP_110");
+   Message_Msg Msg110("XSTEP_110");
    SendFail(start,Msg110);
    return res;
  }
@@ -620,10 +620,10 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
   TopoDS_Shape  Sh = TC.TransferTopoCurve(BaseCrv);
   
   if (Sh.IsNull() || ! ((Sh.ShapeType() == TopAbs_EDGE) || (Sh.ShapeType() == TopAbs_WIRE)) ) {
-    MoniTool_Msg Msg1156("IGES_1156");
+    Message_Msg Msg1156("IGES_1156");
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(BaseCrv);
-    Msg1156.AddString("basis curve");
-    Msg1156.AddString(label);
+    Msg1156.Arg("basis curve");
+    Msg1156.Arg(label);
     SendFail(start,Msg1156);
     //AddFail(start, "Edge or wire expected from TransferTopoCurve");
     return res;
@@ -637,7 +637,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
     BRepBuilderAPI_MakeEdge  ME(OffCrv,start->StartParameter(),start->EndParameter());
     if (!ME.IsDone()) {
       
-      MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+      Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
       SendFail(start,Msg1005);
       //AddFail(start, "Edge construction error");
       return  res;
@@ -663,7 +663,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
       if ((length + last - first) <= staPar) continue;
       if (length >= endPar) {
 	if (begin) {
-	   MoniTool_Msg Msg1105("IGES_1105"); //"Cannot build a ruled surface from these curves."
+	   Message_Msg Msg1105("IGES_1105"); //"Cannot build a ruled surface from these curves."
 	   SendFail(start,Msg1105);
 	  //AddFail(start, "Cannot build a ruled surface from these curves.");
 	  return  res;
@@ -674,7 +674,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
       BRepBuilderAPI_MakeEdge  ME(OffCrv, staPar - length, endPar - length);
 	
       if (!ME.IsDone()) {
-	 MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+	 Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
 	 SendFail(start,Msg1005);
 	//AddFail(start, "Edge construction error");
 	return  res;
@@ -702,7 +702,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferOffsetCurve
       res.Move(L);
     }
     else {
-      MoniTool_Msg Msg1035("IGES_1035");
+      Message_Msg Msg1035("IGES_1035");
       SendWarning(start,Msg1035);
     }
       //AddWarning(start, "Transformation skipped (not a similarity)");
@@ -728,14 +728,14 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dOffsetCurve
 {
   TopoDS_Shape  res;
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"Offset Curve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"Offset Curve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //AddFail(start, "2D OffsetCurve Transfer Error : Null IGESEntity");
     return  res;
   }
 
   if (!start->OffsetType()==1) {
-    MoniTool_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
+    Message_Msg Msg1100("IGES_1100"); //"Offset distance flag different from 1 not treated"
     SendFail(start,Msg1100);
   }
    // AddWarning(start, "Offset distance flag different from 1 not properly treated");
@@ -751,10 +751,10 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dOffsetCurve
     TC.SetModeTransfer(Standard_False);
     TopoDS_Shape  Sh = TC.Transfer2dTopoCurve(BaseCrv, face, trans, uFact);
     if (Sh.IsNull() || !( (Sh.ShapeType()==TopAbs_EDGE) ||(Sh.ShapeType()==TopAbs_WIRE)) ) {
-      MoniTool_Msg Msg1156("IGES_1156"); //"Edge or wire expected from TransferTopoCurve"
+      Message_Msg Msg1156("IGES_1156"); //"Edge or wire expected from TransferTopoCurve"
       Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(BaseCrv);
-      Msg1156.AddString("2D basis curve");
-      Msg1156.AddString(label);
+      Msg1156.Arg("2D basis curve");
+      Msg1156.Arg(label);
       SendFail(start,Msg1156);
       return  res;
     }
@@ -768,7 +768,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dOffsetCurve
       TopoDS_Edge  anEdge;
       ShapeBuild_Edge().MakeEdge (anEdge, OffCrv, face, start->StartParameter(), start->EndParameter());
       if (anEdge.IsNull()/*!ME.IsDone()*/) {
-	MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+	Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
 	SendFail(start,Msg1005);
 	return  res;
       }
@@ -787,7 +787,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dOffsetCurve
 	TopoDS_Edge  anotherEdge;
 	ShapeBuild_Edge().MakeEdge (anotherEdge, OffCrv, face, start->StartParameter(), start->EndParameter());
 	if (anotherEdge.IsNull()/*!ME.IsDone()*/) {
-	  MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+	  Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
 	  SendFail(start,Msg1005);
 	  return  res;
 	}
@@ -816,7 +816,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoCurve
   TopoDS_Shape  res;
   
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"TopoCurve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"TopoCurve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //AddFail(start, "TopoCurve Transfer Error : Null IGESEntity");
     return  res;
@@ -866,7 +866,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoCurve(const Handle(IGESData_IG
   TopoDS_Shape  res;
 
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"2d TopoCurve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"2d TopoCurve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //    AddFail(start, "2D TopoCurve Transfer Error : Null IGESEntity");
     return  res;
@@ -904,7 +904,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
 //  TopoDS_Vertex V1,V2;
 
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"TopoBasicCurve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"TopoBasicCurve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //AddFail(start, "TopoBasicCurve Transfer Error : Null IGESEntity");
     return  myshape;
@@ -939,10 +939,10 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
   // on construit un wire avec des morceaux de courbes C1.
   Standard_Integer nbcurves = NbCurves();
   if ( nbcurves == 0 ) {
-    MoniTool_Msg Msg1156("IGES_1156"); //"TopoBasicCurve Transfer Error : Null Entity"
+    Message_Msg Msg1156("IGES_1156"); //"TopoBasicCurve Transfer Error : Null Entity"
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(start);
-    Msg1156.AddString("Geom_Curve");
-    Msg1156.AddString(label);
+    Msg1156.Arg("Geom_Curve");
+    Msg1156.Arg(label);
     SendFail(start,Msg1156);
     return  myshape;
   }
@@ -964,7 +964,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
       for (Standard_Integer i = 1; i <= NbC0; i++) {
 	BRepBuilderAPI_MakeEdge ME (seqBS->Value (i));
 	if (!ME.IsDone()) {
-	  MoniTool_Msg Msg1005("IGES_1005");
+	  Message_Msg Msg1005("IGES_1005");
 	  SendFail(start,Msg1005);
 	  //  AddFail(start, "Edge construction error");
 	  return myshape;
@@ -981,7 +981,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
       }
       BRepBuilderAPI_MakeEdge ME (mycurve, a, b);
       if (!ME.IsDone() || (Precision::IsInfinite(a) || Precision::IsInfinite(b))) {
-	MoniTool_Msg Msg1005("IGES_1005");
+	Message_Msg Msg1005("IGES_1005");
 	SendFail(start,Msg1005);
 	//AddFail(start, "Edge construction error");
 	return  myshape;
@@ -1014,7 +1014,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
       myshape.Move(L);
     }
     else {
-      MoniTool_Msg Msg1035("IGES_1035");
+      Message_Msg Msg1035("IGES_1035");
       SendWarning(start,Msg1035);
     }
     //AddWarning(start, "Transformation skipped (not a similarity)");
@@ -1025,7 +1025,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferTopoBasicCurve
   
   if (sewd->NbEdges() != 1) {
     //S4054    TheBadCase = Standard_True; //:27
-    MoniTool_Msg Msg1120("IGES_1120");// "Wire not always implemented."
+    Message_Msg Msg1120("IGES_1120");// "Wire not always implemented."
     SendWarning(start,Msg1120);
     //    AddWarning(start, "Wire not always implemented.");
     return myshape;
@@ -1060,7 +1060,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoBasicCurve
   TopoDS_Shape myshape;
 
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"2D TopoBasicCurve Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"2D TopoBasicCurve Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //    AddFail(start, "2D TopoBasicCurve Transfer Error : Null IGESEntity");
     return  edge;
@@ -1099,10 +1099,10 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoBasicCurve
   // on construit un wire avec des morceaux de courbes C1.
   Standard_Integer nbcurves = NbCurves2d();
   if ( nbcurves == 0 ) {
-    MoniTool_Msg Msg1156("IGES_1156"); //"2dTopoBasicCurve Transfer Error : Null Entity"
+    Message_Msg Msg1156("IGES_1156"); //"2dTopoBasicCurve Transfer Error : Null Entity"
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(start);
-    Msg1156.AddString("Geom2d_Curve");
-    Msg1156.AddString(label);
+    Msg1156.Arg("Geom2d_Curve");
+    Msg1156.Arg(label);
     SendFail(start,Msg1156);
     //AddFail(start, "2dTopoBasicCurve Transfer Error : Null Entity");
     return  myshape;
@@ -1156,7 +1156,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoBasicCurve
 	ShapeBuild_Edge().MakeEdge (myedge, seqBS->Value (i), face);
 //	BRepBuilderAPI_MakeEdge ME (seqBS->Value (i), mysurf);
 	if (myedge.IsNull()/*!ME.IsDone()*/) {
-	  MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+	  Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
 	  SendFail(start,Msg1005);
 	  //AddFail(start, "Edge construction error");
 	  return myshape;
@@ -1175,7 +1175,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoBasicCurve
       ShapeBuild_Edge().MakeEdge (myedge, mycurve2d, face, a, b);
 //      BRepBuilderAPI_MakeEdge ME (mycurve2d, mysurf);
       if (myedge.IsNull()/*!ME.IsDone()*/) {
-	MoniTool_Msg Msg1005("IGES_1005"); //"Edge construction error"
+	Message_Msg Msg1005("IGES_1005"); //"Edge construction error"
 	SendFail(start,Msg1005);
 	return myshape;
       }
@@ -1203,7 +1203,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::Transfer2dTopoBasicCurve
 
   if (sewd->NbEdges() != 1) {
     //S4054 TheBadCase = Standard_True; //:27
-    MoniTool_Msg Msg1120("IGES_1120");// "Wire not always implemented."
+    Message_Msg Msg1120("IGES_1120");// "Wire not always implemented."
     SendWarning(start,Msg1120);
 //    AddWarning(start, "Wire not always implemented.");
     return myshape;
@@ -1228,14 +1228,14 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferBoundary
 {  
   TopoDS_Shape  res;
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"Boundary Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"Boundary Transfer Error : Null IGESEntity"
     SendFail(start, Msg1005);
     //AddFail(start, "Boundary Transfer Error : Null IGESEntity");
     return  res;
   }
 
   if (start->BoundaryType()==0) {
-    MoniTool_Msg Msg1125("IGES_1125"); //"Model space representation not implemented"
+    Message_Msg Msg1125("IGES_1125"); //"Model space representation not implemented"
     SendFail(start,Msg1125);
     //AddFail(start, "Model space representation not implemented");
     return res;
@@ -1246,7 +1246,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferBoundary
 
   Handle (IGESData_IGESEntity) igesSurface = start->Surface();
   if (igesSurface.IsNull() || !IGESToBRep::IsTopoSurface(igesSurface) ) {
-    MoniTool_Msg Msg124("XSTEP_124"); //"BasicSurface Transfer Error : Null IGESEntity"
+    Message_Msg Msg124("XSTEP_124"); //"BasicSurface Transfer Error : Null IGESEntity"
     SendFail(start,Msg124);
     //    AddFail(start, "BasicSurface Transfer Error : Null IGESEntity");
     return res;
@@ -1277,7 +1277,7 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferBoundary
 	}
 	//szv#4:S4163:12Mar99 optimized
 	if (nbfaces != 1) {
-	   MoniTool_Msg Msg1061("IGES_1061"); //"Not Implemented Trimmed Composite Surface."
+	   Message_Msg Msg1061("IGES_1061"); //"Not Implemented Trimmed Composite Surface."
 	    SendFail(start,Msg1061);
 	  //AddFail(start,"Not Implemented Trimmed Composite Surface.");
 	  return res;
@@ -1286,10 +1286,10 @@ TopoDS_Shape  IGESToBRep_TopoCurve::TransferBoundary
       break;
     default:
       {
-	MoniTool_Msg Msg1156("IGES_1156"); //"Basis Surface Error." ?? Msg1066
+	Message_Msg Msg1156("IGES_1156"); //"Basis Surface Error." ?? Msg1066
 	Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSurface);
-	Msg1156.AddString("basic surface");
-	Msg1156.AddString(label);
+	Msg1156.Arg("basic surface");
+	Msg1156.Arg(label);
 	SendFail(start,Msg1156);
 	//	AddFail(start, "Basis Surface Error.");
 	return res;
@@ -1316,7 +1316,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferBoundaryOnFace(TopoDS_Face&  face,
 {
   TopoDS_Shape  res;  
   if (start.IsNull()) {
-    MoniTool_Msg Msg1005("IGES_1005"); //"BoundaryOnFace Transfer Error : Null IGESEntity"
+    Message_Msg Msg1005("IGES_1005"); //"BoundaryOnFace Transfer Error : Null IGESEntity"
     SendFail(start,Msg1005);
     return res;
   }
@@ -1332,9 +1332,9 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferBoundaryOnFace(TopoDS_Face&  face,
   for (Standard_Integer i = 1; i <= start->NbModelSpaceCurves(); i++) {
     Handle(IGESData_HArray1OfIGESEntity) Curves2d;
     if (start->NbParameterCurves(i) == 0 && start->BoundaryType() == 1) {
-      MoniTool_Msg Msg1135("IGES_1135");  
-      Msg1135.AddInteger(2); 
-      Msg1135.AddInteger(3); 
+      Message_Msg Msg1135("IGES_1135");  
+      Msg1135.Arg(2); 
+      Msg1135.Arg(3); 
       SendWarning(start,Msg1135);
     } 
     else
@@ -1346,7 +1346,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferBoundaryOnFace(TopoDS_Face&  face,
   IB->Check(Result, Standard_True, okCurve3d, okCurve2d);
   Handle(ShapeExtend_WireData) sewd = IB->WireData();
   if (sewd->NbEdges() == 0) {
-     MoniTool_Msg Msg1095("IGES_1095");//"Both 2d and 3d representations are invalid"
+     Message_Msg Msg1095("IGES_1095");//"Both 2d and 3d representations are invalid"
      SendFail(start,Msg1095);
     return res;
   }
@@ -1366,7 +1366,7 @@ TopoDS_Shape IGESToBRep_TopoCurve::TransferBoundaryOnFace(TopoDS_Face&  face,
       mywire.Move(L);
     }
     else {
-      MoniTool_Msg Msg1035("IGES_1035"); //"Transformation skipped (not a similarity)"
+      Message_Msg Msg1035("IGES_1035"); //"Transformation skipped (not a similarity)"
       SendWarning(start,Msg1035);
     }
   }
