@@ -424,8 +424,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferRuledSurface
       Message_Msg msg1156("IGES_1156");
       const Standard_CString typeName(igesCurve1->DynamicType()->Name());
       Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesCurve1);
-      msg1156.AddString(typeName);
-      msg1156.AddString(label);
+      msg1156.Arg(typeName);
+      msg1156.Arg(label);
       SendFail(st, msg1156);
       return res;
     }
@@ -444,8 +444,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferRuledSurface
 //	Message_Msg msg1156("IGES_1156");
 //	const Standard_CString typeName(igesCurve1->DynamicType()->Name());
 //	Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesCurve1);
-//	msg1156.AddString(typeName);
-//	msg1156.AddString(label);
+//	msg1156.Arg(typeName);
+//	msg1156.Arg(label);
 //	SendFail(st, msg1156);  
 //	return res;
 //      }
@@ -499,8 +499,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferRuledSurface
       Message_Msg msg1156("IGES_1156");
       const Standard_CString typeName(igesCurve2->DynamicType()->Name());
       Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesCurve2);
-      msg1156.AddString(typeName);
-      msg1156.AddString(label);
+      msg1156.Arg(typeName);
+      msg1156.Arg(label);
       SendFail(st, msg1156);
       // Curve Conversion Error.
       return res;
@@ -707,8 +707,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferSurfaceOfRevolution
     Message_Msg msg1156("IGES_1156");
     const Standard_CString typeName("generatrix");
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesGeneratrix);
-    msg1156.AddString(typeName);
-    msg1156.AddString(label);
+    msg1156.Arg(typeName);
+    msg1156.Arg(label);
     SendFail(st, msg1156);
     // Generatrix Conversion Error.
     return res;
@@ -846,8 +846,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferTabulatedCylinder
     Message_Msg msg1156("IGES_1156");
     const Standard_CString typeName("directrix");
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesDirectrix);
-    msg1156.AddString(typeName);
-    msg1156.AddString(label);
+    msg1156.Arg(typeName);
+    msg1156.Arg(label);
     SendFail(st, msg1156);
     // Directrix Conversion Error.
     return res;
@@ -989,8 +989,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferOffsetSurface
     Message_Msg msg1156("IGES_1156");
     const Standard_CString typeName("basis surface");
     Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSrf);
-    msg1156.AddString(typeName);
-    msg1156.AddString(label);
+    msg1156.Arg(typeName);
+    msg1156.Arg(label);
     SendFail(st, msg1156);  // Basis Surface Conversion Error.
     return res;
   }
@@ -1017,8 +1017,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferOffsetSurface
       Message_Msg msg1156("IGES_1156");
       const Standard_CString typeName("basis surface");
       Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSrf);
-      msg1156.AddString(typeName);
-      msg1156.AddString(label);
+      msg1156.Arg(typeName);
+      msg1156.Arg(label);
       SendFail(st, msg1156);  // Basis Surface Conversion Error.
       return res;
     }
@@ -1166,8 +1166,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferTrimmedSurface
 	  Message_Msg msg1156("IGES_1156");
 	  const Standard_CString typeName("basis surface");
           Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSurface);
-	  msg1156.AddString(typeName);
-	  msg1156.AddString(label);
+	  msg1156.Arg(typeName);
+	  msg1156.Arg(label);
 	  SendFail(st, msg1156);  // Not Implemented Trimmed Composite Surface.
 	  return myshape;
 	}
@@ -1178,8 +1178,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferTrimmedSurface
 	Message_Msg msg1156("IGES_1156");
 	const Standard_CString typeName("basis surface");
 	Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSurface);
-	msg1156.AddString(typeName);
-	msg1156.AddString(label);
+	msg1156.Arg(typeName);
+	msg1156.Arg(label);
 	SendFail(st, msg1156);  // Basis Surface Conversion Error.
 	return res;
       }
@@ -1277,8 +1277,8 @@ TopoDS_Shape  IGESToBRep_TopoSurface::TransferBoundedSurface
 	  Message_Msg msg1156("IGES_1156");
 	  const Standard_CString typeName("basis surface");
 	  Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSrf);
-	  msg1156.AddString(typeName);
-	  msg1156.AddString(label);
+	  msg1156.Arg(typeName);
+	  msg1156.Arg(label);
 	  SendFail(st, msg1156);
 	  // Not Implemented Trimmed Composite Surface.
 	  return myshape;
@@ -1290,8 +1290,8 @@ TopoDS_Shape  IGESToBRep_TopoSurface::TransferBoundedSurface
 	Message_Msg msg1156("IGES_1156");
 	const Standard_CString typeName("basis surface");
 	Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(igesSrf);
-	msg1156.AddString(typeName);
-	msg1156.AddString(label);
+	msg1156.Arg(typeName);
+	msg1156.Arg(label);
 	SendFail(st, msg1156);
 	return res;
       }
@@ -1389,7 +1389,7 @@ TopoDS_Shape  IGESToBRep_TopoSurface::TransferPerforate
     DeclareAndCast(IGESGeom_Plane,pi,st->Child(i));
     if (pi.IsNull()) {
       Message_Msg msg1285("IGES_1285");
-      msg1285.AddInteger(i);
+      msg1285.Arg(i);
       // A child is not a Plane, skipped, n0 %d
       SendWarning(st,msg1285);
       continue;
@@ -1402,8 +1402,8 @@ TopoDS_Shape  IGESToBRep_TopoSurface::TransferPerforate
       Message_Msg msg1156("IGES_1156");
       const Standard_CString typeName("hole");
       Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(pi);
-      msg1156.AddString(typeName);
-      msg1156.AddString(label);
+      msg1156.Arg(typeName);
+      msg1156.Arg(label);
       SendWarning(st, msg1156);
       // A hole could not be transferred, skipped, n0 %d
       continue;
@@ -1411,7 +1411,7 @@ TopoDS_Shape  IGESToBRep_TopoSurface::TransferPerforate
 //    coplanaires ? verifier
     if (!pln.Position().IsCoplanar(pli.Position(),GetEpsGeom(),GetEpsilon())) {
       Message_Msg msg1295("IGES_1295");
-      msg1295.AddInteger(i);
+      msg1295.Arg(i);
       SendWarning(st,msg1295);
       // "A hole is not well coplanar to the face, n0 %d",i);
     }
@@ -1532,8 +1532,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferPlaneParts(const Handle(IGESGeom_Pl
 	      Message_Msg msg1156("IGES_1156");
 	      const Standard_CString typeName("Bounding curve");
 	      Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(crv);
-	      msg1156.AddString(typeName);
-	      msg1156.AddString(label);
+	      msg1156.Arg(typeName);
+	      msg1156.Arg(label);
 	      SendWarning(st, msg1156);
 	      if (first) res = plane;
 	      else       res = wire;
@@ -1575,8 +1575,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::TransferPlaneParts(const Handle(IGESGeom_Pl
 	Message_Msg msg1156("IGES_1156");
 	const Standard_CString typeName("Bounding curve");
 	Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(crv);
-	msg1156.AddString(typeName);
-	msg1156.AddString(label);
+	msg1156.Arg(typeName);
+	msg1156.Arg(label);
 	SendWarning(st, msg1156);
 	// Plane Cannot Be Trimmed.
       }
@@ -1633,8 +1633,8 @@ TopoDS_Shape IGESToBRep_TopoSurface::ParamSurface(const Handle(IGESData_IGESEnti
 	 Message_Msg msg1156("IGES_1156");
 	 const Standard_CString typeName("basis surface");
 	 Handle(TCollection_HAsciiString) label = GetModel()->StringLabel(st);
-	 msg1156.AddString(typeName);
-	 msg1156.AddString(label);
+	 msg1156.Arg(typeName);
+	 msg1156.Arg(label);
 	 SendWarning(st, msg1156);
 	 return basisSurface;
       }
