@@ -21,6 +21,7 @@
 #include <gp_Elips.hxx>
 #include <IntTools.hxx>
 #include <ElCLib.hxx>
+#include <Geom_Line.hxx>
 
 
 static void LocalPrepareArgs(BRepAdaptor_Curve& theCurve,
@@ -265,12 +266,10 @@ void IntTools_BeanBeanIntersector::Perform()
   //
   ComputeRoughIntersection();
   
-  //modified by NIZNHY-PKV Tue Dec  5 14:43:36 2006f
   //Standard_Real aMidParameter = (myFirstParameter2 + myLastParameter2) * 0.5;
   aCoeff=0.5753;
   aMidParameter = myFirstParameter2+(myLastParameter2-myFirstParameter2)*aCoeff;
-  //modified by NIZNHY-PKV Tue Dec  5 14:43:33 2006t
-
+  //
   for(k = 0; k < 2; ++k) {
     if(!k) {
       aRange2.SetFirst(myFirstParameter2);
@@ -494,65 +493,80 @@ Standard_Real IntTools_BeanBeanIntersector::Distance(const Standard_Real theArg,
 // ==================================================================================
 void IntTools_BeanBeanIntersector::ComputeRoughIntersection() 
 {
-  if(myRangeManager.Length() <= 0) {
-    return;
-  }
-
-  Standard_Real aDeflection;
+  Standard_Boolean isintersection;
+  Standard_Integer i, aNbArgs, aNbArgs1, aNbRanges, j, aNbLines, k, pIt, extIt, iFlag;
+  Standard_Real aDeflection, aGPR, aCurDeflection, aT1, aT2, aD;
+  Standard_Real aMaxDistance, aDistance, aPPC, aPrm1, aPrm2, aPPA;
+  GeomAbs_CurveType aCT1, aCT2;
+  gp_Pnt aPoint1, aPoint2, aMidPOnCurve, aMidPOnLine, aP1, aP2;
   IntTools_CArray1OfReal anArgs;
   LocalPrepareArgs(myCurve2, myFirstParameter2, myLastParameter2, aDeflection, anArgs);
-
-  if(anArgs.Length() <= 0)
+  //
+  aNbArgs=anArgs.Length();
+  if(!aNbArgs) {
     return;
-
-  Intf_Array1OfLin aLines(1, anArgs.Length() - 1);
-  TColStd_Array1OfInteger aLineFlags(1, anArgs.Length() - 1);
-  TColStd_Array1OfReal aDistances(1, anArgs.Length() - 1);
-  gp_Pnt aPoint1 = myCurve2.Value(anArgs(0));
-
-  Standard_Integer i=0;
-
-  for(i = 1; i < anArgs.Length(); i++) {
-    gp_Pnt aPoint2 = myCurve2.Value(anArgs(i));
+  }
+  //
+  aCT1=myCurve1.GetType();
+  aCT2=myCurve2.GetType();
+  aGPR=gp::Resolution();
+  aPPC=Precision::PConfusion();
+  aPPA=Precision::Angular();
+  aNbArgs1=aNbArgs-1;
+  //
+  Intf_Array1OfLin aLines(1, aNbArgs1);
+  TColStd_Array1OfInteger aLineFlags(1, aNbArgs1);
+  TColStd_Array1OfReal aDistances(1, aNbArgs1);
+  //
+  aT1=anArgs(0);
+  aPoint1 = myCurve2.Value(aT1);
+  for(i=1; i<aNbArgs; ++i) {
+    aT2=anArgs(i);
+    aPoint2 = myCurve2.Value(aT2);
     gp_Vec aVec(aPoint1, aPoint2);
-    aDistances.SetValue(i, aVec.Magnitude());
-
-    if(aVec.Magnitude() <= gp::Resolution()) {
+    aD=aVec.Magnitude();
+    aDistances.SetValue(i, aD);
+    //
+    if(aD<=aGPR) {
       aLineFlags.SetValue(i, 0);
-      continue;
     }
     else {
       aLineFlags.SetValue(i, 1);
-    }
-    gp_Lin aLine(aPoint1, gp_Dir(aVec));
-    aLines.SetValue(i, aLine);
-
-    if((myCurve2.GetType() == GeomAbs_BezierCurve) ||
-       (myCurve2.GetType() == GeomAbs_BSplineCurve)) {
-      gp_Pnt aMidPOnCurve = myCurve2.Value((anArgs(i-1) + anArgs(i)) * 0.5);
-      gp_Pnt aMidPOnLine = ElCLib::Value((aDistances(i)*0.5), aLine);
-      Standard_Real aCurDeflection = aMidPOnCurve.Distance(aMidPOnLine);
-
-      if(aCurDeflection > aDeflection) {
-	aDeflection = aCurDeflection;
+      gp_Lin aLine(aPoint1, gp_Dir(aVec));
+      aLines.SetValue(i, aLine);
+      //
+      if((aCT2 == GeomAbs_BezierCurve) ||
+	 (aCT2 == GeomAbs_BSplineCurve)) {
+	aMidPOnCurve = myCurve2.Value((aT1+aT2) * 0.5);
+	aMidPOnLine = ElCLib::Value((aDistances(i)*0.5), aLine);
+	aCurDeflection = aMidPOnCurve.Distance(aMidPOnLine);
+	if(aCurDeflection > aDeflection) {
+	  aDeflection = aCurDeflection;
+	}
       }
     }
-
+    aT1=aT2;
     aPoint1 = aPoint2;
   }
-
-  Standard_Real aMaxDistance = myCriteria + myDeflection + aDeflection;
+  //
+  aNbLines=aLines.Upper();
+  aMaxDistance = myCriteria + myDeflection + aDeflection;
   
-  aPoint1 = myCurve1.Value(myRangeManager.Range(1).First());
-
-  for(i = 1; i <= myRangeManager.Length(); i++) {
+  aT1=myRangeManager.Range(1).First();
+  aPoint1 = myCurve1.Value(aT1);
+  aNbRanges=myRangeManager.Length();
+  for(i = 1; i <= aNbRanges; ++i) {
     const IntTools_Range& aRange = myRangeManager.Range(i);
-    gp_Pnt aPoint2 = myCurve1.Value(aRange.Last());
-
-    if(myRangeManager.Flag(i) == 4) {
+    aT2=aRange.Last();
+    aPoint2 = myCurve1.Value(aT2);
+    //
+    iFlag=myRangeManager.Flag(i);
+    if(iFlag==4) {// coincided
+      aT1=aT2;
       aPoint1 = aPoint2;
       continue;
     }
+    //
     myRangeManager.SetFlag(i, 1); // not intersected
     
     Bnd_Box aBox1;
@@ -562,110 +576,128 @@ void IntTools_BeanBeanIntersector::ComputeRoughIntersection()
 
     gp_Vec aVec(aPoint1, aPoint2);
 
-    if(aVec.Magnitude() <= gp::Resolution()) {
+    aDistance=aVec.Magnitude();
+    if(aDistance <= aGPR) {
       myRangeManager.SetFlag(i, 0);
       continue;
     }
+    //
     gp_Lin aLine(aPoint1, gp_Dir(aVec));
-    Standard_Real aDistance = aVec.Magnitude();
-
-    if((myCurve1.GetType() == GeomAbs_BezierCurve) ||
-       (myCurve1.GetType() == GeomAbs_BSplineCurve)) {
-      gp_Pnt aMidPOnCurve = myCurve1.Value((aRange.First() + aRange.Last()) * 0.5);
-      gp_Pnt aMidPOnLine = ElCLib::Value((aDistance*0.5), aLine);
-      Standard_Real aCurDeflection = aMidPOnCurve.Distance(aMidPOnLine);
-      
+    //
+    if((aCT1 == GeomAbs_BezierCurve) ||
+       (aCT1 == GeomAbs_BSplineCurve)) {
+      aMidPOnCurve = myCurve1.Value((aRange.First() + aRange.Last()) * 0.5);
+      aMidPOnLine = ElCLib::Value((aDistance*0.5), aLine);
+      aCurDeflection = aMidPOnCurve.Distance(aMidPOnLine);
       if(myDeflection < aCurDeflection) {
 	aMaxDistance += aCurDeflection - myDeflection;
 	myDeflection = aCurDeflection;	
       }
     }
-
-    for(Standard_Integer j = aLines.Lower(); j <= aLines.Upper(); j++) {
-
-      if(aLineFlags(j) == 0) {
+    //
+    for(j=1; j<=aNbLines; ++j) {
+      if(!aLineFlags(j)) {
 	myRangeManager.SetFlag(i, 0);
 	continue;
       }
-      Extrema_ExtElC anExtrema(aLine, aLines(j), Precision::Angular());
-      
+      //
+      const gp_Lin& aL2=aLines(j);
+      //Handle(Geom_Line) aC2=new Geom_Line(aL2); // DEB ft
+      aD=aDistances(j);
+      aP1=ElCLib::Value(0., aL2);
+      aP2=ElCLib::Value(aD, aL2);
+      //
+      Extrema_ExtElC anExtrema(aLine, aL2, aPPA);
       if(anExtrema.IsDone() && (anExtrema.IsParallel() || (anExtrema.NbExt() > 0))) {
-	Standard_Boolean isintersection = Standard_False;
+	isintersection = Standard_False;
 
 	if(anExtrema.IsParallel()) {
 	  isintersection = (anExtrema.Value(1) < aMaxDistance);
 	}
-	else {
-	  for(Standard_Integer k = 1; !isintersection && k <= anExtrema.NbExt(); k++) {
-	    
+	else { //1
+	  for(k = 1; !isintersection && k <= anExtrema.NbExt(); ++k) {
 	    if(anExtrema.Value(k) < aMaxDistance) {
 	      Extrema_POnCurv P1, P2;
 	      anExtrema.Points(k, P1, P2);
-	      
-	      if((P1.Parameter() >= 0.) &&
-		 (P1.Parameter() <= aDistance) &&
-		 (P2.Parameter() >= 0.) &&
-		 (P2.Parameter() <= aDistances(j))) {
+	      aPrm1=P1.Parameter();
+	      aPrm2=P2.Parameter();
+	      //modified by NIZNHY-PKV Tue Jun  5 15:47:13 2007f
+	      /*
+	      if((aPrm1 >= 0.) && (aPrm1 <= aDistance) &&
+		 (aPrm2 >= 0.) && (aPrm2 <= aD)) {
 		isintersection = Standard_True;
 	      }
-	      else {
+	      */
+	      if((aPrm1 >= -aMaxDistance) && (aPrm1 <= aDistance+aMaxDistance) &&
+		 (aPrm2 >= -aMaxDistance) && (aPrm2 <= aD+aMaxDistance)) {
+		isintersection = Standard_True;
+	      }
+	      //modified by NIZNHY-PKV Tue Jun  5 15:47:17 2007t
+	      else { // 2
 		Extrema_ExtPElC aPointProjector;
 
-		for(Standard_Integer pIt = 0; !isintersection && (pIt < 4); pIt++) {
+		for(pIt = 0; !isintersection && (pIt < 4); ++pIt) {
 		  switch (pIt) {
-		  case 0: {
-		    aPointProjector = Extrema_ExtPElC(aPoint1, aLines(j), Precision::PConfusion(), 0., aDistances(j));
-		    break;
+		    case 0: {
+		      aPointProjector = 
+			//Extrema_ExtPElC(aPoint1, aLines(j), aPPC, 0., aDistances(j));
+			Extrema_ExtPElC(aPoint1, aL2, aPPC, -aMaxDistance, aD+aMaxDistance);
+		      break;
+		    }
+		    case 1: {
+		      aPointProjector =
+			//Extrema_ExtPElC(aPoint2, aLines(j), aPPC, 0., aD);
+			Extrema_ExtPElC(aPoint2, aL2, aPPC, -aMaxDistance, aD+aMaxDistance);
+		      break;
+		    }
+		    case 2: {
+		      aPointProjector = 
+			//Extrema_ExtPElC(ElCLib::Value(0., aLines(j)), aLine, aPPC, 0., aDistance);
+			Extrema_ExtPElC(aP1, aLine, aPPC, -aMaxDistance, aDistance+aMaxDistance);
+		      break;
+		    }
+		    case 3: {
+		      aPointProjector =
+			//Extrema_ExtPElC(ElCLib::Value(aDistances(j), aLines(j)), aLine, aPPC, 0., aDistance);
+			Extrema_ExtPElC(aP2, aLine, aPPC, -aMaxDistance, aDistance+aMaxDistance);
+		      break;
+		    }
+		    default: {
+		      break;
+		    }
 		  }
-		  case 1: {
-		    aPointProjector = Extrema_ExtPElC(aPoint2, aLines(j), Precision::PConfusion(), 0., aDistances(j));
-		    break;
-		  }
-		  case 2: {
-		    aPointProjector = Extrema_ExtPElC( ElCLib::Value(0., aLines(j)), aLine, Precision::PConfusion(), 0, aDistance);
-		    break;
-		  }
-		  case 3: {
-		    aPointProjector = Extrema_ExtPElC( ElCLib::Value(aDistances(j), aLines(j)), aLine, Precision::PConfusion(), 0, aDistance);
-		    break;
-		  }
-		  default: {
-		    break;
-		  }
-		  }
-
+		  //
 		  if(aPointProjector.IsDone()) {
-		    for(Standard_Integer extIt = 1; extIt <= aPointProjector.NbExt(); extIt++) {
+		    for(extIt = 1; extIt <= aPointProjector.NbExt(); extIt++) {
 		      if(aPointProjector.Value(extIt) < aMaxDistance) {
 			isintersection = Standard_True;
 		      }
 		    }
 		  }
 		} // end for
-	      }
-	    }
-	  }
-	}
-
+	      }// else { // 2
+	    }//if(anExtrema.Value(k) < aMaxDistance) {
+	  }//for(k = 1; !isintersection && k <= anExtrema.NbExt(); k++) {
+	}//else { //1
+	
 	if(isintersection) {
 	  myRangeManager.SetFlag(i, 2); // roughly intersected
 	  break;
 	}
-      }
+      }//if(anExtrema.IsDone() && (anExtrema.IsParallel() || (anExtrema.NbExt() > 0))) {
       else {
-	if(j > 0) {
-	  Bnd_Box aBox2;
-	  aBox2.Add(myCurve2.Value(anArgs(j-1)));
-	  aBox2.Add(myCurve2.Value(anArgs(j)));
-	  aBox2.Enlarge(myBeanTolerance2 + aDeflection);
-
-	  if(!aBox1.IsOut(aBox2)) {
-	    myRangeManager.SetFlag(i, 2); // roughly intersected
-	    break;
-	  }
+	Bnd_Box aBox2;
+	aBox2.Add(myCurve2.Value(anArgs(j-1)));
+	aBox2.Add(myCurve2.Value(anArgs(j)));
+	aBox2.Enlarge(myBeanTolerance2 + aDeflection);
+	//
+	if(!aBox1.IsOut(aBox2)) {
+	  myRangeManager.SetFlag(i, 2); // roughly intersected
+	  break;
 	}
       }
     }
+    aT1=aT2;
     aPoint1 = aPoint2;
   }
 }
