@@ -1882,6 +1882,13 @@ Standard_Boolean IntTools_BeanFaceIntersector::ComputeLocalized() {
 	    if (mySurface.IsVPeriodic())
 	      V = ElCLib::InPeriod(V, parVF, parVF + mySurface.VPeriod());
 
+	    //To avoid occasional going out of boundaries because of numerical
+	    //problem
+	    if(U < myUMinParameter) U = myUMinParameter;
+	    if(U > myUMaxParameter) U = myUMaxParameter;
+	    if(V < myVMinParameter) U = myVMinParameter;
+	    if(V > myVMaxParameter) U = myVMaxParameter;
+
 	    Standard_Integer aNbRanges = myRangeManager.Length();
 	    ComputeRangeFromStartPoint(Standard_False, T, U, V);
 	    ComputeRangeFromStartPoint(Standard_True, T, U, V);
