@@ -251,20 +251,45 @@ static void Parameters(const Handle(GeomAdaptor_HSurface)& myHS1,
     for(i=1;i<nbvtx;i++) { 
       firstp = GeomInt_LineTool::Vertex(L,i).ParameterOnLine();
       lastp =  GeomInt_LineTool::Vertex(L,i+1).ParameterOnLine();
-      if(firstp!=lastp) {  
-	Standard_Integer pmid = (Standard_Integer )( (firstp+lastp)/2);
-	const IntSurf_PntOn2S& Pmid = WLine->Point(pmid);
-	Pmid.Parameters(u1,v1,u2,v2);
-	Recadre(myHS1,myHS2,u1,v1,u2,v2);
+      if(firstp!=lastp) { 
+	if(lastp != firstp+1) {
+	  Standard_Integer pmid = (Standard_Integer )( (firstp+lastp)/2);
+	  const IntSurf_PntOn2S& Pmid = WLine->Point(pmid);
+	  Pmid.Parameters(u1,v1,u2,v2);
+	  Recadre(myHS1,myHS2,u1,v1,u2,v2);
 
-	TopAbs_State in1 = myDom1->Classify(gp_Pnt2d(u1,v1),Tol);
-	if(in1 !=  TopAbs_OUT) {  //-- !=ON donne Pb 
-	  TopAbs_State in2 = myDom2->Classify(gp_Pnt2d(u2,v2),Tol);
-	  if(in2 != TopAbs_OUT) { //-- !=ON  
-	    seqp.Append(firstp);
-	    seqp.Append(lastp);
+	  TopAbs_State in1 = myDom1->Classify(gp_Pnt2d(u1,v1),Tol);
+	  if(in1 !=  TopAbs_OUT) {  //-- !=ON donne Pb 
+	    TopAbs_State in2 = myDom2->Classify(gp_Pnt2d(u2,v2),Tol);
+	    if(in2 != TopAbs_OUT) { //-- !=ON  
+	      seqp.Append(firstp);
+	      seqp.Append(lastp);
+	    }
 	  }
 	}
+	else {
+	  const IntSurf_PntOn2S& Pfirst = WLine->Point((Standard_Integer)(firstp));
+	  Pfirst.Parameters(u1,v1,u2,v2);
+	  Recadre(myHS1,myHS2,u1,v1,u2,v2);
+	  TopAbs_State in1 = myDom1->Classify(gp_Pnt2d(u1,v1),Tol);
+	  if(in1 !=  TopAbs_OUT) {  //-- !=ON donne Pb 
+	    TopAbs_State in2 = myDom2->Classify(gp_Pnt2d(u2,v2),Tol);
+	    if(in2 != TopAbs_OUT) { //-- !=ON  
+	      const IntSurf_PntOn2S& Plast = WLine->Point((Standard_Integer)(lastp));
+	      Plast.Parameters(u1,v1,u2,v2);
+	      Recadre(myHS1,myHS2,u1,v1,u2,v2);
+	      in1 = myDom1->Classify(gp_Pnt2d(u1,v1),Tol);
+	      if(in1 !=  TopAbs_OUT) {  //-- !=ON donne Pb 
+		in2 = myDom2->Classify(gp_Pnt2d(u2,v2),Tol);
+		if(in2 != TopAbs_OUT) {
+		  seqp.Append(firstp);
+		  seqp.Append(lastp);
+		}
+	      }
+	    }
+	  }
+	  
+	}
       }
     }
     //XX
