@@ -12,7 +12,7 @@
 #include <Interface_DataMapIteratorOfDataMapOfIntegerTransient.hxx>
 #include <Standard_OutOfRange.hxx>
 #include <Interface_SignType.hxx>
-
+#include <Message_Messenger.hxx>
 
 // Un Modele d`Interface est un ensemble ferme d`Entites d`interface : chacune
 // est dans un seul modele a la fois; elle y a un numero (Number) qui permet de
@@ -906,7 +906,7 @@ void Interface_InterfaceModel::VerifyCheck (Handle(Interface_Check)& /*ach*/) co
 //=======================================================================
 
 void Interface_InterfaceModel::Print(const Handle(Standard_Transient)& ent,
-                                     Standard_OStream& S,
+                                     const Handle(Message_Messenger)& S,
                                      const Standard_Integer mode) const
 { 
   if (ent.IsNull())  {  S<<"NULL";  return;  }
@@ -928,7 +928,7 @@ void Interface_InterfaceModel::Print(const Handle(Standard_Transient)& ent,
 //=======================================================================
 
 void Interface_InterfaceModel::PrintToLog(const Handle(Standard_Transient)& ent,
-                                          Standard_OStream& S) const
+                                          const Handle(Message_Messenger)& S) const
 {
   PrintLabel (ent,S);
 }
