@@ -336,7 +336,7 @@ LDOM_XmlReader::RecordType LDOM_XmlReader::ReadRecord
         }
       {
         theData.rdbuf()->sputn(aStartData, aNameEnd - aStartData);
-        char* aDataString = theData.str();
+        char* aDataString = (char *)theData.str();
         myElement = & LDOM_BasicElement::Create (aDataString, theData.Length(),
                                                  myDocument);
         theData.Clear();
@@ -397,7 +397,7 @@ LDOM_XmlReader::RecordType LDOM_XmlReader::ReadRecord
           else {
             theData.rdbuf()->sputn(myPtr, aNameEnd - myPtr);
 attr_name:
-            char* aDataString = theData.str();
+            char* aDataString = (char *)theData.str();
             theData.Clear();
             anAttrName = LDOMBasicString (aDataString, myDocument);
             delete [] aDataString;
@@ -457,7 +457,7 @@ attr_name:
           //    Append the end of the string to previously taken data
           if (theData.Length() > 0) {
             theData.rdbuf()->sputn(aStartData, aPtr-aStartData);
-            aDataString = theData.str();
+            aDataString = (char *)theData.str();
             ePtr = strchr (aDataString, '\0');
           }
 
@@ -563,10 +563,14 @@ Standard_Boolean LDOM_XmlReader::getInteger (LDOMBasicString&    theValue,
 {
   char * ptr;
   errno = 0;
-  long aResult = strtol (theStart, &ptr, 10);
-  if (ptr == theEnd && errno == 0) {
-    theValue = Standard_Integer(aResult);
-    return Standard_False;
+  if (theEnd - theStart == 1 || theStart[0] != '0')
+  {
+      long aResult = strtol (theStart, &ptr, 10);
+      if (ptr == theEnd && errno == 0) 
+      {
+        theValue = Standard_Integer(aResult);
+        return Standard_False;
+      }
   }
   return Standard_True;
 }
