@@ -31,7 +31,6 @@
 #include <BRepMesh_Triangle.hxx>
 #include <BRepMesh_DataStructureOfDelaun.hxx>
 #include <BRepMesh_Delaun.hxx>
-#include <BRepMesh_Discret.hxx>
 #include <BRepMesh_FastDiscret.hxx>
 #include <BRepMesh_Array1OfVertexOfDelaun.hxx>
 #include <BRepMesh_Vertex.hxx>
@@ -105,7 +104,7 @@ OSD_Chronometer chIsos, chPointsOnIsos;
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer shapesection(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+static Standard_Integer shapesection(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 4) return 1;
 
@@ -132,7 +131,7 @@ static Standard_Integer shapesection(Draw_Interpretor&, Standard_Integer nbarg,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer planesection(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+static Standard_Integer planesection(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 4) return 1;
 
@@ -163,7 +162,7 @@ static Standard_Integer planesection(Draw_Interpretor&, Standard_Integer nbarg,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer incrementalmesh(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+static Standard_Integer incrementalmesh(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 3) return 1;
 
@@ -180,7 +179,7 @@ static Standard_Integer incrementalmesh(Draw_Interpretor&, Standard_Integer nbar
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer fastdiscret(Draw_Interpretor& di, Standard_Integer nbarg, char** argv)
+static Standard_Integer fastdiscret(Draw_Interpretor& di, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 3) return 1;
 
@@ -196,15 +195,15 @@ static Standard_Integer fastdiscret(Draw_Interpretor& di, Standard_Integer nbarg
   BRepBndLib::Add(S,B);
   BRepMesh_FastDiscret MESH(d,0.5,B,WithShare,Standard_True,Standard_False,Standard_True);
 
-  Standard_Integer NbIterations = MESH.NbIterations();
-  if (nbarg > 4) NbIterations = atoi(argv[4]);
-  MESH.NbIterations() = NbIterations;
+  //Standard_Integer NbIterations = MESH.NbIterations();
+  //if (nbarg > 4) NbIterations = atoi(argv[4]);
+  //MESH.NbIterations() = NbIterations;
 
   di<<"Starting FastDiscret with :"<<"\n";
   di<<"  Deflection="<<d<<"\n";
   di<<"  Angle="<<0.5<<"\n";
   di<<"  SharedMode="<< (Standard_Integer) WithShare<<"\n";
-  di<<"  NbIterations="<<NbIterations<<"\n";
+  //di<<"  NbIterations="<<NbIterations<<"\n";
 
   Handle(Poly_Triangulation) T;
   BRep_Builder aBuilder;
@@ -290,13 +289,13 @@ static Standard_Integer fastdiscret(Draw_Interpretor& di, Standard_Integer nbarg
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer triangule(Draw_Interpretor& di, Standard_Integer nbarg, char** argv)
+static Standard_Integer triangule(Draw_Interpretor& di, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 4) return 1;
 
   Standard_Boolean save = Standard_False;
 
-  char *id1 = argv[2];
+  const char *id1 = argv[2];
   TopoDS_Shape S = DBRep::Get(id1);
   if (S.IsNull()) return 1;
   di << argv[1] << " ";
@@ -355,7 +354,7 @@ static Standard_Integer triangule(Draw_Interpretor& di, Standard_Integer nbarg,
 //purpose  : 
 //=======================================================================
 
-Standard_Integer addshape(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer addshape(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   Handle(MeshTest_DrawableMesh) D =
@@ -376,7 +375,7 @@ Standard_Integer addshape(Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer smooth(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer smooth(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   Handle(MeshTest_DrawableMesh) D =
@@ -398,7 +397,7 @@ Standard_Integer smooth(Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer domain(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer domain(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   Handle(MeshTest_DrawableMesh) D =
@@ -421,7 +420,7 @@ Standard_Integer domain(Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer edges (Draw_Interpretor&, Standard_Integer n, char** a)
+static Standard_Integer edges (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -433,7 +432,7 @@ static Standard_Integer edges (Draw_Interpretor&, Standard_Integer n, char** a)
 
   TopExp_Explorer ex;
   TColStd_SequenceOfInteger& eseq = D->Edges();
-  Handle(BRepMesh_Discret) M = D->Mesh();
+  Handle(BRepMesh_FastDiscret) M = D->Mesh();
   Handle(BRepMesh_DataStructureOfDelaun) DS = M->Result();
   Standard_Integer e1, e2, e3, iTri;
   Standard_Boolean o1, o2, o3;
@@ -444,8 +443,9 @@ static Standard_Integer edges (Draw_Interpretor&, Standard_Integer n, char** a)
     for (f = 1; f <= M->NbDomains(); f++)
       if (M->DomainFace(f).IsSame(ex.Current())) break;
     if (f <= M->NbDomains()) {
-      const TColStd_MapOfInteger& elems = DS->ElemOfDomain(f);
-      TColStd_MapIteratorOfMapOfInteger it;
+      //const TColStd_MapOfInteger& elems = DS->ElemOfDomain(f);
+      const MeshDS_MapOfInteger& elems = DS->ElemOfDomain(f);
+      MeshDS_MapOfInteger::Iterator it;
       for (it.Initialize(elems); it.More(); it.Next()) {
 	iTri = it.Key();
 	const BRepMesh_Triangle& triang = M->Triangle(iTri);
@@ -472,7 +472,7 @@ static Standard_Integer edges (Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer vertices (Draw_Interpretor&, Standard_Integer n, char** a)
+static Standard_Integer vertices (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -484,7 +484,7 @@ static Standard_Integer vertices (Draw_Interpretor&, Standard_Integer n, char**
 
   TopExp_Explorer ex;
   TColStd_SequenceOfInteger& vseq = D->Vertices();
-  Handle(BRepMesh_Discret) M = D->Mesh();
+  Handle(BRepMesh_FastDiscret) M = D->Mesh();
   
   // the faces
   Standard_Integer f;
@@ -492,9 +492,9 @@ static Standard_Integer vertices (Draw_Interpretor&, Standard_Integer n, char**
     for (f = 1; f <= M->NbDomains(); f++)
       if (M->DomainFace(f).IsSame(ex.Current())) break;
     if (f <= M->NbDomains()) {
-      TColStd_MapOfInteger vtx;
+      MeshDS_MapOfInteger vtx;
       M->VerticesOfDomain(f,vtx);
-      for (TColStd_MapIteratorOfMapOfInteger it(vtx);
+      for (MeshDS_MapOfInteger::Iterator it(vtx);
 	   it.More(); it.Next())
 	vseq.Append(it.Key());
     }
@@ -514,7 +514,7 @@ static Standard_Integer vertices (Draw_Interpretor&, Standard_Integer n, char**
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer medge (Draw_Interpretor&, Standard_Integer n, char** a)
+static Standard_Integer medge (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -558,7 +558,7 @@ static Standard_Integer medge (Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer mvertex (Draw_Interpretor&, Standard_Integer n, char** a)
+static Standard_Integer mvertex (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -601,7 +601,7 @@ static Standard_Integer mvertex (Draw_Interpretor&, Standard_Integer n, char** a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer triangle (Draw_Interpretor&, Standard_Integer n, char** a)
+static Standard_Integer triangle (Draw_Interpretor&, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
 
@@ -676,7 +676,7 @@ static void printdegree(MeshDS_DegreeOfFreedom dof, Draw_Interpretor& di)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer dumpvertex(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+Standard_Integer dumpvertex(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1;
 
@@ -704,7 +704,7 @@ Standard_Integer dumpvertex(Draw_Interpretor& di, Standard_Integer argc, char**
       <<nod.Location3d()<<") ";
     printdegree(nod.Movability(), di);
     di<<" (edgeconex";
-    TColStd_ListIteratorOfListOfInteger tati(struc->LinkNeighboursOf(in));
+    MeshDS_ListOfInteger::Iterator tati(struc->LinkNeighboursOf(in));
     for (; tati.More(); tati.Next()) di<<" "<<tati.Value();
     di << "))\n";
   }
@@ -717,7 +717,7 @@ Standard_Integer dumpvertex(Draw_Interpretor& di, Standard_Integer argc, char**
 //purpose  : 
 //=======================================================================
 
-Standard_Integer dumpedge(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+Standard_Integer dumpedge(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1;
 
@@ -743,7 +743,7 @@ Standard_Integer dumpedge(Draw_Interpretor& di, Standard_Integer argc, char** ar
       <<" ";
     printdegree(edg.Movability(), di);
     di<<") (triconex";
-    TColStd_ListIteratorOfListOfInteger titi(struc->ElemConnectedTo(il));
+    MeshDS_ListOfInteger::Iterator titi(struc->ElemConnectedTo(il));
     for (; titi.More(); titi.Next()) di<<" "<<titi.Value();
     di << "))\n";
   }
@@ -756,7 +756,7 @@ Standard_Integer dumpedge(Draw_Interpretor& di, Standard_Integer argc, char** ar
 //purpose  : 
 //=======================================================================
 
-Standard_Integer dumptriangle(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+Standard_Integer dumptriangle(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2) return 1;
 
@@ -799,7 +799,7 @@ Standard_Integer dumptriangle(Draw_Interpretor& di, Standard_Integer argc, char*
 //purpose  : 
 //=======================================================================
 
-Standard_Integer debshape(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+Standard_Integer debshape(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   Standard_Integer val=1;
   if (nbarg>1) val=atoi(argv[1]);
@@ -812,7 +812,7 @@ Standard_Integer debshape(Draw_Interpretor&, Standard_Integer nbarg, char** argv
 //purpose  : 
 //=======================================================================
 
-Standard_Integer debalgo(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+Standard_Integer debalgo(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   Standard_Integer val=1;
   if (nbarg>1) val=atoi(argv[1]);
@@ -825,7 +825,7 @@ Standard_Integer debalgo(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer chroshape(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+Standard_Integer chroshape(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   Standard_Integer val=1;
   if (nbarg>1) val=atoi(argv[1]);
@@ -838,7 +838,7 @@ Standard_Integer chroshape(Draw_Interpretor&, Standard_Integer nbarg, char** arg
 //purpose  : 
 //=======================================================================
 
-Standard_Integer chroalgo(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+Standard_Integer chroalgo(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   Standard_Integer val=1;
   if (nbarg>1) val=atoi(argv[1]);
@@ -850,7 +850,7 @@ Standard_Integer chroalgo(Draw_Interpretor&, Standard_Integer nbarg, char** argv
 //function : trianglesinfo
 //purpose  : 
 //=======================================================================
-static Standard_Integer trianglesinfo(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer trianglesinfo(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n != 2) return 1;
   TopoDS_Shape S = DBRep::Get(a[1]);
@@ -944,7 +944,7 @@ static Standard_Integer trianglesinfo(Draw_Interpretor& di, Standard_Integer n,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer veriftriangles(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer veriftriangles(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   Standard_Boolean quiet = 1;
@@ -1088,7 +1088,7 @@ static Standard_Integer veriftriangles(Draw_Interpretor& di, Standard_Integer n,
 //purpose  : 
 //=======================================================================
 
-Standard_Integer tri2d(Draw_Interpretor&, Standard_Integer n, char** a)
+Standard_Integer tri2d(Draw_Interpretor&, Standard_Integer n, const char** a)
 {
 
   if (n != 2) return 1;
@@ -1188,7 +1188,7 @@ Standard_Integer tri2d(Draw_Interpretor&, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer wavefront(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+static Standard_Integer wavefront(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
   if (nbarg < 2) return 1;
 
@@ -1318,7 +1318,7 @@ static Standard_Integer wavefront(Draw_Interpretor&, Standard_Integer nbarg, cha
 //purpose  : 
 //=======================================================================
 
-Standard_Integer onetriangulation(Draw_Interpretor&, Standard_Integer nbarg, char** argv)
+Standard_Integer onetriangulation(Draw_Interpretor&, Standard_Integer nbarg, const char** argv)
 {
 
 /*
@@ -1374,7 +1374,7 @@ Standard_Integer onetriangulation(Draw_Interpretor&, Standard_Integer nbarg, cha
 //purpose  : 
 //=======================================================================
 
-Standard_Integer vb(Draw_Interpretor& di, Standard_Integer nbarg, char** argv)
+Standard_Integer vb(Draw_Interpretor& di, Standard_Integer nbarg, const char** argv)
 {
   Standard_Integer NbPoints = 1, Deg = 1;
 
@@ -1423,7 +1423,7 @@ Standard_Integer vb(Draw_Interpretor& di, Standard_Integer nbarg, char** argv)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer extrema(Draw_Interpretor& di, Standard_Integer nbarg, char** argv)
+Standard_Integer extrema(Draw_Interpretor& di, Standard_Integer nbarg, const char** argv)
 {
   
   
@@ -1462,8 +1462,8 @@ Standard_Integer extrema(Draw_Interpretor& di, Standard_Integer nbarg, char** ar
   Draw::Commands(theCommands);
   BRepTest::AllCommands(theCommands);
   GeometryTest::AllCommands(theCommands);
-  
-  char* g;
+  MeshTest::PluginCommands(theCommands);
+  const char* g;
 
   g = "Mesh Commands";
   
