@@ -5,6 +5,8 @@
 
 #include <MeshVS_Mesh.ixx>
 
+#include <AIS_InteractiveContext.hxx>
+
 #include <Prs3d_Root.hxx>
 #include <gp_Pnt.hxx>
 #include <TColgp_Array1OfPnt.hxx>
@@ -34,21 +36,25 @@
 
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_Array1OfInteger.hxx>
-#include <TColStd_HArray1OfInteger.hxx>
 #include <TColStd_MapIteratorOfPackedMapOfInteger.hxx>
 #include <TColStd_ListIteratorOfListOfReal.hxx>
 #include <TColStd_SequenceOfInteger.hxx>
+#include <TColStd_ListIteratorOfListOfInteger.hxx>
 
 #include <Bnd_Box.hxx>
 
 #include <MeshVS_DataSource.hxx>
+#include <MeshVS_MeshEntityOwner.hxx>
 #include <MeshVS_MeshOwner.hxx>
+#include <MeshVS_SensitiveMesh.hxx>
 #include <MeshVS_DummySensitiveEntity.hxx>
 #include <MeshVS_SensitiveSegment.hxx>
 #include <MeshVS_SensitiveFace.hxx>
 #include <MeshVS_DrawerAttribute.hxx>
-#include <MeshVS_DataMapIteratorOfDataMapOfIntegerMeshOwner.hxx>
+#include <MeshVS_DataMapIteratorOfDataMapOfIntegerOwner.hxx>
 #include <MeshVS_SensitivePolyhedron.hxx>
+#include <MeshVS_SelectionModeFlags.hxx>
+#include <MeshVS_Buffer.hxx>
 
 #include <OSD_Timer.hxx>
 
@@ -150,17 +156,13 @@ void MeshVS_Mesh::Compute ( const Handle(PrsMgr_PresentationManager3d)& thePrsMg
   if ( aDS.IsNull() )
     return;
 
-  Standard_Boolean HasNodes    = !aDS->GetAllNodes().IsEmpty(),
-                   HasElements = !aDS->GetAllElements().IsEmpty();
+  const TColStd_PackedMapOfInteger& aNodes = aDS->GetAllNodes();
+  const TColStd_PackedMapOfInteger& aElems = aDS->GetAllElements();
+  Standard_Boolean HasNodes    = !aNodes.IsEmpty(),
+                   HasElements = !aElems.IsEmpty();
 
-  MeshVS_Array1OfIntegerBoolean aNodes( 1, HasNodes ? aDS->GetAllNodes().Extent() : 1 ),
-                                anElements( 1, HasElements ? aDS->GetAllElements().Extent() : 1 );
+  TColStd_PackedMapOfInteger aNodesToExclude, aElemsToExclude;
 
-  if( HasNodes )
-    TColStdMapToMeshVSArray ( aDS->GetAllNodes(), aNodes );
-  if( HasElements )
-    TColStdMapToMeshVSArray ( aDS->GetAllElements(), anElements );
-  
   thePresentation->Clear();
   Standard_Integer len = myBuilders.Length();
   if ( theMode > 0 )
@@ -171,9 +173,9 @@ void MeshVS_Mesh::Compute ( const Handle(PrsMgr_PresentationManager3d)& thePrsMg
       {
         aCurrent->SetPresentationManager( thePrsMgr );
         if( HasNodes )
-          aCurrent->Build ( thePresentation, aNodes,     Standard_False, theMode );
+          aCurrent->Build ( thePresentation, aNodes, aNodesToExclude, Standard_False, theMode );
         if( HasElements )
-          aCurrent->Build ( thePresentation, anElements, Standard_True,  theMode );
+          aCurrent->Build ( thePresentation, aElems, aElemsToExclude, Standard_True,  theMode );
       }
     }
 
@@ -216,7 +218,8 @@ void MeshVS_Mesh::ComputeSelection ( const Handle(SelectMgr_Selection)& theSelec
          ( MeshVS_DA_MaxFaceNodes, aMaxFaceNodes ) || aMaxFaceNodes<=0 )
     return;
 
-  TColStd_Array1OfReal aCoords (1, 3*aMaxFaceNodes);
+  MeshVS_Buffer aCoordsBuf (3*aMaxFaceNodes*sizeof(Standard_Real));
+  TColStd_Array1OfReal aCoords (aCoordsBuf, 1, 3*aMaxFaceNodes);
   Standard_Integer NbNodes;
 
   MeshVS_EntityType aType;
@@ -227,47 +230,72 @@ void MeshVS_Mesh::ComputeSelection ( const Handle(SelectMgr_Selection)& theSelec
   Standard_Integer aMode = HasDisplayMode() ? DisplayMode() : DefaultDisplayMode();
   if ( myHilighter.IsNull() || ( aMode & MeshVS_DMF_OCCMask ) == 0 )
     return;
-
   const TColStd_PackedMapOfInteger& anAllNodesMap   = aSource->GetAllNodes();
   const TColStd_PackedMapOfInteger& anAllElementsMap= aSource->GetAllElements();
 //agv  Standard_Integer i;
 
-  switch ( theMode )
-  {
-  case MeshVS_ET_Node:   // Nodes
-    myNodeOwners.Clear();
-
-    for ( anIter.Initialize( anAllNodesMap ); anIter.More(); anIter.Next() )
+  // skt: advanced mesh selection
+  if( aSource->IsAdvancedSelectionEnabled() ) {
+    Handle(MeshVS_MeshOwner) anOwner;    
+    // Get the owner if it is already created
+    MeshVS_DataMapIteratorOfDataMapOfIntegerOwner anIt( GetOwnerMaps( Standard_False ) );
+    for( ; anIt.More(); anIt.Next() )
     {
-      Standard_Integer aKey = anIter.Key();
-      if ( !myDataSource->GetGeom ( aKey, Standard_False, aCoords, NbNodes, aType ) )
-        continue;
-
-      anAddr = myDataSource->GetAddr ( aKey, Standard_False );
-
-      Handle (MeshVS_MeshOwner) anOwner = new MeshVS_MeshOwner
-        ( this, aKey, anAddr, aType, 5 );
-
-      myNodeOwners.Bind ( aKey, anOwner );
-
-      if ( IsSelectableNode( aKey ) )
-      {
-        x = aCoords(1);
-        y = aCoords(2);
-        z = aCoords(3);
-        Handle (Select3D_SensitivePoint) aPoint = new Select3D_SensitivePoint
-          ( anOwner, gp_Pnt (x, y, z) );
-        theSelection->Add ( aPoint );
-      }
-      else
-        theSelection->Add ( new MeshVS_DummySensitiveEntity ( anOwner ) );
+      anOwner = Handle(MeshVS_MeshOwner)::DownCast( anIt.Value() );
+      // clear selected entities
+      if( !anOwner.IsNull() )
+	break;
     }
-    break;
-  case 0:
+    if( anOwner.IsNull() )
+      // Create one owner for the whole mesh and for all selection modes
+      anOwner = new MeshVS_MeshOwner( this, aSource, 5 );
+    // Save the owner. It will be available via GetOwnerMaps method
+    if( !myMeshOwners.IsBound( 1 ) )
+      myMeshOwners.Bind( 1, anOwner );
+    // Create one sensitive entity. It should detect mesh entities correspondingly
+    // to selection mode
+    Handle(MeshVS_SensitiveMesh) aSensMesh = new MeshVS_SensitiveMesh( anOwner, theMode );
+    theSelection->Add ( aSensMesh );
+  }
+  else {
+    switch ( theMode )
     {
-      if( myWholeMeshOwner.IsNull() )
-        myWholeMeshOwner = new SelectMgr_EntityOwner( this );
+    case MeshVS_SMF_Node:   // Nodes
+	
+      myNodeOwners.Clear();
+      
+      for ( anIter.Initialize( anAllNodesMap ); anIter.More(); anIter.Next() )
+      {
+	Standard_Integer aKey = anIter.Key();
+	if ( !myDataSource->GetGeom ( aKey, Standard_False, aCoords, NbNodes, aType ) )
+	  continue;
+	    
+	anAddr = myDataSource->GetAddr ( aKey, Standard_False );
+	
+	Handle (MeshVS_MeshEntityOwner) anOwner = new MeshVS_MeshEntityOwner
+	  ( this, aKey, anAddr, aType, 5 );
+	    
+	myNodeOwners.Bind ( aKey, anOwner );
+	    
+	if ( IsSelectableNode( aKey ) )
+	{
+	  x = aCoords(1);
+	  y = aCoords(2);
+	  z = aCoords(3);
+	  Handle (Select3D_SensitivePoint) aPoint = new Select3D_SensitivePoint
+	    ( anOwner, gp_Pnt (x, y, z) );
+	  theSelection->Add ( aPoint );
+	}
+	else
+	  theSelection->Add ( new MeshVS_DummySensitiveEntity ( anOwner ) );
+      }
+      break;
 
+    case MeshVS_SMF_Mesh:
+
+      if( myWholeMeshOwner.IsNull() )
+	myWholeMeshOwner = new SelectMgr_EntityOwner( this );
+      
       switch( mySelectionMethod )
       {
       case MeshVS_MSM_BOX:
@@ -326,15 +354,17 @@ void MeshVS_Mesh::ComputeSelection ( const Handle(SelectMgr_Selection)& theSelec
               myDataSource->GetGeom ( aKey, Standard_True, aCoords, NbNodes, aType );
               if( NbNodes==0 )
                 continue;
-              
-              Handle(TColStd_HArray1OfInteger) aElemNodes = 
-                myDataSource->GetNodesByElement( aKey );
+
+              MeshVS_Buffer aNodesBuf (NbNodes*sizeof(Standard_Integer));
+              TColStd_Array1OfInteger aElemNodes(aNodesBuf, 1, NbNodes);
+              if ( !myDataSource->GetNodesByElement ( aKey, aElemNodes, NbNodes ) )
+                continue;
 
               TColgp_Array1OfPnt Points( 1, NbNodes );
               for ( Standard_Integer i=1; i<=NbNodes; i++ )
               {
                 Points (i) = gp_Pnt ( aCoords (3*i-2), aCoords (3*i-1), aCoords (3*i) );
-                aSharedNodes.Add( aElemNodes->Value( i ) );
+                aSharedNodes.Add( aElemNodes( i ) );
               }
 
               anEnt = new Select3D_SensitiveFace( myWholeMeshOwner, Points );
@@ -352,17 +382,19 @@ void MeshVS_Mesh::ComputeSelection ( const Handle(SelectMgr_Selection)& theSelec
               myDataSource->GetGeom ( aKey, Standard_True, aCoords, NbNodes, aType );
               if( NbNodes==0 )
                 continue;
-              
-              Handle(TColStd_HArray1OfInteger) aElemNodes = 
-                myDataSource->GetNodesByElement( aKey );
+
+              MeshVS_Buffer aNodesBuf (NbNodes*sizeof(Standard_Integer));
+              TColStd_Array1OfInteger aElemNodes(aNodesBuf, 1, NbNodes);
+              if ( !myDataSource->GetNodesByElement ( aKey, aElemNodes, NbNodes ) )
+                continue;
 
               TColgp_Array1OfPnt Points( 1, NbNodes );
               Standard_Boolean all_shared = Standard_True;
               for ( Standard_Integer i=1; i<=NbNodes; i++ )
               {
                 Points (i) = gp_Pnt ( aCoords (3*i-2), aCoords (3*i-1), aCoords (3*i) );
-                all_shared = all_shared && aSharedNodes.Contains( aElemNodes->Value( i ) );
-                aSharedNodes.Add( aElemNodes->Value( i ) );
+                all_shared = all_shared && aSharedNodes.Contains( aElemNodes( i ) );
+                aSharedNodes.Add( aElemNodes( i ) );
               }
 
               if( !all_shared )
@@ -386,94 +418,194 @@ void MeshVS_Mesh::ComputeSelection ( const Handle(SelectMgr_Selection)& theSelec
         }
         break;
       }
-    }
-    break;
+      break;
 
-  default: // all residuary modes
-    {
-      Handle( MeshVS_HArray1OfSequenceOfInteger ) aTopo;
-
-      myElementOwners.Clear();
-
-      MeshVS_DataMapOfIntegerMeshOwner* CurMap = &my0DOwners;
-      if ( theMode == MeshVS_ET_Link )
-        CurMap = &myLinkOwners;
-      else if ( theMode == MeshVS_ET_Face )
-        CurMap = &myFaceOwners;
-      else if ( theMode == MeshVS_ET_Volume )
-        CurMap = &myVolumeOwners;
-
-      CurMap->Clear();
-
-      for (TColStd_MapIteratorOfPackedMapOfInteger anIterMV (anAllElementsMap);
-           anIterMV.More(); anIterMV.Next() )
+    case MeshVS_SMF_Group:
       {
-        Standard_Integer aKey = anIterMV.Key();
+        myGroupOwners.Clear();
 
-        if ( myDataSource->GetGeomType ( aKey, Standard_True, aType ) && theMode == aType )
+        TColStd_PackedMapOfInteger anAllGroupsMap;
+        aSource->GetAllGroups( anAllGroupsMap );
+
+        Handle( MeshVS_HArray1OfSequenceOfInteger ) aTopo;
+
+        for ( anIter.Initialize( anAllGroupsMap ); anIter.More(); anIter.Next() )
         {
-          myDataSource->GetGeom ( aKey, Standard_True, aCoords, NbNodes, aType );
-          anAddr = myDataSource->GetAddr ( aKey, Standard_True );
+          Standard_Integer aKeyGroup = anIter.Key();
 
+          MeshVS_EntityType aGroupType;
+          TColStd_PackedMapOfInteger aGroupMap;
+          if ( !myDataSource->GetGroup( aKeyGroup, aGroupType, aGroupMap ) )
+            continue;
+
+          anAddr = myDataSource->GetGroupAddr ( aKeyGroup );
           Standard_Integer aPrior = 0;
 
-          if( aType == MeshVS_ET_Volume )
+          if( aGroupType == MeshVS_ET_Volume )
             aPrior = 1;
-          if ( aType == MeshVS_ET_Face )
+          if ( aGroupType == MeshVS_ET_Face )
             aPrior = 2;
-          else if ( aType == MeshVS_ET_Link )
+          else if ( aGroupType == MeshVS_ET_Link )
             aPrior = 3;
-          else if ( aType == MeshVS_ET_0D )
+          else if ( aGroupType == MeshVS_ET_0D )
             aPrior = 4;
+          else if ( aGroupType == MeshVS_ET_Node )
+            aPrior = 5;
 
-          Handle (MeshVS_MeshOwner) anOwner = new MeshVS_MeshOwner
-            ( this, aKey, anAddr, aType, aPrior );
+          Handle (MeshVS_MeshEntityOwner) anOwner = new MeshVS_MeshEntityOwner
+            ( this, aKeyGroup, anAddr, aGroupType, aPrior, Standard_True );
 
-          CurMap->Bind ( aKey, anOwner );
+          myGroupOwners.Bind( aKeyGroup, anOwner );
 
-          if ( IsSelectableElem( aKey ) ) //The element is selectable
+          Standard_Boolean added = Standard_False;
+          for ( TColStd_MapIteratorOfPackedMapOfInteger anIterMG (aGroupMap);
+                anIterMG.More(); anIterMG.Next() )
           {
-            TColgp_Array1OfPnt anArr( 1, NbNodes );
-            for ( Standard_Integer i=1; i<=NbNodes; i++ )
-            {
-              x = aCoords(3*i-2);
-              y = aCoords(3*i-1);
-              z = aCoords(3*i);
-              anArr.SetValue ( i, gp_Pnt ( x, y, z ) );
+            Standard_Integer aKey = anIterMG.Key();
+            if ( aGroupType == MeshVS_ET_Node ) {
+              if( myDataSource->GetGeom( aKey, Standard_False, aCoords, NbNodes, aType ) &&
+                  IsSelectableNode/*!IsHiddenNode*/( aKey ) ) {
+                theSelection->Add( new Select3D_SensitivePoint( anOwner, gp_Pnt ( aCoords(1), aCoords(2), aCoords(3) ) ) );
+                added = Standard_True;
+              }
             }
+            else if ( myDataSource->GetGeomType ( aKey, Standard_True, aType ) &&
+                      IsSelectableElem/*!IsHiddenElem*/( aKey ) ) {
+              myDataSource->GetGeom ( aKey, Standard_True, aCoords, NbNodes, aType );
 
-            if ( aType == MeshVS_ET_Face && NbNodes > 0 )      // Faces: 2D-elements
-            {
-              Handle (MeshVS_SensitiveFace) aFace = 
+              TColgp_Array1OfPnt anArr( 1, NbNodes );
+              for ( Standard_Integer i=1; i<=NbNodes; i++ )
+              {
+                x = aCoords(3*i-2);
+                y = aCoords(3*i-1);
+                z = aCoords(3*i);
+                anArr.SetValue ( i, gp_Pnt ( x, y, z ) );
+              }
+
+              if ( aType == MeshVS_ET_Face && NbNodes > 0 )      // Faces: 2D-elements
+              {
+                Handle (MeshVS_SensitiveFace) aFace = 
                   new MeshVS_SensitiveFace( anOwner, anArr );
-              theSelection->Add ( aFace );
-            }
-            else if ( aType == MeshVS_ET_Link && NbNodes > 0 ) // Links: 1D-elements
-            {
-              Handle (MeshVS_SensitiveSegment) aSeg = new MeshVS_SensitiveSegment
-                ( anOwner, anArr(1), anArr(2) );
-              theSelection->Add ( aSeg );
-            }
-            else if( aType == MeshVS_ET_Volume && aSource->Get3DGeom( aKey, NbNodes, aTopo ) )
-            {
-              Handle( MeshVS_SensitivePolyhedron ) aPolyhedron = 
+                theSelection->Add ( aFace );
+                added = Standard_True;
+              }
+              else if ( aType == MeshVS_ET_Link && NbNodes > 0 ) // Links: 1D-elements
+              {
+                Handle (MeshVS_SensitiveSegment) aSeg = new MeshVS_SensitiveSegment
+                  ( anOwner, anArr(1), anArr(2) );
+                theSelection->Add ( aSeg );
+                added = Standard_True;
+              }
+              else if( aType == MeshVS_ET_Volume && aSource->Get3DGeom( aKey, NbNodes, aTopo ) )
+              {
+                Handle( MeshVS_SensitivePolyhedron ) aPolyhedron = 
                   new MeshVS_SensitivePolyhedron( anOwner, anArr, aTopo );
-              theSelection->Add( aPolyhedron );
-            }
-            else //if ( aType == MeshVS_ET_0D )   // Custom : not only 0D-elements !!!
-            {
-              Handle (SelectBasics_SensitiveEntity) anEnt =
-                myHilighter->CustomSensitiveEntity ( anOwner, aKey );
-              if (!anEnt.IsNull())
-                theSelection->Add ( anEnt );
+                theSelection->Add( aPolyhedron );
+                added = Standard_True;
+              }
+              else //if ( aType == MeshVS_ET_0D )   // Custom : not only 0D-elements !!!
+              {
+                Handle (SelectBasics_SensitiveEntity) anEnt =
+                  myHilighter->CustomSensitiveEntity ( anOwner, aKey );
+                if (!anEnt.IsNull()) {
+                  theSelection->Add ( anEnt );
+                  added = Standard_True;
+                }
+              }
             }
           }
-          else
+          if ( !added )
             theSelection->Add ( new MeshVS_DummySensitiveEntity ( anOwner ) );
         }
       }
+      break;
+
+    default: // all residuary modes
+      {
+        Handle( MeshVS_HArray1OfSequenceOfInteger ) aTopo;
+
+        myElementOwners.Clear();
+
+        MeshVS_DataMapOfIntegerOwner* CurMap = &my0DOwners;
+        if ( theMode == MeshVS_ET_Link )
+          CurMap = &myLinkOwners;
+        else if ( theMode == MeshVS_ET_Face )
+          CurMap = &myFaceOwners;
+        else if ( theMode == MeshVS_ET_Volume )
+          CurMap = &myVolumeOwners;
+
+        CurMap->Clear();
+
+        for (TColStd_MapIteratorOfPackedMapOfInteger anIterMV (anAllElementsMap);
+             anIterMV.More(); anIterMV.Next() )
+        {
+          Standard_Integer aKey = anIterMV.Key();
+
+          if ( myDataSource->GetGeomType ( aKey, Standard_True, aType ) && theMode == aType )
+          {
+            myDataSource->GetGeom ( aKey, Standard_True, aCoords, NbNodes, aType );
+            anAddr = myDataSource->GetAddr ( aKey, Standard_True );
+
+            Standard_Integer aPrior = 0;
+
+            if( aType == MeshVS_ET_Volume )
+              aPrior = 1;
+            if ( aType == MeshVS_ET_Face )
+              aPrior = 2;
+            else if ( aType == MeshVS_ET_Link )
+              aPrior = 3;
+            else if ( aType == MeshVS_ET_0D )
+              aPrior = 4;
+
+            Handle (MeshVS_MeshEntityOwner) anOwner = new MeshVS_MeshEntityOwner
+              ( this, aKey, anAddr, aType, aPrior );
+
+            CurMap->Bind ( aKey, anOwner );
+
+            if ( IsSelectableElem( aKey ) ) //The element is selectable
+            {
+              TColgp_Array1OfPnt anArr( 1, NbNodes );
+              for ( Standard_Integer i=1; i<=NbNodes; i++ )
+              {
+                x = aCoords(3*i-2);
+                y = aCoords(3*i-1);
+                z = aCoords(3*i);
+                anArr.SetValue ( i, gp_Pnt ( x, y, z ) );
+              }
+
+              if ( aType == MeshVS_ET_Face && NbNodes > 0 )      // Faces: 2D-elements
+              {
+                Handle (MeshVS_SensitiveFace) aFace = 
+                  new MeshVS_SensitiveFace( anOwner, anArr );
+                theSelection->Add ( aFace );
+              }
+              else if ( aType == MeshVS_ET_Link && NbNodes > 0 ) // Links: 1D-elements
+              {
+                Handle (MeshVS_SensitiveSegment) aSeg = new MeshVS_SensitiveSegment
+                  ( anOwner, anArr(1), anArr(2) );
+                theSelection->Add ( aSeg );
+              }
+              else if( aType == MeshVS_ET_Volume && aSource->Get3DGeom( aKey, NbNodes, aTopo ) )
+              {
+                Handle( MeshVS_SensitivePolyhedron ) aPolyhedron = 
+                  new MeshVS_SensitivePolyhedron( anOwner, anArr, aTopo );
+                theSelection->Add( aPolyhedron );
+              }
+              else //if ( aType == MeshVS_ET_0D )   // Custom : not only 0D-elements !!!
+              {
+                Handle (SelectBasics_SensitiveEntity) anEnt =
+                  myHilighter->CustomSensitiveEntity ( anOwner, aKey );
+                if (!anEnt.IsNull())
+                  theSelection->Add ( anEnt );
+              }
+            }
+            else
+              theSelection->Add ( new MeshVS_DummySensitiveEntity ( anOwner ) );
+          }
+        }
+      }
+      break;
     }
-    break;
   }
 
   if ( ShowComputeSelectionTime )
@@ -607,24 +739,6 @@ void MeshVS_Mesh::RemoveBuilderById ( const Standard_Integer Id )
   }
 }
 
-//================================================================
-// Function : TColStdMapToMeshVSMap
-// Purpose  :
-//================================================================
-void MeshVS_Mesh::TColStdMapToMeshVSArray(const TColStd_PackedMapOfInteger& Map,
-                                          MeshVS_Array1OfIntegerBoolean& Array)
-{
-  Standard_Integer i, low = Array.Lower();
-  TColStd_MapIteratorOfPackedMapOfInteger anIter (Map);
-
-  for( i=0; anIter.More(); anIter.Next(), i++ )
-  {
-    MeshVS_IntegerBoolean& anArrayElem = Array.ChangeValue (low+i);
-    anArrayElem.Key = anIter.Key();
-    anArrayElem.Value = Standard_True;
-  }
-}
-
 //================================================================
 // Function : SetHiddenElems
 // Purpose  :
@@ -677,9 +791,9 @@ const Handle(TColStd_HPackedMapOfInteger)& MeshVS_Mesh::GetHiddenNodes () const
 // Function : AddToMap
 // Purpose  :
 //================================================================
-void AddToMap ( MeshVS_DataMapOfIntegerMeshOwner& Result, const MeshVS_DataMapOfIntegerMeshOwner& Addition )
+void AddToMap ( MeshVS_DataMapOfIntegerOwner& Result, const MeshVS_DataMapOfIntegerOwner& Addition )
 {
-  MeshVS_DataMapIteratorOfDataMapOfIntegerMeshOwner anIt ( Addition );
+  MeshVS_DataMapIteratorOfDataMapOfIntegerOwner anIt ( Addition );
   for ( ; anIt.More(); anIt.Next() )
     if ( Result.IsBound ( anIt.Key() ) )
       Result.ChangeFind ( anIt.Key() ) = anIt.Value();
@@ -691,8 +805,11 @@ void AddToMap ( MeshVS_DataMapOfIntegerMeshOwner& Result, const MeshVS_DataMapOf
 // Function : GetOwnerMaps
 // Purpose  :
 //================================================================
-const MeshVS_DataMapOfIntegerMeshOwner& MeshVS_Mesh::GetOwnerMaps ( const Standard_Boolean IsElements )
+const MeshVS_DataMapOfIntegerOwner& MeshVS_Mesh::GetOwnerMaps ( const Standard_Boolean IsElements )
 {
+  Handle(MeshVS_DataSource) aDS = GetDataSource();
+  if( !aDS.IsNull() && aDS->IsAdvancedSelectionEnabled() )
+    return myMeshOwners;
   if ( IsElements )
   {
     if ( myElementOwners.IsEmpty() )
@@ -797,18 +914,50 @@ void MeshVS_Mesh::HilightSelected ( const Handle(PrsMgr_PresentationManager3d)&
 
   Standard_Integer len = theOwners.Length(), i;
 
-  Handle (MeshVS_MeshOwner) anOwner;
+  Handle (MeshVS_MeshEntityOwner) anOwner;
   TColStd_PackedMapOfInteger aSelNodes, aSelElements;
 
   for( i=1; i<=len; i++ )
   {
-    anOwner = Handle (MeshVS_MeshOwner)::DownCast ( theOwners.Value ( i ) );
+    anOwner = Handle (MeshVS_MeshEntityOwner)::DownCast ( theOwners.Value ( i ) );
     if ( !anOwner.IsNull() )
     {
-      if( anOwner->Type() == MeshVS_ET_Node )
-        aSelNodes.Add( anOwner->ID() );
-      else
-        aSelElements.Add( anOwner->ID() );
+      // nkv: add support of mesh groups
+      if ( anOwner->IsGroup() ) {
+        MeshVS_EntityType aGroupType;
+        TColStd_PackedMapOfInteger aGroupMap;
+        if ( GetDataSource()->GetGroup( anOwner->ID(), aGroupType, aGroupMap ) ) {
+          if ( aGroupType == MeshVS_ET_Node ) {
+            for( TColStd_MapIteratorOfPackedMapOfInteger anIt(aGroupMap); anIt.More(); anIt.Next() )
+              if( IsSelectableNode/*!IsHiddenNode*/( anIt.Key() ) )
+                aSelNodes.Add( anIt.Key() );
+          }
+          else {
+            for( TColStd_MapIteratorOfPackedMapOfInteger anIt(aGroupMap); anIt.More(); anIt.Next() )
+              if( IsSelectableElem/*!IsHiddenElem*/( anIt.Key() ) )
+                aSelElements.Add( anIt.Key() );
+          }
+        }
+      }
+      else {
+        if( anOwner->Type() == MeshVS_ET_Node )
+          aSelNodes.Add( anOwner->ID() );
+        else
+          aSelElements.Add( anOwner->ID() );
+      }
+    }
+    else if( GetDataSource()->IsAdvancedSelectionEnabled() )
+    {
+      Handle(MeshVS_MeshOwner) aMeshOwner = Handle(MeshVS_MeshOwner)::DownCast ( theOwners.Value ( i ) );
+      if( !aMeshOwner.IsNull() )
+      {
+	Handle(TColStd_HPackedMapOfInteger) aNodes = aMeshOwner->GetSelectedNodes();
+	Handle(TColStd_HPackedMapOfInteger) aElems = aMeshOwner->GetSelectedElements();
+	if( !aNodes.IsNull() )
+	  aSelNodes.Assign( aNodes->Map() );
+	if( !aElems.IsNull() )
+	  aSelElements.Assign( aElems->Map() );
+      }
     }
 //agv    else if( theOwners.Value ( i )==myWholeMeshOwner )
     else if (IsWholeMeshOwner (theOwners.Value ( i )))
@@ -835,15 +984,13 @@ void MeshVS_Mesh::HilightSelected ( const Handle(PrsMgr_PresentationManager3d)&
 
   if( aSelNodes.Extent()>0 )
   {
-    MeshVS_Array1OfIntegerBoolean aNodes( 1, aSelNodes.Extent() );
-    TColStdMapToMeshVSArray( aSelNodes, aNodes );
-    myHilighter->Build ( aSelectionPrs, aNodes, Standard_False, MeshVS_DMF_SelectionPrs );
+    TColStd_PackedMapOfInteger tmp;
+    myHilighter->Build ( aSelectionPrs, aSelNodes, tmp, Standard_False, MeshVS_DMF_SelectionPrs );
   }
   if( aSelElements.Extent()>0 )
   {
-    MeshVS_Array1OfIntegerBoolean anElems( 1, aSelElements.Extent() );
-    TColStdMapToMeshVSArray( aSelElements, anElems );
-    myHilighter->Build( aSelectionPrs, anElems, Standard_True, MeshVS_DMF_SelectionPrs );
+    TColStd_PackedMapOfInteger tmp;
+    myHilighter->Build( aSelectionPrs, aSelElements, tmp, Standard_True, MeshVS_DMF_SelectionPrs );
   }
 
   myHilighter->SetDrawer ( 0 );
@@ -897,58 +1044,82 @@ void MeshVS_Mesh::HilightOwnerWithColor ( const Handle(PrsMgr_PresentationManage
     aHilightPrs->SetTransformPersistence( Presentation()->TransformPersistenceMode(), Presentation()->TransformPersistencePoint() );
   //----------------
 
-  const Standard_Boolean isElementOwner   =
-    !Owner.IsNull() && Owner->IsKind ( STANDARD_TYPE ( MeshVS_MeshOwner ) );
+  if( Owner.IsNull() ) return;
+
+  const Standard_Boolean isMeshEntityOwner = Owner->IsKind ( STANDARD_TYPE ( MeshVS_MeshEntityOwner ) );
   const Standard_Boolean isWholeMeshOwner =
 //agv    !Owner.IsNull() && Owner==myWholeMeshOwner;
     IsWholeMeshOwner (Owner);
 
-  if( isElementOwner || isWholeMeshOwner/* || IsGroupOwner( Owner ) */)
+  Standard_Integer aDispMode = MeshVS_DMF_Shading;
+  if ( HasDisplayMode() && ( DisplayMode() & MeshVS_DMF_OCCMask ) > MeshVS_DMF_WireFrame )
+    aDispMode = ( DisplayMode() & MeshVS_DMF_OCCMask );
+  //It because we draw hilighted owners only in shading or shrink (not in wireframe)
+
+  myHilightDrawer->SetColor( MeshVS_DA_InteriorColor, Color );
+  myHilightDrawer->SetColor( MeshVS_DA_BackInteriorColor, Color );
+  myHilightDrawer->SetColor( MeshVS_DA_EdgeColor, Color );
+  myHilightDrawer->SetColor( MeshVS_DA_BeamColor, Color );
+  myHilightDrawer->SetColor( MeshVS_DA_MarkerColor, Color );
+  myHilighter->SetDrawer( myHilightDrawer );
+
+  if( isMeshEntityOwner )
   {
-    Handle ( MeshVS_MeshOwner ) theAISOwner = Handle ( MeshVS_MeshOwner )::DownCast ( Owner );
+    Handle ( MeshVS_MeshEntityOwner ) theAISOwner = Handle ( MeshVS_MeshEntityOwner )::DownCast ( Owner );
+    MeshVS_EntityType aType = theAISOwner->Type();
+    Standard_Integer  anID  = theAISOwner->ID();
 
-    Standard_Integer aDispMode = MeshVS_DMF_Shading;
-    if ( HasDisplayMode() && ( DisplayMode() & MeshVS_DMF_OCCMask ) > MeshVS_DMF_WireFrame )
-      aDispMode = ( DisplayMode() & MeshVS_DMF_OCCMask );
-    //It because we draw hilighted owners only in shading or shrink (not in wireframe)
-
-    myHilightDrawer->SetColor( MeshVS_DA_InteriorColor, Color );
-    myHilightDrawer->SetColor( MeshVS_DA_BackInteriorColor, Color );
-    myHilightDrawer->SetColor( MeshVS_DA_EdgeColor, Color );
-    myHilightDrawer->SetColor( MeshVS_DA_BeamColor, Color );
-    myHilightDrawer->SetColor( MeshVS_DA_MarkerColor, Color );
-    myHilighter->SetDrawer( myHilightDrawer );
-
-    if( isElementOwner )
-    {
-      MeshVS_EntityType aType = theAISOwner->Type();
-      Standard_Integer  anID  = theAISOwner->ID();
-
-      MeshVS_Array1OfIntegerBoolean anOne( 1, 1 );
-      anOne.ChangeValue( 1 ).Key = anID;
-      anOne.ChangeValue( 1 ).Value = Standard_True;
-
-      myHilighter->Build( aHilightPrs, anOne, aType!=MeshVS_ET_Node, aDispMode | MeshVS_DMF_HilightPrs );
+    if ( theAISOwner->IsGroup() ) {
+      MeshVS_EntityType aGroupType;
+      TColStd_PackedMapOfInteger aGroupMap;
+      if ( myDataSource->GetGroup( anID, aGroupType, aGroupMap ) ) {
+        TColStd_PackedMapOfInteger tmp;
+        myHilighter->Build( aHilightPrs, aGroupMap, tmp, aType!=MeshVS_ET_Node,
+                            aDispMode | MeshVS_DMF_HilightPrs );
+      }
     }
-//      else if( IsGroupOwner( Owner ))
-//      {
-//        MeshVS_Array1OfIntegerBoolean anElements( 1, GetAllElementsFromGroup().Extent() );
-//        TColStdMapToMeshVSArray ( GetAllElementsFromGroup(), anElements );
-
-//        myHilighter->Build( aHilightPrs, anElements, Standard_True, MeshVS_DMF_WireFrame );
-//      }
-    else if( ! GetDataSource().IsNull() )
-    {
-      MeshVS_Array1OfIntegerBoolean anElements( 1, GetDataSource()->GetAllElements().Extent() );
-      TColStdMapToMeshVSArray ( GetDataSource()->GetAllElements(), anElements );
-
-      myHilighter->Build( aHilightPrs, anElements, Standard_True, MeshVS_DMF_WireFrame );
+    else {
+      TColStd_PackedMapOfInteger anOne, tmp;
+      anOne.Add (anID);
+      myHilighter->Build( aHilightPrs, anOne, tmp, aType!=MeshVS_ET_Node,
+                          aDispMode | MeshVS_DMF_HilightPrs );
     }
-
-    if( PM->IsImmediateModeOn() )
-      PM->AddToImmediateList( aHilightPrs );
-    myHilighter->SetDrawer ( 0 );
   }
+  else if( isWholeMeshOwner  )
+  {
+    if( ! GetDataSource().IsNull() )
+    {
+      TColStd_PackedMapOfInteger tmp;
+      myHilighter->Build( aHilightPrs, GetDataSource()->GetAllElements(), tmp,
+                          Standard_True, MeshVS_DMF_WireFrame );
+    }
+  }
+  else 
+  {
+    Handle(MeshVS_MeshOwner) aMeshOwner = Handle(MeshVS_MeshOwner)::DownCast ( Owner );
+    if( !aMeshOwner.IsNull() )
+    {
+      Handle(TColStd_HPackedMapOfInteger) aNodes = aMeshOwner->GetDetectedNodes();
+      Handle(TColStd_HPackedMapOfInteger) aElems = aMeshOwner->GetDetectedElements();
+      // hilight detected entities
+      if( !aNodes.IsNull() )
+      {
+        TColStd_PackedMapOfInteger tmp;
+	myHilighter->Build( aHilightPrs, aNodes->Map(), tmp, Standard_False,
+                            aDispMode | MeshVS_DMF_HilightPrs );
+      }
+      if( !aElems.IsNull() )
+      {
+        TColStd_PackedMapOfInteger tmp;
+	myHilighter->Build( aHilightPrs, aElems->Map(), tmp, Standard_True,
+                            aDispMode | MeshVS_DMF_HilightPrs );
+      }
+    }    
+  }
+
+  if( PM->IsImmediateModeOn() )
+    PM->AddToImmediateList( aHilightPrs );
+  myHilighter->SetDrawer ( 0 );
 }
 
 //=======================================================================
@@ -959,7 +1130,7 @@ void MeshVS_Mesh::ClearSelected ()
 {
   Handle( Prs3d_Presentation ) aSelectionPrs = GetSelectPresentation( NULL );  
   if( !aSelectionPrs.IsNull() )
-    aSelectionPrs->Clear();
+    aSelectionPrs->Clear(); 
 }
 
 //=======================================================================
@@ -972,10 +1143,8 @@ Handle (MeshVS_PrsBuilder) MeshVS_Mesh::FindBuilder ( const Standard_CString the
   Handle(MeshVS_PrsBuilder) aBuilder;
   Standard_Boolean IsExist = Standard_False;
 
-  Handle ( Standard_Type ) aType = new Standard_Type ( theTypeName );
-
   for ( Standard_Integer i=1; i<=len && !IsExist; i++)
-    if ( myBuilders.Value (i)->IsKind ( aType ) )
+    if ( myBuilders.Value (i)->IsKind ( theTypeName ) )
     {
       aBuilder = myBuilders.Value (i);
       IsExist = Standard_True;
@@ -1043,8 +1212,8 @@ Standard_Boolean MeshVS_Mesh::IsSelectableElem ( const Standard_Integer ID ) con
 //=======================================================================
 Standard_Boolean MeshVS_Mesh::IsSelectableNode ( const Standard_Integer ID ) const
 {
-  // by default, all nodes are selectable
-  return mySelectableNodes.IsNull() || mySelectableNodes->Map().Contains( ID );
+  return mySelectableNodes.IsNull() ? ! IsHiddenNode ( ID ) : 
+                                      mySelectableNodes->Map().Contains( ID );
 }
 
 //=======================================================================
@@ -1073,8 +1242,10 @@ void MeshVS_Mesh::UpdateSelectableNodes()
 {
   mySelectableNodes = new TColStd_HPackedMapOfInteger;
   
+  Standard_Integer aMaxFaceNodes;
   Handle( MeshVS_DataSource ) aSource = GetDataSource();
-  if ( aSource.IsNull() )
+  if ( aSource.IsNull() || myCurrentDrawer.IsNull() || !myCurrentDrawer->GetInteger
+         ( MeshVS_DA_MaxFaceNodes, aMaxFaceNodes ) || aMaxFaceNodes<=0 )
     return;
 
   // all non-hidden nodes are selectable;
@@ -1084,7 +1255,7 @@ void MeshVS_Mesh::UpdateSelectableNodes()
     mySelectableNodes->ChangeMap().Subtraction (aSource->GetAllNodes(),
                                                 myHiddenNodes->Map());
   } 
-  
+
   // add all nodes belonging to non-hidden elements
   TColStd_MapIteratorOfPackedMapOfInteger anIter( aSource->GetAllElements() );
   for ( ; anIter.More(); anIter.Next() )
@@ -1093,10 +1264,13 @@ void MeshVS_Mesh::UpdateSelectableNodes()
     if ( IsHiddenElem (aKey) )
       continue;
 
-    Handle(TColStd_HArray1OfInteger) aNodes = 
-      myDataSource->GetNodesByElement ( aKey );
-    for ( Standard_Integer i=1, n=aNodes->Length(); i<=n; i++ )
-      mySelectableNodes->ChangeMap().Add ( aNodes->Value(i) );
+    MeshVS_Buffer aNodesBuf (aMaxFaceNodes*sizeof(Standard_Integer));
+    TColStd_Array1OfInteger aNodes (aNodesBuf, 1, aMaxFaceNodes);
+    Standard_Integer NbNodes;
+    if ( !aSource->GetNodesByElement ( aKey, aNodes, NbNodes ) )
+      continue;
+    for ( Standard_Integer i=1; i<=NbNodes; i++ )
+      mySelectableNodes->ChangeMap().Add ( aNodes(i) );
   }
 }
 
