@@ -20,12 +20,13 @@
 #include <Prs3d_Root.hxx>
 #include <Prs3d_LineAspect.hxx>
 
-#include <TColStd_MapIteratorOfMapOfInteger.hxx>
+#include <TColStd_MapIteratorOfPackedMapOfInteger.hxx>
 #include <TColStd_ListIteratorOfListOfInteger.hxx>
 #include <TColStd_Array1OfReal.hxx>
 #include <TColStd_HArray1OfReal.hxx>
-#include <TColStd_HArray1OfInteger.hxx>
+#include <TColStd_Array1OfInteger.hxx>
 #include <TColStd_SequenceOfInteger.hxx>
+#include <TColStd_HPackedMapOfInteger.hxx>
 
 #include <MeshVS_DisplayModeFlags.hxx>
 #include <MeshVS_DrawerAttribute.hxx>
@@ -34,6 +35,7 @@
 #include <MeshVS_Mesh.hxx>
 #include <MeshVS_MeshPrsBuilder.hxx>
 #include <MeshVS_HArray1OfSequenceOfInteger.hxx>
+#include <MeshVS_Buffer.hxx>
 
 #include <gp_Pnt.hxx>
 #include <Image_ColorImage.hxx>
@@ -67,8 +69,9 @@ DEFINE_STANDARD_HANDLE(MeshVS_ImageTexture2D,Graphic3d_Texture2D)
 IMPLEMENT_STANDARD_HANDLE(MeshVS_ImageTexture2D,Graphic3d_Texture2D)
 IMPLEMENT_STANDARD_RTTIEXT(MeshVS_ImageTexture2D, Graphic3d_Texture2D)
 
-MeshVS_ImageTexture2D::MeshVS_ImageTexture2D( Handle(Graphic3d_StructureManager) theSM, 
-				const Handle(AlienImage_AlienImage)& theImg )
+MeshVS_ImageTexture2D::MeshVS_ImageTexture2D
+                        (Handle(Graphic3d_StructureManager) theSM, 
+                         const Handle(AlienImage_AlienImage)& theImg)
 : Graphic3d_Texture2D( theSM, "", Graphic3d_TOT_2D )
 {
   MyCInitTexture.doModulate = 0/*1*/;
@@ -137,7 +140,8 @@ MeshVS_NodalColorPrsBuilder::MeshVS_NodalColorPrsBuilder ( const Handle(MeshVS_M
 // Purpose  :
 //================================================================
 void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
-                                          MeshVS_Array1OfIntegerBoolean& IDs,
+                                          const TColStd_PackedMapOfInteger& IDs,
+                                          TColStd_PackedMapOfInteger& IDsToExclude,
                                           const Standard_Boolean IsElement,
                                           const Standard_Integer DisplayMode) const
 {
@@ -150,7 +154,8 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
   if ( !aDrawer->GetInteger ( MeshVS_DA_MaxFaceNodes, aMaxFaceNodes ) || aMaxFaceNodes <= 0 )
     return;
 
-  TColStd_Array1OfReal aCoords ( 1, 3 * aMaxFaceNodes );
+  MeshVS_Buffer aCoordsBuf (3*aMaxFaceNodes*sizeof(Standard_Real));
+  TColStd_Array1OfReal aCoords ( aCoordsBuf, 1, 3 * aMaxFaceNodes );
   Standard_Integer NbNodes;
   MeshVS_EntityType aType;
 
@@ -161,6 +166,14 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
        !myUseTexture && !myNodeColorMap.Extent() )
     return;
 
+  // subtract the hidden elements and ids to exclude (to minimise allocated memory)
+  TColStd_PackedMapOfInteger anIDs;
+  anIDs.Assign( IDs );
+  Handle(TColStd_HPackedMapOfInteger) aHiddenElems = myParentMesh->GetHiddenElems();
+  if ( !aHiddenElems.IsNull() )
+    anIDs.Subtract( aHiddenElems->Map() );
+  anIDs.Subtract( IDsToExclude );
+
   Standard_Boolean IsReflect = Standard_False, IsMeshSmoothShading = Standard_False;
   aDrawer->GetBoolean( MeshVS_DA_ColorReflection, IsReflect );
   aDrawer->GetBoolean( MeshVS_DA_SmoothShading,   IsMeshSmoothShading );
@@ -178,14 +191,16 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
     nbTextureColors = getNearestPow2( nbColors );
   }
   
-  Standard_Integer aSize = IDs.Upper() - IDs.Lower() + 1;
+  Standard_Integer aSize = anIDs.Extent();
 
   // Calculate maximum possible number of vertices and bounds
   Handle( MeshVS_HArray1OfSequenceOfInteger ) aTopo;
-  Standard_Integer PolygonVerticesFor3D = 0, PolygonBoundsFor3D = 0, index, up;
-  for ( index=IDs.Lower(), up=IDs.Upper(); index<=up; index++ )
+  Standard_Integer PolygonVerticesFor3D = 0, PolygonBoundsFor3D = 0;
+  TColStd_MapIteratorOfPackedMapOfInteger it (anIDs);
+  for( ; it.More(); it.Next() )
   {
-    if ( aSource->Get3DGeom( IDs.Value( index ).Key, NbNodes, aTopo ) )
+    Standard_Integer aKey = it.Key();
+    if ( aSource->Get3DGeom( aKey, NbNodes, aTopo ) )
       MeshVS_MeshPrsBuilder::HowManyPrimitives
       ( aTopo, Standard_True, Standard_False, NbNodes,
       PolygonVerticesFor3D, PolygonBoundsFor3D );
@@ -206,33 +221,30 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
   gp_Pnt P, Start;
   Standard_Real aMin = gp::Resolution() * gp::Resolution();
   gp_Dir aDefNorm( 0., 0., 1. );
-  
-  for ( index = IDs.Lower(), up = IDs.Upper(); index <= up; index++ )
+
+  for( it.Reset(); it.More(); it.Next() )
   {
-    MeshVS_IntegerBoolean& str = IDs.ChangeValue( index );
-    if ( str.Value && 
-      aSource->GetGeom  ( str.Key, Standard_True, aCoords, NbNodes, aType ) && 
-      !myParentMesh->IsHiddenElem( IDs.Value( index ).Key ) )
+    Standard_Integer aKey = it.Key();
+    if ( aSource->GetGeom  ( aKey, Standard_True, aCoords, NbNodes, aType ) )
     {
-      Handle(TColStd_HArray1OfInteger) aNodes =
-        aSource->GetNodesByElement ( str.Key );
-      if ( aNodes.IsNull() )
+      MeshVS_Buffer aNodesBuf (NbNodes*sizeof(Standard_Integer));
+      TColStd_Array1OfInteger aNodes(aNodesBuf, 1, NbNodes);
+      if ( !aSource->GetNodesByElement ( aKey, aNodes, NbNodes ) )
         continue;
 
-      Standard_Integer aLen = aNodes->Length();
       Quantity_Color aNColor;
 
       Standard_Boolean isValid = Standard_True;
       Standard_Integer i;
       if ( myUseTexture )
       {
-        for ( i = 1; i <= aLen && isValid; i++ )
-          isValid = myTextureCoords.IsBound( aNodes->Value( i ) );
+        for ( i = 1; i <= NbNodes && isValid; i++ )
+          isValid = myTextureCoords.IsBound( aNodes( i ) );
       }
       else
       {
-        for ( i = 1; i <= aLen && isValid; i++ )
-          isValid = GetColor ( aNodes->Value( i ), aNColor );
+        for ( i = 1; i <= NbNodes && isValid; i++ )
+          isValid = GetColor ( aNodes( i ), aNColor );
       }
 
       if ( !isValid )
@@ -241,19 +253,19 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
       // Preparing normal(s) to show reflections if requested
       Handle(TColStd_HArray1OfReal) aNormals;
       Standard_Boolean hasNormals = 
-        ( IsReflect && aSource->GetNormalsByElement( str.Key, IsMeshSmoothShading, aMaxFaceNodes, aNormals ) );
+        ( IsReflect && aSource->GetNormalsByElement( aKey, IsMeshSmoothShading, aMaxFaceNodes, aNormals ) );
 
       if ( aType == MeshVS_ET_Face )
       {
-        aCPolyArr->AddBound ( aLen );
-        aPolyL->AddBound ( aLen + 1 );
+        aCPolyArr->AddBound ( NbNodes );
+        aPolyL->AddBound ( NbNodes + 1 );
 
-        for ( i = 1; i <= aLen; i++)
+        for ( i = 1; i <= NbNodes; i++)
         {
           P = gp_Pnt( aCoords( 3 * i - 2 ), aCoords( 3 * i - 1 ), aCoords( 3 * i ) );
           if ( myUseTexture )
           {
-            int anId = aNodes->Value( i );
+            int anId = aNodes( i );
             double aTexCoord = myTextureCoords( anId );
 
             // transform texture coordinate in accordance with number of colors specified 
@@ -265,7 +277,7 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
           }
           else
           {
-            GetColor ( aNodes->Value( i ), aNColor );
+            GetColor ( aNodes( i ), aNColor );
             if ( IsReflect )
             {
               if ( hasNormals )
@@ -291,11 +303,11 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
 
         // if IsExcludingOn then presentation must not be built by other builders
         if ( IsExcludingOn() )
-          str.Value = Standard_False;
+          IDsToExclude.Add( aKey );
       }
       else if ( aType == MeshVS_ET_Volume )
       {
-        if ( !aSource->Get3DGeom( str.Key, NbNodes, aTopo ) )
+        if ( !aSource->Get3DGeom( aKey, NbNodes, aTopo ) )
           continue;
 
         // iterate through faces of volume 
@@ -315,7 +327,7 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
                         aCoords( 3 * ind + 3 ) );
             if ( myUseTexture )
             {
-              Standard_Integer anId = aNodes->Value( i );
+              Standard_Integer anId = aNodes( ind + 1 );
               Standard_Real aTexCoord = myTextureCoords( anId );
 
               // transform texture coordinate in accordance with number of colors specified 
@@ -327,7 +339,7 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
             }
             else
             {
-              GetColor( aNodes->Value( ind + 1 ), aNColor );
+              GetColor( aNodes( ind + 1 ), aNColor );
               if  ( IsReflect )
               {
                 if ( hasNormals )
@@ -354,10 +366,10 @@ void MeshVS_NodalColorPrsBuilder::Build ( const Handle(Prs3d_Presentation)& Prs,
 
         // if IsExcludingOn then presentation must not be built by other builders
         if ( IsExcludingOn() )
-          str.Value = Standard_False;
+          IDsToExclude.Add( aKey );
       } 
     } 
-  } // for ( index = ...
+  } // for ( ...
 
   Handle(Graphic3d_AspectFillArea3d) anAsp;
 
