@@ -5,9 +5,22 @@
 
 
 #include <Message.ixx>
+#include <Message_Messenger.hxx>
+
 #include <stdio.h>
 #include <string.h>
 
+//=======================================================================
+//function : DefaultMessenger
+//purpose  : 
+//=======================================================================
+
+const Handle(Message_Messenger)& Message::DefaultMessenger ()
+{
+  static Handle(Message_Messenger) aMessenger = new Message_Messenger;
+  return aMessenger;
+}
+
 //=======================================================================
 //function : FillTime
 //purpose  : 
