@@ -1,8 +1,8 @@
 ;#
 ;# Retourne la liste ordonnee des noms de Modules
 ;# 
-proc OS:Modules {} {
-   return [list FoundationClasses \
+proc OS:Modules { {plat ""} } {
+    set ret [list FoundationClasses \
 	   ModelingData \
 	   ModelingAlgorithms \
 	   Visualization \
@@ -10,6 +10,7 @@ proc OS:Modules {} {
 	   DataExchange \
 	   Draw \
 	   WOK \
-	   Wrappers \
 	   ]
+    if { $plat != "win64" } { lappend ret Wrappers }
+    return $ret
 }
