@@ -15,6 +15,8 @@
 #include <OSD_FromWhere.hxx>
 #include <OSD_File.ixx>
 
+#include <Standard_PCharacter.hxx>
+
 const OSD_WhoAmI Iam = OSD_WFile;
 
 #if defined (sun) || defined(SOLARIS)
@@ -278,7 +280,7 @@ OSD_File OSD_File::BuildTemporary(){
  
 void  OSD_File::Read(TCollection_AsciiString& Buffer, 
                      const Standard_Integer Nbyte){
- Standard_CString readbuf;
+ Standard_PCharacter readbuf;
  int status;
 
   if ( OSD_File::KindOfFile ( ) == OSD_DIRECTORY ) { 
@@ -297,10 +299,10 @@ void  OSD_File::Read(TCollection_AsciiString& Buffer,
   Standard_ProgramError::Raise("OSD_File::Read : Nbyte is null");
 
  TCollection_AsciiString transfert(Nbyte,' ');
- readbuf = transfert.ToCString();  // Get (char *) pointer of transfert
+ readbuf = (Standard_PCharacter)transfert.ToCString();  
 
  status = read( (int)myFileChannel, readbuf, Nbyte);
-
+ //
  Buffer = transfert;  // Copy transfert to Buffer
 
  if (status == -1) myError.SetValue (errno, Iam, "Read");
@@ -313,49 +315,49 @@ void  OSD_File::Read(TCollection_AsciiString& Buffer,
 // Read a line from a file
 // ---------------------------------------------------------------------
 
-void  OSD_File::ReadLine(TCollection_AsciiString& Buffer, 
-                         const Standard_Integer Nbyte,
-			       Standard_Integer& NByteRead){
- Standard_CString readbuf;
- Standard_CString abuffer;
-
-  if ( OSD_File::KindOfFile ( ) == OSD_DIRECTORY ) { 
+void OSD_File::ReadLine(TCollection_AsciiString& Buffer, 
+			const Standard_Integer Nbyte,
+			Standard_Integer& NByteRead)
+{
+  Standard_PCharacter readbuf, abuffer;
+  //
+  if (OSD_File::KindOfFile() == OSD_DIRECTORY ) { 
     Standard_ProgramError::Raise("OSD_File::Read : it is a directory");
   }
-
- if (myFileChannel == -1)
-  Standard_ProgramError::Raise("OSD_File::ReadLine : file is not open");
-
- if (Failed()) Perror();
-
- if (myMode == OSD_WriteOnly)
-  Standard_ProgramError::Raise("OSD_File::ReadLine : file is Write only");
-
- if (Nbyte <= 0)
-  Standard_ProgramError::Raise("OSD_File::ReadLine : Nbyte is null");
-
- TCollection_AsciiString transfert(Nbyte,' ');
- readbuf = transfert.ToCString();  // Get (char *) pointer of transfert
-
- abuffer = fgets(readbuf, Nbyte, (FILE *) myFILE);
-
- if (abuffer == NULL)
-   if (!feof((FILE *) myFILE)) {
-     myError.SetValue (errno, Iam, "ReadLine");
-     return;
-   }
-   else {
-     myIO = EOF;
-     Buffer.Clear();
-     NByteRead = 0 ;
-   }
- else
-   {
-     NByteRead = strlen(abuffer);
-     Buffer.SetValue(1,abuffer);  // Copy transfert to Buffer
-     Buffer.Trunc(NByteRead);
-   }
- return;
+  if (myFileChannel == -1){
+    Standard_ProgramError::Raise("OSD_File::ReadLine : file is not open");
+  }
+  if (Failed()) {
+    Perror();
+  }
+  if (myMode == OSD_WriteOnly) {
+    Standard_ProgramError::Raise("OSD_File::ReadLine : file is Write only");
+  }
+  if (Nbyte <= 0){
+    Standard_ProgramError::Raise("OSD_File::ReadLine : Nbyte is null");
+  }
+  //
+  TCollection_AsciiString transfert(Nbyte,' ');
+  readbuf = (Standard_PCharacter)transfert.ToCString();
+  //
+  abuffer = fgets(readbuf, Nbyte, (FILE *) myFILE);
+  //
+  if (abuffer == NULL) {
+    if (!feof((FILE *) myFILE)) {
+      myError.SetValue (errno, Iam, "ReadLine");
+      return;
+    }
+    else {
+      myIO = EOF;
+      Buffer.Clear();
+      NByteRead = 0 ;
+    }
+  }
+  else   {
+    NByteRead = strlen(abuffer);
+    Buffer.SetValue(1,abuffer);  // Copy transfert to Buffer
+    Buffer.Trunc(NByteRead);
+  }
 }
 // -------------------------------------------------------------------------- 
 // OSD::KindOfFile Retourne le type de fichier.
@@ -814,6 +816,8 @@ Standard_Boolean OSD_File::IsExecutable()
 //-------------------  Windows NT sources for OSD_File -------------------
 //------------------------------------------------------------------------
 
+#include <windows.h>
+
 #include <OSD_File.hxx>
 #include <OSD_Protection.hxx>
 #include <OSD_Printer.hxx>
@@ -823,6 +827,7 @@ Standard_Boolean OSD_File::IsExecutable()
 
 #include <stdio.h>
 #include <io.h>
+#include <Standard_PCharacter.hxx>
 
 #ifndef _INC_TCHAR
 # include <tchar.h>
@@ -850,11 +855,11 @@ PSECURITY_DESCRIPTOR __fastcall _osd_wnt_protection_to_sd ( const OSD_Protection
 BOOL                 __fastcall _osd_wnt_sd_to_protection (
                                  PSECURITY_DESCRIPTOR, OSD_Protection&, BOOL
                                 );
-BOOL                 __fastcall _osd_print ( Standard_CString, Standard_CString );
+BOOL                 __fastcall _osd_print (const Standard_PCharacter, Standard_CString );
 
 static void      __fastcall _test_raise ( Standard_Integer, Standard_CString );
-static DWORDLONG __fastcall _get_line   ( Standard_CString, DWORD );
-static int       __fastcall _get_buffer ( HANDLE, Standard_CString, DWORD, BOOL, BOOL );
+static DWORDLONG __fastcall _get_line   ( Standard_PCharacter&, DWORD );
+static int       __fastcall _get_buffer ( HANDLE, Standard_PCharacter&, DWORD, BOOL, BOOL );
 static DWORD     __fastcall _get_access_mask ( OSD_SingleProtection );
 static DWORD     __fastcall _get_dir_access_mask ( OSD_SingleProtection prt );
 static HANDLE    __fastcall _open_file  ( Standard_CString, OSD_OpenMode, DWORD, LPBOOL = NULL );
@@ -1036,11 +1041,11 @@ void OSD_File :: Read (
 
  Read ( buff, Nbyte, NbyteRead );
 
- (  ( Standard_CString )buff  )[ NbyteRead ] = 0;
+ (  ( Standard_PCharacter )buff  )[ NbyteRead ] = 0;
 
  if ( NbyteRead != 0 )
 
-  Buffer = ( Standard_CString )buff;
+  Buffer = ( Standard_PCharacter )buff;
 
  else
 
@@ -1071,7 +1076,8 @@ void OSD_File :: ReadLine (
  DWORD              dwBytesRead;
  DWORD              dwDummy;
  Standard_Character peekChar;
- Standard_CString   cBuffer;
+ Standard_PCharacter ppeekChar;
+ Standard_PCharacter cBuffer;
  Standard_CString   eos;
  DWORD              dwSeekPos;
 
@@ -1088,6 +1094,8 @@ void OSD_File :: ReadLine (
                                         // +----> leave space for end-of-string
                                         // |       plus <CR><LF> sequence      
                                         // |
+
+ ppeekChar=&peekChar;
  cBuffer = new Standard_Character[ NByte + 3 ];
 
  if ( myIO & FLAG_FILE ) {
@@ -1120,7 +1128,7 @@ void OSD_File :: ReadLine (
                                           // peek next character to see if it is a <LF>
 #endif
     if (  !ReadFile (
-            ( HANDLE )myFileChannel, &peekChar, 1, &dwDummy, NULL
+            ( HANDLE )myFileChannel, ppeekChar, 1, &dwDummy, NULL
            )
     ) {
     
@@ -1186,7 +1194,7 @@ void OSD_File :: ReadLine (
     NbyteRead = dwBytesRead; // (LD) always fits this case.
 
     dwDummy = _get_buffer (
-               ( HANDLE )myFileChannel, &peekChar, 1, TRUE, myIO & FLAG_SOCKET
+               ( HANDLE )myFileChannel, ppeekChar, 1, TRUE, myIO & FLAG_SOCKET
               );
     if (  ( int )dwDummy == -1  ) {  // an error occured
    
@@ -1212,7 +1220,7 @@ void OSD_File :: ReadLine (
 
    // Don't rewrite datas in cBuffer.
 
-   Standard_CString cDummyBuffer = new Standard_Character[ NByte + 3 ];
+   Standard_PCharacter cDummyBuffer = new Standard_Character[ NByte + 3 ];
 
    _get_buffer (  // remove pending input
     ( HANDLE )myFileChannel, cDummyBuffer, dwBytesRead, FALSE, myIO & FLAG_SOCKET
@@ -1229,7 +1237,7 @@ void OSD_File :: ReadLine (
 
   Buffer = cBuffer;
 
- delete [] cBuffer;
+ delete [] (Standard_PCharacter)cBuffer;
 
 }  // end OSD_File :: ReadLine
 
@@ -1867,7 +1875,7 @@ void OSD_File :: Print ( const OSD_Printer& WhichPrinter ) {
  WhichPrinter.Name ( pName );
  myPath.SystemName ( fName );
 
- if (   !_osd_print ( pName.ToCString (), fName.ToCString ()  )   )
+ if (   !_osd_print ( (Standard_PCharacter)pName.ToCString (), fName.ToCString ()  )   )
 
   _osd_wnt_set_error ( myError, OSD_WFile );
 
@@ -2175,10 +2183,10 @@ static void __fastcall _test_raise ( Standard_Integer hFile, Standard_CString st
 // Modified so that we have <nl> at end of line if we have read <nl> or <cr>
 // by LD 17 dec 98 for B4.4
 
-static DWORDLONG __fastcall _get_line ( Standard_CString buffer, DWORD dwBuffSize ) {
+static DWORDLONG __fastcall _get_line ( Standard_PCharacter& buffer, DWORD dwBuffSize ) {
 
  DWORDLONG        retVal;
- Standard_CString ptr;
+ Standard_PCharacter ptr;
 
  buffer[ dwBuffSize ] = 0;
  ptr                  = buffer;
@@ -2306,7 +2314,8 @@ static DWORDLONG __fastcall _get_line ( Standard_CString buffer, DWORD dwBuffSiz
 
 static int __fastcall _get_buffer (
                         HANDLE hChannel,
-                        Standard_CString buffer, DWORD dwSize,
+                        Standard_PCharacter& buffer, 
+				   DWORD dwSize,
                         BOOL fPeek, BOOL fSocket
                        ) {
 
@@ -3017,7 +3026,7 @@ static OSD_SingleProtection __fastcall _get_protection_dir ( DWORD mask ) {
 #define __leave return fOK
 #endif
 
-BOOL __fastcall _osd_print ( Standard_CString pName, Standard_CString fName ) {
+BOOL __fastcall _osd_print (const Standard_PCharacter pName, Standard_CString fName ) {
 
  BOOL   fOK, fJob;                
  HANDLE hPrinter;
@@ -3028,7 +3037,7 @@ BOOL __fastcall _osd_print ( Standard_CString pName, Standard_CString fName ) {
 
  __try {
  
-  if (  !OpenPrinter ( pName, &hPrinter, NULL )  ) {
+  if (  !OpenPrinter ( Standard_PCharacter(pName), &hPrinter, NULL )  ) {
   
    hPrinter = NULL;
    __leave;
