@@ -223,9 +223,9 @@ int static copy_file( const char* src, const char* trg )
 
 
 
-void  OSD_FileNode::Copy(const OSD_Path& ToPath){
+void  OSD_FileNode::Copy(const OSD_Path& ToPath)
+{
 int status;
-char cmd_line [512];
 TCollection_AsciiString second_name;
 
 // if (myPath.Name().Length()==0)   Copy .login would raise !!
@@ -729,7 +729,7 @@ void OSD_FileNode::SetProtection ( const OSD_Protection& Prot ) {
         _get_file_type ( fName.ToCString (),
                          ( Standard_Integer )INVALID_HANDLE_VALUE  ) ==
         FLAG_DIRECTORY,
-        fName.ToCString ()
+        (char *)fName.ToCString ()
        );
  
  if ( pSD == NULL || !SetFileSecurity (
@@ -959,7 +959,7 @@ void _osd_wnt_set_error ( OSD_Error& err, OSD_WhoAmI who, ... ) {
         )
  ) {
  
-  wsprintf ( buffer, "error code %d", errCode );
+  sprintf ( buffer, "error code %d", (Standard_Integer)errCode );
   SetLastError ( errCode );
 
  }  // end if
