@@ -138,18 +138,22 @@ static void VmsExtract(const TCollection_AsciiString& what,
 }
 
 
+//=======================================================================
+//function : UnixExtract
+//purpose  : 
+//=======================================================================
 static void UnixExtract(const TCollection_AsciiString& what,
-                TCollection_AsciiString& node,
-                TCollection_AsciiString& username,
-                TCollection_AsciiString& password,
-                TCollection_AsciiString& trek,
-                TCollection_AsciiString& name,
-                TCollection_AsciiString& ext){
+			TCollection_AsciiString& node,
+			TCollection_AsciiString& username,
+			TCollection_AsciiString& password,
+			TCollection_AsciiString& trek,
+			TCollection_AsciiString& name,
+			TCollection_AsciiString& ext){
 
  Standard_Integer pos;
  TCollection_AsciiString buffer;   // To manipulate 'what' without modifying it
 
- char *p;
+ Standard_PCharacter p;
  buffer = what;
 
 #ifdef TOTO  // Username, password and node are no longer given in the string (LD)
@@ -187,7 +191,7 @@ static void UnixExtract(const TCollection_AsciiString& what,
 
  pos = trek.SearchFromEnd("|");  // Extract name
  if (pos != -1) {
-  p = trek.ToCString();
+  p = (Standard_PCharacter)trek.ToCString();
   name = &p[pos];
   if(name.Length()) trek.Remove(pos+1,name.Length());
  }
@@ -225,6 +229,10 @@ static void UnixExtract(const TCollection_AsciiString& what,
 }
 
 
+//=======================================================================
+//function : DosExtract
+//purpose  : 
+//=======================================================================
 static void DosExtract(const TCollection_AsciiString& what,
                 TCollection_AsciiString& disk,
                 TCollection_AsciiString& trek,
@@ -233,7 +241,7 @@ static void DosExtract(const TCollection_AsciiString& what,
 
  TCollection_AsciiString buffer;
  Standard_Integer pos;
- char *p;
+ Standard_PCharacter p;
 
  buffer = what;
 
@@ -264,7 +272,7 @@ static void DosExtract(const TCollection_AsciiString& what,
 
  pos = trek.SearchFromEnd("|");  // Extract name
  if (pos != -1) {
-  p = trek.ToCString();
+  p = (Standard_PCharacter)trek.ToCString();
   name = &p[pos];
   trek.Remove(trek.Search(name),name.Length());
  }
@@ -275,38 +283,42 @@ static void DosExtract(const TCollection_AsciiString& what,
 }
 
 
+//=======================================================================
+//function : MacExtract
+//purpose  : 
+//=======================================================================
 static void MacExtract(const TCollection_AsciiString& what,
                 TCollection_AsciiString& ,
                 TCollection_AsciiString& trek,
                 TCollection_AsciiString& name,
                 TCollection_AsciiString& ){
 
- Standard_Integer pos;
- char *p;
-
- // I don't know how to distingish a disk from a trek !
-
- trek = what;
-
- pos = trek.Search("::");
- while (pos != -1){        // Changes every "::" by '^'
-  trek.SetValue(pos,'^');
-  trek.Remove(pos+1,1);
+  Standard_Integer pos;
+  Standard_PCharacter p;
+  
+  // I don't know how to distingish a disk from a trek !
+  
+  trek = what;
+  
   pos = trek.Search("::");
- }
+  while (pos != -1){        // Changes every "::" by '^'
+    trek.SetValue(pos,'^');
+    trek.Remove(pos+1,1);
+    pos = trek.Search("::");
+  }
 
- trek.ChangeAll(':','|');  // Translates to portable syntax
+  trek.ChangeAll(':','|');  // Translates to portable syntax
 
- pos = trek.SearchFromEnd("|");  // Extract name
- if (pos != -1) {
-  p = trek.ToCString();
-  name = &p[pos+1];
-  trek.Remove(trek.Search(name),name.Length());
- }
- else {   // No '|' means no trek but a name
-  name = what;
-  trek = "";
- }
+  pos = trek.SearchFromEnd("|");  // Extract name
+  if (pos != -1) {
+    p = (Standard_PCharacter)trek.ToCString();
+    name = &p[pos+1];
+    trek.Remove(trek.Search(name),name.Length());
+  }
+  else {   // No '|' means no trek but a name
+    name = what;
+    trek = "";
+  }
 }
 
 
