@@ -154,7 +154,7 @@ void OSD::SetSignal(const Standard_Boolean aFloatingSignal)
 #endif
   }
   else if ( first_time & 1 ) {
-    cout << "SetSignal( Standard_False ) is not implemented..." << endl ;
+//    cout << "SetSignal( Standard_False ) is not implemented..." << endl ;
     first_time = first_time & (~ 1) ;
   }
 
@@ -565,28 +565,22 @@ void OSD::Handler(const OSD_Signals theSignal,
 //==== SegvHandler 
 //============================================================================
 
-#if defined(__osf__) || defined(DECOSF1)
-#define UndefinedHandleAddress ((Standard_Transient *)0xfefdfefdfefd0000)
-#else
-#define UndefinedHandleAddress ((Standard_Transient *)0xfefd0000)
-#endif
-
 #ifdef SA_SIGINFO
 
+#ifdef NO_CXX_EXCEPTION
 void OSD::SegvHandler(const OSD_Signals theSig,
                       const Standard_Address ip,
-		      const Standard_Address
-#ifdef NO_CXX_EXCEPTION
-                                             theContext
-#endif
-                      )
+		      const Standard_Address theContext)
 {
-  char Msg[100] ;
-#ifdef NO_CXX_EXCEPTION
   if (!Standard_ErrorHandler::IsInTryBlock()) {
-    Handler(theSig, ip,theContext);
+    Handler(theSig, ip, theContext);
     return;
   }
+#else
+void OSD::SegvHandler(const OSD_Signals,
+                      const Standard_Address ip,
+		      const Standard_Address)
+{
 #endif
 
 #ifdef linux
@@ -606,6 +600,7 @@ void OSD::SegvHandler(const OSD_Signals theSig,
 	Standard_NullObject::NewInstance("Attempt to access to null object")->Jump();
       }
      else {
+       char Msg[100];
        sprintf(Msg,"SIGSEGV 'segmentation violation' detected. Address %lx",
 	       (long ) address ) ;
        OSD_SIGSEGV::NewInstance(Msg)->Jump();
