@@ -13,6 +13,10 @@ static Standard_Boolean fSETranslator =
 //---------------------------- Windows NT System --------------------------------
 
 #define STRICT
+#ifdef NOUSER
+#undef NOUSER
+#endif
+#include <windows.h>
 
 #include <OSD_Exception_ACCESS_VIOLATION.hxx>
 #include <OSD_Exception_ARRAY_BOUNDS_EXCEEDED.hxx>
@@ -53,7 +57,7 @@ static LONG __fastcall _osd_raise ( DWORD, LPTSTR );
 static BOOL WINAPI     _osd_ctrl_break_handler ( DWORD );
 
 extern "C" Standard_EXPORT LONG _osd_debug   ( void );
-extern "C" Standard_EXPORT void _debug_break ( Standard_CString );
+extern "C" Standard_EXPORT void _debug_break ( Standard_PCharacter );
 
 MB_DESC fatalErrorDesc[] = {
 									  
@@ -205,7 +209,16 @@ static LONG CallHandler (DWORD dwExceptionCode ,
       lstrcpy (  buffer, TEXT( "FLT UNDERFLOW" )  );
       flterr = 1 ;
       break ;
-
+  case STATUS_FLOAT_MULTIPLE_TRAPS:
+//      cout << "CallHandler : EXCEPTION_FLT_UNDERFLOW:" << endl ;
+      lstrcpy (  buffer, TEXT( "FLT MULTIPLE TRAPS (possible overflow in conversion of double to integer)" )  );
+      flterr = 1 ;
+      break ;
+  case STATUS_FLOAT_MULTIPLE_FAULTS:
+//      cout << "CallHandler : EXCEPTION_FLT_UNDERFLOW:" << endl ;
+      lstrcpy (  buffer, TEXT( "FLT MULTIPLE FAULTS" )  );
+      flterr = 1 ;
+      break ;
 
   case STATUS_NO_MEMORY:
 //      cout << "CallHandler : STATUS_NO_MEMORY:" << endl ;
@@ -477,9 +490,9 @@ static BOOL WINAPI _osd_ctrl_break_handler ( DWORD dwCode ) {
 //==== _osd_raise 
 //============================================================================
 
-static LONG __fastcall _osd_raise ( DWORD dwCode, LPTSTR msg ) {
-
-if (  msg[ 0 ] == TEXT( '\x03' )  ) ++msg;
+static LONG __fastcall _osd_raise ( DWORD dwCode, LPTSTR msg ) 
+{
+  if (  msg[ 0 ] == TEXT( '\x03' )  ) ++msg;
 
  switch ( dwCode ) {
     
@@ -535,10 +548,10 @@ if (  msg[ 0 ] == TEXT( '\x03' )  ) ++msg;
   case EXCEPTION_FLT_UNDERFLOW:
        Standard_Underflow :: Raise ( msg );
   case EXCEPTION_FLT_INVALID_OPERATION:
-       Standard_NumericError :: Raise ( msg );
   case EXCEPTION_FLT_DENORMAL_OPERAND:
-       Standard_NumericError :: Raise ( msg );
   case EXCEPTION_FLT_INEXACT_RESULT:
+  case STATUS_FLOAT_MULTIPLE_TRAPS:
+  case STATUS_FLOAT_MULTIPLE_FAULTS:
        Standard_NumericError :: Raise ( msg );
   default:
     break;
@@ -651,7 +664,7 @@ LONG _osd_debug ( void ) {
 //==== _debug_break 
 //============================================================================
 
-void _debug_break ( Standard_CString msg ) {
+void _debug_break ( Standard_PCharacter msg ) {
 
  OSD_Environment    env ( "CSF_DEBUG_MODE" );
  Standard_Character buff[ 2048 ];
