@@ -53,6 +53,7 @@ static unsigned long vRand = 1L;
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 #include <OpenGl_LightBox.h>
 #include <OpenGl_TextureBox.h>
 #include <InterfaceGraphic_PrimitiveArray.hxx>
@@ -91,7 +92,7 @@ static  TStatus  ParrayInquire( TSM_ELEM_DATA, Tint, cmn_key* );
 static void draw_array(
              call_def_parray,
              Tint,          /* highlight_flag */
-             TelLModelType, /* front_lighting_model,  */
+             Tint,          /* front_lighting_model,  */
              Tint,          /* interior_style,  */
              Tint,          /* edge_flag,  */
              tel_colour,    /* interior_colour, */
@@ -161,7 +162,7 @@ ParrayDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 {
    CMN_KEY       k11, k12, k17, k18, k111, k114, k115;
 
-   TelLModelType  front_lighting_model;
+   Tint           front_lighting_model;
    Tint           interior_style;
    TEL_COLOUR     interior_colour;
    TEL_COLOUR     edge_colour;
@@ -216,7 +217,7 @@ ParrayDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
       if( TelGetHighlightRep( TglActiveWs, k11.data.ldata, &hrep ) == TSuccess ) {
         if( hrep.type == TelHLForcedColour ) {
           edge_colour = interior_colour = line_colour = hrep.col;
-          front_lighting_model = TelLModelNone;
+          front_lighting_model = CALL_PHIGS_REFL_NONE;
         } else if( hrep.type == TelHLColour ) {
           edge_colour = hrep.col;
           k[0]->id = TOff;
@@ -225,7 +226,7 @@ ParrayDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
         TelGetHighlightRep( TglActiveWs, 0, &hrep );
         if( hrep.type == TelHLForcedColour ) {
           edge_colour = interior_colour = line_colour = hrep.col;
-          front_lighting_model = TelLModelNone;
+          front_lighting_model = CALL_PHIGS_REFL_NONE;
         } else if( hrep.type == TelHLColour ) {
           edge_colour = hrep.col;
           k[0]->id = TOff;
@@ -296,7 +297,7 @@ draw_primitive_elements( call_def_parray p, GLenum mode, GLsizei count, GLenum t
 /*----------------------------------------------------------------------*/
 static void
 draw_array( call_def_parray p, Tint hflag,
-             TelLModelType lighting_model,
+             Tint lighting_model,
              Tint interior_style,
              Tint edge_flag,
              tel_colour interior_colour,
@@ -393,7 +394,6 @@ draw_array( call_def_parray p, Tint hflag,
      glPushAttrib(GL_ENABLE_BIT);
      glDisable(GL_TEXTURE_1D);
      glDisable(GL_TEXTURE_2D);
-     glDisable(GL_BLEND);
    }
 
 #ifdef PRINT
@@ -418,7 +418,7 @@ printf(" $$$ g_nDegenerateModel %d\n",g_nDegenerateModel);
 	to call LightOn() to synchronize LightOn/Off mechanism*/
       LightOn();
 
-      if( lighting_model == TelLModelNone || draw_mode <= GL_LINE_STRIP )
+      if( lighting_model == CALL_PHIGS_REFL_NONE || draw_mode <= GL_LINE_STRIP )
           LightOff();
      
 	  glGetIntegerv( GL_RENDER_MODE, &renderMode );
@@ -473,7 +473,7 @@ printf(" $$$ g_nDegenerateModel %d\n",g_nDegenerateModel);
 				if( pfc ) glColor3fv  ( pfc[i].rgb  );
 				if( renderMode == GL_FEEDBACK )
 					draw_primitive_elements( p, draw_mode, p->bounds[i], 
-                                 GL_UNSIGNED_INT, &p->edges[n]);
+                                 GL_UNSIGNED_INT, (GLenum*) &p->edges[n]);
 				else
 					glDrawElements( draw_mode, p->bounds[i], 
                                GL_UNSIGNED_INT, &p->edges[n]);
@@ -493,7 +493,7 @@ printf(" $$$ g_nDegenerateModel %d\n",g_nDegenerateModel);
 	  } else if( p->num_edges > 0 ) {
 			if( renderMode == GL_FEEDBACK )
 				draw_primitive_elements( p, draw_mode, p->num_edges, 
-                                  GL_UNSIGNED_INT, p->edges);
+                                  GL_UNSIGNED_INT, (GLenum*) &p->edges[0]);
 			else
 				glDrawElements( draw_mode, p->num_edges, 
                                 GL_UNSIGNED_INT, p->edges);
@@ -810,7 +810,7 @@ draw_edges ( call_def_parray p, tel_colour edge_colour )
     Tint    i, j, n;
     Tint    edge_type=0, line_type_preserve=0;
     Tfloat  edge_width=0, line_width_preserve=0;
-    GLboolean texture_on;
+    /*GLboolean texture_on;*/
 
 	GLint renderMode;
     
@@ -875,7 +875,7 @@ draw_edges ( call_def_parray p, tel_colour edge_colour )
 #endif
 		  if( renderMode == GL_FEEDBACK )
 				draw_primitive_elements( p, draw_mode, p->bounds[i], 
-                                 GL_UNSIGNED_INT, &p->edges[n]);
+                                 GL_UNSIGNED_INT, (GLenum*) &p->edges[n]);
 		  else
 				glDrawElements( draw_mode, p->bounds[i], 
                                 GL_UNSIGNED_INT, &p->edges[n]);
@@ -903,7 +903,7 @@ draw_edges ( call_def_parray p, tel_colour edge_colour )
 #endif
 	  if( renderMode == GL_FEEDBACK )
 			draw_primitive_elements( p, draw_mode, p->num_edges, 
-                                GL_UNSIGNED_INT, p->edges);
+                                GL_UNSIGNED_INT, (GLenum*) p->edges);
 	  else
 			glDrawElements( draw_mode, p->num_edges, 
                                 GL_UNSIGNED_INT, p->edges);
@@ -1641,7 +1641,7 @@ static void draw_degenerates_as_lines ( call_def_parray p,
           for( i=n=0 ; i<p->num_bounds ; i++ ) {
 			if( renderMode == GL_FEEDBACK )
 				draw_primitive_elements( p, draw_mode, p->bounds[i], 
-                                GL_UNSIGNED_INT, &p->edges[n]);
+                                GL_UNSIGNED_INT, (GLenum*) &p->edges[n]);
 			else
 				glDrawElements( draw_mode, p->bounds[i],
                                 GL_UNSIGNED_INT, &p->edges[n]);
@@ -1659,7 +1659,7 @@ static void draw_degenerates_as_lines ( call_def_parray p,
       } else if( p->num_edges > 0 ) {
 		if( renderMode == GL_FEEDBACK )
 			draw_primitive_elements( p, draw_mode, p->num_edges, 
-                                GL_UNSIGNED_INT, p->edges);
+                                GL_UNSIGNED_INT, (GLenum*) p->edges);
 		else
 			glDrawElements( draw_mode, p->num_edges,
                                 GL_UNSIGNED_INT, p->edges);
