@@ -192,8 +192,8 @@ typedef  struct  TSM_ATTRI_BLK_STRUCT {
     TEL_ALIGN_DATA  TextAlign;
 /*OCC7456 abd 14.12.2004 Text alingnment attributes  */
     Tint            PolymarkerType;
-    TelLModelType   InteriorReflectanceEquation;
-    TelLModelType   BackInteriorReflectanceEquation;
+    Tint            InteriorReflectanceEquation;
+    Tint            BackInteriorReflectanceEquation;
     TEL_SURF_PROP   SurfaceAreaProperties;
     TEL_SURF_PROP   BackSurfaceAreaProperties;
     TelCullMode     FaceCullingMode;
@@ -267,8 +267,8 @@ static  TSM_ATTRI_BLK  attri_default =
       0 }, /*Vertical Text Alignment*/
     /*OCC7456 abd 14.12.2004 Text alingnment attributes  */
     TEL_PM_PLUS,            /* PolymarkerType */
-    TelLModelNone,          /* InteriorReflectanceEquation */
-    TelLModelNone,          /* BackInteriorReflectanceEquation */
+    CALL_PHIGS_REFL_NONE,      /* InteriorReflectanceEquation */
+    CALL_PHIGS_REFL_NONE,      /* BackInteriorReflectanceEquation */
     { 0.2F, 0.8F, 0.1F, 0.0F,  /* Coef d eclairage */
       1.0F, 10.0F, 0.0F,  
       1,  1,  1,  0, 0,          /* Etat des eclairage */
@@ -1103,12 +1103,12 @@ printf("TsmSetAttri.linetype %d\n",ls);
 
             case  TelInteriorReflectanceEquation:
                 attri_tail->InteriorReflectanceEquation =
-                                            (TelLModelType) k[i]->data.ldata;
+                                            (Tint) k[i]->data.ldata;
                 break;
 
             case  TelBackInteriorReflectanceEquation:
                attri_tail->BackInteriorReflectanceEquation =
-                                            (TelLModelType) k[i]->data.ldata;
+                                            (Tint) k[i]->data.ldata;
                 break;
 
             case  TelSurfaceAreaProperties:
@@ -1482,7 +1482,7 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
    GLenum        face=0;
    tel_colour    col=NULL;
    tel_surf_prop prop=NULL;
-   TelLModelType rm=TelLModelNone;
+   Tint rm=CALL_PHIGS_REFL_NONE;
    static float  mAmb[4];
    static float  mDiff[4];
    static float  mSpec[4];
@@ -1492,6 +1492,7 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
    static int    physic;
    CMN_KEY_DATA key;
    Tfloat *rgb;
+   Tfloat newDiff3;
 
    /* Hors Hiddenline */
    if (attri_tail->InteriorStyle != TSM_HIDDENLINE)
@@ -1521,8 +1522,8 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
        attri_tail->InteriorColour.rgb[0]=rgb[0];
        attri_tail->InteriorColour.rgb[1]=rgb[1];
        attri_tail->InteriorColour.rgb[2]=rgb[2];
-       attri_tail->InteriorReflectanceEquation = TelLModelNone;
-       attri_tail->BackInteriorReflectanceEquation = TelLModelNone;        
+       attri_tail->InteriorReflectanceEquation = CALL_PHIGS_REFL_NONE;
+       attri_tail->BackInteriorReflectanceEquation = CALL_PHIGS_REFL_NONE;        
        return;  
    }
    
@@ -1535,10 +1536,10 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
 #endif
 #ifdef TRACE_MATERIAL
     printf("    InteriorReflectanceEquation: %d\n", attri_tail->InteriorReflectanceEquation);
-    printf(" controle mode rm == TelLModelNone : %d\n",  rm == (TelLModelNone));
+    printf(" controle mode rm == CALL_PHIGS_REFL_NONE : %d\n",  rm == CALL_PHIGS_REFL_NONE);
 #endif
 
-    if( rm == TelLModelNone ) return; 
+    if( rm == CALL_PHIGS_REFL_NONE ) return;
 
     /* 
      * Gestion de la transparence 
@@ -1682,7 +1683,7 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
 #ifdef TRACE_MATERIAL
         printf(" Material Properties are need_reset:\n") ;
         printf("    Ambient color   is (%f, %f, %f)\n", mAmb[0], mAmb[1], mAmb[2]);
-        printf("    Diffuse color   is (%f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2]);
+        printf("    Diffuse color   is (%f, %f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2], mDiff[3]);
         printf("    Specular color  is (%f, %f, %f)\n", mSpec[0], mSpec[1], mSpec[2]);
         printf("    Emission color  is (%f, %f, %f)\n", mEmsv[0], mEmsv[1], mEmsv[2]);
         printf("    Shininess: %f Transparency: %f EnvReflexion: %f \n", mShin, prop->trans, prop->env_reflexion);
@@ -1778,34 +1779,39 @@ void TelUpdateMaterial( Tint flag )  /* flag == TEL_FRONT_MATERIAL or
 
             glMaterialfv(face, GL_DIFFUSE, mDiff );
 #ifdef TRACE_MATERIAL
-            printf("    Diffuse color   is (%f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2]);
+            printf("    Diffuse color   is (%f, %f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2], mDiff[3]);
 #endif
          }
         }
         else
         {
-            if (  mDiff[0] != 0.0 || mDiff[1] != 0.0 || mDiff[2] != 0.0 )
+            newDiff3 = 1.0F;
+            if (SecondPassDo)
+            {
+                newDiff3 = prop->env_reflexion; 
+            }
+            else
+            {
+                if (need_trans) newDiff3 = prop->trans;
+                /* si le materiau reflechi la scene environnante,
+                alors il faudra faire une seconde passe */
+                if (prop->env_reflexion != 0.0) SecondPassNeeded = 1;
+            }
+	    
+	    /* OCC19915: Even if diffuse reflectance is disabled,
+	       still trying to update the current transparency if it
+	       differs from the previous value  */
+            if (  mDiff[0] != 0.0 || mDiff[1] != 0.0 || mDiff[2] != 0.0 
+                  || fabs(mDiff[3] - newDiff3) > 0.01 )
             {
                 mDiff[0] = 0.0F;
                 mDiff[1] = 0.0F;
                 mDiff[2] = 0.0F;
-                mDiff[3] = 1.0F;
-            
-                if (SecondPassDo)
-                {
-                    mDiff[3] = prop->env_reflexion; 
-                }
-                else
-                {
-                    if (need_trans) mDiff[3] = prop->trans;
-                    /* si le materiau reflechi la scene environnante,
-                       alors il faudra faire une seconde passe */
-                    if (prop->env_reflexion != 0.0) SecondPassNeeded = 1;
-                }
+                mDiff[3] = newDiff3;
 
                 glMaterialfv(face, GL_DIFFUSE, mDiff);
 #ifdef TRACE_MATERIAL
-                printf("    Diffuse color  is (%f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2]);
+                printf("    Diffuse color  is (%f, %f, %f, %f)\n", mDiff[0], mDiff[1], mDiff[2], mDiff[3]);
 #endif
             }
         }
