@@ -742,10 +742,23 @@ call_func_set_do_texturemap(Tint dcid)
 
 #define EPSI 0.0001
 
+#ifdef DEBUG
+static void
+pr_matrix( matrix3 mat )
+{
+    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[0][0], mat[0][1], mat[0][2], mat[0][3] );
+    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[1][0], mat[1][1], mat[1][2], mat[1][3] );
+    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[2][0], mat[2][1], mat[2][2], mat[2][3] );
+    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[3][0], mat[3][1], mat[3][2], mat[3][3] );
+    printf( "\n" );
+    return;
+}
+#endif
+
 /*
  *  Evaluates orientation matrix.
  */
-
+/* OCC18942: obsolete in OCCT6.3, might be removed in further versions! */
 void call_func_eval_ori_matrix3 (
     point3  *vrp,               /* view reference point */
     vec3    *vpn,               /* view plane normal    */
@@ -868,7 +881,7 @@ void call_func_eval_ori_matrix3 (
 /*
  *  Evaluates mapping matrix.
  */
-
+/* OCC18942: obsolete in OCCT6.3, might be removed in further versions! */
 void call_func_eval_map_matrix3(
     view_map3 *Map, 
     int *err_ind, 
@@ -955,7 +968,7 @@ void call_func_eval_map_matrix3(
         printf( "\n->call_func_eval_map_matrix3 FMN\n" );
         printf("prp %f %f %f \n", Prp.x, Prp.y, Prp.z);
         printf("vpd fpd bpd %f %f %f \n", Map->view_plane, Map->front_plane, Map->back_plane);
-        printf("view_plane_normal %f %f %f %f\n", Map->win.x_min, Map->win.x_max, 
+        printf("window limits %f %f %f %f\n", Map->win.x_min, Map->win.x_max, 
                                                   Map->win.y_min, Map->win.y_max);
         printf( "mapping_matrix :\n" );
         pr_matrix(mat);
@@ -1022,10 +1035,10 @@ void call_func_eval_map_matrix3(
         call_util_mat_mul (aux_mat2, aux_mat1, mat);
             
 #ifdef DEBUG
-        printf( "\n->call_func_eval_map_matrix3 \n" );
+        printf( "\n->call_func_eval_map_matrix3 - ORTHOGRAPHIC projection\n" );
         printf("prp %f %f %f \n", Prp.x, Prp.y, Prp.z);
         printf("vpd fpd bpd %f %f %f \n", Map->view_plane, Map->front_plane, Map->back_plane);
-        printf("view_plane_normal %f %f %f %f\n", Map->win.x_min, Map->win.x_max, 
+        printf("window limits %f %f %f %f\n", Map->win.x_min, Map->win.x_max, 
                                                   Map->win.y_min, Map->win.y_max);
         printf( "mapping_matrix :\n" );
         pr_matrix(mat);
@@ -1118,6 +1131,19 @@ void call_func_eval_map_matrix3(
         aux_mat2[3][2] = aux_mat2[2][2]+Map->proj_vp.z_min;
         call_util_mat_mul (Shear, aux_mat2, mat);
 
+#ifdef DEBUG
+        printf( "\n->call_func_eval_map_matrix3 - PERSPECTIVE projection\n" );
+        printf("prp %f %f %f \n", Prp.x, Prp.y, Prp.z);
+        printf("vpd fpd bpd %f %f %f \n", Map->view_plane, Map->front_plane, Map->back_plane);
+        printf("window limits %f %f %f %f\n", Map->win.x_min, Map->win.x_max, 
+                                                  Map->win.y_min, Map->win.y_max);
+        printf("viewport limits %f %f %f %f %f %f\n", Map->proj_vp.x_min, Map->proj_vp.x_max, 
+                                                  Map->proj_vp.y_min, Map->proj_vp.y_max,
+                                                  Map->proj_vp.z_min, Map->proj_vp.z_max);
+        printf( "mapping_matrix :\n" );
+        pr_matrix(mat);
+#endif
+
         return;
     }
     else
@@ -1155,21 +1181,6 @@ call_util_mat_mul( matrix3 mat_a, matrix3 mat_b, matrix3 mat_c)
 
 /*----------------------------------------------------------------------*/
 
-#ifdef DEBUG
-static void
-pr_matrix( matrix3 mat )
-{
-    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[0][0], mat[0][1], mat[0][2], mat[0][3] );
-    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[1][0], mat[1][1], mat[1][2], mat[1][3] );
-    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[2][0], mat[2][1], mat[2][2], mat[2][3] );
-    printf( "%1.12f %1.12f %1.12f %1.12f\n", mat[3][0], mat[3][1], mat[3][2], mat[3][3] );
-    printf( "\n" );
-    return;
-}
-#endif
-
-/*----------------------------------------------------------------------*/
-
 void
 call_func_redraw_all_structs_begin( Tint wsid )
 {
