@@ -75,6 +75,7 @@
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 #include <OpenGl_LightBox.h>
 #include <OpenGl_TextureBox.h>
 
@@ -162,7 +163,7 @@ static TEL_INDEXPOLY_DATA indexpoly_defaults =
 static void draw_indexpoly(
              tel_indexpoly_data,
  	     Tint,          /* highlight_flag */
-             TelLModelType, /* front_lighting_model,  */
+             Tint,          /* front_lighting_model,  */
              Tint,          /* interior_style,  */
              tel_colour     /* edge_colour, */
 #ifdef OCC749
@@ -389,7 +390,7 @@ PolygonIndicesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
    CMN_KEY       k117;
 #endif
 
-   TelLModelType  front_lighting_model;
+   Tint           front_lighting_model;
    Tint           interior_style;
    TEL_COLOUR     interior_colour;
    TEL_COLOUR     edge_colour;
@@ -438,7 +439,7 @@ PolygonIndicesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
 	    {
                 edge_colour = interior_colour = hrep.col;
-		front_lighting_model = TelLModelNone;
+		front_lighting_model = CALL_PHIGS_REFL_NONE;
 	    }
             else if( hrep.type == TelHLColour )
 	    {
@@ -452,7 +453,7 @@ PolygonIndicesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
 	    {
                 edge_colour = interior_colour = hrep.col;
-		front_lighting_model = TelLModelNone;
+		front_lighting_model = CALL_PHIGS_REFL_NONE;
 	    }
             else if( hrep.type == TelHLColour )
 	    {
@@ -487,7 +488,7 @@ PolygonIndicesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 
 static void
 draw_indexpoly( tel_indexpoly_data p, Tint hflag,
-             TelLModelType front_lighting_model,
+             Tint front_lighting_model,
              Tint interior_style,
              tel_colour edge_colour
 #ifdef OCC749
@@ -496,7 +497,7 @@ draw_indexpoly( tel_indexpoly_data p, Tint hflag,
 	      )
 {
     Tint i, j, k, a, newList = 0;
-    TelLModelType  lighting_model;
+    Tint  lighting_model;
     
     /* Following pointers have been provided for performance improvement */
     Tint       *ind;
@@ -529,7 +530,7 @@ draw_indexpoly( tel_indexpoly_data p, Tint hflag,
 	   pfc = 0;
 	}
 	
-	if (front_lighting_model == TelLModelNone)
+	if (front_lighting_model == CALL_PHIGS_REFL_NONE)
 	  LightOff();
 	else LightOn();
     
@@ -562,7 +563,7 @@ draw_indexpoly( tel_indexpoly_data p, Tint hflag,
 doDraw:
 #endif  /* G003 */
 	  
-      if ( lighting_model == TelLModelNone ) {
+      if ( lighting_model == CALL_PHIGS_REFL_NONE ) {
         if ( p -> bounds[ 0 ] == 3 )
 	  glBegin ( GL_TRIANGLES );
 	else if ( p -> bounds[ 0 ] == 4 )
@@ -705,7 +706,7 @@ doDraw:
 	glNewList ( p -> d.dlist, GL_COMPILE_AND_EXECUTE );
 	newList = 1;
 	set_drawable_items ( p -> d.bDraw, p -> num_bounds );
-	if ( lighting_model == TelLModelNone ) {
+	if ( lighting_model == CALL_PHIGS_REFL_NONE ) {
 	  if ( p -> bounds[ 0 ] == 3 )
 	    glBegin ( GL_TRIANGLES );
 	  else if ( p -> bounds[ 0 ] == 4 )
