@@ -63,6 +63,7 @@
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 #include <OpenGl_LightBox.h>
 #include <OpenGl_TextureBox.h>
 
@@ -76,7 +77,9 @@
 
 #ifndef WNT
 # define CALLBACK
+#if !defined(APIENTRY)
 # define APIENTRY
+#endif // APIENTRY
 # define STATIC static
 #else
 # include <GL\GLU.H>
@@ -177,8 +180,8 @@ static void endtriangulate(void);
 /*static void out_vertex2( void* );*/
 /*static void out_vertex3( void* );*/
 static void draw_tmesh( tel_polygon_data, Tint );
-static void draw_polygon( tel_polygon_data, TelLModelType, Tint );
-static void draw_polygon_concav( tel_polygon_data, TelLModelType, Tint );
+static void draw_polygon( tel_polygon_data, Tint, Tint );
+static void draw_polygon_concav( tel_polygon_data, Tint, Tint );
 
 #if !defined(GLU_VERSION_1_2)
 #define GLUtesselator GLUtriangulatorObj
@@ -348,7 +351,7 @@ PolygonDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 /*   Tint           front_face = 1;*/
    CMN_KEY        k11, k12, k17, k111, k114;
 
-   TelLModelType  front_lighting_model;
+   Tint           front_lighting_model;
    Tint           interior_style;
    TEL_COLOUR     interior_colour;
    TEL_COLOUR     edge_colour;
@@ -387,7 +390,7 @@ PolygonDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 	    {
 		interior_colour = hrep.col;
 		edge_colour = hrep.col;
-		front_lighting_model = TelLModelNone;
+		front_lighting_model = CALL_PHIGS_REFL_NONE;
 	    }
 	    else
 		k[0]->id = TOff;
@@ -399,7 +402,7 @@ PolygonDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 	    {
 		interior_colour = hrep.col;
 		edge_colour = hrep.col;
-		front_lighting_model = TelLModelNone;
+		front_lighting_model = CALL_PHIGS_REFL_NONE;
 	    }
 	    else
 		k[0]->id = TOff;
@@ -414,7 +417,7 @@ PolygonDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
     if( interior_style != TSM_EMPTY ) 
 #endif	/*G003*/
     {          
-	if (front_lighting_model == TelLModelNone)
+	if (front_lighting_model == CALL_PHIGS_REFL_NONE)
 	  LightOff();
 	else LightOn();
 
@@ -465,7 +468,7 @@ PolygonDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 /*----------------------------------------------------------------------*/
 
 static void
-draw_polygon( tel_polygon_data d, TelLModelType front_lighting_model, Tint hflag )
+draw_polygon( tel_polygon_data d, Tint front_lighting_model, Tint hflag )
 {
     Tint      i;
 
@@ -484,7 +487,7 @@ draw_polygon( tel_polygon_data d, TelLModelType front_lighting_model, Tint hflag
     ptr = d->vertices;
     if( pfc )
 	glColor3fv( pfc->rgb );
-    if( front_lighting_model != TelLModelNone )
+    if( front_lighting_model != CALL_PHIGS_REFL_NONE )
         glNormal3fv( d->fnormal.xyz );
 
     if( d->reverse_order ) glFrontFace( GL_CW );
@@ -492,7 +495,7 @@ draw_polygon( tel_polygon_data d, TelLModelType front_lighting_model, Tint hflag
     if (d->num_vertices == 3) glBegin(GL_TRIANGLES);
     else if(d->num_vertices == 4) glBegin(GL_QUADS);
     else glBegin(GL_POLYGON);
-    if( front_lighting_model == TelLModelNone )
+    if( front_lighting_model == CALL_PHIGS_REFL_NONE )
     {
        if( pvc )
        {
@@ -614,7 +617,7 @@ out_vert1( void *data )
 
 
     if ( data < (void *)0xffff ) {
-	int a = (int)data;
+	long a = (long)data;
 
     	glVertex3fv( DaTa->vertices[a].xyz );
     }
@@ -658,7 +661,7 @@ out_vert2( void *data )
     s->tmesh_sequence[ s->ts_num - 1 ] = data;
 
     if ( data < (void *)0xffff ) {
-	int a = (int)data;
+	long a = (long)data;
 
     	glColor3fv( DaTa->vcolours[a].rgb );
     	glVertex3fv(  DaTa->vertices[a].xyz );
@@ -701,7 +704,7 @@ out_vert3( void *data )
     s->tmesh_sequence[ s->ts_num - 1 ] = data;
 
     if ( data <= (void *)0xffff ) {
-	int a = (int)data;
+	long a = (long)data;
 
     	glNormal3fv(  DaTa->vnormals[a].xyz );
     	glVertex3fv(  DaTa->vertices[a].xyz);
@@ -805,9 +808,9 @@ endtriangulate()
 /*----------------------------------------------------------------------*/
 
 static void
-draw_polygon_concav( tel_polygon_data d, TelLModelType front_lighting_model, Tint hflag )
+draw_polygon_concav( tel_polygon_data d, Tint front_lighting_model, Tint hflag )
 {
-    Tint      i;
+    long       i;
 
     tel_point  pvn;
     tel_point  ptr;
@@ -828,7 +831,7 @@ draw_polygon_concav( tel_polygon_data d, TelLModelType front_lighting_model, Tin
 
     if( pfc )
 	glColor3fv( pfc->rgb );
-    if( front_lighting_model != TelLModelNone )
+    if( front_lighting_model != CALL_PHIGS_REFL_NONE )
         glNormal3fv( d->fnormal.xyz );
   
   if( d->reverse_order ) glFrontFace( GL_CW );
@@ -836,7 +839,7 @@ draw_polygon_concav( tel_polygon_data d, TelLModelType front_lighting_model, Tin
   if( d->display == 0 )
   {
 
-    if( front_lighting_model == TelLModelNone )
+    if( front_lighting_model == CALL_PHIGS_REFL_NONE )
     {
        if( pvc )
        {
@@ -881,7 +884,7 @@ draw_polygon_concav( tel_polygon_data d, TelLModelType front_lighting_model, Tin
     } 
     else 
     {
-       if( front_lighting_model == TelLModelNone )
+       if( front_lighting_model == CALL_PHIGS_REFL_NONE )
        {
 	  if( pvc ) draw_tmesh( d, 2 );
 	  else draw_tmesh( d, 1 );
@@ -919,7 +922,7 @@ draw_tmesh( tel_polygon_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
                  if ( s->tmesh_sequence[j] < (void *)0xffff )
-                        glVertex3fv( d->vertices[ (int)s->tmesh_sequence[ j ] ].xyz );
+                        glVertex3fv( d->vertices[ (long)s->tmesh_sequence[ j ] ].xyz );
                  else {
                         extra_vertex b = (extra_vertex)s->tmesh_sequence[j];
                         glVertex3fv( b->vert );
@@ -933,8 +936,8 @@ draw_tmesh( tel_polygon_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
                  if ( s->tmesh_sequence[j] < (void *)0xffff ) {
-                        glColor3fv( d->vcolours[ (int) s->tmesh_sequence[ j ] ].rgb );
-                        glVertex3fv( d->vertices[ (int) s->tmesh_sequence[ j ] ].xyz );
+                        glColor3fv( d->vcolours[ (long) s->tmesh_sequence[ j ] ].rgb );
+                        glVertex3fv( d->vertices[ (long) s->tmesh_sequence[ j ] ].xyz );
                  } else {
                         b = (extra_vertex) s->tmesh_sequence[j];
                         glColor3fv( d->vcolours[(b->ind)].rgb);
@@ -948,8 +951,8 @@ draw_tmesh( tel_polygon_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
                  if ( s->tmesh_sequence[j] < (void *)0xffff ) {
-                        glNormal3fv( d->vnormals[ (int) s->tmesh_sequence[ j ] ].xyz);
-                        glVertex3fv( d->vertices[ (int) s->tmesh_sequence[ j ] ].xyz);
+                        glNormal3fv( d->vnormals[ (long) s->tmesh_sequence[ j ] ].xyz);
+                        glVertex3fv( d->vertices[ (long) s->tmesh_sequence[ j ] ].xyz);
                  } else {
                         b = (extra_vertex) s->tmesh_sequence[j];
                         glNormal3fv( d->vnormals[(b->ind)].xyz);
