@@ -50,9 +50,12 @@
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 
 #ifndef WNT
+#if !defined(APIENTRY)
 # define APIENTRY
+#endif // APIENTRY
 # define STATIC static
 #else
 # include <GL\GLU.H>
@@ -155,7 +158,7 @@ STATIC void APIENTRY out_vertex2( void* );
 STATIC void APIENTRY out_vertex3( void* );
 static void draw_tmesh( tel_polygon_holes_data, Tint );
 static void draw_polygon_holes( tel_polygon_holes_data, Tint,
-                                TelLModelType, Tint );
+                                Tint, Tint );
 static void draw_edges( tel_polygon_holes_data, Tmatrix3, tel_colour, Tint,
                         TelCullMode, Tint, Tint );
 
@@ -312,8 +315,8 @@ PolygonHolesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
                   k112, k113, k117;
 
    Tint           fl=0;
-   TelLModelType  front_lighting_model, back_lighting_model;
-   TelLModelType  front_lighting_model_preserve, back_lighting_model_preserve;
+   Tint           front_lighting_model, back_lighting_model;
+   Tint           front_lighting_model_preserve, back_lighting_model_preserve;
    Tint           front_shading_method;
    Tint           interior_style;
    Tint           interior_index;
@@ -366,11 +369,11 @@ PolygonHolesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
             {
                 edge_colour = back_interior_colour = interior_colour = hrep.col;
-                front_lighting_model = back_lighting_model = TelLModelNone;
+                front_lighting_model = back_lighting_model = CALL_PHIGS_REFL_NONE;
                 kkk.id = TelInteriorReflectanceEquation;
-                kkk.data.ldata = TelLModelNone;
+                kkk.data.ldata = CALL_PHIGS_REFL_NONE;
                 kkl.id = TelBackInteriorReflectanceEquation;
-                kkl.data.ldata = TelLModelNone;
+                kkl.data.ldata = CALL_PHIGS_REFL_NONE;
                 TsmSetAttri( 2, &kkk, &kkl );
                 fl = 0;
             }
@@ -386,11 +389,11 @@ PolygonHolesDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
             {
                 back_interior_colour = interior_colour = hrep.col;
-                front_lighting_model = back_lighting_model = TelLModelNone;
+                front_lighting_model = back_lighting_model = CALL_PHIGS_REFL_NONE;
                 kkk.id = TelInteriorReflectanceEquation;
-                kkk.data.ldata = TelLModelNone;
+                kkk.data.ldata = CALL_PHIGS_REFL_NONE;
                 kkl.id = TelBackInteriorReflectanceEquation;
-                kkl.data.ldata = TelLModelNone;
+                kkl.data.ldata = CALL_PHIGS_REFL_NONE;
                 TsmSetAttri( 2, &kkk, &kkl );
                 fl = 0;
             }
@@ -458,9 +461,9 @@ static GLUtesselator *tripak;
 
 static void
 draw_polygon_holes( tel_polygon_holes_data d,
-                    Tint style, TelLModelType u, Tint hflag )
+                    Tint style, Tint u, Tint hflag )
 {
-    Tint      i, j, m;
+    long      i, j, m;
 
     GLdouble  xyz[3];
 
@@ -478,13 +481,13 @@ draw_polygon_holes( tel_polygon_holes_data d,
 
     if( pfc )
         glColor3fv( pfc->rgb );
-    if( u != TelLModelNone )
+    if( u != CALL_PHIGS_REFL_NONE )
         glNormal3fv( d->fnormal.xyz );
 
     if( d->display == 0 )
     {
 
-       if( u == TelLModelNone )
+       if( u == CALL_PHIGS_REFL_NONE )
        {
           if( pvc )
           {
@@ -536,7 +539,7 @@ draw_polygon_holes( tel_polygon_holes_data d,
     }
     else
     {
-       if( u == TelLModelNone )
+       if( u == CALL_PHIGS_REFL_NONE )
        {
           if( pvc )
              draw_tmesh( d, 2 );
@@ -575,7 +578,7 @@ draw_tmesh( tel_polygon_holes_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
                  if ( s->tmesh_sequence[j] < (void *)0xffff ) {
-		     glVertex3fv( d->vertices[ (int)s->tmesh_sequence[ j ] ].xyz );
+		     glVertex3fv( d->vertices[ (long)s->tmesh_sequence[ j ] ].xyz );
 		 }
 		 else {
 		     extra_vertex b = (extra_vertex)s->tmesh_sequence[j];
@@ -589,8 +592,8 @@ draw_tmesh( tel_polygon_holes_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
 		 if ( s->tmesh_sequence[j] < (void *)0xffff ) {
-		     glColor3fv( d->vcolours[ (int) s->tmesh_sequence[ j ] ].rgb );
-		     glVertex3fv( d->vertices[ (int) s->tmesh_sequence[ j ] ].xyz );
+		     glColor3fv( d->vcolours[ (long) s->tmesh_sequence[ j ] ].rgb );
+		     glVertex3fv( d->vertices[ (long) s->tmesh_sequence[ j ] ].xyz );
 		 } else {
 		     extra_vertex b = (extra_vertex)s->tmesh_sequence[j];
 		     glColor3fv( d->vcolours[(b->ind)].rgb);
@@ -604,8 +607,8 @@ draw_tmesh( tel_polygon_holes_data d, Tint v )
               for( j = 0, k = 0; j < s->ts_num; j++ )
               {
 		 if ( s->tmesh_sequence[j] < (void *)0xffff) {
-		     glNormal3fv( d->vnormals[ (int) s->tmesh_sequence[ j ] ].xyz );
-		     glVertex3fv( d->vertices[ (int) s->tmesh_sequence[ j ] ].xyz );
+		     glNormal3fv( d->vnormals[ (long) s->tmesh_sequence[ j ] ].xyz );
+		     glVertex3fv( d->vertices[ (long) s->tmesh_sequence[ j ] ].xyz );
 		 } else {
 		     extra_vertex b = (extra_vertex)s->tmesh_sequence[j];
 		     glNormal3fv( d->vnormals[(b->ind)].xyz);
@@ -1026,7 +1029,7 @@ out_vertex1( void *data )
     s->tmesh_sequence[ s->ts_num - 1 ] = data;
 
     if ( data < (void *)0xffff ) {
-	Tint a = (Tint)data;
+	long int a = (long int)data;
 
     	glVertex3fv( DaTa->vertices[a].xyz );
     }
@@ -1063,7 +1066,7 @@ out_vertex2( void *data )
     s->tmesh_sequence[ s->ts_num - 1 ] = data;
 
     if ( data < (void *)0xffff ){
-	Tint a = (Tint)data;
+	long int a = (long int)data;
 
     	glColor3fv( DaTa->vcolours[a].rgb );
     	glVertex3fv( DaTa->vertices[a].xyz );
@@ -1102,7 +1105,7 @@ out_vertex3( void *data )
     s->tmesh_sequence[ s->ts_num - 1 ] = data;
 
     if ( data < (void *)0xffff ) {
-	Tint a = (Tint)data;
+	long int a = (long int)data;
 
     	glNormal3fv( DaTa->vnormals[a].xyz );
     	glVertex3fv( DaTa->vertices[a].xyz );
