@@ -65,6 +65,7 @@
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 #include <OpenGl_LightBox.h>
 #include <OpenGl_TextureBox.h>
 
@@ -132,7 +133,7 @@ static  TStatus  QuadrangleInquire( TSM_ELEM_DATA, Tint, cmn_key* );
 static void
 draw_qstrip( tel_qstrip_data,
              Tint,          /* highlight flag */
-             TelLModelType, /* front_lighting_model,  */
+             Tint,          /* front_lighting_model,  */
              Tint,          /* interior_style,  */
              tel_colour    /* edge_colour, */
              );
@@ -437,7 +438,7 @@ QuadrangleDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 {
    CMN_KEY       k11, k12, k17, k111, k114;
 
-   TelLModelType  front_lighting_model;
+   Tint           front_lighting_model;
    Tint           interior_style;
    TEL_COLOUR     interior_colour;
    TEL_COLOUR     edge_colour;
@@ -476,7 +477,7 @@ QuadrangleDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
 	    {
                 edge_colour = interior_colour = hrep.col;
-                front_lighting_model = TelLModelNone;
+                front_lighting_model = CALL_PHIGS_REFL_NONE;
 	    }
 	    else if( hrep.type == TelHLColour )
 	    {
@@ -490,7 +491,7 @@ QuadrangleDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
             {
                 edge_colour = interior_colour = hrep.col;
-                front_lighting_model = TelLModelNone;
+                front_lighting_model = CALL_PHIGS_REFL_NONE;
             }
             else if( hrep.type == TelHLColour )
             {
@@ -518,14 +519,14 @@ QuadrangleDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 static void draw_qstrip (
              tel_qstrip_data                  p,
              Tint                         hflag,
-             TelLModelType front_lighting_model,
+             Tint          front_lighting_model,
              Tint                interior_style,
              tel_colour             edge_colour
             ) {
 
  Tint              i, m, newList = 0;
  Tint              nf, nv, nr, nc;
- TelLModelType     lighting_model;
+ Tint              lighting_model;
  tel_point         pv, pfn, pvn;
  tel_colour        pfc, pvc;
  tel_texture_coord pvt;
@@ -549,7 +550,7 @@ static void draw_qstrip (
 #else
  if ( interior_style != TSM_EMPTY ) {
 #endif  /* G003 */
-  if ( front_lighting_model == TelLModelNone )
+  if ( front_lighting_model == CALL_PHIGS_REFL_NONE )
 
    LightOff ();
 
@@ -589,7 +590,7 @@ static void draw_qstrip (
 #ifdef G004
 doDraw:
 #endif  /* G004 */
-    if ( lighting_model == TelLModelNone ) {
+    if ( lighting_model == CALL_PHIGS_REFL_NONE ) {
 
      if ( pvc ) {
 
@@ -721,7 +722,7 @@ doDraw:
     glNewList ( p -> d.dlist, GL_COMPILE_AND_EXECUTE );
     newList = 1;
 
-    if ( lighting_model == TelLModelNone ) {
+    if ( lighting_model == CALL_PHIGS_REFL_NONE ) {
 
      if ( pvc ) {
 
