@@ -106,7 +106,7 @@ static txfmfonthandle alloc_new_font(char *);
  * Prototypes variables statiques
  */
 
-static txfmfonthandle current_fonthandle = NULL;
+txfmfonthandle current_fonthandle = NULL;
 static char current_fontname[255];
 static txfmfonthandle tXfmfontset[CACHE_SIZE];
 
@@ -268,6 +268,13 @@ txfmfonthandle tXfmfindfont(Display *fdpy,  char *fontname, float bestfont_size)
 
     /* Pour  optimiser il faudrait un putXsizetostring */
     fontList = XListFonts(fdpy, fontEntry[i].xlfd,  NUM_FONT_SIZES, &count);
+    if (!count)
+    {
+      /* if the font is not found in Unix library
+	 the default font is used */
+      i = 0;
+      fontList = XListFonts(fdpy, fontEntry[i].xlfd,  NUM_FONT_SIZES, &count);
+    }
     if (!count) return((txfmfonthandle) 0);
     getXsizefromstr(fontEntry[i].xsizes, fontList, count);
     fontEntry[i].count = count;
@@ -383,6 +390,7 @@ void tXfmprstr(unsigned char *str, GLuint Base, GLfloat x, GLfloat y, GLfloat z
  GLdouble xw, yw, zw;
  GLdouble xv, yv, zv;
  GLdouble xdis = 0., ydis = 0.;
+ GLint renderMode;  /* SAMTECH modif -- Geoff Levner 19/7/2007 */
 
  TEL_ALIGN_DATA align;
 
@@ -399,7 +407,7 @@ void tXfmprstr(unsigned char *str, GLuint Base, GLfloat x, GLfloat y, GLfloat z
  key.data.pdata = &align;
  TsmGetAttri( 1, &key );
 
- sizeString( str, &widthFont, &ascentFont, &descentFont );
+ sizeString( (char*) str, &widthFont, &ascentFont, &descentFont );
 
  switch( align.Hmode )
  {
@@ -455,10 +463,14 @@ void tXfmprstr(unsigned char *str, GLuint Base, GLfloat x, GLfloat y, GLfloat z
 /*OCC7456 abd 14.12.2004 Text alignment attributes  */
 
 #ifdef OCC7667
-    exportText( str, current_fontname,
-                current_fonthandle->charsize * call_tox_getpitchsize(),
-                x, y, z, GL_FALSE );
-    glRasterPos3f( x, y, z );
+    /* SAMTECH modif -- Geoff Levner 19/7/2007 -- added render mode test */
+    glGetIntegerv(GL_RENDER_MODE, &renderMode);
+    if (renderMode == GL_FEEDBACK) {
+      exportText( (char*) str, current_fontname,
+		  current_fonthandle->charsize * call_tox_getpitchsize(),
+		  x, y, z, GL_FALSE );
+      glRasterPos3f( x, y, z );
+    }
 #endif
 
     glPushAttrib(GL_LIST_BIT);
@@ -1119,6 +1131,7 @@ void WNTPuts ( char* str, GLuint base ) {
  GLdouble xw, yw, zw;
  GLdouble xv, yv, zv;
  GLdouble xdis = 0., ydis = 0.;
+ GLint renderMode;  /* SAMTECH modif -- Geoff Levner 19/7/2007 */
 
  TEL_ALIGN_DATA aling;
 
@@ -1172,9 +1185,13 @@ void WNTPuts ( char* str, GLuint base ) {
 /*OCC7456 abd 14.12.2004 Text alingnment attributes  */
 
 #ifdef OCC7667
-  exportText( str, fontEntry[curFont].name,
-              ( GLfloat )fontEntry[ curFont ].fs[ curSize ].lHeight,
-              x, y, z, is2d!=0 );
+ /* SAMTECH modif -- Geoff Levner 19/7/2007 -- added render mode test */
+ glGetIntegerv(GL_RENDER_MODE, &renderMode);
+ if (renderMode == GL_FEEDBACK) {
+   exportText( str, fontEntry[curFont].name,
+	       ( GLfloat )fontEntry[ curFont ].fs[ curSize ].lHeight,
+	       x, y, z, is2d!=0 );
+ }
 #endif
 
 #ifdef OCC2934
