@@ -744,6 +744,41 @@ printf("OPENGL: TelDrawImage: %d %d %d %d \n", posx, posy, width, height);
     return;
 }
 
+/*----------------------------------------------------------------------*/
+void
+TelReadDepths(Tint ws, Tint posx, Tint posy, Tint width, Tint height, float *depths)
+{
+    CMN_KEY_DATA key;
+    Tint w, h;
+
+#ifdef TRACE
+printf("OPENGL: TelReadDepths: %d %d %d %d \n", posx, posy, width, height);
+#endif
+
+    if ( TsmGetWSAttri (ws, WSWindow, &key) != TSuccess ) return;
+
+    if (depths != NULL && TxglWinset (call_thedisplay, (Window) key.ldata) == TSuccess)
+    {
+	TsmGetWSAttri (ws, WSWidth, &key);
+	w = key.ldata;
+	TsmGetWSAttri (ws, WSHeight, &key);
+	h = key.ldata;
+
+	glMatrixMode (GL_PROJECTION);
+	glLoadIdentity ();
+	gluOrtho2D ((GLdouble) 0., (GLdouble) w, 0., (GLdouble) h);
+	glMatrixMode (GL_MODELVIEW);
+	glLoadIdentity ();
+	
+	glRasterPos2i (posx, posy);
+	TelDisable (ws);
+	glReadPixels (posx, posy, width, height, GL_DEPTH_COMPONENT, GL_FLOAT, depths);
+	TelEnable (ws);
+    }
+    
+    return;
+}
+
 /*----------------------------------------------------------------------*/
 void
 TelEnable (Tint ws)
@@ -947,6 +982,94 @@ TelUnProjectionRaster(Tint ws, Tint xr, Tint yr, Tfloat *x, Tfloat *y, Tfloat *z
     }
 }
 
+/*----------------------------------------------------------------------*/
+TStatus
+TelUnProjectionRasterWithRay(Tint ws, Tint xr, Tint yr, Tfloat *x, Tfloat *y, Tfloat *z,
+                             Tfloat *dx, Tfloat *dy, Tfloat *dz)
+{
+    Tint w, h;
+    CMN_KEY_DATA key;
+    Tint vid;          /* View index */
+    TEL_VIEW_REP vrep; /* View definition */
+    
+    int i, j, k;
+    GLdouble objx, objy, objz;
+    GLdouble objx1, objy1, objz1;
+    GLdouble modelMatrix[16], projMatrix[16];
+    GLint viewport[4];
+    GLdouble winx, winy, winz;
+    GLint status;
+
+    vid = ws;
+
+    if (TelGetViewRepresentation (ws, vid, &vrep) != TSuccess)
+	    return TFailure;
+
+    TsmGetWSAttri (ws, WSWidth, &key);
+    w = key.ldata;
+    TsmGetWSAttri (ws, WSHeight, &key);
+    h = key.ldata;
+
+    winx = ( GLdouble )xr; winy = ( GLdouble )yr; winz = ( GLdouble )0.0;
+
+    for (k = 0, i = 0; i < 4; i++)
+	    for (j = 0; j < 4; j++, k++)
+		    modelMatrix[k] = ( GLdouble )vrep.orientation_matrix[i][j];
+
+    for (k = 0, i = 0; i < 4; i++)
+	    for (j = 0; j < 4; j++, k++)
+		    projMatrix[k] = ( GLdouble )vrep.mapping_matrix[i][j];
+
+    viewport[0] = 0;
+    viewport[1] = 0;
+    viewport[2] = w;
+    viewport[3] = h;
+
+    /*
+     * glGetIntegerv (GL_VIEWPORT, viewport);
+     * glGetDoublev (GL_MODELVIEW_MATRIX, modelMatrix);
+     * glGetDoublev (GL_PROJECTION_MATRIX, projMatrix);
+     */
+
+    status = gluUnProject (winx, winy, winz, modelMatrix, projMatrix, viewport,
+	    &objx, &objy, &objz);
+    
+    if (status == GL_TRUE) {
+	    *x = ( Tfloat )objx;
+	    *y = ( Tfloat )objy;
+	    *z = ( Tfloat )objz;
+
+      winz = ( GLdouble ) -10.0;
+      status = gluUnProject (winx, winy, winz, modelMatrix, projMatrix, viewport,
+	      &objx1, &objy1, &objz1);
+    
+      if (status == GL_TRUE) {
+        *dx = ( Tfloat )(objx-objx1);
+	*dy = ( Tfloat )(objy-objy1);
+	*dz = ( Tfloat )(objz-objz1);
+
+        return TSuccess;
+      }
+      else {
+	    *dx = 0.0F;
+	    *dy = 0.0F;
+	    *dz = 0.0F;
+
+	    return TFailure;
+      }
+    }
+    else {
+	    *x = 0.0F;
+	    *y = 0.0F;
+	    *z = 0.0F;
+	    *dx = 0.0F;
+	    *dy = 0.0F;
+	    *dz = 0.0F;
+
+	    return TFailure;
+    }
+}
+
 /*----------------------------------------------------------------------*/
 void
 TelFlush(Tint wait)
