@@ -69,6 +69,7 @@
 #include <OpenGl_telem_highlight.h>
 #include <OpenGl_telem_inquire.h>
 #include <OpenGl_telem_view.h>
+#include <OpenGl_tgl_funcs.h>
 #include <OpenGl_LightBox.h>
 #include <OpenGl_TextureBox.h>
 
@@ -130,7 +131,7 @@ static  TStatus  TriangleMeshInquire( TSM_ELEM_DATA, Tint, cmn_key* );
 
 static void draw_tmesh( tel_tmesh_data,
                         Tint,          /* highlight flag        */
-                        TelLModelType, /* front_lighting_model, */
+                        Tint,          /* front_lighting_model, */
                         Tint,          /* interior_style,       */
                         tel_colour     /* edge_colour,          */
                      );
@@ -361,7 +362,7 @@ TriangleMeshDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 {
    CMN_KEY       k11, k12, k17, k111, k114;
 
-   TelLModelType  front_lighting_model;
+   Tint           front_lighting_model;
    Tint           interior_style;
    TEL_COLOUR     interior_colour;
    TEL_COLOUR     edge_colour;
@@ -398,7 +399,7 @@ TriangleMeshDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
             {
                 edge_colour = interior_colour = hrep.col;
-                front_lighting_model = TelLModelNone;
+                front_lighting_model = CALL_PHIGS_REFL_NONE;
             }
             else if( hrep.type == TelHLColour )
             {
@@ -412,7 +413,7 @@ TriangleMeshDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
             if( hrep.type == TelHLForcedColour )
             {
                 edge_colour = interior_colour = hrep.col;
-                front_lighting_model = TelLModelNone;
+                front_lighting_model = CALL_PHIGS_REFL_NONE;
              }
             else if( hrep.type == TelHLColour )
             {
@@ -440,7 +441,7 @@ TriangleMeshDisplay( TSM_ELEM_DATA data, Tint n, cmn_key *k )
 static void draw_tmesh (
              tel_tmesh_data                   p,
              Tint                         hflag,
-             TelLModelType front_lighting_model,
+             Tint          front_lighting_model,
              Tint                interior_style,
              tel_colour             edge_colour
             ) {
@@ -463,7 +464,7 @@ static void draw_tmesh (
 #else
  if( interior_style != TSM_EMPTY ) {
 #endif  /* G003 */
-  if ( front_lighting_model == TelLModelNone )
+  if ( front_lighting_model == CALL_PHIGS_REFL_NONE )
 
    LightOff ();
 
@@ -498,7 +499,7 @@ doDraw:
 #endif  /* G004 */
     glBegin ( GL_TRIANGLE_STRIP );
 
-     if ( front_lighting_model == TelLModelNone ) {
+     if ( front_lighting_model == CALL_PHIGS_REFL_NONE ) {
 
       if ( pvc )
 
@@ -558,7 +559,7 @@ doDraw:
 
     glBegin ( GL_TRIANGLES );
 
-     if ( front_lighting_model == TelLModelNone ) {
+     if ( front_lighting_model == CALL_PHIGS_REFL_NONE ) {
 
       if ( pvc ) {
 
