@@ -19,7 +19,15 @@ HISTORIQUE DES MODIFICATIONS   :
 * Includes
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#if defined(HAVE_MALLOC_H) || defined(WNT)
 #include <malloc.h>
+#endif
 
 #include <OpenGl_tgl_all.h>
 
@@ -76,7 +84,9 @@ HISTORIQUE DES MODIFICATIONS   :
 
 extern GLuint linestyleBase;
 extern GLuint fontBase;
-
+#ifndef WNT
+extern txfmfonthandle current_fonthandle;
+#endif
 /*----------------------------------------------------------------------*/
 /*
 * Prototypes fonctions
@@ -1003,7 +1013,7 @@ call_togl_textsize2d
   *width = 0.;
   *ascent = 0.;
   *descent = 0.;
- 
+
 	ptrLayer = (call_def_ptrLayer) ACLayer.ptrLayer;
 	if (ptrLayer == NULL) return;
 	if (ptrLayer->listIndex == 0) return;
@@ -1028,6 +1038,10 @@ call_togl_textsize2d
   *width = (float) Width;
   *ascent = (float) Ascent;
   *descent = (float) Descent;
+
+#ifndef WNT
+  current_fonthandle->dirty=1;
+#endif
 }
 
 /*----------------------------------------------------------------------*/
@@ -1055,6 +1069,46 @@ call_def_ptrLayer ptrLayer;
 	glColor3f (r, g, b);
 }
 
+/*----------------------------------------------------------------------*/
+void EXPORT
+call_togl_set_transparency
+(
+	float a
+)
+{
+call_def_ptrLayer ptrLayer;
+
+	ptrLayer = (call_def_ptrLayer) ACLayer.ptrLayer;
+	if (ptrLayer == NULL) return;
+	if (ptrLayer->listIndex == 0) return;
+#ifdef PRINT
+	printf ("call_togl_set_transparency %d\n", ptrLayer->listIndex);
+	printf ("\ttransparency %f\n", a);
+#endif
+
+  glEnable (GL_BLEND);
+  glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	glColor4f (layerRed, layerGreen, layerBlue, a);
+}
+
+/*----------------------------------------------------------------------*/
+void EXPORT
+call_togl_unset_transparency
+(
+)
+{
+call_def_ptrLayer ptrLayer;
+
+	ptrLayer = (call_def_ptrLayer) ACLayer.ptrLayer;
+	if (ptrLayer == NULL) return;
+	if (ptrLayer->listIndex == 0) return;
+#ifdef PRINT
+	printf ("call_togl_set_untransparency %d\n", ptrLayer->listIndex);
+#endif
+
+  glDisable (GL_BLEND);
+}
+
 /*----------------------------------------------------------------------*/
 void EXPORT
 call_togl_set_line_attributes
