@@ -49,3 +49,34 @@ Tint xr, yr;
 	else
 		return (1);
 }
+
+int EXPORT
+call_togl_unproject_raster_with_ray
+(
+	int wsid,
+	int xm,
+	int ym,
+	int xM,
+	int yM,
+	int ixr,
+	int iyr,
+	float *x,
+	float *y,
+	float *z,
+	float *dx,
+	float *dy,
+	float *dz
+)
+{
+TStatus result;
+Tint xr, yr;
+
+	xr = ixr;
+	yr = yM-ym-iyr;
+	result = TelUnProjectionRasterWithRay (wsid, xr, yr, x, y, z, dx, dy, dz);
+
+	if (result == TSuccess)
+		return (0);
+	else
+		return (1);
+}
