@@ -122,6 +122,8 @@ static  cmn_htbl  txgltbl;		/* Hash table pour le GLXContext */
 static  int BackDitherProp = False;	/* Dithering pour le background */
 static  int DitherProp = True;		/* Dithering pour le trace	*/
 static	GLXContext previous_ctx = 0;	/* Use for share display list	*/
+static  GLXContext dead_ctx;            /* Context to be destroyed */
+static  Display *dead_dpy;              /* Display associated with dead_ctx */
 #else
 static  int BackDitherProp = FALSE;	/* Dithering pour le background */
 static  int DitherProp = TRUE;		/* Dithering pour le trace	*/
@@ -296,13 +298,18 @@ TxglCreateWindow( Display  *disp, Window par,
     if (call_util_osd_getenv ("CALL_OPENGL_NO_BACKDITHER", string, CALL_DEF_STRING_LENGTH))
         BackDitherProp = False;
 
-    if (previous_ctx == 0) {
+    if (dead_ctx) {
+	/* recover display lists from dead_ctx, then destroy it */
+	ctx = glXCreateContext( disp, vis, dead_ctx, GL_TRUE );
+	glXDestroyContext(dead_dpy, dead_ctx);
+	dead_ctx = 0;
+    } else if (previous_ctx == 0) {
         ctx = glXCreateContext( disp, vis, NULL, GL_TRUE );
-        previous_ctx = ctx;
     } else {
 	/* ctx est une copie du previous */
     	ctx = glXCreateContext( disp, vis, previous_ctx, GL_TRUE );
     }
+    previous_ctx = ctx;
 
     if( !ctx) return TFailure;
 
@@ -896,14 +903,25 @@ TxglDestroyWindow( Display *disp, Window win )
     /* FSXXX sync necessary if non-direct rendering */
     glXWaitGL();
 
-    glXDestroyContext(disp, ctx);
     cmn_delete_from_htbl( txgltbl, win, (void**)&ctx );
 
     if (previous_ctx == ctx) {
-       /* san -- OCC12977: it's important to put some valid GLXContext or null into
-	  previous_ctx here, otherwise next glxCreateContext() will crash on some ATI Radeon cards
-        */
-       cmn_get_from_htbl( txgltbl, &dummy, (void**)&previous_ctx, 0 );
+      /* san -- OCC12977: it's important to put some valid GLXContext or null into
+	 previous_ctx here, otherwise next glxCreateContext() will crash on some ATI Radeon cards
+      */
+      cmn_get_from_htbl( txgltbl, &dummy, (void**)&previous_ctx, 0 );
+      /*
+       * if this is the last remaining context, do not destroy it yet, to avoid
+       * losing any shared display lists (fonts...)
+       */
+      if (previous_ctx) {
+	glXDestroyContext(disp, ctx);
+      } else {
+	dead_ctx = ctx;
+	dead_dpy = disp;
+      }
+    } else {
+      glXDestroyContext(disp, ctx);
     }
 
 #else /* WNT */
