@@ -101,6 +101,8 @@
  */
 
 EXPORT extern GLboolean env_walkthrow; /* definit dans OpenGl_togl_begin.c */
+/* OCC18942: The new perspective projection matrix is off by default */
+EXPORT extern GLboolean env_sym_perspective; /* defined in OpenGl_togl_begin.c */
 
 /*----------------------------------------------------------------------*/
 /*
@@ -123,7 +125,7 @@ EXPORT extern GLboolean env_walkthrow; /* definit dans OpenGl_togl_begin.c */
  */
 
 #ifdef DEB
-/*static void pr_matrix( Tmatrix3 );*/
+static void pr_matrix( Tmatrix3 );
 #endif
 
 
@@ -196,6 +198,10 @@ EvalViewMappingMatrix( tel_view_mapping mapping /* View Mapping */,
 {
     Tfloat    gx, gy, xsf, ysf, zsf;
     Tfloat    fpd, bpd;
+
+    /* OCC18942 */
+    Tfloat    n, f, r, l, t, b, Zprp, dx, dy, VPD;
+
     /* FSXXX */
     /* GLint gdtmp; */
     Tlimit3   vp = { ( float )-1.0, ( float )1.0, ( float )-1.0, ( float )1.0, ( float )1.0, ( float )-1.0 };
@@ -208,29 +214,6 @@ EvalViewMappingMatrix( tel_view_mapping mapping /* View Mapping */,
                        { ( float )0.0, ( float )0.0, ( float )1.0, ( float )0.0 },
                        { ( float )0.0, ( float )0.0, ( float )0.0, ( float )1.0 } };
 
-/*
-   There are two ways of implementing clip limits.
-   1) Calculate the front plane and back plane distance according to new
-      clip limits and use them in evaluating the mapping matrix.
-   2) Use user defined clipplanes.
-
-   This toolkit uses second approach if it is supported by the system
-   otherwise it uses the first approach.
-*/
-/*  FMN On ne fait pas de simulation. OpenGL doit avoir de plans de clipping.
-    glGetIntegerv( GL_MAX_CLIP_PLANES , &gdtmp);
-
-    if( clip_flag &&  gdtmp < 2 )
-    {
-       fpd = (mapping->fpd - mapping->bpd) * clip_limit->zmax + mapping->bpd;
-       bpd = (mapping->fpd - mapping->bpd) * clip_limit->zmin + mapping->bpd;
-    }
-    else
-    {
-       fpd = mapping->fpd;
-       bpd = mapping->bpd;
-    }
-*/
     fpd = mapping->fpd;
     bpd = mapping->bpd;
     
@@ -288,30 +271,42 @@ EvalViewMappingMatrix( tel_view_mapping mapping /* View Mapping */,
 
     *error_ind = 0;
 
+    /* OCC18942: Moved here while debugging perspective projection matrix */
+    /* centers */
+    if( flag == 0 )
+    {
+        cx = mapping->window.xmin + mapping->window.xmax, cx /= ( float )2.0;
+        cy = mapping->window.ymin + mapping->window.ymax, cy /= ( float )2.0;
+    }
+
+    gx = (cx - mapping->prp[0]) / (mapping->vpd - mapping->prp[2]);
+    gy = (cy - mapping->prp[1]) / (mapping->vpd - mapping->prp[2]);
+
+#ifdef PRINT
+    printf("EvalViewMappingMatrix \n");
+    printf("prp %f %f %f \n", mapping->prp[0], mapping->prp[1], mapping->prp[2]);
+    printf("vpd fpd bpd %f %f %f \n", mapping->vpd, mapping->fpd, mapping->bpd);
+    printf("window limit %f %f %f %f\n", mapping->window.xmin, mapping->window.xmax, 
+                                         mapping->window.ymin, mapping->window.ymax);
+    printf("viewport limit %f %f %f %f\n", mapping->viewport.xmin, mapping->viewport.xmax, 
+                                           mapping->viewport.ymin, mapping->viewport.ymax);
+#endif
+
     /* projection matrix */
     if( mapping->proj == TelParallel )
     {
-        /* centers */
-        if( flag == 0 )
-        {
-            cx = mapping->window.xmin + mapping->window.xmax, cx /= ( float )2.0;
-            cy = mapping->window.ymin + mapping->window.ymax, cy /= ( float )2.0;
-        }
-
-        gx = (cx - mapping->prp[0]) / (mapping->vpd - mapping->prp[2]);
-        gy = (cy - mapping->prp[1]) / (mapping->vpd - mapping->prp[2]);
 
         pmat[2][0] = -gx; pmat[3][0] = mapping->vpd*gx;
         pmat[2][1] = -gy; pmat[3][1] = mapping->vpd*gy;
     }
-    else /* TelPerspective */
+    else if ( !env_sym_perspective )/* TelPerspective */
     {
         pmat[0][0] = pmat[1][1] = mapping->prp[2] - mapping->vpd;
-        pmat[2][0] = -mapping->prp[0];
-        pmat[2][1] = -mapping->prp[1];
+        pmat[2][0] = -gx; 
+        pmat[2][1] = -gy; 
         pmat[2][3] = ( float )-1.0;
-        pmat[3][0] = mapping->vpd * mapping->prp[0];
-        pmat[3][1] = mapping->vpd * mapping->prp[1];
+        pmat[3][0] = mapping->vpd * gx; 
+        pmat[3][1] = mapping->vpd * gy; 
         pmat[3][3] = mapping->prp[2];
 
         /* modify the next two cells to change clipping policy */
@@ -321,6 +316,83 @@ EvalViewMappingMatrix( tel_view_mapping mapping /* View Mapping */,
         pmat[3][2] = fpd * bpd; 
         }
     }
+    /* OCC18942: New approach to calculation of mapping (projection) matrix */
+    else 
+    {
+      dx = mapping->window.xmax - mapping->window.xmin;
+      dy = mapping->window.ymax - mapping->window.ymin;
+      Zprp = mapping->prp[2];
+      VPD = Zprp - mapping->vpd;
+      
+      /* 
+      Calculate canonical perspective projection parameters as if we were about 
+      to use glFrustum() to create symmetric perspective frustum.
+
+      After the view orientation matrix is applied, the coordinate system origin is located 
+      at the VRP and oriented properly. However, the viewplane has width = dx and height = dy 
+      and its center (cx, cy, VPD) is not always located at the view Z axis.
+      The canonical perspective projection matrix assumes the eye is located at (0, 0, 0).
+      Thus the old approach resulted in a non-symmetric perspective, 
+      as X and Y coordinates of the projection reference point (PRP) were not updated
+      when cx and cy changed. Moreover, such "static" perspective had some other disadvantages,
+      such as non-realistic panning, i.e. instead of moving the eye (or camera) over the model
+      a sort of "frame" moved over the static perspective projection picture, 
+      exposing a part of this static picture to the user.
+
+      In order to make the perspective symmetric, we need to translate 
+      the coordinate system to PRP before projection.
+      Thus we translate X, Y and Z co-ordinates by -cx, -cy and -Zprp respectively.
+
+      NOTE: mat[i][j] means j-th element of i-th column, as OpenGL accepts the matrices
+      in column-major order, while in C two-dimensional arrays are stored in memory
+      in row-major order!
+
+      VPD is used below instead of near clipping plane dispance (n) in order to simplify 
+      calculation of l and r values. If we did not use VPD in the matrix calculation, we would have to 
+      project 0.5 * dx, -0.5 * dx, 0.5 * dy and - 0.5 * dy onto the near clipping plane 
+      to calculate these values.
+
+      Pending issues:
+      1. It is still necessary to find a way to calculate the perspective projection matrix 
+      for TPM_WALKTHROUGH projection model. This projection model is not supported yet 
+      by the new code.
+      */
+      r = .5f * dx;
+      l = -r;
+      t = .5f * dy;
+      b = -t;
+      n = Zprp - fpd; f = Zprp - bpd;
+      
+      mat[0][0] = 2.f * VPD / (r - l);
+      mat[1][1] = 2.f * VPD / (t - b);
+      mat[2][0] = (r + l) / (r - l);
+      mat[2][1] = (t + b) / (t - b);
+      mat[2][2] = - (f + n) / (f - n);
+      mat[2][3] = -1.f;
+      /* 
+      The last column takes into account translation along X, Y and Z axis
+      before projecting. This can be considered as a result of right-multiplying the canonical 
+      perspective projection matrix P by a translation matrix T 
+      (it differs form the canonical matrix by the last column only):
+                             | 1 0 0  -cx  |
+                             | 0 1 0  -cy  |
+      mat = P * T, where T = | 0 0 1 -Zprp |
+                             | 0 0 0   1   |
+      */
+      mat[3][0] = -mat[2][0] * Zprp - mat[0][0] * cx;
+      mat[3][1] = -mat[2][1] * Zprp - mat[1][1] * cy;
+      mat[3][2] = -2.f * f * n / (f - n) - mat[2][2] * Zprp;
+      mat[3][3] = Zprp;
+      
+#ifdef PRINT
+      printf("r l t b n f: %f %f %f %f %f %f \n", r,l,t,b,n,f);
+      printf( "mapping_matrix (new code):\n" );
+      pr_matrix(mat);
+#endif
+      
+      /* return here, as further calculations are related to the old approach */
+      return;
+    }
 
     /* scale factors */
     xsf = (vp.xmax - vp.xmin) / (mapping->window.xmax - mapping->window.xmin);
@@ -335,17 +407,11 @@ EvalViewMappingMatrix( tel_view_mapping mapping /* View Mapping */,
 
     /* multiply to obtain mapping matrix */
     TelMultiplymat3( mat, pmat, mmat );
-    
+
 #ifdef PRINT
-    printf("EvalViewMappingMatrix \n");
-    printf("prp %f %f %f \n", mapping->prp[0], mapping->prp[1], mapping->prp[2]);
-    printf("vpd fpd bpd %f %f %f \n", mapping->vpd, mapping->fpd, mapping->bpd);
-    printf("window limit %f %f %f %f\n", mapping->window.xmin, mapping->window.xmax, 
-                                              mapping->window.ymin, mapping->window.ymax);
+    printf( "mapping_matrix :\n" );
     pr_matrix(mat);
 #endif
-
-    return;
 }
 
 /*----------------------------------------------------------------------*/
@@ -392,17 +458,9 @@ TelSetViewRepresentation( Tint  Wsid /* Workstation id*/,
         TsmSetWSAttri( Wsid, WSViews, &key ); /* Set defined view data*/
     }
 
-    vptr->vrep = *vrep; /* copy view definition to storage table record */
-    if( ( ( vrep->clip_limit.zmin > 0.0 && vrep->clip_limit.zmin < 1.0 ) ||
-          ( vrep->clip_limit.zmax < 1.0 && vrep->clip_limit.zmax > 0.0 ) ) &&
-          ( vrep->clip_limit.zmax > vrep->clip_limit.zmin ) )
-    {
-       Tint error_ind;
-       EvalViewMappingMatrix( &(vrep->extra.map),
-                              &error_ind,
-                              vptr->vrep.mapping_matrix,
-                              0, ( float )0.0, ( float )0.0, 1, &( vrep->clip_limit ) );
-    }
+    /* copy view definition to storage table record */
+    /* NOTE: Use the matrices already calculated and stored in vrep */
+    vptr->vrep = *vrep; 
 
 #ifdef CAL_100498
     /* compute inverse transformation matrix */
@@ -704,8 +762,7 @@ TelConvertCoord( Tint  Wsid        /* Workstation id */,
     Debug tool
 +*/
 
-/* Unused :*/
-/*#ifdef DEB
+#ifdef DEB
 void
 pr_matrix( Tmatrix3 mat )
 {
@@ -716,7 +773,7 @@ pr_matrix( Tmatrix3 mat )
     printf( "\n" );
     return;
 }
-#endif*/
+#endif
 
 /*----------------------------------------------------------------------*/
 /*+
