@@ -78,7 +78,7 @@
 #define UNDERLINE "UnderLine "
 #define SCALEDRAWING "ScaleDrawing "
 #define SCALEFONT "ScaleFont "
-static char* MONTHS [] = {
+static const char* MONTHS [] = {
   "January", "February", "March",
   "April", "May", "June", "July",
   "August", "September", "October",
