@@ -62,7 +62,7 @@ Prs2d_Axis::Prs2d_Axis( const Handle(Graphic2d_GraphicObject)& aGO,
    gp_Pnt2d theOrigine( 0., 0.), P1, P2, P3;
    gp_Vec2d VX( 1., 0. ), VDir;
   
-   P1 = gp_Pnt2d( X1, Y1 );;
+   P1 = gp_Pnt2d( X1, Y1 );
    P2 = gp_Pnt2d( anArrLength,  anArrLength*Tan( ArrAngle/2. ) );
    P3 = gp_Pnt2d( anArrLength, -anArrLength*Tan( ArrAngle/2. ) );
   
@@ -671,3 +671,47 @@ Standard_Boolean Prs2d_Axis::Pick( const Standard_ShortReal X,
 void Prs2d_Axis::Save(Aspect_FStream& aFStream) const
 {
 }
+
+Prs2d_TypeOfArrow Prs2d_Axis::TypeOfArrow( ) const
+{
+  return myArrType;
+}
+
+const Handle(TColgp_HArray1OfPnt2d)  Prs2d_Axis::ArrayOfPnt2d( ) const
+{
+   Handle(TColgp_HArray1OfPnt2d) points = new TColgp_HArray1OfPnt2d( 1, 3 );
+		
+   points->SetValue( 1, gp_Pnt2d( myX1, myY1 ) );
+   points->SetValue( 2, gp_Pnt2d( myX0, myY0 ) );
+   points->SetValue( 3, gp_Pnt2d( myX2, myY2 ) );
+   return points;
+}
+
+const Handle(TColgp_HArray1OfPnt2d)  Prs2d_Axis::ArrayOfXArrowPnt2d( ) const
+{
+   Handle(TColgp_HArray1OfPnt2d) points = new TColgp_HArray1OfPnt2d( 1, 3 );
+		
+   for ( Standard_Integer i = 1; i <= 3; i++ ) 
+   {
+     points->SetValue( i, gp_Pnt2d( myXVertX(i), myYVertX(i) ) );
+   }   
+   return points;
+}
+
+const Handle(TColgp_HArray1OfPnt2d)  Prs2d_Axis::ArrayOfYArrowPnt2d( ) const
+{
+   Handle(TColgp_HArray1OfPnt2d) points = new TColgp_HArray1OfPnt2d( 1, 3 );
+		
+   for ( Standard_Integer i = 1; i <= 3; i++ ) 
+   {
+     points->SetValue( i, gp_Pnt2d( myXVertY(i), myYVertY(i) ) );
+   }   
+   return points;
+}
+
+Standard_Real Prs2d_Axis::TextScale( ) const
+{
+  return myTextScale;
+}
+
+
