@@ -33,3 +33,27 @@ Prs2d_Dimension::Prs2d_Dimension( const Handle(Graphic2d_GraphicObject)& aGO,
 
 {
 }
+
+const Handle(TColgp_HArray1OfPnt2d)  Prs2d_Dimension::ArrayOfFirstArrowPnt( ) const
+{
+   Handle(TColgp_HArray1OfPnt2d) points = new TColgp_HArray1OfPnt2d( 1, 3 );
+		
+   for ( Standard_Integer i = 1; i <= 3; i++ ) 
+   {
+     points->SetValue( i, gp_Pnt2d( myXVert1(i), myYVert1(i) ) );
+   }   
+   return points;
+}
+
+const Handle(TColgp_HArray1OfPnt2d)  Prs2d_Dimension::ArrayOfSecondArrowPnt( ) const
+{
+   Handle(TColgp_HArray1OfPnt2d) points = new TColgp_HArray1OfPnt2d( 1, 3 );
+		
+   for ( Standard_Integer i = 1; i <= 3; i++ ) 
+   {
+     points->SetValue( i, gp_Pnt2d( myXVert2(i), myYVert2(i) ) );
+   }   
+   return points;
+}
+
+
