@@ -907,3 +907,20 @@ void Prs2d_Length::SetAttachLinLength( const Standard_Real aLength )
 void Prs2d_Length::Save(Aspect_FStream& aFStream) const
 {
 }
+
+void Prs2d_Length::LineCoord( gp_Pnt2d& aFirstPnt, gp_Pnt2d& aSecondPnt ) const
+{
+  aFirstPnt = gp_Pnt2d( myXT1, myYT1 );
+  aSecondPnt = gp_Pnt2d( myXT2, myYT2 );
+}
+
+void Prs2d_Length::CallOutCoord( gp_Pnt2d& aFirstPnt, gp_Pnt2d& aSecondPnt ) const
+{
+  aFirstPnt = gp_Pnt2d( myAX1, myAY1 );
+  aSecondPnt = gp_Pnt2d( myAX2, myAY2 );
+}
+
+Prs2d_TypeOfDist Prs2d_Length::TypeOfDist() const
+{
+  return myTypeDist;
+}
