@@ -36,6 +36,7 @@
 #include <STEPConstruct.hxx>
 #include <STEPConstruct_Styles.hxx>
 #include <STEPConstruct_ExternRefs.hxx>
+#include <STEPConstruct_UnitContext.hxx>
 #include <STEPCAFControl_Controller.hxx>
 #include <STEPCAFControl_DataMapOfSDRExternFile.hxx>
 
@@ -378,7 +379,6 @@ Standard_Boolean STEPCAFControl_Reader::Transfer (STEPControl_Reader &reader,
   Handle(Interface_InterfaceModel) Model = reader.Model();
   Handle(Transfer_TransientProcess) TP = reader.WS()->TransferReader()->TransientProcess();
   Standard_Integer nb = Model->NbEntities();
-  const Interface_Graph& graph = TP->Graph();
 
   Handle(TColStd_HSequenceOfTransient) SeqPDS = new TColStd_HSequenceOfTransient;
 
@@ -1494,28 +1494,10 @@ static Standard_Boolean GetLengthConversionFactor(Handle(StepBasic_NamedUnit)& N
     if(NU2->IsKind(STANDARD_TYPE(StepBasic_SiUnit))) {
       Handle(StepBasic_SiUnit) SU = Handle(StepBasic_SiUnit)::DownCast(NU2);
       if(SU->Name()==StepBasic_sunMetre) {
-        if(SU->HasPrefix()) {
-          switch(SU->Prefix())
-            {
-            case StepBasic_spKilo:
-              afact = afact*1000000.;
-              break;
-            case StepBasic_spDeci:
-              afact = afact*100.;
-              break;
-            case StepBasic_spCenti:
-              afact = afact*10.;
-              break;
-            case StepBasic_spMilli:
-              afact = afact*1.;
-              break;
-            case StepBasic_spMicro:
-              afact = afact*0.001;
-            break;
-//              default : 
-            }
-        }
-        else afact = afact*1000.;
+        if(SU->HasPrefix()) 
+	  afact *= STEPConstruct_UnitContext::ConvertSiPrefix (SU->Prefix());
+	// convert m to mm
+	afact *= 1000.;
       }
     }
   }
@@ -1542,18 +1524,8 @@ static Standard_Boolean GetMassConversionFactor(Handle(StepBasic_NamedUnit)& NU,
     if(NU2->IsKind(STANDARD_TYPE(StepBasic_SiUnit))) {
       Handle(StepBasic_SiUnit) SU = Handle(StepBasic_SiUnit)::DownCast(NU2);
       if(SU->Name()==StepBasic_sunGram) {
-        if(SU->HasPrefix()) {
-          switch(SU->Prefix())
-            {
-            case StepBasic_spKilo:
-              afact = afact*1000.;
-              break;
-            case StepBasic_spMilli:
-              afact = afact*0.001;
-              break;
-            }
-        }
-        //else afact = afact*1000.;
+        if(SU->HasPrefix())
+	  afact *= STEPConstruct_UnitContext::ConvertSiPrefix (SU->Prefix());
       }
     }
   }
@@ -1807,7 +1779,7 @@ Standard_Boolean STEPCAFControl_Reader::ReadGDTs(const Handle(XSControl_WorkSess
             Handle(StepDimTol_GeometricToleranceWithDatumReference) GTWDR =
               Handle(StepDimTol_GeometricToleranceWithDatumReference)::DownCast(subs3.Value());
             if(GTWDR.IsNull()) continue;
-            Standard_Integer kind;
+            Standard_Integer kind = 0;
             if     (GTWDR->IsKind(STANDARD_TYPE(StepDimTol_AngularityTolerance)))       kind = 24;
             else if(GTWDR->IsKind(STANDARD_TYPE(StepDimTol_CircularRunoutTolerance)))   kind = 25;
             else if(GTWDR->IsKind(STANDARD_TYPE(StepDimTol_CoaxialityTolerance)))       kind = 26;
@@ -1959,7 +1931,6 @@ Standard_Boolean STEPCAFControl_Reader::ReadMaterials(const Handle(XSControl_Wor
               for(Standard_Integer idu=1; idu<=DU->NbElements(); idu++) {
                 Handle(StepBasic_DerivedUnitElement) DUE = DU->ElementsValue(idu);
                 Handle(StepBasic_NamedUnit) NU = DUE->Unit();
-                Standard_Real exp = DUE->Exponent();
                 Standard_Real afact=1.;
                 if(NU->IsKind(STANDARD_TYPE(StepBasic_ConversionBasedUnitAndLengthUnit))) {
                   if(GetLengthConversionFactor(NU,afact)) aDensity = aDensity/(afact*afact*afact);
