@@ -179,7 +179,7 @@ Handle(StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx) STEPCon
 // Purpose : Computes SiPrefix conversion
 // ==========================================================================
 
-static Standard_Real ConvertSiPrefix(StepBasic_SiPrefix& aPrefix)
+Standard_Real STEPConstruct_UnitContext::ConvertSiPrefix (const StepBasic_SiPrefix aPrefix)
 {
   switch(aPrefix)
     {
