@@ -6,6 +6,8 @@
 #include <STEPConstruct_ValidationProps.ixx>
 #include <STEPConstruct_UnitContext.hxx>
 
+#include <Message.hxx>
+#include <Message_Messenger.hxx>
 #include <Interface_Macros.hxx>
 #include <Interface_Static.hxx>
 #include <Interface_EntityIterator.hxx>
@@ -484,7 +486,8 @@ Standard_Boolean STEPConstruct_ValidationProps::LoadProps (TColStd_SequenceOfTra
     
     // check that PDR is for validation props
     Handle(StepRepr_PropertyDefinition) PD = PDR->Definition().PropertyDefinition();
-    if ( PD.IsNull() || PD->Name()->String() != "geometric_validation_property" ) 
+    if ( PD.IsNull() || PD->Name().IsNull() 
+         || PD->Name()->String() != "geometric_validation_property" ) 
       continue;
 
     seq.Append ( PDR );
@@ -508,7 +511,10 @@ Handle(StepBasic_ProductDefinition) STEPConstruct_ValidationProps::GetPropPD (co
     Handle(StepRepr_ShapeAspect) SA = CD.ShapeAspect();
     if ( SA.IsNull() ) {
 #ifdef DEB
-      cout << "Error: Cannot find target entity (SA) for geometric_validation_property "; Model()->PrintLabel ( PD, cout ); cout << endl;
+      Handle(Message_Messenger) sout = Message::DefaultMessenger();
+      sout << "Error: Cannot find target entity (SA) for geometric_validation_property "; 
+      Model()->PrintLabel ( PD, sout ); 
+      sout << endl;
 #endif
       return ProdDef;
     }
@@ -530,7 +536,10 @@ Handle(StepBasic_ProductDefinition) STEPConstruct_ValidationProps::GetPropPD (co
   }
 #ifdef DEB
   if ( ProdDef.IsNull() ) {
-    cout << "Error: Cannot find target entity (SDR) for geometric_validation_property "; Model()->PrintLabel ( PD, cout ); cout << endl;
+    Handle(Message_Messenger) sout = Message::DefaultMessenger();
+    sout << "Error: Cannot find target entity (SDR) for geometric_validation_property "; 
+    Model()->PrintLabel ( PD, sout ); 
+    sout << endl;
   }
 #endif
   return ProdDef;
@@ -580,7 +589,10 @@ TopoDS_Shape STEPConstruct_ValidationProps::GetPropShape (const Handle(StepBasic
   //}
 #ifdef DEB
   if ( S.IsNull() ) {
-    cout << "Warning: Entity "; Model()->PrintLabel ( ProdDef, cout ); cout << " is not mapped to shape" << endl;
+    Handle(Message_Messenger) sout = Message::DefaultMessenger();
+    sout << "Warning: Entity "; 
+    Model()->PrintLabel ( ProdDef, sout ); 
+    sout << " is not mapped to shape" << endl;
   }
 #endif
   return S;
