@@ -3,7 +3,6 @@
 //    gka 05.04.99 S4136: eliminate parameter lastpreci
 //gka,abv 14.04.99 S4136: maintain unit context, precision and maxtolerance values
 #include <STEPControl_ActorRead.ixx>
-#include <Interface_TraceFile.hxx>
 #include <OSD_Timer.hxx>
 
 // #include <Interface_InterfaceModel.hxx>  // pour mise au point
@@ -87,6 +86,7 @@
 
 #include <TColStd_HSequenceOfTransient.hxx>
 #include <Message_ProgressSentry.hxx>
+#include <Message_Messenger.hxx>
 #include <StepRepr_HSequenceOfRepresentationItem.hxx>
 #include <StepBasic_ProductDefinition.hxx>
 #include <Standard_Failure.hxx>
@@ -337,8 +337,7 @@ static void getSDR(const Handle(StepRepr_ProductDefinitionShape)& PDS,
                                                                         const Handle(Transfer_TransientProcess)& TP) 
 
 {
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
-  Standard_OStream& sout  = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = TP->Messenger();
   Handle(TransferBRep_ShapeBinder) shbinder;
   
   TopoDS_Compound Cund;
@@ -413,7 +412,8 @@ static void getSDR(const Handle(StepRepr_ProductDefinitionShape)& PDS,
       Handle(StepRepr_NextAssemblyUsageOccurrence)::DownCast(listNAUO->Value(nbNauo));
       
 #ifdef TRANSLOG
-    if (trlev > 1) sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(PD)<<" -> Shared Ent.no"<<TP->Model()->Number(NAUO)<<endl;
+    if (TP->TraceLevel() > 1) 
+      sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(PD)<<" -> Shared Ent.no"<<TP->Model()->Number(NAUO)<<endl;
 #endif
     Handle(Transfer_Binder) binder;
     if (!TP->IsBound(NAUO)) binder = TransferEntity(NAUO,TP);
@@ -600,10 +600,10 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Han
     return shbinder;
   isBound = Standard_False;
   Standard_Integer i,nb = sr->NbItems();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
-  Standard_OStream& sout  = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = TP->Messenger();
 #ifdef TRANSLOG
-  if (trlev > 2) sout<<" -- Actor : case  ShapeRepr. NbItems="<<nb<<endl;
+  if (TP->TraceLevel() > 2) 
+    sout<<" -- Actor : case  ShapeRepr. NbItems="<<nb<<endl;
 #endif
   
     // Compute unit convertion factors and geometric Accuracy
@@ -619,7 +619,8 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Han
   for (i = 1; i <= nb && PS.More(); i ++,PS.Next()) {
   //for (i = 1; i <= nb ; i ++) {
 #ifdef TRANSLOG
-    if (trlev > 2) sout<<" -- Actor, shape_representation.item n0. "<<i<<endl;
+    if (TP->TraceLevel() > 2) 
+      sout<<" -- Actor, shape_representation.item n0. "<<i<<endl;
 #endif
     Handle(StepRepr_RepresentationItem) anitem = sr->ItemsValue(i);
     Handle(Transfer_Binder) binder;
@@ -681,7 +682,8 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Han
     if ( subs.Value()->IsKind(STANDARD_TYPE(StepShape_ShapeDefinitionRepresentation))) {
       DeclareAndCast(StepShape_ShapeDefinitionRepresentation,SDR,subs.Value());
 #ifdef TRANSLOG
-      if (trlev > 1) sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(CDSR)<<" -> Sharing Ent.no"<<TP->Model()->Number(SDR)<<endl;
+      if (TP->TraceLevel() > 1) 
+        sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(CDSR)<<" -> Sharing Ent.no"<<TP->Model()->Number(SDR)<<endl;
 #endif
       
       binder = TP->Find ( SDR );
@@ -825,8 +827,7 @@ static Standard_Boolean IsNeedRepresentation(const Handle(StepRepr_ShapeAspect)&
 Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::OldWay(const Handle(Standard_Transient)& start,
                                                                const Handle(Transfer_TransientProcess)& TP)
 {
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
-  Standard_OStream& sout  = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = TP->Messenger();
   const Interface_Graph& graph = TP->Graph();
   Handle(TransferBRep_ShapeBinder) shbinder;
   DeclareAndCast(StepShape_ShapeDefinitionRepresentation,sdr,start);
@@ -845,7 +846,8 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::OldWay(const Handle(Stan
   }
     
 #ifdef TRANSLOG
-  if (trlev > 2) sout<<" -- Actor : case  shape_definition_representation."<<endl;
+  if (TP->TraceLevel() > 2) 
+    sout<<" -- Actor : case  shape_definition_representation."<<endl;
 #endif
   Handle(Transfer_Binder) binder = TP->Find(rep);
   if (binder.IsNull()) binder = TP->Transferring(rep);
@@ -885,7 +887,8 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::OldWay(const Handle(Stan
 //      DeclareAndCast(StepShape_ContextDependentShapeRepresentation,anitem,subs.Value());
 //      if (anitem.IsNull()) continue;
 #ifdef TRANSLOG
-    if (trlev > 1) sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(start)<<" -> Shared Ent.no"<<TP->Model()->Number(anitem)<<endl;
+    if (TP->TraceLevel() > 1) 
+      sout<<" -- Actor : Ent.n0 "<<TP->Model()->Number(start)<<" -> Shared Ent.no"<<TP->Model()->Number(anitem)<<endl;
 #endif
 
     if (!TP->IsBound(anitem)) binder = TP->Transferring(anitem);
@@ -913,8 +916,7 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::OldWay(const Handle(Stan
 Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Handle(StepGeom_GeometricRepresentationItem)& start,
                                                               const Handle(Transfer_TransientProcess)& TP)
 {
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
-  Standard_OStream& sout  = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = TP->Messenger();
   Handle(TransferBRep_ShapeBinder) shbinder;
   Standard_Boolean found = Standard_False;
   StepToTopoDS_Builder myShapeBuilder;
@@ -922,8 +924,9 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Han
   Standard_Integer nbTPitems = TP->NbMapped();
 #ifdef TRANSLOG
   OSD_Timer chrono;
-  if (trlev > 2) sout << "Begin transfer STEP -> CASCADE, Type "
-    <<start->DynamicType()->Name()<<endl;
+  if (TP->TraceLevel() > 2) 
+    sout << "Begin transfer STEP -> CASCADE, Type "
+         << start->DynamicType()->Name() << endl;
   chrono.Start();
 #endif
   
@@ -991,10 +994,12 @@ Handle(TransferBRep_ShapeBinder) STEPControl_ActorRead::TransferEntity(const Han
   }
   found = !mappedShape.IsNull();
   if (found && shbinder.IsNull()) shbinder = new TransferBRep_ShapeBinder (mappedShape);
- #ifdef TRANSLOG
+#ifdef TRANSLOG
   chrono.Stop();
-  if (trlev > 2) sout<<"End transfer STEP -> CASCADE :"<<(found ? "OK" : " : no result")<<endl;
-  if (trlev > 2) chrono.Show();
+  if (TP->TraceLevel() > 2) 
+    sout<<"End transfer STEP -> CASCADE :" << (found ? "OK" : " : no result")<<endl;
+  if (TP->TraceLevel() > 2) 
+    chrono.Show();
 #endif
   if ( oldSRContext.IsNull() && ! mySRContext.IsNull() ) //:S4136
     PrepareUnits ( oldSRContext, TP );
@@ -1148,12 +1153,12 @@ Handle(Transfer_Binder) STEPControl_ActorRead::TransferShape (const Handle(Stand
 
 //  myContext.SetModel ( Handle(StepData_StepModel)::DownCast ( TP->Model() ) ); // for asking IsAP203?
   
-  Standard_OStream& sout  = Interface_TraceFile::Def();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
+  Handle(Message_Messenger) sout = TP->Messenger();
 #ifdef TRANSLOG
 //  POUR MISE AU POINT, a supprimer ensuite
 //  sout<<"STEP->Shape, ent n0 "<<TP->Model()->Number(start)<<" Level="<<TP->NestingLevel()<<endl;
-  if (trlev > 1) sout<<" -- Actor : Transfer Ent.n0 "<<TP->Model()->Number(start)<<"  Type "<<start->DynamicType()->Name()<<endl;
+  if (TP->TraceLevel() > 1) 
+    sout<<" -- Actor : Transfer Ent.n0 "<<TP->Model()->Number(start)<<"  Type "<<start->DynamicType()->Name()<<endl;
 #endif
   
   Handle(TransferBRep_ShapeBinder) shbinder;
@@ -1313,9 +1318,8 @@ void  STEPControl_ActorRead::PrepareUnits (const Handle(StepRepr_Representation)
   // Assign uncertainty
 //  Interface_Static::SetRVal("lastpreci",UpdatedValue);
 #ifdef TRANSLOG
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
-  if (trlev > 1) sout<<"  Cc1ToTopoDS : Length Unit = "<<myUnit.LengthFactor()<<"  Tolerance CASCADE = "<<myPrecision<<endl;
+  if (TP->TraceLevel() > 1) 
+    TP->Messenger() <<"  Cc1ToTopoDS : Length Unit = "<<myUnit.LengthFactor()<<"  Tolerance CASCADE = "<<myPrecision<<endl;
 #endif
 }
 
