@@ -73,7 +73,6 @@
 #include <Interface_Static.hxx>
 
 #include <Interface_Macros.hxx>
-#include <Interface_TraceFile.hxx>
 #include <TopTools_HSequenceOfShape.hxx>
 
 #include <BRep_Tool.hxx>
@@ -457,27 +456,6 @@ Handle(Transfer_Binder) STEPControl_ActorWrite::TransferShape (const Handle(Tran
   // MODE ASSEMBLY : if Compound, (sub-)assembly
   if ( IsAssembly ( theShape ) )
     return TransferCompound (start,SDR0,FP);
-  /*STEPControl_StepModelType trmode = mymode;
-  // Mode AsIs : on va essayer de faire au mieux
-  if (mymode == STEPControl_AsIs) {
-    Standard_OStream& sout = Interface_TraceFile::Def();
-    Standard_Integer trlev = Interface_TraceFile::DefLevel();
-
-    // On va essayer de faire au mieux
-    ShapeExtend_Explorer stu;
-    TopAbs_ShapeEnum sty = stu.ShapeType (theShape,Standard_True);
-    if (sty == TopAbs_COMPOUND) {
-      // Il y a des shells ? on prend shell. Sinon wire
-      TopoDS_Shape sh2 = stu.SortedCompound (theShape,TopAbs_SHELL,Standard_True,Standard_False);
-      if (!sh2.IsNull()) sty = TopAbs_SHELL;
-      else sty = TopAbs_WIRE;
-    }
-    if (trlev > 0) sout<<"-- Shape to STEP, computed mode = ";
-    if      (sty == TopAbs_SOLID) { trmode = STEPControl_ManifoldSolidBrep; if (trlev > 0) sout<<"ManifoldSolid"<<endl; }
-    else if (sty == TopAbs_SHELL) { trmode = STEPControl_ShellBasedSurfaceModel; if (trlev > 0) sout<<"ShellBased"<<endl; }
-    else if (sty == TopAbs_FACE ) { trmode = STEPControl_ShellBasedSurfaceModel; if (trlev > 0) sout<<"Faces:ShellBased"<<endl; }
-    else  { trmode = STEPControl_GeometricCurveSet; if (trlev > 0) sout<<"Wireframe"<<endl; }
-  }*/
 
   // create a list of items to translate
   Handle(TopTools_HSequenceOfShape) RepItemSeq = new TopTools_HSequenceOfShape();
