@@ -8,6 +8,7 @@
 #include <DBRep.hxx>
 #include <SWDRAW.hxx>
 #include <gp_XYZ.hxx>
+#include <gp_Pnt2d.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Shape.hxx>
 #include <TopoDS_Edge.hxx>
@@ -17,8 +18,8 @@
 #include <TopExp_Explorer.hxx>
 #include <BRep_Tool.hxx>
 #include <BRepBuilderAPI.hxx>
+#include <BRepTopAdaptor_FClass2d.hxx>
 
-#include <MDBLIST.hxx>
 #include <ShapeBuild_ReShape.hxx>
 #include <ShapeAnalysis_Edge.hxx>
 #include <ShapeAnalysis_WireOrder.hxx>
@@ -38,11 +39,10 @@
 #include <ShapeExtend_DataMapIteratorOfDataMapOfShapeListOfMsg.hxx>
 #include <Message_ListIteratorOfListOfMsg.hxx>
 #include <Message_Msg.hxx>
+#include <TCollection_AsciiString.hxx>
 #include <TopTools_MapOfShape.hxx>
 #include <TopTools_DataMapOfShapeListOfShape.hxx>
-#include <BRepTopAdaptor_FClass2d.hxx>
 #include <TopAbs_State.hxx>
-#include <gp_Pnt2d.hxx>
 
 #ifdef AIX
 #include <strings.h>
@@ -55,7 +55,7 @@
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer edgesameparam (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer edgesameparam (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
 //  const Standard_CString arg1 = argv[1];
   const Standard_CString arg2 (argc > 2 ? argv[2] : NULL);
@@ -74,7 +74,7 @@ static Standard_Integer edgesameparam (Draw_Interpretor& di, Standard_Integer ar
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer settolerance (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer settolerance (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 3) {
     di<<    "myshape val   : forces tolerances at <val>"<<"\n"
@@ -118,7 +118,7 @@ static Standard_Integer settolerance (Draw_Interpretor& di, Standard_Integer arg
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer stwire (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer stwire (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2) { // help
     di<<"Donner nom shape depart + nom shape resultat + option"<<"\n";
@@ -316,7 +316,7 @@ static Standard_Integer stwire (Draw_Interpretor& di, Standard_Integer argc, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer reface (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer reface (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 3) { di<<"Donner un nom de SHAPE (SHELL ou FACE) + un nom de RESULTAT"<<"\n"; return 1 /* Error */; }
   Standard_CString arg1 = argv[1];
@@ -381,7 +381,7 @@ static Standard_Integer reface (Draw_Interpretor& di, Standard_Integer argc, cha
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer fixshape (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer fixshape (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   Handle(ShapeExtend_MsgRegistrator) msg = new ShapeExtend_MsgRegistrator;
   Handle(ShapeFix_Shape) sfs = new ShapeFix_Shape;
@@ -459,7 +459,7 @@ static Standard_Integer fixshape (Draw_Interpretor& di, Standard_Integer argc, c
       }
       di << ":" << "\n";
       for (Message_ListIteratorOfListOfMsg iter (it.Value()); iter.More(); iter.Next())
-        di << "  " << iter.Value().Value() << "\n";
+        di << "  " << TCollection_AsciiString(iter.Value().Value()).ToCString() << "\n";
     }
   }
   
@@ -471,7 +471,7 @@ static Standard_Integer fixshape (Draw_Interpretor& di, Standard_Integer argc, c
 //purpose  : 
 //=======================================================================
 
-Standard_Integer fixgaps(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer fixgaps(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -497,7 +497,7 @@ Standard_Integer fixgaps(Draw_Interpretor& di, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-Standard_Integer fixsmall(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer fixsmall(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   
@@ -524,7 +524,7 @@ Standard_Integer fixsmall(Draw_Interpretor& di, Standard_Integer n, char** a)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer fixsmalledges(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer fixsmalledges(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if( n < 3) {
     di<<"Invalid number of arguments"<<"\n";
@@ -569,7 +569,7 @@ static Standard_Integer fixsmalledges(Draw_Interpretor& di, Standard_Integer n,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer checkoverlapedges(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer checkoverlapedges(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
    if( n < 3) {
      di<<"Invalid number of arguments"<<"\n";
@@ -614,7 +614,7 @@ static Standard_Integer checkoverlapedges(Draw_Interpretor& di, Standard_Integer
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer checkfclass2d(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer checkfclass2d(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if( n < 4) {
     di<<"Invalid number of arguments"<<"\n";
