@@ -75,7 +75,7 @@
 //=======================================================================
 
 static Standard_Integer DT_ShapeDivide (Draw_Interpretor& di,
-					Standard_Integer n, char** a)
+					Standard_Integer n, const char** a)
 {
   // DT_ShapeDivide result Shape Tol
   // a[1]= result
@@ -138,7 +138,7 @@ static Standard_Integer DT_ShapeDivide (Draw_Interpretor& di,
 }
 
 static Standard_Integer DT_ShapeConvertRev (Draw_Interpretor& di,
-					 Standard_Integer n, char** a)
+					 Standard_Integer n, const char** a)
 {
   if (n<5) {
     di << "bad number of arguments" <<"\n";
@@ -376,7 +376,7 @@ static Standard_Integer DT_ShapeConvertRev (Draw_Interpretor& di,
 }
 */
 static Standard_Integer DT_ShapeConvert (Draw_Interpretor& di,
-					 Standard_Integer n, char** a)
+					 Standard_Integer n, const char** a)
 {
   if (n<5) {
     di << "bad number of arguments" <<"\n";
@@ -428,7 +428,7 @@ static Standard_Integer DT_ShapeConvert (Draw_Interpretor& di,
   return 0;
 }
 static Standard_Integer DT_SplitAngle(Draw_Interpretor& di,
-				      Standard_Integer n, char** a)
+				      Standard_Integer n, const char** a)
 {
   if (n<3) {
     di << "bad number of arguments" <<"\n";
@@ -485,7 +485,7 @@ static Standard_Integer DT_SplitAngle(Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer DT_PlaneDividedFace (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= result
@@ -530,7 +530,7 @@ static Standard_Integer DT_PlaneDividedFace (Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer DT_PlaneGridShell (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
 
@@ -578,7 +578,7 @@ static Standard_Integer DT_PlaneGridShell (Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer DT_PlaneFaceCommon (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= result
@@ -620,7 +620,7 @@ static Standard_Integer DT_PlaneFaceCommon (Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer DT_SplitCurve (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= input curve. This name is used with a suffix to name the output curves
@@ -665,7 +665,7 @@ static Standard_Integer DT_SplitCurve (Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer DT_SplitCurve2d (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= input 2d curve. This name is used with a suffix to name the output curves
@@ -711,7 +711,7 @@ static Standard_Integer DT_SplitCurve2d (Draw_Interpretor& di,
 //=======================================================================
 /*
 static Standard_Integer DT_SplitWire (Draw_Interpretor& di,
-				      Standard_Integer n, char** a)
+				      Standard_Integer n, const char** a)
 {
 
   if (n <3) {
@@ -745,7 +745,7 @@ static Standard_Integer DT_SplitWire (Draw_Interpretor& di,
 */
 /*
 static Standard_Integer DT_SplitFace (Draw_Interpretor& di,
-				      Standard_Integer n, char** a)
+				      Standard_Integer n, const char** a)
 {
 
   if (n <3) {
@@ -798,7 +798,7 @@ static Standard_Integer DT_SplitFace (Draw_Interpretor& di,
 */
 
 static Standard_Integer DT_SplitSurface (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= result (used with a suffix to name the output surfaces)
@@ -900,7 +900,7 @@ di << "transfert resultat" << "\n";
 //
 //=======================================================================
 /*static Standard_Integer DT_SupportModification (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= result
@@ -950,7 +950,7 @@ di << "transfert resultat" << "\n";
 //=======================================================================
 /*
 static Standard_Integer DT_Debug (Draw_Interpretor& di,
-				   Standard_Integer n, char** a)
+				   Standard_Integer n, const char** a)
 
 {
   // a[1]= 0/1
@@ -973,7 +973,7 @@ static Standard_Integer DT_Debug (Draw_Interpretor& di,
 */
 
 /*static Standard_Integer shellsolid
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 4) {
     di<<"Donner option + nom de SHAPE + nom de RESULTAT"<<"\n";
@@ -1060,7 +1060,7 @@ static Standard_Integer DT_Debug (Draw_Interpretor& di,
 //
 //=======================================================================
 static Standard_Integer offset2dcurve
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 4) {
     di<<"result + curve + offset"<<"\n";
@@ -1083,7 +1083,7 @@ static Standard_Integer offset2dcurve
 //
 //=======================================================================
 static Standard_Integer offsetcurve
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 5) {
     di<<"result + curve + offset + Dir"<<"\n";
@@ -1108,7 +1108,7 @@ static Standard_Integer offsetcurve
 //purpose  : 
 //=======================================================================
 static Standard_Integer splitface
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 5) {
     di << "Split face: splitface result face [u usplit1 usplit2...] [v vsplit1 vsplit2 ...]" << "\n";
@@ -1249,7 +1249,7 @@ static Standard_Integer splitface
 }
 
 static Standard_Integer converttobspline
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<3) {
     di << "bad number of arguments" <<"\n";
@@ -1271,7 +1271,7 @@ static Standard_Integer converttobspline
 
 static Standard_Integer splitclosed (Draw_Interpretor& di, 
 				     Standard_Integer argc, 
-				     char** argv)
+				     const char** argv)
 {
   if (argc<3) {
     di << "bad number of arguments" <<"\n";
@@ -1295,7 +1295,7 @@ static Standard_Integer splitclosed (Draw_Interpretor& di,
 
 static Standard_Integer splitarea (Draw_Interpretor& di, 
 				     Standard_Integer argc, 
-				     char** argv)
+				     const char** argv)
 {
   if (argc<4) {
     di << "bad number of arguments" <<"\n";
@@ -1326,7 +1326,7 @@ static Standard_Integer splitarea (Draw_Interpretor& di,
 
 static Standard_Integer removeinternalwires (Draw_Interpretor& di, 
                                              Standard_Integer argc, 
-                                             char** argv)
+                                             const char** argv)
 {
   if (argc<4) {
     di << "bad number of arguments" <<"\n";
