@@ -216,7 +216,7 @@ static Standard_Boolean MinMaxSmall
     // Standard_Real dx = 0, dy = 0, dz = 0;
     // Standard_Real    x,y,z;
     Standard_Real minx,miny,minz,maxx,maxy,maxz;
-    Standard_Boolean small = Standard_True;
+    Standard_Boolean issmall = Standard_True;
 
     for (iu = 1; iu <= nbu; iu ++) {
 //    for each U line, scan poles in V (V direction)
@@ -226,13 +226,13 @@ static Standard_Boolean MinMaxSmall
 	MinMaxPnt (unp, nb, minx,miny,minz, maxx,maxy,maxz);
       }
       if (!MinMaxSmall(minx,miny,minz,maxx,maxy,maxz,toler))
-	{  small = Standard_False;  break;  }    // small in V ?
+	{  issmall = Standard_False;  break;  }    // small in V ?
     }
-    if (small) {
+    if (issmall) {
       myStatusStrip = ShapeExtend::EncodeStatus ( ShapeExtend_DONE2);
-      return small;    // OK, small in V
+      return issmall;    // OK, small in V
     }
-    small = Standard_True;
+    issmall = Standard_True;
     for (iv = 1; iv <= nbv; iv ++) {
 //    for each V line, scan poles in U (U direction)
       Standard_Integer nb = 0;
@@ -241,11 +241,11 @@ static Standard_Boolean MinMaxSmall
 	MinMaxPnt (unp, nb, minx,miny,minz, maxx,maxy,maxz);
       }
       if (!MinMaxSmall(minx,miny,minz,maxx,maxy,maxz,toler))
-	{  small = Standard_False;  break;  }    // small in U ?
+	{  issmall = Standard_False;  break;  }    // small in U ?
     }
-    if (small) {
+    if (issmall) {
       myStatusStrip = ShapeExtend::EncodeStatus (ShapeExtend_DONE1);
-      return small;
+      return issmall;
     }// OK, small in U
   }
 
