@@ -22,7 +22,6 @@
 #include <Adaptor3d_Curve.hxx>
 #include <Extrema_ExtPC.hxx>
 #include <ShapeAnalysis.hxx>
-//#include <MoniTool_Macros.hxx>
 #include <TColgp_SequenceOfPnt.hxx>
 #include <Geom_Line.hxx>
 #include <Geom_Conic.hxx>
@@ -282,13 +281,6 @@ Standard_Real ShapeAnalysis_Curve::ProjectAct(const Adaptor3d_Curve& C3D,
       }
     }
     catch(Standard_Failure) {
-//       MoniTool_DB& dbl = MoniTool_DB::Cur();
-//       dbl.Add("ShapeAnalysis_Geom::Project, excp");
-//       dbl.AddRaised();
-//       dbl.AddText ("Doing direct computation");
-//       dbl.AddXYZ (P3D.XYZ());
-      // dbl.AddGeom (C3D);
-      // cout<<"GeomAPI_ProjectPointOnCurve fails, doing direct computation"<<endl;
       OK = Standard_False;
 #ifdef DEB //:s5
       cout << "\nWarning: ShapeAnalysis_Curve::ProjectAct(): Exception in Extrema_ExtPC: "; 
@@ -1031,17 +1023,17 @@ Standard_Boolean ShapeAnalysis_Curve::GetSamplePoints (const Handle(Geom_Curve)&
   if(!adelta )
     return Standard_False;
   
-  Standard_Real aK = (last - first) / adelta;
-  Standard_Integer nbp =100*ceil(aK);
+  Standard_Integer aK = (Standard_Integer)ceil ((last - first) / adelta);
+  Standard_Integer nbp =100*aK;
   if(curve->IsKind(STANDARD_TYPE(Geom_Line)))
     nbp =2;
   else if(curve->IsKind(STANDARD_TYPE(Geom_Circle)))
-    nbp =360*ceil(aK);
+    nbp =360*aK;
   
   else if (curve->IsKind(STANDARD_TYPE(Geom_BSplineCurve))) {
     Handle(Geom_BSplineCurve) aBspl = Handle(Geom_BSplineCurve)::DownCast(curve);
     
-    nbp = aBspl->NbKnots() * aBspl->Degree()*ceil(aK);
+    nbp = aBspl->NbKnots() * aBspl->Degree()*aK;
     if(nbp < 2.0) nbp=2;
   }
   else if (curve->IsKind(STANDARD_TYPE(Geom_BezierCurve))) {
