@@ -763,88 +763,6 @@ Standard_Boolean ShapeAnalysis_Surface::IsVClosed(const Standard_Real preci)
   return (myVCloseVal <= prec);
 }
 
-
-/* //:study S4030: removed
-static Standard_Real FindUV(const gp_Pnt& aPnt,
-			    const Handle(Geom_Surface)& theSurf,
-			    Standard_Real& U,
-			    Standard_Real& V,
-			    Standard_Real& theU,
-			    Standard_Real& theV)
-{
-  Standard_Real DistMin = RealLast();
-
-  if (theSurf->Continuity() == GeomAbs_C0)
-    return DistMin; // on verra plus tard
-
-  // on construit la droite passant par aPnt, de direction la
-  // normale a la surface en (U,V)
-
-  gp_Vec D1U, D1V;
-  gp_Pnt Eval;
-  theSurf->D1(U, V, Eval, D1U, D1V);
-
-  Standard_Real UU, VV, W, MinCS = RealLast();
-  Standard_Real distres = gp::Resolution();
-  Standard_Real distCS = aPnt.Distance (Eval);  // y est-on deja ?
-  if (distCS <= distres ) { theU = U; theV = V; return distCS; }
-
-  gp_Vec Norm = D1U.Crossed(D1V);
-  if (Norm.Magnitude() < 20. * distres) {
-    //  trop petit mon ami (singularite ?) : on en reste la
-    theU = U; theV = V; return distCS;
-  }
-  gp_Dir NormDir(Norm);
-  gp_Lin theLine(aPnt, NormDir);
-  Handle(Geom_Line) myLine = new Geom_Line(theLine);
-  Handle(Geom_TrimmedCurve) myTC =
-    new Geom_TrimmedCurve (myLine, -distCS * 10, +distCS * 10);
-
-  //:a0 abv 6 Jan 98: prevent exceptions and memory lossage
-  Standard_Real su1, sv1, su2, sv2;
-  theSurf->Bounds(su1, su2, sv1, sv2);
-  if ( Precision::IsInfinite(su1) ) su1 = U - 1000.;
-  if ( Precision::IsInfinite(su2) ) su2 = U + 1000.;
-  if ( Precision::IsInfinite(sv1) ) sv1 = V - 1000.;
-  if ( Precision::IsInfinite(sv2) ) sv2 = V + 1000.;
-  Handle(Geom_RectangularTrimmedSurface) trimSrf =
-     new Geom_RectangularTrimmedSurface ( theSurf, su1, su2, sv1, sv2 );
-
-  try {
-    OCC_CATCH_SIGNALS
-  GeomAPI_IntCS myIntCS(myTC, trimSrf ); //:a0: theSurf);
-//  GeomAPI_IntCS myIntCS(myTC, theSurf);  working on the trimmed surface
-  if (myIntCS.IsDone()) {
-    for (Standard_Integer i = 1 ; i <= myIntCS.NbPoints(); i ++) {
-      myIntCS.Parameters(i, UU, VV, W);
-      gp_Pnt thePoint = theSurf->Value(UU, VV);
-      distCS= thePoint.Distance(aPnt);
-      if (distCS < MinCS) {
-	MinCS = distCS; theU = UU; theV = VV;
-      }
-    }
-  }
-  else {
-    return DistMin;
-  }
-
-  }  // fin try RAJOUT
-  catch(Standard_Failure) {
-    MoniTool_DB& dbl = MoniTool_DB::Cur();
-    dbl.Add("ShapeAnalysis_Surface(FindUV), excp");
-    dbl.AddRaised();
-    dbl.AddGeom  (theSurf);
-    dbl.AddXYZ   (aPnt.XYZ());
-    dbl.AddReals (U,V);
-    const gp_Pnt& lnori = theLine.Location();
-    const gp_Dir& lndir = theLine.Direction();
-    dbl.AddXYZ (lnori.XYZ());
-    dbl.AddXYZ (lndir.XYZ());
-    return DistMin;
-  }
-  return MinCS;
-}
-*/
 //=======================================================================
 //function : SurfaceNewton
 //purpose  : Newton algo (S4030)
@@ -1230,11 +1148,10 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
     // no more precise computation
     return theMin;
   }
- try {    // RAJOUT    
-   OCC_CATCH_SIGNALS
+  try {    // RAJOUT    
+    OCC_CATCH_SIGNALS
     //pdn Create BndBox containing point;
     Bnd_Box aPBox;
-    const Bnd_Box *anIsoBox;
     aPBox.Set(P3d);
 
     //cout<<"Adaptor3d()->Surface().GetType() = "<<Adaptor3d()->Surface().GetType()<<endl;
@@ -1248,19 +1165,20 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
 
       UV = (num < 3);  // 0-1-2 : iso-U  3-4-5 : iso-V
       if( !(Adaptor3d()->Surface().GetType()==GeomAbs_OffsetSurface) ) {
+	const Bnd_Box *anIsoBox = 0;
         switch (num) {
-        case 0 : par = myUF; iso = myIsoUF; anIsoBox = &myBndUF; break;
+        case 0 : par = myUF; iso = myIsoUF;  anIsoBox = &myBndUF; break;
         case 1 : par = myUL; iso = myIsoUL;  anIsoBox = &myBndUL; break;
         case 2 : par = U;    iso = UIso (U); break;
         case 3 : par = myVF; iso = myIsoVF;  anIsoBox = &myBndVF; break;
         case 4 : par = myVL; iso = myIsoVL;  anIsoBox = &myBndVL; break;
         case 5 : par = V;    iso = VIso (V); break;
-          default : break;
+        default: break;
         }
         
         //    On y va la-dessus
         if (!Precision::IsInfinite(par) && !iso.IsNull()) {
-          if( num != 2 && num != 5 && anIsoBox->Distance(aPBox) > theMin)
+          if( anIsoBox && anIsoBox->Distance(aPBox) > theMin)
             continue;
           
           Cf = iso->FirstParameter();
@@ -1282,6 +1200,7 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
         Adaptor3d_Curve *anAdaptor = NULL;
         GeomAdaptor_Curve aGeomCurve;
         
+	const Bnd_Box *anIsoBox = 0;
         switch (num) {
         case 0 : par = myUF; aGeomCurve.Load(myIsoUF); anAdaptor=&aGeomCurve; anIsoBox = &myBndUF; break;
         case 1 : par = myUL; aGeomCurve.Load(myIsoUL); anAdaptor=&aGeomCurve; anIsoBox = &myBndUL;break;
@@ -1291,7 +1210,7 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
         case 5 : par = V;    anIsoCurve.Load(GeomAbs_IsoV,V); anAdaptor=&anIsoCurve; break;
           default : break;
         }
-        if( num != 2 && num != 5 && anIsoBox->Distance(aPBox) > theMin)
+        if( anIsoBox && anIsoBox->Distance(aPBox) > theMin)
           continue;
         dist = ShapeAnalysis_Curve().Project(*anAdaptor,P3d,preci,pntres,other);
         if (dist < theMin) {
@@ -1386,14 +1305,6 @@ Standard_Real ShapeAnalysis_Surface::UVFromIso(const gp_Pnt& P3d,const Standard_
 
   }  // fin try RAJOUT
   catch(Standard_Failure) {
-#ifdef DEBUG
-//     MoniTool_DB& dbl = MoniTool_DB::Cur();
-//     dbl.Add("ShapeAnalysis_Surface::UVFromIso, excp");
-//     dbl.AddRaised();
-//     dbl.AddGeom  (theSurf);
-//     dbl.AddXYZ   (aPnt.XYZ());
-//     dbl.AddReals (U,V);
-#endif
     theMin = RealLast();    // theMin de depart
 #ifdef DEB //:s5
     cout << "\nWarning: ShapeAnalysis_Curve::UVFromIso(): Exception: "; 
