@@ -574,11 +574,6 @@ Standard_Boolean ShapeAnalysis_Wire::CheckOrder(ShapeAnalysis_WireOrder& sawo,
   case  -2: myStatus = ShapeExtend::EncodeStatus (ShapeExtend_DONE4); break;
   case -10: myStatus = ShapeExtend::EncodeStatus (ShapeExtend_FAIL1); break;
   }
-//   if (stat == -10) {  // loops remain
-//     MoniTool_DB& dbl = MoniTool_DB::Cur();
-//     dbl.Add("ShapeAnalysis_Wire::CheckOrder, loops remain");
-//     if (!myFace.IsNull()) dbl.AddShape (myFace);
-//   }
   return LastCheckStatus (ShapeExtend_DONE);
 }
 
@@ -647,7 +642,7 @@ Standard_Boolean ShapeAnalysis_Wire::CheckSmall (const Standard_Integer num,
   if ( BRep_Tool::Degenerated ( E ) ) {
     //:n2 abv 22 Jan 99: ma-test5.igs -> IGES (brep) -> read (pref3d):
     // degen edge with no pcurve should be removed
-    if ( sae.HasPCurve ( E, Face() ) ) return Standard_False;
+    if ( ! myFace.IsNull() && sae.HasPCurve ( E, Face() ) ) return Standard_False;
     myStatus = ShapeExtend::EncodeStatus (ShapeExtend_FAIL1);
   }
   
