@@ -80,121 +80,88 @@ Standard_Boolean ShapeFix::SameParameter(const TopoDS_Shape& shape,
 
   while (ex.More()) {
     TopoDS_Edge E;
-    //try { //szv#4:S4163:12Mar99 waste try
-    //  OCC_CATCH_SIGNALS
-      while (ex.More()) {
-	numedge ++;
-	int ierr = 0;
-	TopLoc_Location loc;  //Standard_Real u0,u1; //szv#4:S4163:12Mar99 moved down unused
-	E = TopoDS::Edge (ex.Current());
-	ex.Next();
+    while (ex.More()) {
+      numedge ++;
+      int ierr = 0;
+      TopLoc_Location loc;  //Standard_Real u0,u1; //szv#4:S4163:12Mar99 moved down unused
+      E = TopoDS::Edge (ex.Current());
+      ex.Next();
 	
-	//pdn degenerated edges shuld be samerange and sameparameter.
-	//if (BRep_Tool::Degenerated(E)) continue;  // ne vaut pas
-	if (!iatol) tol = BRep_Tool::Tolerance (E);
-	if (enforce) {
-	  B.SameRange     (E,Standard_False);
-	  B.SameParameter (E,Standard_False);
-	}
+      //pdn degenerated edges shuld be samerange and sameparameter.
+      //if (BRep_Tool::Degenerated(E)) continue;  // ne vaut pas
+      if (!iatol) tol = BRep_Tool::Tolerance (E);
+      if (enforce) {
+	B.SameRange     (E,Standard_False);
+	B.SameParameter (E,Standard_False);
+      }
 //:pdn	if (BRep_Tool::SameParameter(E)) continue;
 //	Handle(Geom_Curve) crv = BRep_Tool::Curve (E,loc,u0,u1);
 //	if (crv.IsNull()) BRepLib::BuildCurve3d (E,tol);
-	sfe->FixSameParameter (E);  // et non BRepLib::  jusqu a K2-SEP97
-	if (!BRep_Tool::SameParameter (E)) { ierr = 1; nbfail ++; }
-
-	if (ierr) {
-// 	  MoniTool_DB& curdb = MoniTool_DB::Cur();
-// 	  curdb.Add ("ShapeFix::SameParameter, fail on an edge");
-// 	  curdb.AddShape (shape,"Shape");
-// 	  curdb.AddShape (E,"Edge");
-// 	  curdb.AddReal  (tol,"Tol");
-	  status = Standard_False;
-	  B.SameRange (E,Standard_False);
-	  B.SameParameter (E,Standard_False);
-	}
-
-      }    // -- end while
-    /* }
-    catch(Standard_Failure) {
-      nbexcp ++;
-      // ex.Next();  already done
-      MoniTool_DB& curdb = MoniTool_DB::Cur();
-      curdb.Add ("SameParameter, excp on an edge");
-      curdb.AddRaised();
-      curdb.AddShape (shape,"Shape");
-      curdb.AddShape (E,"Edge");
-      curdb.AddReal  (tol,"Tol");
-      status = Standard_False;
-      B.SameRange (E,Standard_False);
-      B.SameParameter (E,Standard_False);
-    } */
+      sfe->FixSameParameter (E);  // et non BRepLib::  jusqu a K2-SEP97
+      if (!BRep_Tool::SameParameter (E)) { ierr = 1; nbfail ++; }
+      
+      if (ierr) {
+	status = Standard_False;
+	B.SameRange (E,Standard_False);
+	B.SameParameter (E,Standard_False);
+      }
+      
+    }    // -- end while
   }
 
   //:i2 abv 21 Aug 98: ProSTEP TR8 Motor.rle face 710:
   // Update tolerance of edges on planes (no pcurves are stored)
-  //try { //szv#4:S4163:12Mar99 waste try
-  //  OCC_CATCH_SIGNALS
-    for ( TopExp_Explorer exp ( shape, TopAbs_FACE ); exp.More(); exp.Next() ) {
-      TopoDS_Face face = TopoDS::Face ( exp.Current() );
-      Handle(Geom_Surface) Surf = BRep_Tool::Surface ( face );
+  for ( TopExp_Explorer exp ( shape, TopAbs_FACE ); exp.More(); exp.Next() ) {
+    TopoDS_Face face = TopoDS::Face ( exp.Current() );
+    Handle(Geom_Surface) Surf = BRep_Tool::Surface ( face );
       
-      Handle(Geom_Plane) plane = Handle(Geom_Plane)::DownCast ( Surf );
-      if ( plane.IsNull() ) {
-	Handle(Geom_RectangularTrimmedSurface) GRTS = 
-	  Handle(Geom_RectangularTrimmedSurface)::DownCast ( Surf );
-	if ( ! GRTS.IsNull() ) 
-	  plane = Handle(Geom_Plane)::DownCast ( GRTS->BasisSurface() );
-	if ( plane.IsNull() ) continue;
-      }
+    Handle(Geom_Plane) plane = Handle(Geom_Plane)::DownCast ( Surf );
+    if ( plane.IsNull() ) {
+      Handle(Geom_RectangularTrimmedSurface) GRTS = 
+	Handle(Geom_RectangularTrimmedSurface)::DownCast ( Surf );
+      if ( ! GRTS.IsNull() ) 
+	plane = Handle(Geom_Plane)::DownCast ( GRTS->BasisSurface() );
+      if ( plane.IsNull() ) continue;
+    }
       
 //      Handle(ShapeConstruct_ProjectCurveOnSurface) Proj = new ShapeConstruct_ProjectCurveOnSurface; //:k2 abv 16 Dec 98: use existing tool //smh#14
 //      Handle(ShapeAnalysis_Surface) sas = new ShapeAnalysis_Surface ( plane );
 //      Proj->Init ( sas, Precision::Confusion() ); // projection will be analitic
-      Handle(GeomAdaptor_HSurface) AS = new GeomAdaptor_HSurface ( plane );
-      for ( TopExp_Explorer ed ( face, TopAbs_EDGE ); ed.More(); ed.Next() ) {
-	TopoDS_Edge edge = TopoDS::Edge ( ed.Current() );
-	Standard_Real f, l;
-	Handle(Geom_Curve) crv = BRep_Tool::Curve ( edge, f, l );
-	if ( crv.IsNull() ) continue;
+    Handle(GeomAdaptor_HSurface) AS = new GeomAdaptor_HSurface ( plane );
+    for ( TopExp_Explorer ed ( face, TopAbs_EDGE ); ed.More(); ed.Next() ) {
+      TopoDS_Edge edge = TopoDS::Edge ( ed.Current() );
+      Standard_Real f, l;
+      Handle(Geom_Curve) crv = BRep_Tool::Curve ( edge, f, l );
+      if ( crv.IsNull() ) continue;
 	
 //	Handle(Geom2d_Curve) c2d;
 //	Proj->Perform ( crv, f, l, c2d );
-	Handle(Geom2d_Curve) c2d = BRep_Tool::CurveOnSurface ( edge, face, f, l );;
-	if ( c2d.IsNull() ) continue;
-	Handle(Geom2dAdaptor_HCurve) GHPC = new Geom2dAdaptor_HCurve ( c2d, f, l );
-	Adaptor3d_CurveOnSurface ACS(GHPC,AS);//sas->Adaptor3d());
+      Handle(Geom2d_Curve) c2d = BRep_Tool::CurveOnSurface ( edge, face, f, l );;
+      if ( c2d.IsNull() ) continue;
+      Handle(Geom2dAdaptor_HCurve) GHPC = new Geom2dAdaptor_HCurve ( c2d, f, l );
+      Adaptor3d_CurveOnSurface ACS(GHPC,AS);//sas->Adaptor3d());
 	
-	Standard_Real tol0 = BRep_Tool::Tolerance ( edge );
-	tol = tol0;
-	Standard_Real tol2 = tol*tol;
-	const Standard_Integer NCONTROL = 23;
-	for ( Standard_Integer i=0; i < NCONTROL; i++ ) {
-	  Standard_Real par = ( f * ( NCONTROL - 1 - i ) + l * i ) / ( NCONTROL - 1 );
-	  gp_Pnt pnt = crv->Value ( par );
-	  gp_Pnt prj = ACS.Value( par );
-	  Standard_Real dist = pnt.SquareDistance(prj);
-	  if ( tol2 < dist ) tol2 = dist;
-	}
-	tol = 1.00005 * sqrt(tol2); // coeff: see trj3_pm1-ct-203.stp #19681, edge 10
-        if ( tol >= tol0 ) {
-	  B.UpdateEdge ( edge, tol );
-	  for ( TopoDS_Iterator itV(edge); itV.More(); itV.Next() ) {
-	    TopoDS_Shape S = itV.Value();
-	    B.UpdateVertex ( TopoDS::Vertex ( S ), tol );
-	  }
+      Standard_Real tol0 = BRep_Tool::Tolerance ( edge );
+      tol = tol0;
+      Standard_Real tol2 = tol*tol;
+      const Standard_Integer NCONTROL = 23;
+      for ( Standard_Integer i=0; i < NCONTROL; i++ ) {
+	Standard_Real par = ( f * ( NCONTROL - 1 - i ) + l * i ) / ( NCONTROL - 1 );
+	gp_Pnt pnt = crv->Value ( par );
+	gp_Pnt prj = ACS.Value( par );
+	Standard_Real dist = pnt.SquareDistance(prj);
+	if ( tol2 < dist ) tol2 = dist;
+      }
+      tol = 1.00005 * sqrt(tol2); // coeff: see trj3_pm1-ct-203.stp #19681, edge 10
+      if ( tol >= tol0 ) {
+	B.UpdateEdge ( edge, tol );
+	for ( TopoDS_Iterator itV(edge); itV.More(); itV.Next() ) {
+	  TopoDS_Shape S = itV.Value();
+	  B.UpdateVertex ( TopoDS::Vertex ( S ), tol );
 	}
       }
     }
-  /* }
-  catch(Standard_Failure) {
-    nbexcp ++;
-    MoniTool_DB& curdb = MoniTool_DB::Cur();
-    curdb.Add ("SameParameter, excp on whole shape");
-    curdb.AddRaised();
-    curdb.AddShape (shape,"Shape");
-    curdb.AddReal  (preci,"Tol");
-    status = Standard_False;
-  } */
+  }
 
   if (!status) {
 #ifdef DEB
@@ -317,7 +284,6 @@ static TopoDS_Edge ReplaceVertex(const TopoDS_Edge& theEdge,
 //=======================================================================
 static Standard_Real getNearPoint(const TColgp_SequenceOfPnt& aSeq1,
                                   const TColgp_SequenceOfPnt& aSeq2,
-                                  const Standard_Real theTolerance, 
                                   gp_XYZ& acent)
 {
   Standard_Integer i =1;
@@ -387,7 +353,6 @@ static Standard_Boolean getNearestEdges(TopTools_ListOfShape& theLEdges,
   alIter.Next();
   TopTools_SequenceOfShape aseqreject;
   TopTools_SequenceOfShape aseqsuit;
-  Standard_Integer numEdge =1;
   
   Standard_Integer anumLoop =0;
   for( ; alIter.More(); ) {
@@ -437,7 +402,7 @@ static Standard_Boolean getNearestEdges(TopTools_ListOfShape& theLEdges,
         aSeq2.Append(p1);
         if(isSame)
           aSeq2.Append(p2);
-        aMinDist = getNearPoint(aSeq1,aSeq2,theTolerance,acent);
+        aMinDist = getNearPoint(aSeq1,aSeq2,acent);
       }
       
       if(aMinDist > theTolerance) {
@@ -552,7 +517,6 @@ Standard_Boolean ShapeFix::FixVertexPosition(TopoDS_Shape& theshape,
       Standard_Boolean isLast = (aVert2.IsSame(aVert));
       if(!isFirst && !isLast)
         continue;
-      Standard_Boolean isSame = aVert1.IsSame(aVert2);
       Standard_Real aFirst,aLast;
       Handle(Geom_Curve) aCurve;
       TopoDS_Edge aEdge = TopoDS::Edge(thecontext->Apply(aEdgeOld));
