@@ -807,7 +807,6 @@ Standard_Boolean ShapeFix_IntersectionTool::FixSelfIntersectWire
   //if(area2d<Precision::PConfusion()*Precision::PConfusion()) return Standard_False; //gka 06.09.04 BUG 6555
 
   TopoDS_Shape SF = face;
-  TopAbs_Orientation ori = face.Orientation();
   Standard_Real MaxTolVert=0.0;
   for(TopExp_Explorer exp(SF,TopAbs_VERTEX); exp.More(); exp.Next()) { 
     Standard_Real tolV = BRep_Tool::Tolerance(TopoDS::Vertex(exp.Current()));
@@ -826,7 +825,7 @@ Standard_Boolean ShapeFix_IntersectionTool::FixSelfIntersectWire
   NbSplit=0;
   NbCut=0;
   Standard_Integer nbReplaced =0;
-  Standard_Boolean isFail = Standard_False, isDone = Standard_False;
+  Standard_Boolean isDone = Standard_False;
   for(Standard_Integer num1=1; num1<sewd->NbEdges() && NbSplit<30; num1++) {
     // for each edge from first wire
     for(Standard_Integer num2=num1+2; num2<=sewd->NbEdges() && NbSplit<30; num2++) {
@@ -1472,8 +1471,6 @@ Standard_Boolean ShapeFix_IntersectionTool::FixIntersectingWires
       Standard_Integer NbModif=0;
       Standard_Integer nbReplaced =0;//gka 06.09.04
       Standard_Boolean hasModifWire = Standard_False; //gka 06.09.04
-
-      Standard_Boolean isFail = Standard_False;
       for(Standard_Integer num1 = 1; num1<=sewd1->NbEdges() && NbModif<30; num1++) {
         // for each edge from first wire
         TopoDS_Edge edge1 = sewd1->Edge(num1); //gka 06.09.04
