@@ -13,8 +13,6 @@
 #include <BRepLib.hxx>
 
 #include <Message_MsgFile.hxx>
-#include <Message_Printer.hxx>
-#include <Message_TraceFile.hxx>
 #include <ShapeExtend_MsgRegistrator.hxx>
 #include <ShapeProcess.hxx>
 #include <ShapeProcess_UOperator.hxx>
