@@ -1,4 +1,5 @@
 #include <Handle_Standard_Transient.hxx>
+#include <Standard_Atomic.hxx>
 
 //============================================================================
 
@@ -26,20 +27,35 @@ void Handle(Standard_Transient)::Dump(Standard_OStream& out) const
 
 void Handle(Standard_Transient)::Assign (const Standard_Transient *anItem)
 {
-  if ( anItem == entity ) return;
+  Standard_Transient *anIt = ( anItem ? (Standard_Transient*)anItem : UndefinedHandleAddress );
+  if ( anIt == entity ) return;
   EndScope();
-  entity = ( anItem ? (Standard_Transient*)anItem : UndefinedHandleAddress );
+  entity = anIt;
   BeginScope();
 }
 
 //============================================================================
 
+void Handle(Standard_Transient)::BeginScope()
+{
+  if (entity != UndefinedHandleAddress) 
+  {
+    if ( Standard::IsReentrant() ) 
+      Standard_Atomic_Increment (&entity->count);
+    else 
+      entity->count++;
+  }
+}
+
+//============================================================================
+
 void Handle(Standard_Transient)::EndScope()
 {
   if (entity == UndefinedHandleAddress) 
     return;
-  entity->count--;
-  if (entity->count == 0)
+  if ( Standard::IsReentrant() ? 
+       Standard_Atomic_DecrementTest (&entity->count) : 
+       (--entity->count == 0) )
     entity->Delete();
   entity = UndefinedHandleAddress;
 }
