@@ -22,8 +22,6 @@
 # include <errno.h>
 #endif
 
-#include <Standard_Stream.hxx>
-
 #ifdef WNT
 #include <windows.h>
 #else
@@ -86,10 +84,16 @@ extern "C" int getpagesize() ;
 #elif defined (__osf__) || defined(DECOSF1)
 #define MMAP_BASE_ADDRESS 0x1000000000
 #define MMAP_FLAGS (MAP_ANONYMOUS | MAP_PRIVATE | MAP_VARIABLE)
-#elif _AIX
+#elif defined(_AIX)
 #define MMAP_BASE_ADDRESS  0x80000000
 #define MMAP_FLAGS (MAP_ANONYMOUS | MAP_PRIVATE | MAP_VARIABLE)
-#elif WNT
+#elif defined(__APPLE__)
+#define MMAP_BASE_ADDRESS  0x80000000
+#define MMAP_FLAGS (MAP_ANON | MAP_PRIVATE)
+#elif defined(LIN)
+#define MMAP_BASE_ADDRESS 0x20000000
+#define MMAP_FLAGS (MAP_PRIVATE)
+#elif defined(WNT)
 //static HANDLE myhMap;
 #else
 #define MMAP_BASE_ADDRESS 0x60000000
@@ -136,9 +140,29 @@ extern "C" int getpagesize() ;
 #endif
 */
 
+
+/* In the allocated block, first bytes are used for storing of memory manager's data.
+   (size of block). The minimal size of these data is sizeof(int).
+   The memory allocated in system usually alligned by 16 bytes.Tthe aligment of the 
+   data area in the memory block is shfted on BLOCK_SHIFT*sizeof(Standard_Size) 
+   bytes.
+   It is OK for WNT, SUN and Linux systems, but on SGI aligment should be 8 bytes.
+   So, BLOCK_SHIFT is formed as macro for support on other possible platforms.
+*/
+
+#define BLOCK_SHIFT 1
+#if defined(IRIX)
+#define BLOCK_SHIFT 2
+#endif
+
+
 // Get address of user area from block address, and vice-versa
-#define GET_USER(block)    (((Standard_Size*)(block))  +1)
-#define GET_BLOCK(storage) (((Standard_Size*)(storage))-1)
+#define GET_USER(block)    (((Standard_Size*)(block)) + BLOCK_SHIFT)
+#define GET_BLOCK(storage) (((Standard_Size*)(storage))-BLOCK_SHIFT)
+
+// create static instance of out-of-memory exception to protect
+// against possible lack of memory for its raising
+static Handle(Standard_OutOfMemory) anOutOfMemError = new Standard_OutOfMemory;
 
 //=======================================================================
 //function : Standard_MMgr
@@ -204,8 +228,8 @@ Standard_MMgrOpt::~Standard_MMgrOpt()
 void Standard_MMgrOpt::Initialize()
 {
   // check number of pages in small blocks pools 
-  if ( myNbPages <= 100 ) 
-    myNbPages = 10000; // 10000 - for compatibility with previous implementation
+  if ( myNbPages < 100 ) 
+    myNbPages = 1000;
   
   // get system-dependent page size
 #ifndef WNT
@@ -258,7 +282,7 @@ void Standard_MMgrOpt::Initialize()
       perror("ERR_MEMRY_FAIL");
 #endif
     
-#if defined(IRIX) || defined(__sgi) || defined(SOLARIS) || defined(__sun) || defined(LIN) || defined(linux)
+#if defined(IRIX) || defined(__sgi) || defined(SOLARIS) || defined(__sun) || defined(LIN) || defined(linux) || defined(__FreeBSD__)
     if ((myMMap = open ("/dev/zero", O_RDWR)) < 0) {
       if ((myMMap = open ("/dev/null", O_RDWR)) < 0){
         myMMap = 0;
@@ -272,7 +296,7 @@ void Standard_MMgrOpt::Initialize()
   }
   
   // initialize free lists
-  myFreeListMax = INDEX_CELL(ROUNDUP_CELL(myThreshold-1)); // all blocks less than myThreshold are to be recycled
+  myFreeListMax = INDEX_CELL(ROUNDUP_CELL(myThreshold-BLOCK_SHIFT)); // all blocks less than myThreshold are to be recycled
   myFreeList = (Standard_Size **) calloc (myFreeListMax+1, sizeof(Standard_Size *));
   myCellSize = ROUNDUP16(myCellSize);
 }
@@ -337,7 +361,7 @@ Standard_Address Standard_MMgrOpt::Allocate(const Standard_Size aSize)
 
       // check for availability of requested space in the current pool
       Standard_Size *aBlock = myNextAddr;
-      if ( &aBlock[1+RoundSizeN] > myEndBlock ) {
+      if ( &aBlock[ BLOCK_SHIFT+RoundSizeN] > myEndBlock ) {
         // otherwise, allocate new memory pool with page-aligned size
         Standard_Size Size = myPageSize * myNbPages;
         aBlock = AllocMemory(Size); // note that size may be aligned by this call
@@ -347,7 +371,8 @@ Standard_Address Standard_MMgrOpt::Allocate(const Standard_Size aSize)
         *(Standard_Size**)aBlock = myAllocList;
         // and made new pool current (last)
         // and get pointer to the first memory block in the pool
-        myAllocList = aBlock++;
+	aBlock+=BLOCK_SHIFT;
+        myAllocList = aBlock;
       }
 
       // initialize header of the new block by its size
@@ -364,16 +389,16 @@ Standard_Address Standard_MMgrOpt::Allocate(const Standard_Size aSize)
       if ( myReentrant ) myMutex.Unlock();
 
       // we use operator ?: instead of if() since it is faster
-      Standard_Size *aBlock = (Standard_Size*) (myClear ? calloc( RoundSizeN+1,   sizeof(Standard_Size)) :
-                                                          malloc((RoundSizeN+1) * sizeof(Standard_Size)) );
+      Standard_Size *aBlock = (Standard_Size*) (myClear ? calloc( RoundSizeN+BLOCK_SHIFT,   sizeof(Standard_Size)) :
+                                                          malloc((RoundSizeN+BLOCK_SHIFT) * sizeof(Standard_Size)) );
 
       // if allocation failed, try to free some memory by purging free lists, and retry
       if ( ! aBlock ) {
         if ( Purge (Standard_False) )
-          aBlock = (Standard_Size*)calloc(RoundSizeN+1, sizeof(Standard_Size));
+          aBlock = (Standard_Size*)calloc(RoundSizeN+BLOCK_SHIFT, sizeof(Standard_Size));
         // if still not succeeded, raise exception
         if ( ! aBlock )
-          Standard_OutOfMemory::Raise("Standard_MMgrOpt::Allocate(): malloc failed");
+          anOutOfMemError->Reraise ("Standard_MMgrOpt::Allocate(): malloc failed");
       }
 
       // initialize new block header by its size
@@ -449,7 +474,7 @@ void Standard_MMgrOpt::Free(Standard_Address& theStorage)
 //purpose  : Frees all free lists except small blocks (less than CellSize)
 //=======================================================================
 
-Standard_Integer Standard_MMgrOpt::Purge(Standard_Boolean isDeleted)
+Standard_Integer Standard_MMgrOpt::Purge(Standard_Boolean )//isDeleted)
 {
   // Lock access to critical data by mutex
   Standard_Mutex::SentryNested aSentry (myMutex, myReentrant);
@@ -459,7 +484,7 @@ Standard_Integer Standard_MMgrOpt::Purge(Standard_Boolean isDeleted)
   // free memory blocks contained in free lists
   // whose sizes are greater than cellsize
   Standard_Integer nbFreed = 0;
-  Standard_Size i = INDEX_CELL(ROUNDUP_CELL(myCellSize+1));
+  Standard_Size i = INDEX_CELL(ROUNDUP_CELL(myCellSize+BLOCK_SHIFT));
   for (; i <= myFreeListMax; i++ ) {
     Standard_Size * aFree = myFreeList[i];      
     while(aFree) {
@@ -557,7 +582,7 @@ retry:
       if ( Purge(Standard_False) )
         goto retry;
       // if nothing helps, raise exception
-      Standard_OutOfMemory::Raise(strerror(errcode));
+      anOutOfMemError->Reraise (strerror(errcode));
     }
 
     // save actually allocated size into argument
@@ -591,7 +616,7 @@ retry:
       char message[BUFSIZE];
       if ( FormatMessage (FORMAT_MESSAGE_FROM_SYSTEM, 0, GetLastError(), 0, message, BUFSIZE-1, 0) <=0 )
         strcpy (message, "Standard_MMgrOpt::AllocMemory() failed to mmap");
-      Standard_OutOfMemory::Raise(message);
+      anOutOfMemError->Reraise (message);
     }
 
     // record map handle in the beginning
@@ -614,7 +639,7 @@ retry:
       if ( Purge(Standard_False) )
         goto retry;
       // if nothing helps, raise exception
-      Standard_OutOfMemory::Raise("Standard_MMgrOpt::AllocMemory(): malloc failed");
+      anOutOfMemError->Reraise ("Standard_MMgrOpt::Allocate(): malloc failed");
     }
   }
   // clear whole block if clearing option is set
@@ -645,10 +670,20 @@ void Standard_MMgrOpt::FreeMemory (Standard_Address aBlock,
     // recover handle to the memory mapping stored just before the block
     const HANDLE * aMBlock = (const HANDLE *)aBlock;
     HANDLE hMap = *(--aMBlock);
-    UnmapViewOfFile(aMBlock);
+    UnmapViewOfFile((LPCVOID)aMBlock);
     CloseHandle (hMap);
 #endif
   }
   else
     free(aBlock);
 }
+
+//=======================================================================
+//function : SetReentrant
+//purpose  : 
+//=======================================================================
+
+void Standard_MMgrOpt::SetReentrant(Standard_Boolean isReentrant)
+{
+  myReentrant = isReentrant;
+}
