@@ -25,7 +25,7 @@ Standard_SStream::Standard_SStream()
 
 ostream& operator<< (ostream& anOstream, Standard_SStream& aSStream)
 {
-  aSStream << "\0";
-  anOstream << aSStream.rdbuf()->str();
+  aSStream << ends;
+  anOstream << GetSString (aSStream);
   return anOstream;
 }
