@@ -9,15 +9,8 @@
 class Handle(Standard_Persistent);
 Handle_Standard_Type &Standard_Persistent_Type_();
 
-//
-//
-Standard_EXPORT void ShallowDump(const Standard_Address,const Handle(Standard_Type)&,Standard_OStream &)
-{
-
-}
-
 //============================================================================
-Standard_EXPORT void ShallowDump(const Handle(Standard_Persistent)& me, Standard_OStream &aOut)
+void ShallowDump(const Handle(Standard_Persistent)& me, Standard_OStream &aOut)
 {
   Handle(Standard_Type) aType = me->DynamicType();
 
