@@ -83,6 +83,7 @@ mypixtol(2),
 myupdatetol(Standard_True)
 {
   for (Standard_Integer i=0;i<=13;i++) {mycoeff [i] = 0.;myprevcoeff[i]=0.0;} 
+  for (Standard_Integer j=0;j<2;j++) {mycenter [j] = 0.;myprevcenter[j]=0.0;} 
 }
 
 
@@ -98,6 +99,7 @@ mypixtol(2),
 myupdatetol(Standard_True)
 {  
   for (Standard_Integer i=0;i<=13;i++) {mycoeff [i] = 0.;myprevcoeff[i]=0.0;} 
+  for (Standard_Integer j=0;j<2;j++) {mycenter [j] = 0.;myprevcenter[j]=0.0;} 
 }
 
 
@@ -109,6 +111,7 @@ void StdSelect_ViewerSelector3d::
 InitProj(const Handle(V3d_View)& aView)
 {
   for (Standard_Integer i=0;i<=10;i++) mycoeff [i] = 0.; 
+  for (Standard_Integer j=0;j<2;j++) mycenter [j] = 0.; 
   UpdateProj(aView);
 }
 
@@ -366,18 +369,20 @@ UpdateProj(const Handle(V3d_View)& aView)
     myprevcoeff[ 9]=0.;
     myprevcoeff[10]=0.;
     Standard_Boolean Pers = Standard_False;
-    if(aView->DynamicType()==STANDARD_TYPE(V3d_PerspectiveView)) {
+    if ( aView->Type() == V3d_PERSPECTIVE ) {
       Pers = Standard_True;
       myprevcoeff[10]=1.;
-      myprevcoeff[ 9]=aView->Focale();}
+      myprevcoeff[ 9]=aView->Focale();
+    }
     aView->At(myprevcoeff[0],myprevcoeff[1],myprevcoeff[2]);
     aView->Up(myprevcoeff[3],myprevcoeff[4],myprevcoeff[5]);
     aView->Proj(myprevcoeff[6],myprevcoeff[7],myprevcoeff[8]);
     aView->AxialScale(myprevcoeff[11],myprevcoeff[12],myprevcoeff[13]);
+    aView->Center(myprevcenter[0],myprevcenter[1]);
     Standard_Integer ii;  
     
     for(ii=0;ii<= 13 && (myprevcoeff[ii]==mycoeff[ii]);ii++){}
-    if(ii<=13){
+    if(ii<=13 || (myprevcenter[0]!=mycenter[0]) || (myprevcenter[1]!=mycenter[1])){
       if(SELDebugModeOn()){
 	cout<<"\t\t\t\t\t VS3d::UpdateProj====> coefficients changes on reprojette"<<endl;
 	cout<<"\t\t\t\t\t";
@@ -387,11 +392,14 @@ UpdateProj(const Handle(V3d_View)& aView)
 	    cout<<"\n\t\t\t\t\t";
 	}
 	cout<<"focale :"<<mycoeff[9]<<" persp :"<<mycoeff[10]<<endl;
+	cout<<"center :"<<mycenter[0]<<"  "<<mycenter[1]<<endl;
       }
       toupdate     = Standard_True;
       myupdatetol=Standard_True;
       for(Standard_Integer imod=ii;imod<=13;imod++)
-	{mycoeff[imod] = myprevcoeff[imod];}
+      	{mycoeff[imod] = myprevcoeff[imod];}
+      for(Standard_Integer jmod=0;jmod<2;jmod++)
+      	{mycenter[jmod] = myprevcenter[jmod];}
       
       gp_Dir Zpers (mycoeff[6],mycoeff[7],mycoeff[8]); //DX,DY,DZ);
       gp_Dir Ypers (mycoeff[3],mycoeff[4],mycoeff[5]); // XUp,YUp,ZUp);
@@ -412,6 +420,9 @@ UpdateProj(const Handle(V3d_View)& aView)
       // SAV 08/05/02 : fix for detection problem in a perspective view
       if ( aView->Type() == V3d_PERSPECTIVE )
         myprj.SetView( aView );
+      // NKV 31/07/07 : fix for detection problem in case of custom matrix
+      else if ( aView->ViewOrientation().IsCustomMatrix() )
+        myprj.SetView( aView );
     }
     
     if(Abs(aView->Scale()-TheZoom)>1.e-3) {
