@@ -12,7 +12,6 @@
 #include <StepToTopoDS_Builder.ixx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
-#include <Interface_TraceFile.hxx>
 #include <Interface_Static.hxx>
 #include <TransferBRep.hxx>
 
@@ -66,6 +65,7 @@
 #include <StepShape_HArray1OfFace.hxx>
 
 #include <Message_ProgressSentry.hxx>
+#include <Message_Messenger.hxx>
 
 static void ResetPreci (const TopoDS_Shape& S, Standard_Real maxtol)
 {
@@ -162,8 +162,7 @@ void StepToTopoDS_Builder::Init
 (const Handle(StepShape_ManifoldSolidBrep)& aManifoldSolid,
  const Handle(Transfer_TransientProcess)& TP)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
+  Handle(Message_Messenger) sout = TP->Messenger();
   // Initialisation of the Tool
 
   StepToTopoDS_Tool         myTool;
@@ -195,16 +194,19 @@ void StepToTopoDS_Builder::Init
 
     // Get Statistics :
 
-    if (trlev > 2) sout << "Geometric Statitics : " << endl;
-    if (trlev > 2) sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
-    if (trlev > 2) sout << "                        - C1 : " << myTool.C1Surf() << endl;
-    if (trlev > 2) sout << "                        - C2 : " << myTool.C2Surf() << endl;
-    if (trlev > 2) sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
-    if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur3() << endl;
-    if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur3() << endl;
-    if (trlev > 2) sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
-    if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur2() << endl;
-    if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+    if ( TP->TraceLevel() > 2 )
+    {
+      sout << "Geometric Statitics : " << endl;
+      sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
+      sout << "                        - C1 : " << myTool.C1Surf() << endl;
+      sout << "                        - C2 : " << myTool.C2Surf() << endl;
+      sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
+      sout << "                        - C1 : " << myTool.C1Cur3() << endl;
+      sout << "                        - C2 : " << myTool.C2Cur3() << endl;
+      sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
+      sout << "                        - C1 : " << myTool.C1Cur2() << endl;
+      sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+    }
 
 //:S4136    ShapeFix::SameParameter (S,Standard_False);
     ResetPreci (S, MaxTol());
@@ -225,8 +227,7 @@ void StepToTopoDS_Builder::Init
 (const Handle(StepShape_BrepWithVoids)& aBRepWithVoids,
  const Handle(Transfer_TransientProcess)& TP)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
+  Handle(Message_Messenger) sout = TP->Messenger();
  // Initialisation of the Tool
   StepToTopoDS_Tool         myTool;
   StepToTopoDS_DataMapOfTRI aMap;
@@ -299,16 +300,19 @@ void StepToTopoDS_Builder::Init
 
   // Get Statistics :
   
-  if (trlev > 2) sout << "Geometric Statitics : " << endl;
-  if (trlev > 2) sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Surf() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Surf() << endl;
-  if (trlev > 2) sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur3() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur3() << endl;
-  if (trlev > 2) sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur2() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+  if ( TP->TraceLevel() > 2 )
+  {
+    sout << "Geometric Statitics : " << endl;
+    sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
+    sout << "                        - C1 : " << myTool.C1Surf() << endl;
+    sout << "                        - C2 : " << myTool.C2Surf() << endl;
+    sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
+    sout << "                        - C1 : " << myTool.C1Cur3() << endl;
+    sout << "                        - C2 : " << myTool.C2Cur3() << endl;
+    sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
+    sout << "                        - C1 : " << myTool.C1Cur2() << endl;
+    sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+  }
 
 //:S4136  ShapeFix::SameParameter (S,Standard_False);
   ResetPreci (S, MaxTol());
@@ -434,8 +438,7 @@ void StepToTopoDS_Builder::Init
 (const Handle(StepShape_ShellBasedSurfaceModel)& aSBSM,
  const Handle(Transfer_TransientProcess)& TP)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer  trlev = Interface_TraceFile::DefLevel();
+  Handle(Message_Messenger) sout = TP->Messenger();
   // Initialisation of the Tool
 
   StepToTopoDS_Tool         myTool;
@@ -515,16 +518,19 @@ void StepToTopoDS_Builder::Init
 
   // Get Statistics :
   
-  if (trlev > 2) sout << "Geometric Statitics : " << endl;
-  if (trlev > 2) sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Surf() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Surf() << endl;
-  if (trlev > 2) sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur3() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur3() << endl;
-  if (trlev > 2) sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
-  if (trlev > 2) sout << "                        - C1 : " << myTool.C1Cur2() << endl;
-  if (trlev > 2) sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+  if ( TP->TraceLevel() > 2 )
+  {
+    sout << "Geometric Statitics : " << endl;
+    sout << "   Surface Continuity : - C0 : " << myTool.C0Surf() << endl;
+    sout << "                        - C1 : " << myTool.C1Surf() << endl;
+    sout << "                        - C2 : " << myTool.C2Surf() << endl;
+    sout << "   Curve Continuity :   - C0 : " << myTool.C0Cur3() << endl;
+    sout << "                        - C1 : " << myTool.C1Cur3() << endl;
+    sout << "                        - C2 : " << myTool.C2Cur3() << endl;
+    sout << "   PCurve Continuity :  - C0 : " << myTool.C0Cur2() << endl;
+    sout << "                        - C1 : " << myTool.C1Cur2() << endl;
+    sout << "                        - C2 : " << myTool.C2Cur2() << endl;
+  }
 
 //:S4136  ShapeFix::SameParameter (S,Standard_False);
   ResetPreci (S, MaxTol());
@@ -726,14 +732,9 @@ void StepToTopoDS_Builder::Init
 	  aGeomCrv = ptgC.Value();
 	}
 	catch(Standard_Failure) {
-//	  Standard_OStream& sout = Interface_TraceFile::Def();
-//	  sout<<"StepToTopoDS, GeometricSet, elem "<<i<<" of "<<nbElem<<": excp.";
-//	  Standard_Failure::Caught()->Print(sout);
-//	  aGeomCrv.Nullify();
-#ifdef DEB
-	  cout<<"StepToTopoDS, GeometricSet, elem "<<i<<" of "<<nbElem<<": Exception";
-	  Standard_Failure::Caught()->Print(cout); cout << endl;
-#endif
+	  Handle(Message_Messenger) sout = TP->Messenger();
+	  sout<<"StepToTopoDS, GeometricSet, elem "<<i<<" of "<<nbElem<<": exception ";
+	  sout<<Standard_Failure::Caught()->GetMessageString() << endl;
 	}
 	if ( ! aGeomCrv.IsNull() ) {
 	  BRepBuilderAPI_MakeEdge anEdge(aGeomCrv, aGeomCrv->FirstParameter(), aGeomCrv->LastParameter());
