@@ -297,14 +297,13 @@ TColStd_PackedMapOfInteger& TColStd_PackedMapOfInteger::Assign
 
 void TColStd_PackedMapOfInteger::ReSize (const Standard_Integer nbBuckets)
 {
-  TColStd_intMapNode** newdata = 0L;
-  TColStd_intMapNode** dummy = 0L;
   Standard_Integer newBuck;
-  if (BeginResize (nbBuckets, newBuck,
-                   (TCollection_MapNode*&)newdata,
-                   (TCollection_MapNode*&)dummy))
+  Standard_Address newData1=NULL, dummy=NULL;
+  if (BeginResize (nbBuckets, newBuck, newData1, dummy))
   {
     if (myData1) {
+      TColStd_intMapNode** newdata = 
+        reinterpret_cast <TColStd_intMapNode**> (newData1);
       TColStd_intMapNode** olddata =
         reinterpret_cast <TColStd_intMapNode**> (myData1);
       TColStd_intMapNode * p;
@@ -322,9 +321,7 @@ void TColStd_PackedMapOfInteger::ReSize (const Standard_Integer nbBuckets)
 	}
       }
     }
-    EndResize (nbBuckets, newBuck,
-               (TCollection_MapNode*)newdata,
-               (TCollection_MapNode*)dummy);
+    EndResize (nbBuckets, newBuck, newData1, dummy);
   }
 }
 
@@ -921,6 +918,10 @@ Standard_Boolean TColStd_PackedMapOfInteger::Subtract
               aNewExtent += TColStd_Population (p1->ChangeMask(), aNewData);
               q = p1;
             }
+            else {
+              aNewExtent += p1->NbValues();
+              q = p1;
+            }
             break;
           }
           p2 = reinterpret_cast <const TColStd_intMapNode*> (p2->Next());
