@@ -27,9 +27,95 @@
 #include <Standard_String.hxx>
 #include <TCollection_AsciiString.hxx>
 
+static
+  Standard_PExtCharacter Allocate(const Standard_Size aLength);
+
+static
+  Standard_PExtCharacter Reallocate(Standard_Address aAddr,
+				    const Standard_Size aLength);
 
 Standard_EXPORT short NULL_EXTSTRING[1] = {0};
 
+//============================== input value have len = 2 bytes ====
+inline Standard_ExtCharacter ConvertToUnicode2B (unsigned char *p)
+{
+  // *p, *(p+1)
+  union {
+    struct {
+      unsigned char  h;
+      unsigned char  l;
+    } hl;
+    Standard_ExtCharacter chr;
+  } EL;
+
+  unsigned char l = *(p+1);
+  l |= 0xC0;
+  unsigned char h = *p;
+  h <<= 6;
+  h |= 0x3F;
+  l &= h;// l is defined
+  h = *p;
+  h >>= 2;
+  h &= 0x07;
+  EL.hl.l = l;
+  EL.hl.h = h;
+  return EL.chr;
+}
+
+//============================== input value have len = 3 bytes ====
+inline Standard_ExtCharacter ConvertToUnicode3B (unsigned char *p)
+{
+  // *p, *(p+1), *(p+2) =>0 , 1, 2
+  union {
+    struct {
+      unsigned char  h;
+      unsigned char  l;
+    } hl;
+    Standard_ExtCharacter chr;
+  } EL;
+
+
+  unsigned char h = *(p+1);//h = 10yyyyyy
+  unsigned char l = *(p+2);//h = 10zzzzzz
+
+  l |= 0xC0;
+  h <<= 6;   //yy------
+  h |= 0x3F; //yy111111
+  l &= h;   //  yyzzzzzz - l is defined 
+  EL.hl.l = l; 
+ 
+  unsigned char a = *p;// a = 1110xxxx
+  a <<= 4;//xxxx----
+  a |= 0x0F;//a = xxxx1111
+  h = *(p+1);
+  h >>= 2;//----yyyy
+  h |= 0xF0; //1111yyyy
+  a &= h; // a = xxxxyyyy
+  EL.hl.h = a; //h is defined
+  return EL.chr;
+}
+//============================== returns number of symbols in UTF8 string ====
+inline Standard_Integer  nbSymbols(const Standard_CString aStr) {
+  Standard_Integer aLen = 0;// length in symbols
+  int i = 0;
+  while (aStr[i] != '\0') {  
+    if((aStr[i] & 0x80) == 0x00) //1byte => 1 symb - Lat1
+      {aLen++; i++;}
+    else if((aStr[i] & 0xE0) == 0xC0 && 
+	    (aStr[i+1] && 
+	     (aStr[i+1] & 0xC0) == 0x80)) {//2 bytes => 1 symb
+      aLen++;
+      i += 2;
+    } else if((aStr[i] & 0xF0) == 0xE0 && 
+	      ((aStr[i+1] && (aStr[i+1] & 0xC0) == 0x80)) &&
+	      (aStr[i+2] && (aStr[i+2] & 0xC0) == 0x80)) {
+      aLen++;
+      i += 3;
+    } else 
+      i++; 
+  }
+  return aLen;
+}
 
 //-----------------------------------------------------------------------------
 // Create an empty ExtendedString
@@ -38,7 +124,7 @@ TCollection_ExtendedString::TCollection_ExtendedString()
 {
 //  mystring = 0L;
   mylength = 0;
-  mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+  mystring = Allocate((mylength+1)*2);
   mystring[mylength] = '\0';
 }
 
@@ -46,18 +132,30 @@ TCollection_ExtendedString::TCollection_ExtendedString()
 // Create an ExtendedString from a Standard_CString
 //----------------------------------------------------------------------------
 TCollection_ExtendedString::TCollection_ExtendedString
-                                        (const Standard_CString astring) 
+                                          (const Standard_CString astring, 
+					   const Standard_Boolean isMultiByte) 
 {
   if (astring) {
+    if(!isMultiByte) {
 #if OptJr
-    STRINGLEN( astring , mylength ) ;
+      STRINGLEN( astring , mylength ) ;
 #else
-    STRLEN(astring,mylength);
+      STRLEN(astring,mylength);
 #endif
-    mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
-    for (int i = 0 ; i < mylength ; i++)
-      mystring[i] = ToExtCharacter(astring[i]); 
-    mystring[mylength] =  '\0';
+      mystring = Allocate((mylength+1)*2);
+      for (int i = 0 ; i < mylength ; i++)
+	mystring[i] = ToExtCharacter(astring[i]); 
+      mystring[mylength] =  '\0';
+    }
+    else {
+      mylength = nbSymbols(astring);
+      mystring = Allocate(ROUNDMEM((mylength+1)*2));
+      if(!ConvertToUnicode (astring))
+#ifdef DEB
+	cout <<"UTF8 decoding failure..." <<endl;
+#endif
+      ;
+    }
   }
   else {
     Standard_NullObject::Raise("TCollection_ExtendedString : "
@@ -78,7 +176,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
 #else
     EXTSTRLEN(astring,mylength);
 #endif
-    mystring = (Standard_ExtString)Standard::Allocate(ROUNDMEM((mylength+1)*2));
+    mystring = Allocate(ROUNDMEM((mylength+1)*2));
 #if OptJr
     EXTSTRINGCOPY( mystring , astring , mylength );
 #else
@@ -99,14 +197,14 @@ TCollection_ExtendedString::TCollection_ExtendedString
 {
   if ( aChar != '\0' ) {
     mylength    = 1;
-    mystring    = (Standard_ExtString)Standard::Allocate(2*2);
+    mystring    = Allocate(2*2);
     mystring[0] = ToExtCharacter(aChar);
     mystring[1] =  '\0';
   }
   else {
     //    mystring = 0L;
     mylength = 0;
-    mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+    mystring = Allocate((mylength+1)*2);
     mystring[mylength] = '\0';
   }
 }
@@ -118,7 +216,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
                                         (const Standard_ExtCharacter aChar)
 {
   mylength    = 1;
-  mystring    = (Standard_ExtString)Standard::Allocate(2*2);
+  mystring    = Allocate(2*2);
   mystring[0] = aChar;
   mystring[1] =  '\0';
 }
@@ -130,7 +228,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
                                         (const Standard_Integer      length,
                                          const Standard_ExtCharacter filler )
 {
-  mystring = (Standard_ExtString)Standard::Allocate((length+1)*2);
+  mystring = Allocate((length+1)*2);
   mylength = length;
   for (int i = 0 ; i < length ; i++) mystring[i] = filler;
   mystring[length] =  '\0';
@@ -150,7 +248,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
 #else
   STRLEN(CHN.t,mylength);
 #endif
-  mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+  mystring = Allocate((mylength+1)*2);
   for (int i = 0 ; i < mylength ; i++) mystring[i] = ToExtCharacter(CHN.t[i]);
   mystring[mylength] =  '\0';
 }
@@ -169,7 +267,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
 #else
   STRLEN(CHN.t,mylength);
 #endif
-  mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+  mystring = Allocate((mylength+1)*2);
   for (int i = 0 ; i < mylength ; i++) mystring[i] = ToExtCharacter(CHN.t[i]);
   mystring[mylength] =  '\0';
 }
@@ -182,7 +280,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
 {
 
   mylength = astring.mylength;
-  mystring = (Standard_ExtString)Standard::Allocate(ROUNDMEM((mylength+1)*2));
+  mystring = Allocate(ROUNDMEM((mylength+1)*2));
   if (astring.mystring)
 #if OptJr
     EXTENDEDSTRINGCOPY( mystring , astring.mystring , mylength );
@@ -199,7 +297,7 @@ TCollection_ExtendedString::TCollection_ExtendedString
                                 (const TCollection_AsciiString& astring) 
 {
   mylength = astring.Length();
-  mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+  mystring = Allocate((mylength+1)*2);
 #if OptJr
   Standard_CString aCString = astring.ToCString() ;
   for (Standard_Integer i = 0; i <= mylength ; i++)
@@ -222,7 +320,7 @@ void TCollection_ExtendedString::AssignCat
     Standard_ExtString sother = other.mystring;
     Standard_Integer newlength = mylength +otherlength; 
     if (mystring) {
-        mystring = (Standard_ExtString)Standard::Reallocate((void*&)mystring,
+        mystring = Reallocate((void*&)mystring,
                                                              ROUNDMEM((newlength+1)*2));
 #if OptJr
 //      if ( ((long ) ( &mystring[ mylength ] ) & 3) == 0 ) {
@@ -235,7 +333,7 @@ void TCollection_ExtendedString::AssignCat
 #endif
     }
     else {
-      mystring = (Standard_ExtString)Standard::Allocate(ROUNDMEM((newlength+1)*2));
+      mystring = Allocate(ROUNDMEM((newlength+1)*2));
 #if OptJr
       EXTENDEDSTRINGCOPY( mystring , sother , newlength );
 #else
@@ -311,7 +409,7 @@ void TCollection_ExtendedString::Clear()
   if (mystring) Standard::Free((void*&)mystring);
 //  mystring = 0L;
   mylength = 0;
-  mystring = (Standard_ExtString)Standard::Allocate((mylength+1)*2);
+  mystring = Allocate((mylength+1)*2);
   mystring[mylength] = '\0';
 }
 
@@ -324,17 +422,10 @@ void TCollection_ExtendedString::Copy (const TCollection_ExtendedString& fromwhe
   if (fromwhere.mystring) {
     Standard_Integer newlength = fromwhere.mylength;
     if (mystring) {
-      //modified by NIZNHY-PKV Wed Mar 16 10:38:47 2005f
-      //if ( !Standard::ReAllocatedLength( mystring , ROUNDMEM(( newlength + 1)*2)) ) {
-      //  Standard::Free((void*&) mystring ) ;
-      //  mystring = (Standard_ExtString)Standard::Allocate(ROUNDMEM(( newlength + 1)*2 ));
-      //}
-      mystring = (Standard_ExtString)Standard::Reallocate((void*&)mystring,
-							  ROUNDMEM(( newlength + 1)*2 ));
-      //modified by NIZNHY-PKV Wed Mar 16 10:40:12 2005t
+      mystring = Reallocate((void*&)mystring, ROUNDMEM(( newlength + 1)*2 ));
     }
     else {
-      mystring = (Standard_ExtString)Standard::Allocate(ROUNDMEM((newlength+1)*2));
+      mystring = Allocate(ROUNDMEM((newlength+1)*2));
     }
     mylength = newlength;
 #if OptJr
@@ -375,11 +466,11 @@ void TCollection_ExtendedString::Insert(const Standard_Integer where,
                                "Parameter where is negative");
 
   if (mystring) {
-      mystring = (Standard_ExtString)Standard::Reallocate((void*&)mystring,
+      mystring = Reallocate((void*&)mystring,
                                                            (mylength+2)*2);
   }
   else {
-    mystring = (Standard_ExtString)Standard::Allocate((mylength+2)*2);
+    mystring = Allocate((mylength+2)*2);
   }
   if (where != mylength +1) {
     for (int i=mylength-1; i >= where-1; i--)
@@ -403,11 +494,11 @@ void TCollection_ExtendedString::Insert(const Standard_Integer            where,
       Standard_Integer newlength = mylength + whatlength;
       
       if (mystring) {
-          mystring = (Standard_ExtString)Standard::Reallocate(
+          mystring = Reallocate(
                                          (void*&)mystring,(newlength+1)*2);
       }
       else {
-        mystring = (Standard_ExtString)Standard::Allocate((newlength+1)*2);
+        mystring = Allocate((newlength+1)*2);
       }
       if (where != mylength +1) {
         for (int i=mylength-1; i >= where-1; i--)
@@ -752,11 +843,10 @@ void TCollection_ExtendedString::SetValue
     size += (where - 1);  
     if (size >= mylength){
       if (mystring) {
-        mystring = (Standard_ExtString)Standard::Reallocate
-                                                ((void*&)mystring,(size+1)*2);
+        mystring = Reallocate ((void*&)mystring,(size+1)*2);
       }
       else {
-        mystring = (Standard_ExtString)Standard::Allocate((size+1)*2);
+        mystring = Allocate((size+1)*2);
       }
       mylength = size;
     } 
@@ -798,8 +888,7 @@ TCollection_ExtendedString TCollection_ExtendedString::Token
                                "parameter 'separators'");
   
   int                   i,j,k,l;
-  Standard_ExtString    buftmp =
-    (Standard_ExtString)Standard::Allocate((mylength+1)*2); 
+  Standard_PExtCharacter  buftmp = Allocate((mylength+1)*2); 
   Standard_ExtCharacter aSep;
   
   Standard_Boolean isSepFound   = Standard_False, otherSepFound;
@@ -921,3 +1010,123 @@ Standard_Boolean TCollection_ExtendedString::IsEqual
 {
   return string1.IsEqual(string2);
 }
+
+//----------------------------------------------------------------------------
+// Convert CString (including multibyte case) to UniCode representation
+//----------------------------------------------------------------------------
+Standard_Boolean TCollection_ExtendedString::ConvertToUnicode 
+                                                (const Standard_CString aStr)
+{
+  Standard_Boolean aRes = Standard_True;
+  short * p = mystring;
+  int i = 0;
+  while (aStr[i] != '\0') { 
+    if((aStr[i] & 0x80) == 0x00) //1byte => 1 symb - Lat1
+      {*p++ = ToExtCharacter(aStr[i]); i++;}
+    else if((aStr[i] & 0xE0) == 0xC0 && 
+	    (aStr[i+1] && 
+	     (aStr[i+1] & 0xC0) == 0x80)) {//2 bytes => 1 symb
+      *p++ = ConvertToUnicode2B((unsigned char*)&aStr[i]);
+      i += 2;
+    } else if((aStr[i] & 0xF0) == 0xE0 && 
+	      ((aStr[i+1] && (aStr[i+1] & 0xC0) == 0x80)) &&
+	      (aStr[i+2] && (aStr[i+2] & 0xC0) == 0x80)) {      
+      *p++ = ConvertToUnicode3B((unsigned char*)&aStr[i]);
+      i += 3;
+    } else { //unsupported case ==> not UTF8
+      aRes = Standard_False;
+      break;
+    }
+  }
+  *p = 0x0000;
+  return aRes;
+}
+//----------------------------------------------------------------------------
+// Returns expected CString length in UTF8 coding.
+//----------------------------------------------------------------------------
+Standard_Integer TCollection_ExtendedString::LengthOfCString() const
+{
+  Standard_Integer i=0, aLen=0;
+  while(mystring[i]) {
+    if((mystring[i] & 0xFF80) == 0) 
+      aLen++;
+    else if((mystring[i] & 0xF800) == 0) 
+      aLen +=2;
+    else  
+      aLen += 3;
+    i++;
+  }
+ return aLen;
+}
+
+//----------------------------------------------------------------------------
+// Converts the internal <mystring> to UTF8 coding and returns length of the 
+// out CString.
+//----------------------------------------------------------------------------
+Standard_Integer TCollection_ExtendedString::ToUTF8CString(Standard_PCharacter& theCString) const
+{
+  Standard_Integer i=0, j=0;
+  unsigned char a,b,c;
+  while(mystring[i]) {
+    if((mystring[i] & 0xFF80) == 0) {
+      theCString[j++] = (char)mystring[i];
+    } 
+    else if((mystring[i] & 0xF800) == 0) {
+      b = (unsigned char)mystring[i];//yyzzzzzz
+      c = (unsigned char)mystring[i];//yyzzzzzz
+      a = (unsigned char)(mystring[i]>>8);//00000yyy
+      b &= 0x3F;
+      b |= 0x80;
+      a <<=2;
+      a |= 0xC0;//110yyy00;
+      c >>=6;
+      c &= 0x03;
+      a |=c;
+      theCString[j++] = a;
+      theCString[j++] = b;
+    } else {
+      b = (unsigned char)mystring[i];//yyzzzzzz
+      c = (unsigned char)mystring[i];//yyzzzzzz
+      unsigned char d = a = (unsigned char)(mystring[i]>>8);//xxxxyyyy
+      c &= 0x3F;
+      c |= 0x80;//10zzzzzz
+      b >>= 6; //000000yy
+      d <<= 2;//xxyyyy00;
+      b |= d;
+      b = (b & 0x3F) | 0x80;//10yyyyyy
+      a >>= 4; //0000xxxx
+      a |= 0xE0;//1110xxxx
+      theCString[j++] = a;
+      theCString[j++] = b;
+      theCString[j++] = c;
+    }
+    i++;
+  }
+  theCString[j] = 0x00;
+  return j;
+}
+//=======================================================================
+//function : Allocate
+//purpose  : 
+//=======================================================================
+Standard_PExtCharacter Allocate(const Standard_Size aLength)
+{
+  Standard_PExtCharacter pChar;
+  //
+  pChar=(Standard_PExtCharacter)Standard::Allocate(aLength);
+  //
+  return pChar;
+}
+//=======================================================================
+//function : Reallocate
+//purpose  : 
+//=======================================================================
+Standard_PExtCharacter Reallocate(Standard_Address aAddr,
+				  const Standard_Size aLength)
+{
+  Standard_PExtCharacter pChar;
+  //
+  pChar= (Standard_PExtCharacter)Standard::Reallocate(aAddr, aLength);
+  //
+  return pChar;
+}
