@@ -624,6 +624,7 @@ void TDF_Label::ForgetFromNode (const TDF_LabelNodePtr& fromNode,
             anAttribute->BeforeRemoval();
           }
           fromNode->RemoveAttribute(lastAtt,anAttribute);
+	  anAttribute->Forget(fromNode->Data()->Transaction()); // vro
           break;
         }
         lastAtt = itr.Value();
@@ -651,16 +652,14 @@ void TDF_Label::ResumeToNode (const TDF_LabelNodePtr& toNode,
 {
   if (anAttribute.IsNull())
     Standard_NullObject::Raise("The attribute is a null handle.");
-  if (anAttribute->Label().IsNull())
+  if (!anAttribute->Label().IsNull())
     Standard_NullObject::Raise
-      ("Cannot resume an attribute not attached to a label.");
+      ("Cannot resume an attribute already attached to a label.");
   if (!anAttribute->IsForgotten()) 
     Standard_DomainError::Raise
       ("Cannot resume an unforgotten attribute.");
-  if (toNode != anAttribute->Label().myLabelNode)
-    Standard_DomainError::Raise
-      ("Attribute to resume not attached to my label.");
 
+  AddToNode(toNode, anAttribute); // vro
   anAttribute->Resume();
   if (toNode->Data()->NotUndoMode()) anAttribute->AfterResume();
 }
