@@ -86,7 +86,7 @@ const Standard_GUID& TDataStd_TreeNode::ID() const
 //=======================================================================
 
 TDataStd_TreeNode::TDataStd_TreeNode () :
-  myFather(NULL),  myPrevious(NULL), myNext(NULL), myFirst(NULL)
+  myFather(NULL),  myPrevious(NULL), myNext(NULL), myFirst(NULL), myLast(NULL)
 {}  
 
 
@@ -109,15 +109,13 @@ Standard_Boolean TDataStd_TreeNode::Append (const Handle(TDataStd_TreeNode)& TN)
     TN->SetPrevious(bid); // Deconnects from previous.
   }
   else {
-    Handle(TDataStd_TreeNode) Last = First();
-    while (Last->HasNext()) {
-      Last = Last->Next();
-    }
-    Last->SetNext(TN);
-    TN->SetPrevious(Last);
+    Handle(TDataStd_TreeNode) aLast = Last();
+    aLast->SetNext(TN);
+    TN->SetPrevious(aLast);
   }
   // Set Father
   TN->SetFather(this);
+  myLast=TN.operator->();
   return !TN.IsNull();
 }
 
@@ -187,7 +185,7 @@ Standard_Boolean TDataStd_TreeNode::InsertAfter (const Handle(TDataStd_TreeNode)
   TN->SetNext(Next());
   
   if (HasNext()) Next()->SetPrevious(TN);
-  
+
   SetNext(TN);
   return !TN.IsNull();
 }
@@ -224,6 +222,15 @@ Standard_Boolean TDataStd_TreeNode::Remove ()
     }
   }
   
+  if(Father()->HasLast()) {
+    if (Handle(TDataStd_TreeNode)::DownCast(this) == Father()->Last()) {
+      if(HasPrevious()) {
+	Father()->SetLast(Previous());
+      }
+      else Father()->SetLast(bid);
+    }
+  }
+
   SetFather(bid);
   SetNext(bid);
   SetPrevious(bid);
@@ -311,7 +318,7 @@ Standard_Boolean TDataStd_TreeNode::IsFather (const Handle(TDataStd_TreeNode)& o
 
 Standard_Boolean TDataStd_TreeNode::IsChild (const Handle(TDataStd_TreeNode)& ofTN) const
 {
-  return (Father() == ofTN);
+  return (myFather == ofTN.operator->());
 }
 
 
@@ -387,6 +394,27 @@ Handle(TDataStd_TreeNode) TDataStd_TreeNode::First () const
   return O;
 }
 
+//=======================================================================
+//TreeNode : Last 
+//purpose  : Returns last child
+//           Optimize an Append operation if it is called in a circle
+//=======================================================================
+
+Handle(TDataStd_TreeNode) TDataStd_TreeNode::Last ()
+{
+  if(myLast && !myLast->IsChild(this))
+    myLast=NULL;
+
+  if(myLast == NULL) {
+    Handle(TDataStd_TreeNode) Last = First();
+    while (Last->HasNext()) {
+      Last = Last->Next();
+    }
+    return Last.operator->();
+  }
+  return myLast;
+}
+
 //=======================================================================
 //TreeNode : SetFather
 //purpose  : Sets the TreeNode F as Father of me
@@ -397,6 +425,7 @@ void TDataStd_TreeNode::SetFather(const Handle(TDataStd_TreeNode)& F)
   Backup();
   if (F.IsNull()) myFather = NULL;
   else            myFather = F.operator->();
+  myLast=NULL;
 }
 
 //=======================================================================
@@ -409,6 +438,7 @@ void TDataStd_TreeNode::SetNext(const Handle(TDataStd_TreeNode)& F)
   Backup();
   if (F.IsNull()) myNext = NULL;
   else            myNext = F.operator->();
+  myLast=NULL;
 }
 
 
@@ -422,6 +452,7 @@ void TDataStd_TreeNode::SetPrevious(const Handle(TDataStd_TreeNode)& F)
   Backup();
   if (F.IsNull()) myPrevious = NULL;
   else            myPrevious = F.operator->();
+  myLast=NULL;
 }
 
 //=======================================================================
@@ -434,6 +465,19 @@ void TDataStd_TreeNode::SetFirst(const Handle(TDataStd_TreeNode)& F)
   Backup();
   if (F.IsNull()) myFirst = NULL;
   else            myFirst = F.operator->();
+  myLast=NULL;
+}
+
+//=======================================================================
+//TreeNode : SetLast
+//purpose  : Sets the TreeNode F as last in the TreeNode tree
+//=======================================================================
+
+void TDataStd_TreeNode::SetLast(const Handle(TDataStd_TreeNode)& F)
+{
+  Backup();
+  if (F.IsNull()) myLast = NULL;
+  else            myLast = F.operator->();
 }
 
 //=======================================================================
@@ -515,6 +559,7 @@ void TDataStd_TreeNode::Restore(const Handle(TDF_Attribute)& other) {
   myNext       = F->myNext;
   myFirst      = F->myFirst; 
   myTreeID     = F->myTreeID;
+  myLast       = NULL;
 }
 
 //=======================================================================
