@@ -785,6 +785,9 @@ void TPrsStd_AISPresentation::Paste (const Handle(TDF_Attribute)& Into,
     into->hasOwnTransparency = Standard_True;
   }
 
+  if (into->isDisplayed)
+    into->AISErase(Standard_True);
+
   into->isDisplayed = isDisplayed;   
   into->myDriverGUID = myDriverGUID;
 
