@@ -106,7 +106,7 @@ static void FUN_test_draw(TCollection_AsciiString aa,
   Standard_Real f,l; const Handle(Geom2d_Curve)& PC = BRep_Tool::CurveOnSurface(E,F,f,l);  
   if (PC.IsNull()) {di<<"************* no curv on surf\n"; return;}
   TCollection_AsciiString bb(aa); bb += TCollection_AsciiString(ie);  
-  char* aaa = bb.ToCString();
+  char* aaa = (char *)bb.ToCString();
   
   Standard_Boolean coldef = Standard_False;
   TopExp_Explorer ex(F,TopAbs_EDGE);
@@ -127,7 +127,7 @@ static void FUN_test_draw(TCollection_AsciiString aa,
 }
 
 void FUN_draw(const TCollection_AsciiString aa,const TopoDS_Shape& s)
-{char* aaa = aa.ToCString(); DBRep::Set(aaa,s);}
+{char* aaa = (char *)aa.ToCString(); DBRep::Set(aaa,s);}
 
 void FUN_cout(const gp_Pnt2d& p2d, Draw_Interpretor& di)
 {di <<" = ("<<p2d.X()<<" "<<p2d.Y()<<") ";}
@@ -137,7 +137,7 @@ Standard_IMPORT void FUN_tool_coutsta(const Standard_Integer& sta, const Standar
 #endif
 
 
-Standard_Integer regularize(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer regularize(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -169,7 +169,7 @@ Standard_Integer regularize(Draw_Interpretor& di, Standard_Integer n, char** a)
   return 0;
 }
 
-static Standard_Integer splitF(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer splitF(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -195,7 +195,7 @@ static Standard_Integer splitF(Draw_Interpretor& di, Standard_Integer n, char**
 }
 
 
-static Standard_Integer regush(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer regush(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   const TopoDS_Shape& sha = DBRep::Get(a[1]);
@@ -233,7 +233,7 @@ static Standard_Integer regush(Draw_Interpretor& di, Standard_Integer n, char**
   return 0;
 }
 
-Standard_Integer reguso(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer reguso(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   const TopoDS_Shape& sha = DBRep::Get(a[1]);
@@ -286,7 +286,7 @@ Standard_Integer reguso(Draw_Interpretor& di, Standard_Integer n, char** a)
   return 0;
 }
 
-static Standard_Integer purge(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer purge(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {  
 
   if (n < 2) return 1;
@@ -372,7 +372,7 @@ static Standard_Integer purge(Draw_Interpretor& di, Standard_Integer n, char** a
 }
 
 
-Standard_Integer correctONISO(Draw_Interpretor& di, Standard_Integer n, char** a)
+Standard_Integer correctONISO(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -398,7 +398,7 @@ Standard_Integer correctONISO(Draw_Interpretor& di, Standard_Integer n, char** a
 //                useful commands :
 // ======================================================================
 
-static Standard_Integer isclosingE(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer isclosingE(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]) ;
@@ -420,7 +420,7 @@ static Standard_Integer isclosingE(Draw_Interpretor& di, Standard_Integer n, cha
   return 0;
 }
 
-static Standard_Integer compareshsh(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer compareshsh(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape sh1 = DBRep::Get(a[1]);
@@ -431,7 +431,7 @@ static Standard_Integer compareshsh(Draw_Interpretor& di, Standard_Integer n, ch
   Standard_Boolean isequal = sh1.IsEqual(sh2); if (isequal) di<<" equal shapes"<<"\n";
   return 0;
 }
-static Standard_Integer pcurveedgeonface(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer pcurveedgeonface(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape ed = DBRep::Get(a[1]);
@@ -441,7 +441,7 @@ static Standard_Integer pcurveedgeonface(Draw_Interpretor& di, Standard_Integer
   return 0;
 }
 
-static Standard_Integer pcurvesonface(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer pcurvesonface(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape sh = DBRep::Get(a[2]);
@@ -456,7 +456,7 @@ static Standard_Integer pcurvesonface(Draw_Interpretor& di, Standard_Integer n,
   return 0;
 }
 
-static Standard_Integer orivine(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer orivine(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -476,7 +476,7 @@ static Standard_Integer orivine(Draw_Interpretor& di, Standard_Integer n, char**
   return 0;
 }
 
-static Standard_Integer vine(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer vine(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -515,7 +515,7 @@ static Standard_Integer vine(Draw_Interpretor& di, Standard_Integer n, char** a)
   return 0;
 }
 
-static Standard_Integer issubshape(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer issubshape(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {  
   if (n < 3) return 1;
   TopoDS_Shape subshape = DBRep::Get(a[1]);
@@ -561,7 +561,7 @@ void FUN_mkBnd2dBREP(const TopoDS_Shape& W, const TopoDS_Shape& F,Bnd_Box2d& B2d
   } //ex(W,EDGE)
 }
 
-static Standard_Integer drawbnd2d(Draw_Interpretor& , Standard_Integer n, char** a)
+static Standard_Integer drawbnd2d(Draw_Interpretor& , Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
   Standard_Integer i = atoi(a[4]);
@@ -590,14 +590,14 @@ static Standard_Integer drawbnd2d(Draw_Interpretor& , Standard_Integer n, char**
   TCollection_AsciiString aa4 = TCollection_AsciiString(a[1]); aa4 += TCollection_AsciiString(4);
   
   TCollection_AsciiString aa;
-  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(1); char* aaa = aa.ToCString(); DrawTrSurf::Set(aaa,tcx);
-  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(2); aaa=aa.ToCString();         DrawTrSurf::Set(aaa,tcy);
-  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(3); aaa=aa.ToCString();         DrawTrSurf::Set(aaa,tccx);
-  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(4); aaa=aa.ToCString();         DrawTrSurf::Set(aaa,tccy);
+  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(1); char* aaa = (char *)aa.ToCString(); DrawTrSurf::Set(aaa,tcx);
+  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(2); aaa=(char *)aa.ToCString();         DrawTrSurf::Set(aaa,tcy);
+  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(3); aaa=(char *)aa.ToCString();         DrawTrSurf::Set(aaa,tccx);
+  aa=TCollection_AsciiString(a[1]); aa+=TCollection_AsciiString(4); aaa=(char *)aa.ToCString();         DrawTrSurf::Set(aaa,tccy);
   return 0;
 }
 
-static Standard_Integer classifBnd2d(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer classifBnd2d(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
   TopoDS_Shape W1 = DBRep::Get(a[1]);
@@ -632,7 +632,7 @@ static Standard_Integer classifBnd2d(Draw_Interpretor& di, Standard_Integer n, c
   return 0;
 }
 
-static Standard_Integer pntonc(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer pntonc(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   Standard_Real x = atof(a[1]);
@@ -644,7 +644,7 @@ static Standard_Integer pntonc(Draw_Interpretor& di, Standard_Integer n, char**
   return 0;
 }
 
-static Standard_Integer pntonc2d(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer pntonc2d(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   Standard_Real x = atof(a[1]);
@@ -660,7 +660,7 @@ static Standard_Integer pntonc2d(Draw_Interpretor& di, Standard_Integer n, char*
   return 0;						          
 }
 
-static Standard_Integer projponf(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer projponf(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -677,7 +677,7 @@ static Standard_Integer projponf(Draw_Interpretor& di, Standard_Integer n, char*
   return 0;
 }  
 
-static Standard_Integer tolmax(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer tolmax(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 2) return 1;
   TopoDS_Shape s = DBRep::Get(a[1]);
@@ -687,7 +687,7 @@ static Standard_Integer tolmax(Draw_Interpretor& di, Standard_Integer n, char**
   return 0;
 }
 
-static Standard_Integer solidclassifier(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer solidclassifier(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   TopoDS_Shape s = DBRep::Get(a[1]);
@@ -712,7 +712,7 @@ static Standard_Integer solidclassifier(Draw_Interpretor& di, Standard_Integer n
   return 0;
 }
 
-static Standard_Integer class3dclassifier(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer class3dclassifier(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 4) return 1;
   TopoDS_Shape s = DBRep::Get(a[1]);
@@ -734,7 +734,7 @@ static Standard_Integer class3dclassifier(Draw_Interpretor& di, Standard_Integer
   di<<" shape s"<<"\n";
   return 0;
 }
-static Standard_Integer shapeclassifier(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer shapeclassifier(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape sh = DBRep::Get(a[1]);
@@ -769,7 +769,7 @@ static Standard_Integer shapeclassifier(Draw_Interpretor& di, Standard_Integer n
 
 
 // normals ..
-static Standard_Integer normal(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer normal(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 3) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -793,7 +793,7 @@ static Standard_Integer normal(Draw_Interpretor& di, Standard_Integer n, char**
   return 0;
 }  
 
-static Standard_Integer curvature(Draw_Interpretor& di, Standard_Integer n, char** a)
+static Standard_Integer curvature(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
   if (n < 5) return 1;
   TopoDS_Shape aLocalShape = DBRep::Get(a[1]);
@@ -847,7 +847,7 @@ void TestTopOpe::CORCommands(Draw_Interpretor& theCommands)
 {
   static Standard_Boolean done = Standard_False;
   if (done) return; done = Standard_True;
-  char* g = "TestTopOpe CORCommands";
+  const char* g = "TestTopOpe CORCommands";
   // purge, regularization commands :
   theCommands.Add("purge",   "purge f",                  __FILE__, purge, g);
   theCommands.Add("corrISO", "corrISO f Fsp",            __FILE__, correctONISO, g);
