@@ -54,7 +54,7 @@ public:
   void set(const TCollection_AsciiString& s) {
     miskind = misshap = misgeom = missect = misdege = misafev = misedcu = Standard_False; 
     mTK = TopOpeBRepDS_UNKNOWN; mTS = TopAbs_SHAPE;
-    char* sK = s.ToCString();
+    char* sK = (char *)s.ToCString();
     miskind = TestTopOpeDraw_TTOT::StringToKind(s,mTK);
     if ( miskind ) {
       misshap = TopOpeBRepDS::IsTopology(mTK);
@@ -136,7 +136,7 @@ public:
   Standard_Boolean IsP() const { return (myETK == TopOpeBRepDS_POINT); }
   Standard_Boolean IsV() const { return (myETK == TopOpeBRepDS_VERTEX); }
   Standard_Boolean Is0() const { return IsP() || IsV(); }
-  Standard_Integer Set(Standard_Integer na,char** a,Standard_Integer iargK,Standard_Integer iargI);
+  Standard_Integer Set(Standard_Integer na,const char** a,Standard_Integer iargK,Standard_Integer iargI);
   void Delete() ;
   Standard_EXPORT virtual ~tsee_entity() {Delete() ;} ;
   void virtual Dump() const;
@@ -146,7 +146,7 @@ public:
 void tsee_entity::Delete()
 {}
 
-Standard_Integer tsee_entity::Set(Standard_Integer na,char** a,Standard_Integer iargK,Standard_Integer iargI) {
+Standard_Integer tsee_entity::Set(Standard_Integer na,const char** a,Standard_Integer iargK,Standard_Integer iargI) {
   myEOK = Standard_False;
   if (iargK>=na) return 1; if (iargI>=na) return 1;
   TCollection_AsciiString ascK = a[iargK]; myEindex = atoi(a[iargI]);
@@ -213,7 +213,7 @@ static void SetPoint
     D = new TestTopOpeDraw_DrawableP3D(P.Point(),Draw_Square,namecolor,
 					 namedisp.ToCString(),namecolor);
   }
-  char *pname = namedbrep.ToCString();
+  char *pname = (char *)namedbrep.ToCString();
   Draw::Set(pname,Handle(Draw_Marker3D)::DownCast(D));
   
 }
@@ -265,7 +265,7 @@ static void SetCurve
   Handle(Geom_TrimmedCurve) GTC = new Geom_TrimmedCurve(GC,f,l);
   Handle(TestTopOpeDraw_DrawableC3D) D;
   D = new TestTopOpeDraw_DrawableC3D(GTC,namecolor,namedisp.ToCString(),namecolor);
-  char *pname = namedbrep.ToCString();
+  char *pname = (char *)namedbrep.ToCString();
   Draw::Set(pname,Handle(DrawTrSurf_Curve)::DownCast(D));
 }
 
@@ -417,7 +417,7 @@ static Standard_Integer SeeShape(TCollection_AsciiString namedbrep)
 {
   if ( !PHDSD || !POCD ) return 0;
   
-  char* pname = namedbrep.ToCString();
+  const char* pname = (const char *)namedbrep.ToCString();
   TopoDS_Shape S = DBRep::Get(pname);
   if ( S.IsNull() ) return 0;
   TCollection_AsciiString namedisp; 
@@ -571,14 +571,14 @@ Standard_Integer TOPOPE_SeeShape(char* name)
 //-----------------------------------------------------------------------
 // Unused :
 #ifdef DEB
-static void decalargs(Standard_Integer& na,char** a,const Standard_Integer d) 
+static void decalargs(Standard_Integer& na,const char** a,const Standard_Integer d) 
 {for(Standard_Integer i=1;i<na;i++)a[i]=a[i+d];na-=d;}
 #endif
 
 //-----------------------------------------------------------------------
 // suppressarg : suppress a[d],modifie na--
 //-----------------------------------------------------------------------
-Standard_EXPORT void suppressarg(Standard_Integer& na,char** a,const Standard_Integer d) 
+Standard_EXPORT void suppressarg(Standard_Integer& na,const char** a,const Standard_Integer d) 
 {
   for(Standard_Integer i=d;i<na;i++) {
     a[i]=a[i+1];
@@ -590,7 +590,7 @@ Standard_EXPORT void suppressarg(Standard_Integer& na,char** a,const Standard_In
 //-----------------------------------------------------------------------
 // suppressargs : suppress a[*] de <f>  <l>,modifie na = na - (l - f)
 //-----------------------------------------------------------------------
-Standard_EXPORT void suppressargs(Standard_Integer& na,char** a,const Standard_Integer f,const Standard_Integer l) 
+Standard_EXPORT void suppressargs(Standard_Integer& na,const char** a,const Standard_Integer f,const Standard_Integer l) 
 {
   if(l == f) 
     suppressarg(na,a,l);
@@ -607,13 +607,13 @@ Standard_EXPORT void suppressargs(Standard_Integer& na,char** a,const Standard_I
 //-----------------------------------------------------------------------
 // Unused :
 #ifdef DEB
-static Standard_Boolean SetTolFlag(Standard_Integer& na,char** a) { decalargs(na,a,1); return Standard_True; }
+static Standard_Boolean SetTolFlag(Standard_Integer& na,const char** a) { decalargs(na,a,1); return Standard_True; }
 #endif
 
 //-----------------------------------------------------------------------
 // tsee_flags
 //-----------------------------------------------------------------------
-static void tsee_flags(Standard_Integer& na,char** a) {
+static void tsee_flags(Standard_Integer& na,const char** a) {
   GFindKeep = Standard_False;
   PrintDistancePP = Standard_False;
   SelectRankShape = 0;
@@ -729,9 +729,9 @@ static void tds_help(Draw_Interpretor& di)
 }
 
 typedef Standard_Integer (*tf_SeeShape)(const Standard_Integer I,const TopoDS_Shape& S);
-Standard_IMPORT void OthersCommands_flags(Standard_Integer& na,char** a,TestTopOpeDraw_Displayer& TD);
+Standard_IMPORT void OthersCommands_flags(Standard_Integer& na,const char** a,TestTopOpeDraw_Displayer& TD);
 void COUTNOHDS(Draw_Interpretor& di) {di<<"no current HDS"<<"\n";}
-Standard_Integer tsee_SeeShapefunc(Draw_Interpretor& di,Standard_Integer na_in,char** a,tf_SeeShape SeeShapefunc)
+Standard_Integer tsee_SeeShapefunc(Draw_Interpretor& di,Standard_Integer na_in,const char** a,tf_SeeShape SeeShapefunc)
 {
   if (na_in == 1 || (na_in == 2 && !strcasecmp(a[1],"-h"))) {
     tsee_help(a[0], di);
@@ -864,7 +864,7 @@ Standard_Integer tsee_SeeShapefunc(Draw_Interpretor& di,Standard_Integer na_in,c
 //-----------------------------------------------------------------------
 // tsee
 //-----------------------------------------------------------------------
-Standard_Integer tsee(Draw_Interpretor& di,Standard_Integer na_in,char** a)
+Standard_Integer tsee(Draw_Interpretor& di,Standard_Integer na_in,const char** a)
 {
   if (na_in == 1 || (na_in == 2 && !strcasecmp(a[1],"-h"))) {
     tsee_help(a[0],di);
@@ -1075,7 +1075,7 @@ Standard_Integer SeeShapeTKI(const Standard_Integer I,const TopoDS_Shape& S,Draw
 //-----------------------------------------------------------------------
 // tseei
 //-----------------------------------------------------------------------
-Standard_Integer tseei(Draw_Interpretor& di,Standard_Integer na_in,char** a)
+Standard_Integer tseei(Draw_Interpretor& di,Standard_Integer na_in,const char** a)
 {
   if (na_in == 1) { tseei_help(di); return 0; }
   tf_SeeShape ssf = (tf_SeeShape)SeeShapeISI;
@@ -1086,7 +1086,7 @@ Standard_Integer tseei(Draw_Interpretor& di,Standard_Integer na_in,char** a)
 //-----------------------------------------------------------------------
 // tki
 //-----------------------------------------------------------------------
-Standard_Integer tki(Draw_Interpretor& di,Standard_Integer na_in,char** a)
+Standard_Integer tki(Draw_Interpretor& di,Standard_Integer na_in,const char** a)
 {
   if (na_in == 1) { tki_help(di); return 0; }
   
@@ -1105,7 +1105,7 @@ Standard_Integer tki(Draw_Interpretor& di,Standard_Integer na_in,char** a)
 // 1 = kind of DS object to dump = [s] [so sh f w e v] [se] [su c p]
 // 2,3 ... = [i1,i2 ...] = indices of DS object to see
 //-----------------------------------------------------------------------
-Standard_Integer tds(Draw_Interpretor& di,Standard_Integer na,char** a)
+Standard_Integer tds(Draw_Interpretor& di,Standard_Integer na,const char** a)
 {
   Standard_Boolean TDSkeep,TDScompact; TDSkeep = TDScompact = Standard_False;
   TopOpeBRepDS_GLOBALHDSinterfselector = 0;
@@ -1202,7 +1202,7 @@ Standard_Integer tds(Draw_Interpretor& di,Standard_Integer na,char** a)
   return 0;
 }
 
-Standard_Integer TPPE(Draw_Interpretor& di,Standard_Integer na,char** a)
+Standard_Integer TPPE(Draw_Interpretor& di,Standard_Integer na,const char** a)
 {
   if (PHDSD == NULL) return 0;
   const Handle(TopOpeBRepDS_HDataStructure)& HDS = PHDSD->CurrentHDS();
@@ -1269,7 +1269,7 @@ Standard_Integer TPPE(Draw_Interpretor& di,Standard_Integer na,char** a)
   if (ok) {
     TCollection_AsciiString pp("p");
     pp.AssignCat(ip); pp.AssignCat("e"); pp.AssignCat(ie);
-    char* ppp = pp.ToCString(); 
+    char* ppp = (char *)pp.ToCString(); 
     DrawTrSurf::Set(ppp,pproj);
     di<<"dist point "<<ip<<" on edge "<<ie<<" = "<<dmin<<"\n";
   } else di<<"projection failed"<<"\n";
@@ -1308,7 +1308,7 @@ void FUN_ChkVertex(Draw_Interpretor& di) //***Check Vertex SameDomain
 }
 
 //---------------------------------------------------------
-Standard_Integer topochk(Draw_Interpretor& di,Standard_Integer na,char** a)
+Standard_Integer topochk(Draw_Interpretor& di,Standard_Integer na,const char** a)
 {
   if (strcmp(a[0],"topochk")) return 1;
   
@@ -1353,7 +1353,7 @@ static void tcx_help(Draw_Interpretor& di)
 //-----------------------------------------------------------------------
 // tcx
 //-----------------------------------------------------------------------
-Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na_in,char** a)
+Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na_in,const char** a)
 {
   if (na_in == 1) { tcx_help(di); return 0; }
   Standard_Integer r = tsee_SeeShapefunc(di,na_in,a,SeeShapeTCX);
@@ -1362,7 +1362,7 @@ Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na_in,char** a)
 
 #if 0
 //---------------------------------------------------------
-Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na,char** a)
+Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na,const char** a)
 {
   if (PHDSD == NULL) return 0;
   const Handle(TopOpeBRepDS_HDataStructure)& HDS = PHDSD->CurrentHDS();
@@ -1377,7 +1377,7 @@ Standard_Integer tcx(Draw_Interpretor& di,Standard_Integer na,char** a)
 #endif
 
 //-----------------------------------------------------------------------
-Standard_Integer tdsri(Draw_Interpretor& di,Standard_Integer na_in,char** a)
+Standard_Integer tdsri(Draw_Interpretor& di,Standard_Integer na_in,const char** a)
 {
   if (na_in == 1 || (na_in == 2 && !strcasecmp(a[1],"-h"))) {
     tsee_help(a[0],di);
@@ -1428,7 +1428,7 @@ void  TestTopOpe::HDSCommands(Draw_Interpretor& theCommands)
   PHDSD = (TestTopOpe_HDSDisplayer*) new (TestTopOpe_HDSDisplayer);
   POCD = (TestTopOpeDraw_Displayer*) new (TestTopOpeDraw_Displayer);
   
-  char* g = "Topological operation data structure commands";
+  const char* g = "Topological operation data structure commands";
   theCommands.Add("tseei","no args to get help",__FILE__,tseei,g);
   theCommands.Add("tsee","no args to get help ",__FILE__,tsee,g);
   theCommands.Add("tki","no args to get help ",__FILE__,tki,g);
