@@ -24,7 +24,7 @@
 // 0 = testtopopedraw_cdinp
 // 1,2,3,4 = display point p of coords x y z
 //-----------------------------------------------------------------------
-Standard_Integer testtopopedraw_cdinp(Draw_Interpretor&,Standard_Integer na,char** a)
+Standard_Integer testtopopedraw_cdinp(Draw_Interpretor&,Standard_Integer na,const char** a)
 {
   if ( na < 5 ) return 0;
   TestTopOpeDraw_P3DDisplayer PD(a[1],atof(a[2]),atof(a[3]),atof(a[4]));
@@ -34,7 +34,7 @@ Standard_Integer testtopopedraw_cdinp(Draw_Interpretor&,Standard_Integer na,char
 //-----------------------------------------------------------------------
 // DRAWsuppressarg : suppress a[d], modifie na--
 //-----------------------------------------------------------------------
-Standard_EXPORT void DRAWsuppressarg(Standard_Integer& na,char** a,const Standard_Integer d) 
+Standard_EXPORT void DRAWsuppressarg(Standard_Integer& na,const char** a,const Standard_Integer d) 
 {
   for(Standard_Integer i=d;i<na;i++) {
     a[i]=a[i+1];
@@ -46,7 +46,7 @@ Standard_EXPORT void DRAWsuppressarg(Standard_Integer& na,char** a,const Standar
 //-----------------------------------------------------------------------
 // DRAWsuppressargs : suppress a[*] de <f>  <l>, modifie na = na - (l - f)
 //-----------------------------------------------------------------------
-Standard_EXPORT void DRAWsuppressargs(Standard_Integer& na,char** a,const Standard_Integer f,const Standard_Integer l) 
+Standard_EXPORT void DRAWsuppressargs(Standard_Integer& na,const char** a,const Standard_Integer f,const Standard_Integer l) 
 {
   if(l == f) 
     DRAWsuppressarg(na,a,l);
@@ -59,7 +59,7 @@ Standard_EXPORT void DRAWsuppressargs(Standard_Integer& na,char** a,const Standa
 }
 
 //-----------------------------------------------------------------------
-Standard_EXPORT void OthersCommands_flags(Standard_Integer& na,char** a,TestTopOpeDraw_Displayer& TD)
+Standard_EXPORT void OthersCommands_flags(Standard_Integer& na,const char** a,TestTopOpeDraw_Displayer& TD)
 //-----------------------------------------------------------------------
 {
   Standard_Integer i,j,l,dloc = 0,iloc,decal = 0, NbArg = na;
@@ -156,10 +156,10 @@ Standard_EXPORT void OthersCommands_help(const char* CommandName, const char* sy
 // 1,2,3,... = display shapes and visualise their names
 //-----------------------------------------------------------------------
 
-Standard_Integer testtopopedraw_cdins(Draw_Interpretor&,Standard_Integer na,char** a)
+Standard_Integer testtopopedraw_cdins(Draw_Interpretor&,Standard_Integer na,const char** a)
 {
   if (na == 1) {
-    char* syntaxe = " [arg] S : display shape S with its DBRep name";
+    const char* syntaxe = " [arg] S : display shape S with its DBRep name";
     OthersCommands_help(a[0], syntaxe);
     return 0;
   }
@@ -205,13 +205,13 @@ Standard_Integer testtopopedraw_cdins(Draw_Interpretor&,Standard_Integer na,char
   return 0;
 }
 
-static void BoopReadInitFile(Draw_Interpretor& di,char* filename)
+static void BoopReadInitFile(Draw_Interpretor& di, const char* filename)
 {
   if (filename == NULL) return;
   di.EvalFile(filename);
 }
 
-static Standard_Integer ttab(Draw_Interpretor& di, Standard_Integer narg, char** a) {
+static Standard_Integer ttab(Draw_Interpretor& di, Standard_Integer narg, const char** a) {
   char s[2000]; strcpy(s,"");
   sprintf(s,"%s%s",s,"proc addt {at args} {upvar $at x;set L \"\";addl L [join $args];");
   sprintf(s,"%s%s",s,"foreach l $L {set x([array size x]) $l}};");
@@ -538,7 +538,7 @@ Standard_Integer cvx2d::displayedge(const TopoDS_Shape& S) {
 //=======================================================================
 // vx2d
 //=======================================================================
-Standard_Integer vx2d(Draw_Interpretor& di, Standard_Integer na, char** a)
+Standard_Integer vx2d(Draw_Interpretor& di, Standard_Integer na, const char** a)
 {
   static cvx2d *pv2d = NULL;
 #define ISINTEGER(MMstr) ((strspn((MMstr),"0123456789") == strlen((MMstr))))
@@ -598,7 +598,7 @@ Standard_Integer vx2d(Draw_Interpretor& di, Standard_Integer na, char** a)
 
 void TestTopOpeDraw::OtherCommands(Draw_Interpretor& theCommands)
 {
-  char* g = "Topological Operation other commands";
+  const char* g = "Topological Operation other commands";
   theCommands.Add("cdinp","cdinp p x y z",__FILE__,testtopopedraw_cdinp,g);
   theCommands.Add("cdins","cdins s1 ... ",__FILE__,testtopopedraw_cdins,g);
   theCommands.Add("vx2d","vx2d f",__FILE__,vx2d,g);
