@@ -227,7 +227,7 @@ Standard_Integer InitContextTopOpeKernel (TestTopOpeTools_Trace& T)
 }
 
 Standard_EXPORT Standard_Integer TestTopOpeTools_SetFlags
-(TestTopOpeTools_Trace& theFlags, Standard_Integer mute, Standard_Integer n , char** a) 
+(TestTopOpeTools_Trace& theFlags, Standard_Integer mute, Standard_Integer n , const char** a) 
 {
   if (n == 1) { 
     theFlags.Dump();
@@ -236,7 +236,7 @@ Standard_EXPORT Standard_Integer TestTopOpeTools_SetFlags
   if (n < 2) {
     return 1;
   }
-  char* flag = a[1];
+  const char* flag = a[1];
   t_value value; // new value of flag
   if (n == 2) value = Standard_True;
   else value = (atoi(a[2]) ? Standard_True : Standard_False);
@@ -266,7 +266,7 @@ Standard_EXPORT Standard_Integer TestTopOpeTools_SetFlags
 // a1 = flag (for example tbs) <a2> = value, if omitted flag becomes True
 //=========================================================================
 
-Standard_Integer TestTopOpeTools_SetTrace(Draw_Interpretor&, Standard_Integer n , char** a) 
+Standard_Integer TestTopOpeTools_SetTrace(Draw_Interpretor&, Standard_Integer n , const char** a) 
 {
   Standard_Integer ok = Standard_True;
 #ifdef DEB
@@ -281,7 +281,7 @@ Standard_Integer TestTopOpeTools_SetTrace(Draw_Interpretor&, Standard_Integer n
 // a1 = flag (for example tbs) <a2> = value, if omitted flag becomes True
 //=========================================================================
 
-Standard_Integer TestTopOpeTools_SetContext(Draw_Interpretor&, Standard_Integer n , char** a) 
+Standard_Integer TestTopOpeTools_SetContext(Draw_Interpretor&, Standard_Integer n , const char** a) 
 {
   Standard_Integer ok = Standard_True;
 #ifdef DEB
@@ -292,15 +292,15 @@ Standard_Integer TestTopOpeTools_SetContext(Draw_Interpretor&, Standard_Integer
   return ok;
 }
 
-Standard_Integer dstrace(Draw_Interpretor& di, Standard_Integer n , char** a) {
-  char ** pa = NULL; TCollection_AsciiString a1;
+Standard_Integer dstrace(Draw_Interpretor& di, Standard_Integer n , const char** a) {
+  const char ** pa = NULL; TCollection_AsciiString a1;
   if      (!strcasecmp(a[0],"tsx")) a1 = "tspsx";
   else if (!strcasecmp(a[0],"tcx")) a1 = "tcx";
   else return 0;
   TCollection_AsciiString a0("trc");
-  Standard_Integer npa = n+1;pa = (char**) malloc((size_t)((npa)*sizeof(char*)));
-  pa[0] = a0.ToCString();
-  pa[1] = a1.ToCString();
+  Standard_Integer npa = n+1;pa = (const char**) malloc((size_t)((npa)*sizeof(char*)));
+  pa[0] = (char *)a0.ToCString();
+  pa[1] = (char *)a1.ToCString();
   for (Standard_Integer i=1;i<n;i++) pa[i+1] = a[i];
   TestTopOpeTools_SetTrace(di,npa,pa);
   if (pa) delete [] pa;
@@ -318,7 +318,7 @@ void  TestTopOpeTools::TraceCommands(Draw_Interpretor& theCommands)
   if (done) return;
   done = Standard_True;
 
-  char* g = "trace commands";
+  const char* g = "trace commands";
   
   theCommands.Add("tsx","tsx 0|1 [{shape index}]",__FILE__,dstrace,g);
   theCommands.Add("tsxx","tsxx 0|1 is1 is2",__FILE__,dstrace,g);
