@@ -368,7 +368,7 @@ void TopOpeBRepBuild_Builder::GFillSolidSFS(const TopoDS_Shape& SO1,const TopToo
 #ifdef DEB
       if(tSPS){
 	DEBSHASET(ss,"--- GFillSolidSFS ",SFS," AddShape SFS+ shell ");  
-	GdumpSHA(SH,ss.ToCString());
+	GdumpSHA(SH,(Standard_Address)ss.ToCString());
 	cout<<" ";TopAbs::Print(TB1,cout)<<" : 1 shell ";
 	TopAbs::Print(neworiSH,cout); cout<<endl;
       }
@@ -452,7 +452,7 @@ void TopOpeBRepBuild_Builder::GFillSurfaceTopologySFS
 #ifdef DEB
     if (tSPS){
       DEBSHASET(ss,"--- GFillSurfaceTopologySFS ",SFS," AddElement SFS+ face ");  
-      GdumpSHA(F,ss.ToCString());
+      GdumpSHA(F,(Standard_Address)ss.ToCString());
       cout<<" ";TopAbs::Print(TB,cout)<<" : 1 face ";
       TopAbs::Print(ori,cout); cout<<endl;
     }
@@ -757,7 +757,7 @@ void TopOpeBRepBuild_Builder::GSplitFaceSFS
 #ifdef DEB
 	if(tSPS){
 	  DEBSHASET(ss,"--- GSplitFaceSFS ",SFS," AddStartElement SFS+ face ");  
-	  GdumpSHA(newF,ss.ToCString());
+	  GdumpSHA(newF,(Standard_Address)ss.ToCString());
 	  cout<<" ";TopAbs::Print(TB1,cout)<<" : 1 face ";
 	  TopAbs::Print(neworiF,cout); cout<<endl;
 	}
@@ -788,7 +788,7 @@ void TopOpeBRepBuild_Builder::GSplitFaceSFS
 #ifdef DEB
       if(tSPS){
 	DEBSHASET(ss,"--- GSplitFaceSFS ",SFS," AddElement SFS+ face ");  
-	GdumpSHA(F,ss.ToCString());
+	GdumpSHA(F,(Standard_Address)ss.ToCString());
 	cout<<" ";TopAbs::Print(TB1,cout)<<" : 1 face ";
 	TopAbs::Print(neworiF,cout); cout<<endl;
       }
@@ -904,7 +904,7 @@ void TopOpeBRepBuild_Builder::GMergeFaceSFS
 #ifdef DEB
       if(tSPS){
 	DEBSHASET(ss,"--- GMergeFaceSFS ",SFS," AddStartElement SFS+ face ");  
-	GdumpSHA(newF,ss.ToCString());
+	GdumpSHA(newF,(Standard_Address)ss.ToCString());
 	cout<<" ";TopAbs::Print(TB1,cout)<<" : 1 face ";
 	TopAbs::Print(neworiF,cout); cout<<endl;
       }
