@@ -433,7 +433,7 @@ void TopOpeBRepBuild_Builder::GFillFaceSFS(const TopoDS_Shape& FOR,const TopTool
 #ifdef DEB
 	  if(tSPS){
 	    DEBSHASET(ss,"--- FillFaceSFS apres fufa",SFS," AddStartElement SFS+ face ");  
-	    GdumpSHA(flfr2,ss.ToCString());
+	    GdumpSHA(flfr2,(Standard_Address)ss.ToCString());
 	    cout<<" ";TopAbs::Print(TB1,cout)<<" : 1 face ";
 	    TopAbs::Print(flfr2.Orientation(),cout); cout<<endl;
 	  }
