@@ -57,6 +57,7 @@ Standard_IMPORT Standard_Boolean TopOpeBRepTool_GettraceCHKBSPL();
 TOPKRO KRO_CURVETOOL_APPRO("approximation");
 Standard_IMPORT Standard_Boolean TopOpeBRepTool_GettraceKRO();
 #endif
+//#define DRAW
 //#define IFV 
 #define CurveImprovement
 #ifdef DRAW
@@ -221,14 +222,20 @@ static Standard_Boolean CheckPCurve
 
 //------------------------------------------------------------------
 static Handle(Geom_Curve) MakeCurve3DfromWLineApprox
-(const BRepApprox_Approx& Approx,const Standard_Integer CI)
+(const BRepApprox_Approx& Approx,const Standard_Integer )
 //------------------------------------------------------------------
 {
   const AppParCurves_MultiBSpCurve& amc = Approx.Value(1); 
   Standard_Integer np = amc.NbPoles();
+  //Standard_Integer nc = amc.NbCurves();
   TColgp_Array1OfPnt poles3d(1,np);
-  Standard_Integer nc = amc.NbCurves();
-  for (Standard_Integer ic=1; ic<=nc; ic++) if (ic == CI) amc.Curve(ic,poles3d);
+  Standard_Integer ic = 1;
+  //for (ic=1; ic<=nc; ic++) {
+     //if (ic == CI) {
+      amc.Curve(ic,poles3d);
+     //}
+  //}
+
   const TColStd_Array1OfReal& knots = amc.Knots();
   const TColStd_Array1OfInteger& mults = amc.Multiplicities();
   Standard_Integer degree = amc.Degree();
@@ -291,7 +298,7 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
 {
   Standard_Boolean CompC3D = myGeomTool.CompC3D();
 
-//  cout << "MakeCurves begin" << endl;
+  //cout << "MakeCurves begin" << endl;
   if (!CompC3D) return Standard_False;
 
   Standard_Boolean CompPC1 = myGeomTool.CompPC1();
@@ -308,13 +315,14 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
 //----------------------------------
 ///*
 #ifdef IFV
-  char* name = "            ";
+  char name[16];
+  char *nm = &name[0];
   sprintf(name,"C3D_%d",++NbCalls);
-  DrawTrSurf::Set(name, C3D);
+  DrawTrSurf::Set(nm, C3D);
   sprintf(name,"PC1_%d",NbCalls);
-  DrawTrSurf::Set(name, PC1);
+  DrawTrSurf::Set(nm, PC1);
   sprintf(name,"PC2_%d",NbCalls);
-  DrawTrSurf::Set(name, PC2);
+  DrawTrSurf::Set(nm, PC2);
 #endif
 //*/
 //---------------------------------------------
@@ -329,7 +337,7 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
 //--------------------- IFV - "improving" initial curves
 #ifdef CurveImprovement
   Standard_Integer nbpol = HC3D->NbPoles();
-//  cout <<"nbpol = " << nbpol << endl;
+  //cout <<"nbpol = " << nbpol << endl;
   if(nbpol > 100) {
     TColgp_Array1OfPnt PolC3D(1, nbpol);
     TColgp_Array1OfPnt2d PolPC1(1, nbpol);
@@ -407,7 +415,6 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
     }
  
     if(NbPol < 2) {IsValid(nbpol) = Standard_True; NbPol++;}
-//      cout << "NbPol, nbpol : " << NbPol << " " <<  nbpol << endl;
     
     if(NbPol < nbpol) {
 #ifdef IFV
@@ -441,11 +448,14 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
 
 #ifdef IFV
       sprintf(name,"C3Dmod_%d",NbCalls);
-      DrawTrSurf::Set(name, HC3D);
+      nm = &name[0];
+      DrawTrSurf::Set(nm, HC3D);
       sprintf(name,"PC1mod_%d",NbCalls);
-      DrawTrSurf::Set(name, HPC1);
+      nm = &name[0];
+      DrawTrSurf::Set(nm, HPC1);
       sprintf(name,"PC2mod_%d",NbCalls);
-      DrawTrSurf::Set(name, HPC2);
+      nm = &name[0];
+      DrawTrSurf::Set(nm, HPC2);
 #endif
 
     }
@@ -552,8 +562,8 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
     }
 
   }
-//  cout << NbCalls << " ksi = " << ksi << endl;
-//  cout << "IsBad = " << IsBad << endl;
+  //cout << NbCalls << " ksi = " << ksi << endl;
+  //cout << "IsBad = " << IsBad << endl;
 
   if(IsBad){
     Standard_Real tt = Min(10.*tol3d,Precision::Approximation());
@@ -634,14 +644,17 @@ Standard_Boolean  TopOpeBRepTool_CurveTool::MakeCurves
 
 #ifdef IFV
     sprintf(name,"C3Dnew_%d", NbCalls);
-    DrawTrSurf::Set(name, C3Dnew);
+    nm = &name[0];
+    DrawTrSurf::Set(nm, C3Dnew);
     if (CompPC1) {
       sprintf(name,"PC1new_%d", NbCalls);
-      DrawTrSurf::Set(name, PC1new);
+      nm = &name[0];
+      DrawTrSurf::Set(nm, PC1new);
     }
     if (CompPC2) {
       sprintf(name,"PC2new_%d", NbCalls);
-      DrawTrSurf::Set(name, PC2new);
+      nm = &name[0];
+      DrawTrSurf::Set(nm, PC2new);
     }
 
 #endif
