@@ -39,7 +39,7 @@
 
     Handle(Transfer_Binder)  Transfer_ActorDispatch::Transfer
   (const Handle(Standard_Transient)& start,
-   const Handle(Transfer_TransientProcess)& TP)
+   const Handle(Transfer_TransientProcess)& /*TP*/)
 {
   thetool.TransferEntity(start);
   return thetool.TransientProcess()->Find(start);
