@@ -55,7 +55,6 @@
 V3d_Camera::V3d_Camera(const Handle(V3d_View)& aView) {
   Standard_Real X,Y,Z;
   Graphic3d_Vertex P,T;
-  V3d_TypeOfView TPV;
 
 // Le point oeil definit la position de la camera
   aView->Eye(X,Y,Z);
@@ -68,8 +67,8 @@ V3d_Camera::V3d_Camera(const Handle(V3d_View)& aView) {
 // Angle d'inclinaison de la camera
   MyAngle = aView->Twist();
 // Angle d'ouverture de la camera
-  TPV = aView->Type();
-  MyAperture = (TPV == V3d_PERSPECTIVE) ? ((Handle(V3d_PerspectiveView)&)aView)->Angle() : 0.;
+  MyAperture = (aView->DynamicType()==STANDARD_TYPE(V3d_PerspectiveView)) ? 
+    ((Handle(V3d_PerspectiveView)&)aView)->Angle() : 0.;
    
 } 
 
