@@ -3,8 +3,11 @@
 #define OCC198 // jfa 06/03/2002 // to prevent exception on bad font index
 #define OCC199 // jfa 06/03/2002 // to prevent exception on bad color index
 
-#include <Viewer2dTest.hxx>
+#ifdef WNT
+#include <windows.h>
+#endif
 
+#include <Viewer2dTest.hxx>
 #include <Viewer2dTest_EventManager.hxx>
 #include <Viewer2dTest_DataMapOfText.hxx>
 
@@ -43,7 +46,7 @@
 //==============================================================================
 //  VIEWER GLOBALs
 //==============================================================================
-Standard_EXPORT int ViewerMainLoop2d (Standard_Integer , char** argv);
+Standard_EXPORT int ViewerMainLoop2d (Standard_Integer , const char** argv);
 
 #ifdef WNT
 static Handle(Graphic3d_WNTGraphicDevice)& GetG2dDevice()
@@ -205,7 +208,7 @@ void Viewer2dTest::ViewerInit()
 //purpose  : Create the window viewer and initialize all the global variable
 //		Use Tk_CreateFileHandler on UNIX to cath the X11 Viewer event
 //==============================================================================
-static int V2dInit (Draw_Interpretor& , Standard_Integer , char** )
+static int V2dInit (Draw_Interpretor& , Standard_Integer , const char** )
 {
   Viewer2dTest::ViewerInit();
   return 0;
@@ -373,7 +376,7 @@ static void ProcessConfigure2d()
 //purpose  : v2dpickgrid : get coordinates of a grid point near to MB1 click
 //==============================================================================
 static int V2dHitGrid (int argc, Standard_Integer anX, Standard_Integer anY,
-                       char* xxname = 0, char* yyname = 0)
+                       const char* xxname = 0, const char* yyname = 0)
 {
   if (argc != 1 && argc != 3 && argc != 5)
   {
@@ -414,7 +417,7 @@ static int V2dHitGrid (int argc, Standard_Integer anX, Standard_Integer anY,
   return 0;
 }
 
-Standard_EXPORT int V2dPickGrid (Draw_Interpretor& , Standard_Integer argc, char** argv)
+Standard_EXPORT int V2dPickGrid (Draw_Interpretor& , Standard_Integer argc, const char** argv)
 {
   if (argc != 1 && argc != 3 && argc != 5)
   {
@@ -427,7 +430,7 @@ Standard_EXPORT int V2dPickGrid (Draw_Interpretor& , Standard_Integer argc, char
   {
     if (argc > 3)
     {
-      char *xxname, *yyname;
+      const char *xxname, *yyname;
       xxname = argv[3];
       yyname = argv[4];
       V2dHitGrid(argc, atoi(argv[1]), atoi(argv[2]), xxname, yyname);
@@ -450,7 +453,7 @@ Standard_EXPORT int V2dPickGrid (Draw_Interpretor& , Standard_Integer argc, char
 //purpose  : Picking
 //==============================================================================
 static Standard_Boolean ProcessButton1Press2d
-  (Standard_Integer , char** argv, Standard_Boolean pick, Standard_Boolean shift)
+  (Standard_Integer , const char** argv, Standard_Boolean pick, Standard_Boolean shift)
 {
   if (pick)
   {
@@ -621,7 +624,7 @@ void Viewer2dTest::GetMousePosition (Standard_Integer& Xpix, Standard_Integer& Y
 //purpose  : Dsiplay help on viewer Keyboead and mouse commands
 //Draw arg : No args
 //==============================================================================
-/*static int V2dHelp (Draw_Interpretor& , Standard_Integer , char** )
+/*static int V2dHelp (Draw_Interpretor& , Standard_Integer , const char** )
 {
   cout << "Q : Quit the application" << endl;
   cout << "=========================" << endl;
@@ -648,7 +651,7 @@ static LRESULT WINAPI Viewer2dWindowProc (HWND hwnd, UINT Msg,
 { 
   static Standard_Boolean Ppick = 0;
   static Standard_Integer Pargc = 0;
-  static char**           Pargv = NULL;
+  static const char**     Pargv = NULL;
   
   static int Up = 1;
 
@@ -766,12 +769,12 @@ static LRESULT WINAPI Viewer2dWindowProc (HWND hwnd, UINT Msg,
 //function : ViewerMainLoop2d
 //purpose  : Get a Event on the view and dispatch it
 //==============================================================================
-static int ViewerMainLoop2d (Standard_Integer argc, char** argv)
+static int ViewerMainLoop2d (Standard_Integer argc, const char** argv)
 { 
   cout << "No yet implemented on WNT" << endl; 
   static Standard_Boolean Ppick = 0;
   static Standard_Integer Pargc = 0;
-  static char**           Pargv = NULL;
+  static const char**     Pargv = NULL;
 
   Ppick = (argc > 0)? -1 : 0;
   Pargc = argc;
@@ -806,7 +809,7 @@ static int ViewerMainLoop2d (Standard_Integer argc, char** argv)
 //function : ViewerMainLoop2d
 //purpose  : Get a Event on the view and dispatch it
 //==============================================================================
-int ViewerMainLoop2d (Standard_Integer argc, char** argv)
+int ViewerMainLoop2d (Standard_Integer argc, const char** argv)
 {
   Standard_Boolean pick = argc > 0;
 
@@ -1016,7 +1019,7 @@ void Viewer2dTest_InitViewer2dTest (const Handle(AIS2D_InteractiveContext)& cont
 //purpose  : Fitall, no DRAW arguments
 //Draw arg : No args
 //==============================================================================
-static int V2dFit (Draw_Interpretor& , Standard_Integer , char** )
+static int V2dFit (Draw_Interpretor& , Standard_Integer , const char** )
 {
   Handle(V2d_View) V = Viewer2dTest::CurrentView(); 
   if (!V.IsNull()) V->Fitall();
@@ -1028,7 +1031,7 @@ static int V2dFit (Draw_Interpretor& , Standard_Integer , char** )
 //purpose  : refresh viewer
 //Draw arg : No args
 //==============================================================================
-static int V2dRepaint (Draw_Interpretor& , Standard_Integer , char** )
+static int V2dRepaint (Draw_Interpretor& , Standard_Integer , const char** )
 { 
   Handle(V2d_View) V = Viewer2dTest::CurrentView(); 
   if (!V.IsNull())
@@ -1042,7 +1045,7 @@ static int V2dRepaint (Draw_Interpretor& , Standard_Integer , char** )
 //purpose  : Remove all the object from the viewer
 //Draw arg : No args
 //==============================================================================
-static int V2dClear (Draw_Interpretor& , Standard_Integer , char** )
+static int V2dClear (Draw_Interpretor& , Standard_Integer , const char** )
 {
   Handle(V2d_View) V = Viewer2dTest::CurrentView(); 
   if (V.IsNull()) return 1;
@@ -1056,7 +1059,7 @@ static int V2dClear (Draw_Interpretor& , Standard_Integer , char** )
 //function : V2dPick
 //purpose  : v2dpick - print mouse coords and color
 //==============================================================================
-static int V2dPick (Draw_Interpretor& , Standard_Integer argc, char** argv)
+static int V2dPick (Draw_Interpretor& , Standard_Integer argc, const char** argv)
 {
   if (argc != 1)
   {
@@ -1074,7 +1077,7 @@ static int V2dPick (Draw_Interpretor& , Standard_Integer argc, char** argv)
 //function : V2dSetBG
 //purpose  : v2dsetbg imagefile [filltype] : load image as background
 //==============================================================================
-static int V2dSetBG (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int V2dSetBG (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2 || argc > 3)
   {
@@ -1086,7 +1089,7 @@ static int V2dSetBG (Draw_Interpretor& di, Standard_Integer argc, char** argv)
   Aspect_FillMethod aFillType = Aspect_FM_CENTERED;
   if (argc == 3)
   {
-    char* szType = argv[2];
+    const char* szType = argv[2];
     if      (strcmp(szType, "NONE"    ) == 0) aFillType = Aspect_FM_NONE;
     else if (strcmp(szType, "CENTERED") == 0) aFillType = Aspect_FM_CENTERED;
     else if (strcmp(szType, "TILED"   ) == 0) aFillType = Aspect_FM_TILED;
@@ -1110,12 +1113,12 @@ static int V2dSetBG (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //purpose  : v2dgrid [type [Origin(X Y) XStep/RadiusStep YStep/DivisionNb RotationAngle] [drawmode]] : load grid
 //         : v2drmgrid : unload grid
 //==============================================================================
-static int V2dGrid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int V2dGrid (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (Viewer2dTest::CurrentView().IsNull()) return 1;
   Handle(V2d_Viewer) aViewer = Viewer2dTest::CurrentView()->Viewer();
 
-  char* szName = argv[0];
+  const char* szName = argv[0];
   if (strcmp(szName, "v2drmgrid") == 0)
   {
     if (argc > 1)
@@ -1140,7 +1143,7 @@ static int V2dGrid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 
   if (argc > 1)
   {
-    char* szType = argv[1];
+    const char* szType = argv[1];
     if      (strcmp(szType, "Rect") == 0) aGridT = Aspect_GT_Rectangular;
     else if (strcmp(szType, "Circ") == 0) aGridT = Aspect_GT_Circular;
     else
@@ -1152,7 +1155,7 @@ static int V2dGrid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 
     if (argc == 3 || argc == 8)
     {
-      char* szMode = (argc == 3) ? argv[2] : argv[7];
+      const char* szMode = (argc == 3) ? argv[2] : argv[7];
       if      (strcmp(szMode, "Lines" ) == 0) aDrawM = Aspect_GDM_Lines;
       else if (strcmp(szMode, "Points") == 0) aDrawM = Aspect_GDM_Points;
       else if (strcmp(szMode, "None"  ) == 0) aDrawM = Aspect_GDM_None;
@@ -1196,7 +1199,7 @@ static int V2dGrid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //function : V2dPSOut
 //purpose  : v2dpsout imagefile [Scale TypeOfColorSpace] [Width Height XCenter YCenter] : PostScript Output
 //==============================================================================
-static int V2dPSOut (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int V2dPSOut (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2 || argc > 8)
   {
@@ -1221,7 +1224,7 @@ static int V2dPSOut (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 
     if (argc > 3)
     {
-      char* szType = argv[3];
+      const char* szType = argv[3];
       if      (strcmp(szType, "RGB")           == 0) aColorType = Aspect_TOCS_RGB;
       else if (strcmp(szType, "BlackAndWhite") == 0) aColorType = Aspect_TOCS_BlackAndWhite;
       else if (strcmp(szType, "GreyScale")     == 0) aColorType = Aspect_TOCS_GreyScale;
@@ -1260,7 +1263,7 @@ static int V2dPSOut (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //function : V2dPlot
 //purpose  : v2dplot format imagefile [Scale TypeOfColorSpace] [Width Height XCenter YCenter]
 //==============================================================================
-/*static int V2dPlot (Draw_Interpretor& , Standard_Integer argc, char** argv)
+/*static int V2dPlot (Draw_Interpretor& , Standard_Integer argc, const char** argv)
 {
   if (argc < 3 || argc > 9)
   {
@@ -1329,7 +1332,7 @@ static int V2dPSOut (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //function : V2dTextColor
 //purpose  : v2dsettextcolor text_name color_index
 //=======================================================================
-static int V2dTextColor (Draw_Interpretor& di, int argc, char** argv)
+static int V2dTextColor (Draw_Interpretor& di, int argc, const char** argv)
 {
   if (argc != 3)
   {
@@ -1367,7 +1370,7 @@ static int V2dTextColor (Draw_Interpretor& di, int argc, char** argv)
 //function : V2dText
 //purpose  : v2dtext text_str position(x y) [angle scale font]
 //=======================================================================
-static int V2dText (Draw_Interpretor& di, int argc, char** argv)
+static int V2dText (Draw_Interpretor& di, int argc, const char** argv)
 {
   if (argc != 4 && argc != 7)
   {
@@ -1434,7 +1437,7 @@ static int V2dText (Draw_Interpretor& di, int argc, char** argv)
 //=======================================================================
 void Viewer2dTest::ViewerCommands(Draw_Interpretor& theCommands)
 {
-  char *group = "2D AIS Viewer - Viewer Commands";
+  const char *group = "2D AIS Viewer - Viewer Commands";
 
   theCommands.Add("v2dinit",
 		  "v2dinit                       : Create the Viewer window",
