@@ -78,8 +78,13 @@
 # include <strings.h>
 #endif
 
+#ifdef WNT
+#define _CRT_SECURE_NO_DEPRECATE
+#pragma warning (disable:4996)
+#endif
+
 extern ViewerTest_DoubleMapOfInteractiveAndName& GetMapOfAIS();
-Standard_IMPORT int ViewerMainLoop(Standard_Integer argc, char** argv);
+Standard_IMPORT int ViewerMainLoop(Standard_Integer argc, const char** argv);
 extern Handle(AIS_InteractiveContext)& TheAISContext();
 
 
@@ -92,7 +97,7 @@ extern Handle(AIS_InteractiveContext)& TheAISContext();
 
 
 
-static int VTrihedron2D (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VTrihedron2D (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
      
 {
   // Verification des arguments
@@ -111,8 +116,8 @@ static int VTrihedron2D (Draw_Interpretor& di, Standard_Integer argc, char** arg
   
   // Boucle d'attente waitpick.
   Standard_Integer argccc = 5;
-  char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvvv = bufff;
+  const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvvv = (const char **) bufff;
   while (ViewerMainLoop( argccc, argvvv) ) { }
   // fin de la boucle
   
@@ -175,7 +180,7 @@ static int VTrihedron2D (Draw_Interpretor& di, Standard_Integer argc, char** arg
 //Draw arg : vtrihedron  name  [Xo] [Yo] [Zo] [Zu] [Zv] [Zw] [Xu] [Xv] [Xw]
 //==============================================================================
 
-static int VTrihedron (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VTrihedron (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
      
 {
   // Verification des arguments
@@ -229,7 +234,7 @@ static int VTrihedron (Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //Draw arg : vsize [name] [size]
 //==============================================================================
 
-static int VSize (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VSize (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
      
 {
   // Declaration de booleens
@@ -267,13 +272,16 @@ static int VSize (Draw_Interpretor& di, Standard_Integer argc, char** argv)
   //===============================================================
   if (!ThereIsName && ThereIsCurrent) {
     
-    ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName it (GetMapOfAIS());
+    ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName
+      it (GetMapOfAIS());
     
     while ( it.More() ) {
       
-      Handle(AIS_InteractiveObject) aShape= it.Key1();
+      Handle(AIS_InteractiveObject) aShape=
+        Handle(AIS_InteractiveObject)::DownCast(it.Key1());
       
-      if (  TheAISContext()->IsCurrent(aShape) )      {
+      if (!aShape.IsNull() &&  TheAISContext()->IsCurrent(aShape) )
+      {
 	
 	// On verifie que l'AIS InteraciveObject selectionne est bien 
 	// un AIS_Trihedron
@@ -308,9 +316,6 @@ static int VSize (Draw_Interpretor& di, Standard_Integer argc, char** argv)
       }
       
       it.Next();
-      
-      
-      
     }
     
     TheAISContext() ->UpdateCurrentViewer();
@@ -334,11 +339,14 @@ static int VSize (Draw_Interpretor& di, Standard_Integer argc, char** argv)
     if (IsBound) {
       
       // on recupere la shape dans la map des objets displayes
-      Handle(AIS_InteractiveObject) aShape = GetMapOfAIS().Find2(name);
+      Handle(AIS_InteractiveObject) aShape =
+        Handle(AIS_InteractiveObject)::DownCast(GetMapOfAIS().Find2(name));
       
       // On verifie que l'AIS InteraciveObject est bien 
       // un AIS_Trihedron
-      if (aShape->Type()==AIS_KOI_Datum && aShape->Signature()==3) {
+      if (!aShape.IsNull() &&
+          aShape->Type()==AIS_KOI_Datum && aShape->Signature()==3)
+      {
 	
 	if (aShape->HasColor()) {
 	  hascol=Standard_True;
@@ -382,7 +390,7 @@ return 0;
 
 
 
-static int VPlaneTrihedron (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VPlaneTrihedron (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
      
 {
   // Verification des arguments
@@ -401,11 +409,14 @@ static int VPlaneTrihedron (Draw_Interpretor& di, Standard_Integer argc, char**
   TheAISContext()->OpenLocalContext(Standard_False);
   myCurrentIndex=TheAISContext()->IndexOfCurrentLocal();
   
-  ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName it (GetMapOfAIS());
+  ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName
+    it (GetMapOfAIS());
   while(it.More()){
-    Handle(AIS_InteractiveObject) ShapeA=it.Key1();
+    Handle(AIS_InteractiveObject) ShapeA =
+      Handle(AIS_InteractiveObject)::DownCast(it.Key1());
     // On verifie que c'est bien un trihedron
-    if (ShapeA->Type()==AIS_KOI_Datum  && ShapeA->Signature()==3  ) {
+    if (!ShapeA.IsNull() &&
+        ShapeA->Type()==AIS_KOI_Datum  && ShapeA->Signature()==3  ) {
       // on le downcast
       Handle(AIS_Trihedron) TrihedronA =((*(Handle(AIS_Trihedron)*)&ShapeA));
       // on le charge dans le contexte et on active le mode Plane.
@@ -418,8 +429,8 @@ static int VPlaneTrihedron (Draw_Interpretor& di, Standard_Integer argc, char**
   di<<" Select a plane."<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argccc = 5;
-  char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvvv = bufff;
+  const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvvv = (const char **) bufff;
   while (ViewerMainLoop( argccc, argvvv) ) { }
   // fin de la boucle
   
@@ -468,7 +479,7 @@ static int VPlaneTrihedron (Draw_Interpretor& di, Standard_Integer argc, char**
 #include <TopExp.hxx>
 #include <Geom_Line.hxx>
 
-static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Boolean HasArg;
@@ -515,8 +526,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle 
       
@@ -539,8 +550,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
 	do {
 	  // Boucle d'attente waitpick.
 	  Standard_Integer argccc = 5;
-	  char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	  char **argvvv = bufff;
+	  const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	  const char **argvvv = (const char **) bufff;
 	  while (ViewerMainLoop( argccc, argvvv) ) { }
 	  // fin de la boucle 
 	  for(TheAISContext()->InitSelected() ;TheAISContext()->MoreSelected() ;TheAISContext()->NextSelected() ) {
@@ -596,8 +607,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle 
       
@@ -612,8 +623,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
       
       // Boucle d'attente waitpick.
       Standard_Integer argccc = 5;
-      char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvvv = bufff;
+      const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvvv = (const char **) bufff;
       while (ViewerMainLoop( argccc, argvvv) ) { }
       // fin de la boucle 
       
@@ -652,8 +663,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle 
       
@@ -668,8 +679,8 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
       
       // Boucle d'attente waitpick.
       Standard_Integer argccc = 5;
-      char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvvv = bufff;
+      const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvvv = (const char **) bufff;
       while (ViewerMainLoop( argccc, argvvv) ) { }
       // fin de la boucle 
       
@@ -722,7 +733,7 @@ static int VAxisBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
 #include <AIS_Point.hxx>
 #include <Geom_CartesianPoint.hxx>
 
-static int VPointBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VPointBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Boolean HasArg;
@@ -761,8 +772,8 @@ static int VPointBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
     
     // Boucle d'attente waitpick.
     Standard_Integer argcc = 5;
-    char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvv = buff;
+    const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvv = (const char **) buff;
     while (ViewerMainLoop( argcc, argvv) ) { }
     // fin de la boucle
     
@@ -839,7 +850,7 @@ static int VPointBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 #include <gp_Pln.hxx>
 #include <GC_MakePlane.hxx>
 
-static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Boolean HasArg;
@@ -860,22 +871,36 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
   if (HasArg) {
     if (!GetMapOfAIS().IsBound2(argv[2] ) ) {di<<"vplane: error 1st name doesn't exist in the GetMapOfAIS()."<<"\n";return 1;}
     // on recupere la shape dans la map
-    Handle(AIS_InteractiveObject) theShapeA = GetMapOfAIS().Find2(argv[2] );
+    Handle(AIS_InteractiveObject) theShapeA =
+      Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[2] ));
     
     // Le premier argument est un AIS_Point 1
-    if (theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1) {
+    if (!theShapeA.IsNull() &&
+        theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1) {
       // le deuxieme argument doit etre un AIS_Point aussi
       if (argc<5 || !GetMapOfAIS().IsBound2(argv[3] ) ) {di<<"vplane: error 2de name doesn't exist in the GetMapOfAIS()."<<"\n";return 1;}
       // on recupere la shape dans la map
-      Handle(AIS_InteractiveObject) theShapeB = GetMapOfAIS().Find2(argv[3] );
+      Handle(AIS_InteractiveObject) theShapeB =
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[3]));
       // si B n'est pas un AIS_Point
-      if (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1) ) {di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";return 1;  }
+      if (theShapeB.IsNull() ||
+          (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1)))
+      {
+        di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";
+        return 1;
+      }
       // le troisieme objet est un AIS_Point
       if (!GetMapOfAIS().IsBound2(argv[4]) ) {di<<"vplane: error 3de name doesn't exist in the GetMapOfAIS()."<<"\n";return 1; }
       // on recupere la shape dans la map
-      Handle(AIS_InteractiveObject) theShapeC = GetMapOfAIS().Find2(argv[4] );
+      Handle(AIS_InteractiveObject) theShapeC =
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[4]));
       // si C n'est pas un AIS_Point
-      if (!(theShapeC->Type()==AIS_KOI_Datum && theShapeC->Signature()==1) ) {di<<"vplane: error 3de object is expected to be an AIS_Point. "<<"\n";return 1;  }
+      if (theShapeC.IsNull() ||
+          (!(theShapeC->Type()==AIS_KOI_Datum && theShapeC->Signature()==1)))
+      {
+        di<<"vplane: error 3de object is expected to be an AIS_Point. "<<"\n";
+        return 1;
+      }
       
       // Traitement des objets A,B,C 
       // Downcaste de AIS_IO en AIS_Point
@@ -927,11 +952,21 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
     // creation d'un plan orthogonal a l'axe passant par un point
     else if (theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==2 ) {
       // le deuxieme argument doit etre un AIS_Point
-      if (argc!=4 || !GetMapOfAIS().IsBound2(argv[3] ) ) {di<<"vplane: error 2de name doesn't exist in the GetMapOfAIS()."<<"\n";return 1;}
+      if (argc!=4 || !GetMapOfAIS().IsBound2(argv[3] ) )
+      {
+        di<<"vplane: error 2de name doesn't exist in the GetMapOfAIS()."<<"\n";
+        return 1;
+      }
       // on recupere la shape dans la map
-      Handle(AIS_InteractiveObject) theShapeB = GetMapOfAIS().Find2(argv[3] );
+      Handle(AIS_InteractiveObject) theShapeB =
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[3]));
       // si B n'est pas un AIS_Point
-      if (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1) ) {di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";return 1;  }
+      if (theShapeB.IsNull() ||
+          (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1)))
+      {
+        di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";
+        return 1;
+      }
       
       // Traitement des objets A et B 
       Handle(AIS_Axis) theAISAxisA= *(Handle(AIS_Axis)*)& theShapeA;
@@ -959,11 +994,20 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
     // Creation d'un Plan parallele a ce plan passant par le point
     else if (theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==7 ) {
       // le deuxieme argument doit etre un AISPoint
-      if (argc!=4 || !GetMapOfAIS().IsBound2(argv[3] ) ) {di<<"vplane: error 2de name doesn't exist in the GetMapOfAIS()."<<"\n";return 1;}
+      if (argc!=4 || !GetMapOfAIS().IsBound2(argv[3] ) ) {
+        di<<"vplane: error 2de name doesn't exist in the GetMapOfAIS()."<<"\n";
+        return 1;
+      }
       // on recupere la shape dans la map
-      Handle(AIS_InteractiveObject) theShapeB = GetMapOfAIS().Find2(argv[3] );
+      Handle(AIS_InteractiveObject) theShapeB =
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[3]));
       // si B n'est pas un AIS_Point
-      if (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1) ) {di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";return 1;  }
+      if (theShapeB.IsNull() ||
+          (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1)))
+      {
+        di<<"vplane: error 2de object is expected to be an AIS_Point. "<<"\n";
+        return 1;
+      }
       
       // Traitement des objets A et B 
       Handle(AIS_Plane) theAISPlaneA= *(Handle(AIS_Plane)*)& theShapeA;
@@ -1003,8 +1047,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle
       
@@ -1020,8 +1064,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1038,8 +1082,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	  
 	  // Boucle d'attente waitpick.
 	  Standard_Integer argcccc = 5;
-	  char *buffff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	  char **argvvvv = buffff;
+	  const char *buffff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	  const char **argvvvv = (const char **) buffff;
 	  while (ViewerMainLoop( argcccc, argvvvv) ) { }
 	  // fin de la boucle
 	  
@@ -1105,8 +1149,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1182,8 +1226,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle
       
@@ -1200,8 +1244,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1243,8 +1287,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1294,8 +1338,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
       
       // Boucle d'attente waitpick.
       Standard_Integer argcc = 5;
-      char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvv = buff;
+      const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvv = (const char **) buff;
       while (ViewerMainLoop( argcc, argvv) ) { }
       // fin de la boucle
       
@@ -1311,8 +1355,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1376,8 +1420,8 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle
 	
@@ -1454,7 +1498,7 @@ static int VPlaneBuilder(Draw_Interpretor& di, Standard_Integer argc, char** arg
 #include <AIS_Line.hxx>
 
 
-static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   Standard_Integer myCurrentIndex;
   // Verifications
@@ -1469,13 +1513,19 @@ static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
   // Parametres: AIS_Point AIS_Point
   // ===============================
   if (argc==4) {
-    theShapeA= GetMapOfAIS().Find2(argv[2] );
+    theShapeA=
+      Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[2]));
     // On verifie que c'est bien une AIS_Point
-    if (theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1   ) {
+    if (!theShapeA.IsNull() &&
+        theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1) {
       // on recupere le deuxieme AIS_Point
-      theShapeB= GetMapOfAIS().Find2(argv[3] );
-      if (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1 ) ) {
-	di <<"vline error: wrong type of 2de argument."<<"\n";return 1;
+      theShapeB=
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[3]));
+      if (theShapeA.IsNull() ||
+          (!(theShapeB->Type()==AIS_KOI_Datum && theShapeB->Signature()==1)))
+      {
+	di <<"vline error: wrong type of 2de argument."<<"\n";
+        return 1;
       }
     }
     else {di <<"vline error: wrong type of 1st argument."<<"\n";return 1; } 
@@ -1536,8 +1586,8 @@ static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
     
     // Boucle d'attente waitpick.
     Standard_Integer argcc = 5;
-    char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvv = buff;
+    const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvv = (const char **) buff;
     while (ViewerMainLoop( argcc, argvv) ) { }
     // fin de la boucle
     
@@ -1556,8 +1606,8 @@ static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle 
 	
@@ -1611,7 +1661,7 @@ static int VLineBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv
 #include <Geom_Plane.hxx>
 #include <gp_Pln.hxx>
 
-static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   Standard_Integer myCurrentIndex;
   // verification of the arguments
@@ -1623,19 +1673,27 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
     Handle(AIS_InteractiveObject) theShapeA;
     Handle(AIS_InteractiveObject) theShapeB;
     
-    theShapeA=GetMapOfAIS().Find2(argv[2]);
-    theShapeB=GetMapOfAIS().Find2(argv[3]);
+    theShapeA=
+      Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[2]));
+    theShapeB=
+      Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[3]));
     
     // Arguments: AIS_Point AIS_Point AIS_Point
     // ========================================
-    if (theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1 ) {
+    if (!theShapeA.IsNull() && theShapeB.IsNull() &&
+        theShapeA->Type()==AIS_KOI_Datum && theShapeA->Signature()==1)
+    {
       if (theShapeB->Type()!=AIS_KOI_Datum || theShapeB->Signature()!=1 ) {
-	di<<"vcircle error: 2de argument is unexpected to be a point."<<"\n";return 1; 
+	di<<"vcircle error: 2de argument is unexpected to be a point."<<"\n";
+        return 1; 
       }
       // Le troisieme objet doit etre un point
-      Handle(AIS_InteractiveObject) theShapeC=GetMapOfAIS().Find2(argv[4]);
-      if (theShapeC->Type()!=AIS_KOI_Datum || theShapeC->Signature()!=1 ) {
-	di<<"vcircle error: 3de argument is unexpected to be a point."<<"\n";return 1; 
+      Handle(AIS_InteractiveObject) theShapeC =
+        Handle(AIS_InteractiveObject)::DownCast (GetMapOfAIS().Find2(argv[4]));
+      if (theShapeC.IsNull() ||
+          theShapeC->Type()!=AIS_KOI_Datum || theShapeC->Signature()!=1 ) {
+	di<<"vcircle error: 3de argument is unexpected to be a point."<<"\n";
+        return 1; 
       }
       // tag
       // On verifie que les 3 points sont differents.
@@ -1730,8 +1788,8 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
     
     // Boucle d'attente waitpick.
     Standard_Integer argcc = 5;
-    char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvv = buff;
+    const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvv = (const char **) buff;
     while (ViewerMainLoop( argcc, argvv) ) { }
     // fin de la boucle
     
@@ -1750,8 +1808,8 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argccc = 5;
-	char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvv = bufff;
+	const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvv = (const char **) bufff;
 	while (ViewerMainLoop( argccc, argvvv) ) { }
 	// fin de la boucle 
 	
@@ -1769,8 +1827,8 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
 	
 	// Boucle d'attente waitpick.
 	Standard_Integer argcccc = 5;
-	char *buffff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-	char **argvvvv = buffff;
+	const char *buffff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+	const char **argvvvv = (const char **) buffff;
 	while (ViewerMainLoop( argcccc, argvvvv) ) { }
 	// fin de la boucle 
 	
@@ -1804,8 +1862,8 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
       TopoDS_Shape ShapeB;
       // Boucle d'attente waitpick.
       Standard_Integer argccc = 5;
-      char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-      char **argvvv = bufff;
+      const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+      const char **argvvv = (const char **) bufff;
       while (ViewerMainLoop( argccc, argvvv) ) { }
       // fin de la boucle 
       
@@ -1860,7 +1918,7 @@ static int VCircleBuilder(Draw_Interpretor& di, Standard_Integer argc, char** ar
 
 void ViewerTest::ObjectCommands(Draw_Interpretor& theCommands)
 {
-  char *group ="AISObjects";
+  const char *group ="AISObjects";
   theCommands.Add("vtrihedron",
 		  "vtrihedron         : vtrihedron name [Xo] [Yo] [Zo] [Zu] [Zv] [Zw] [Xu] [Xv] [Xw] ",
 		  __FILE__,VTrihedron,group);
