@@ -55,7 +55,7 @@
 
 
 extern ViewerTest_DoubleMapOfInteractiveAndName& GetMapOfAIS();
-extern int ViewerMainLoop(Standard_Integer argc, char** argv);
+extern int ViewerMainLoop(Standard_Integer argc, const char** argv);
 extern Handle(AIS_InteractiveContext)& TheAISContext ();
 
 
@@ -184,7 +184,7 @@ static void ComputeNewPlaneForDim(const Handle(AIS_Relation)& R,
 //function : VAngleDimBuilder
 //purpose  : 
 //=======================================================================
-static int VAngleDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VAngleDimBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   Standard_Integer myCurrentIndex;
   
@@ -195,8 +195,8 @@ static int VAngleDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   TheAISContext()->ActivateStandardMode (AIS_Shape::SelectionType(2) );
   di<<" Select two  edges coplanar or not."<<"\n";
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   
   TopoDS_Shape ShapeA;
@@ -208,8 +208,8 @@ static int VAngleDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
     
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -266,7 +266,7 @@ else {
 #include <gp_Circ.hxx>
 
 
-static int VDiameterDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VDiameterDimBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -286,8 +286,8 @@ static int VDiameterDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -343,7 +343,7 @@ static int VDiameterDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char
 #include <TopExp_Explorer.hxx>
 
 
-static int VConcentricBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VConcentricBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -362,8 +362,8 @@ static int VConcentricBuilder(Draw_Interpretor& di, Standard_Integer argc, char*
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -379,8 +379,8 @@ static int VConcentricBuilder(Draw_Interpretor& di, Standard_Integer argc, char*
     
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -434,7 +434,7 @@ static int VConcentricBuilder(Draw_Interpretor& di, Standard_Integer argc, char*
 #include <GC_MakePlane.hxx>
 
 
-static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -456,8 +456,8 @@ static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char*
   
   // Boucle d'attente waitpick.
   Standard_Integer argc1 = 5;
-  char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv1 = buf1;
+  const char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv1 = (const char **) buf1;
   while (ViewerMainLoop( argc1, argv1) ) { }
   // fin de la boucle
   
@@ -469,8 +469,8 @@ static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char*
   di<<" Select an edge or a vertex"<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc2 = 5;
-  char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv2 = buf2;
+  const char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv2 = (const char **) buf2;
   while (ViewerMainLoop( argc2, argv2) ) { }
   // fin de la boucle
   
@@ -492,8 +492,8 @@ static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char*
   di<<" Select an edge or a vertex"<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc3 = 5;
-  char *buf3[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv3 = buf3;
+  const char *buf3[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv3 = (const char **) buf3;
   while (ViewerMainLoop( argc3, argv3) ) { }
   // fin de la boucle
   
@@ -505,8 +505,8 @@ static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char*
   di<<" Select an edge or a vertex"<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc4 = 5;
-  char *buf4[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv4 = buf4;
+  const char *buf4[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv4 = (const char **) buf4;
   while (ViewerMainLoop( argc4, argv4) ) { }
   // fin de la boucle
   
@@ -596,7 +596,7 @@ static int VEqualDistRelation(Draw_Interpretor& di, Standard_Integer argc, char*
 #include <BRepAdaptor_Curve.hxx>
 
 
-static int VEqualRadiusRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VEqualRadiusRelation(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -617,8 +617,8 @@ static int VEqualRadiusRelation(Draw_Interpretor& di, Standard_Integer argc, cha
   
   // Boucle d'attente waitpick.
   Standard_Integer argc1 = 5;
-  char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv1 = buf1;
+  const char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv1 = (const char **) buf1;
   while (ViewerMainLoop( argc1, argv1) ) { }
   // fin de la boucle
   
@@ -630,8 +630,8 @@ static int VEqualRadiusRelation(Draw_Interpretor& di, Standard_Integer argc, cha
   di<<" Select the last circled edge."<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc2 = 5;
-  char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv2 = buf2;
+  const char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv2 = (const char **) buf2;
   while (ViewerMainLoop( argc2, argv2) ) { }
   // fin de la boucle
   
@@ -673,7 +673,7 @@ static int VEqualRadiusRelation(Draw_Interpretor& di, Standard_Integer argc, cha
 #include <GC_MakePlane.hxx>
 #include <BRepAdaptor_Curve.hxx>
 
-static int VFixRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VFixRelation(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -694,8 +694,8 @@ static int VFixRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv
   
   // Boucle d'attente waitpick.
   Standard_Integer argc1 = 5;
-  char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv1 = buf1;
+  const char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv1 = (const char **) buf1;
   while (ViewerMainLoop( argc1, argv1) ) { }
   // fin de la boucle
   
@@ -739,7 +739,7 @@ static int VFixRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv
 #include <TopExp_Explorer.hxx>
 
 
-static int VIdenticRelation(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VIdenticRelation(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -762,8 +762,8 @@ static int VIdenticRelation(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argc1 = 5;
-  char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv1 = buf1;
+  const char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv1 = (const char **) buf1;
   while (ViewerMainLoop( argc1, argv1) ) { }
   // fin de la boucle
   
@@ -775,8 +775,8 @@ static int VIdenticRelation(Draw_Interpretor& di, Standard_Integer argc, char**
   di<<" Select an edge, a face or a vertex. "<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc2 = 5;
-  char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv2 = buf2;
+  const char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv2 = (const char **) buf2;
   while (ViewerMainLoop( argc2, argv2) ) { }
   // fin de la boucle
   
@@ -886,7 +886,7 @@ static int VIdenticRelation(Draw_Interpretor& di, Standard_Integer argc, char**
 #include <GC_MakePlane.hxx>
 #include <TopExp_Explorer.hxx>
 #include <BRepBuilderAPI_MakeVertex.hxx>
-static int VLenghtDimension(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VLenghtDimension(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -907,8 +907,8 @@ static int VLenghtDimension(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argc1 = 5;
-  char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv1 = buf1;
+  const char *buf1[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv1 = (const char **) buf1;
   while (ViewerMainLoop( argc1, argv1) ) { }
 
   // fin de la boucle
@@ -919,8 +919,8 @@ static int VLenghtDimension(Draw_Interpretor& di, Standard_Integer argc, char**
   di<<" Select an edge, a face or a vertex. "<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argc2 = 5;
-  char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argv2 = buf2;
+  const char *buf2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argv2 = (const char **) buf2;
   while (ViewerMainLoop( argc2, argv2) ) { }
   // fin de la boucle
   
@@ -1242,7 +1242,7 @@ static int VLenghtDimension(Draw_Interpretor& di, Standard_Integer argc, char**
 #include <gp_Circ.hxx>
 
 
-static int VRadiusDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VRadiusDimBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1265,8 +1265,8 @@ static int VRadiusDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1357,7 +1357,7 @@ static int VRadiusDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
 #include <BRepExtrema_ExtFF.hxx>
 
 
-static int VOffsetDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VOffsetDimBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1379,8 +1379,8 @@ static int VOffsetDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1392,8 +1392,8 @@ static int VOffsetDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   di<<" Select a face."<<"\n";
   // Boucle d'attente waitpick.
   Standard_Integer argccc = 5;
-  char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvvv = bufff;
+  const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvvv = (const char **) bufff;
   while (ViewerMainLoop( argccc, argvvv) ) { }
   // fin de la boucle
   
@@ -1454,7 +1454,7 @@ static int VOffsetDimBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
 #include <TopExp_Explorer.hxx>
 
 
-static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1476,8 +1476,8 @@ static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1495,8 +1495,8 @@ static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1543,8 +1543,8 @@ static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1610,7 +1610,7 @@ static int VParallelBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
 
 
 
-static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1632,8 +1632,8 @@ static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, ch
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1651,8 +1651,8 @@ static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, ch
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1699,8 +1699,8 @@ static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, ch
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1755,7 +1755,7 @@ static int VPerpendicularBuilder(Draw_Interpretor& di, Standard_Integer argc, ch
 #include <AIS_TangentRelation.hxx>
 
 
-static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1777,8 +1777,8 @@ static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, char** a
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1796,8 +1796,8 @@ static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, char** a
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1841,8 +1841,8 @@ static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, char** a
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -1896,7 +1896,7 @@ static int VTangentBuilder(Draw_Interpretor& di, Standard_Integer argc, char** a
 #include <AIS_SymmetricRelation.hxx>
 
 
-static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   // Declarations
   Standard_Integer myCurrentIndex;
@@ -1917,8 +1917,8 @@ static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc = 5;
-  char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv = buff;
+  const char *buff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv = (const char **) buff;
   while (ViewerMainLoop( argcc, argvv) ) { }
   // fin de la boucle
   
@@ -1936,8 +1936,8 @@ static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
   
   // Boucle d'attente waitpick.
   Standard_Integer argcc2 = 5;
-//  char *buff2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvv2 = buff;
+//  const char *buff2[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvv2 = (const char **) buff;
   while (ViewerMainLoop( argcc2, argvv2) ) { }
   // fin de la boucle
   
@@ -1959,8 +1959,8 @@ static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -2009,8 +2009,8 @@ static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
     di<<" Select a second edge"<<"\n";
     // Boucle d'attente waitpick.
     Standard_Integer argccc = 5;
-    char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-    char **argvvv = bufff;
+    const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+    const char **argvvv = (const char **) bufff;
     while (ViewerMainLoop( argccc, argvvv) ) { }
     // fin de la boucle
     
@@ -2052,7 +2052,7 @@ static int VSymmetricBuilder(Draw_Interpretor& di, Standard_Integer argc, char**
 //function : VMoveDim
 //purpose  : 
 //=======================================================================
-static int VMoveDim(Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static int VMoveDim(Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   if(argc>2) return 1;
   
@@ -2081,8 +2081,8 @@ static int VMoveDim(Draw_Interpretor& di, Standard_Integer argc, char** argv)
     return 1;
   Standard_Integer argccc = 5;
   
-  char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
-  char **argvvv = bufff;
+  const char *bufff[] = { "VPick", "X", "VPickY","VPickZ", "VPickShape" };
+  const char **argvvv = (const char **) bufff;
 
   Handle(AIS_Relation) R = *((Handle(AIS_Relation)*)&pickedobj);
   Handle(Geom_Plane) ThePl;
@@ -2145,7 +2145,7 @@ static int VMoveDim(Draw_Interpretor& di, Standard_Integer argc, char** argv)
 
 void ViewerTest::RelationCommands(Draw_Interpretor& theCommands)
 {
-  char *group = "AISRelations";
+  const char *group = "AISRelations";
 
   
   theCommands.Add("vangledim",
