@@ -5,32 +5,35 @@
 
 // Robert Boehne 30 May 2000 : Dec Osf
 
-#include <AIS_InteractiveContext.hxx>
-#include <ViewerTest.hxx>
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
-#include <string.h>
+#ifdef WNT
+#include <windows.h>
+#endif
+
+#include <ViewerTest.hxx>
+#include <ViewerTest_EventManager.hxx>
+#include <NIS_View.hxx>
+#include <NIS_Triangulated.hxx>
+#include <NIS_InteractiveContext.hxx>
+#include <AIS_InteractiveContext.hxx>
 #include <Draw_Interpretor.hxx>
 #include <Draw.hxx>
 #include <Draw_Appli.hxx>
-#include <DBRep.hxx>
+//#include <DBRep.hxx>
 
-#include <tcl.h>
+//#include <tcl.h>
 
 #ifndef WNT
-#include <tk.h>
 #include <Graphic3d_GraphicDevice.hxx>
 #include <Xw_GraphicDevice.hxx>
 #include <Xw_WindowQuality.hxx>
 #include <Xw_Window.hxx>
-#include <X11/Xlib.h>
+#include <X11/Xlib.h> /* contains some dangerous #defines such as Status, True etc. */
 #include <X11/Xutil.h>
-#include <Graphic3d_GraphicDevice.hxx>
-#include <Xw_GraphicDevice.hxx>
-#include <Xw_WindowQuality.hxx>
-#include <Xw_Window.hxx>
+#include <tk.h>
 
 #else
 
@@ -38,30 +41,9 @@
 #include <WNT_WClass.hxx>
 #include <WNT_Window.hxx>
 
-#endif
+#define _CRT_SECURE_NO_DEPRECATE
+#pragma warning (disable:4996)
 
-#include <Standard_Address.hxx>
-
-
-
-#include <TCollection_AsciiString.hxx>
-#include <V3d_Viewer.hxx>
-#include <V3d_View.hxx>
-#include <V3d.hxx>
-#include <AIS_DisplayMode.hxx>
-#include <TColStd_MapOfInteger.hxx>
-#include <AIS_MapOfInteractive.hxx>
-#include <ViewerTest_DoubleMapOfInteractiveAndName.hxx>
-#include <ViewerTest_DoubleMapIteratorOfDoubleMapOfInteractiveAndName.hxx>
-#include <ViewerTest_EventManager.hxx>
-
-
-#include <Draw_Window.hxx>
-#include <AIS_ListIteratorOfListOfInteractive.hxx>
-#include <AIS_ListOfInteractive.hxx>
-
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
 #endif
 
 #define OCC120
@@ -74,8 +56,8 @@
 
 
 
-Standard_EXPORT int ViewerMainLoop(Standard_Integer , char** argv);
-
+Standard_EXPORT int ViewerMainLoop(Standard_Integer , const char** argv);
+extern const Handle(NIS_InteractiveContext)& TheNISContext(); 
 
 #ifdef WNT
 static Handle(Graphic3d_WNTGraphicDevice)& GetG3dDevice(){
@@ -154,7 +136,6 @@ const Handle(MMgt_TShared)& ViewerTest::WClass()
   return theWClass;
 }
 
-
 //==============================================================================
 //function : ViewerInit
 //purpose  : Create the window viewer and initialize all the global variable
@@ -199,23 +180,27 @@ void ViewerTest::ViewerInit()
 
     TCollection_ExtendedString NameOfWindow("Visu3D");
 
-    a3DViewer = new V3d_Viewer(GetG3dDevice(),NameOfWindow.ToExtString());
+    a3DViewer = new V3d_Viewer(GetG3dDevice(), NameOfWindow.ToExtString());
     NameOfWindow = TCollection_ExtendedString("Collector");
-    a3DCollector = new V3d_Viewer(GetG3dDevice(),NameOfWindow.ToExtString());
+    a3DCollector = new V3d_Viewer(GetG3dDevice(), NameOfWindow.ToExtString());
     a3DViewer->SetDefaultBackgroundColor(Quantity_NOC_BLACK);
     a3DCollector->SetDefaultBackgroundColor(Quantity_NOC_STEELBLUE);
 
-
-    if ( ViewerTest::CurrentView().IsNull() ) {
-      Handle (V3d_View) V = a3DViewer->CreateView();
-      ViewerTest::CurrentView(V);
+    Handle(NIS_View) aView =
+      Handle(NIS_View)::DownCast(ViewerTest::CurrentView());
+    if ( aView.IsNull() ) {
+//       Handle (V3d_View) V = a3DViewer->CreateView();
+      aView = new NIS_View (a3DViewer, VT_GetWindow());
+      ViewerTest::CurrentView(aView);
+      TheNISContext()->AttachView (aView);
     }
     Handle(V3d_View) a3DViewCol;
     if ( a3DViewCol.IsNull() ) a3DViewCol    = a3DViewer->CreateView();
 
     // AIS setup
     if ( ViewerTest::GetAISContext().IsNull() ) {
-      Handle(AIS_InteractiveContext) C = new AIS_InteractiveContext(a3DViewer,a3DCollector);
+      Handle(AIS_InteractiveContext) C =
+        new AIS_InteractiveContext(a3DViewer,a3DCollector);
       ViewerTest::SetAISContext(C);
     }
 
@@ -232,7 +217,7 @@ void ViewerTest::ViewerInit()
 #ifdef OCC120
     DegenerateMode = V->DegenerateModeIsOn();
 #endif
-    V->SetWindow(VT_GetWindow());
+//    V->SetWindow(VT_GetWindow(), NULL, MyViewProc, NULL);
 
     V->SetZClippingDepth(0.5);
     V->SetZClippingWidth(ZCLIPWIDTH/2.);
@@ -264,7 +249,7 @@ void ViewerTest::ViewerInit()
 //==============================================================================
 
 
-static int VInit(Draw_Interpretor& , Standard_Integer , char** ) {
+static int VInit(Draw_Interpretor& , Standard_Integer , const char** ) {
 
   ViewerTest::ViewerInit();
 
@@ -282,35 +267,39 @@ static int VInit(Draw_Interpretor& , Standard_Integer , char** ) {
 static void ProcessKeyPress( char *buf_ret )
 {
   //cout << "KeyPress" << endl;
-
+  const Handle(V3d_View) aView = ViewerTest::CurrentView();
+  const Handle(NIS_View) aNisView = Handle(NIS_View)::DownCast (aView);
   // Letter in alphabetic order
 
   if ( !strcasecmp(buf_ret, "A") ) {
     // AXO
-    ViewerTest::CurrentView()->SetProj(V3d_XposYnegZpos);
+    aView->SetProj(V3d_XposYnegZpos);
   }
   else if ( !strcasecmp(buf_ret, "D") ) {
     // Reset
-    ViewerTest::CurrentView()->Reset();
+    aView->Reset();
   }
   else if ( !strcasecmp(buf_ret, "F") ) {
     // FitAll
-    ViewerTest::CurrentView()->FitAll();
+    if (aNisView.IsNull())
+      aView->FitAll();
+    else
+      aNisView->FitAll3d();
   }
   else if ( !strcasecmp(buf_ret, "H") ) {
     // HLR
     cout << "HLR" << endl;
 #ifdef OCC120
-    if (ViewerTest::CurrentView()->DegenerateModeIsOn()) ViewerTest::CurrentView()->SetDegenerateModeOff();
-    else ViewerTest::CurrentView()->SetDegenerateModeOn();
-    DegenerateMode = ViewerTest::CurrentView()->DegenerateModeIsOn();
+    if (aView->DegenerateModeIsOn()) ViewerTest::CurrentView()->SetDegenerateModeOff();
+    else aView->SetDegenerateModeOn();
+    DegenerateMode = aView->DegenerateModeIsOn();
 #else
     ViewerTest::CurrentView()->SetDegenerateModeOff();
 #endif
   }
   else if ( !strcasecmp(buf_ret, "D") ) {
     // Reset
-    ViewerTest::CurrentView()->Reset();
+    aView->Reset();
   }
   else if ( !strcasecmp(buf_ret, "S") ) {
     // SHADING
@@ -359,19 +348,19 @@ static void ProcessKeyPress( char *buf_ret )
   }
   else if ( !strcasecmp(buf_ret, "T") ) {
     // Top
-    ViewerTest::CurrentView()->SetProj(V3d_Zpos);
+    aView->SetProj(V3d_Zpos);
   }
   else if ( !strcasecmp(buf_ret, "B") ) {
     // Top
-    ViewerTest::CurrentView()->SetProj(V3d_Zneg);
+    aView->SetProj(V3d_Zneg);
   }
   else if ( !strcasecmp(buf_ret, "L") ) {
     // Top
-    ViewerTest::CurrentView()->SetProj(V3d_Xneg);
+    aView->SetProj(V3d_Xneg);
   }
   else if ( !strcasecmp(buf_ret, "R") ) {
     // Top
-    ViewerTest::CurrentView()->SetProj(V3d_Xpos);
+    aView->SetProj(V3d_Xpos);
   }
 
   else if ( !strcasecmp(buf_ret, "W") ) {
@@ -406,15 +395,15 @@ static void ProcessKeyPress( char *buf_ret )
       cout << "ZClipping OFF" << endl;
       ZClipIsOn = 0;
 
-      ViewerTest::CurrentView()->SetZClippingType(V3d_OFF);
-      ViewerTest::CurrentView()->Redraw();
+      aView->SetZClippingType(V3d_OFF);
+      aView->Redraw();
     }
     else {
       cout << "ZClipping ON" << endl;
       ZClipIsOn = 1;
 
-      ViewerTest::CurrentView()->SetZClippingType(V3d_FRONT);
-      ViewerTest::CurrentView()->Redraw();
+      aView->SetZClippingType(V3d_FRONT);
+      aView->Redraw();
     }
   }
   else if ( !strcasecmp(buf_ret, ",") ) {
@@ -463,7 +452,7 @@ static void ProcessConfigure()
 
 static Standard_Boolean ProcessButton1Press(
 	Standard_Integer ,
-	char** argv,
+	const char** argv,
 	Standard_Boolean pick,
 	Standard_Boolean shift )
 {
@@ -529,15 +518,9 @@ void ProcessZClipMotion()
   if ( Abs(X_Motion - X_ButtonPress) > 2 ) {
         static Standard_Real CurZPos = 0.;
 
-	Quantity_Length VDX, VDY;
-
-	a3DView->Size(VDX,VDY);
-
-#ifdef DEB
-	Standard_Real VDZ =
-#endif
-	  a3DView->ZSize();
-
+	//Quantity_Length VDX, VDY;
+	//a3DView->Size(VDX,VDY);
+	//Standard_Real VDZ = a3DView->ZSize();
 	//printf("View size (%lf,%lf,%lf)\n", VDX, VDY, VDZ);
 
 	Quantity_Length dx = a3DView->Convert(X_Motion - X_ButtonPress);
@@ -615,7 +598,7 @@ static void ProcessMotion()
   //pre-hilights detected objects at mouse position
 
   Handle(ViewerTest_EventManager) EM = ViewerTest::CurrentEventManager();
-  EM->MoveTo(X_Motion, Y_Motion, ViewerTest::CurrentView());
+  EM->MoveTo(X_Motion, Y_Motion);
 }
 
 
@@ -630,7 +613,7 @@ void ViewerTest::GetMousePosition(Standard_Integer& Xpix,Standard_Integer& Ypix)
 //Draw arg : No args
 //==============================================================================
 
-static int VAxo(Draw_Interpretor& di, Standard_Integer , char** )
+static int VAxo(Draw_Interpretor& di, Standard_Integer , const char** )
 { if ( ViewerTest::CurrentView().IsNull() ) {
     di<<"La commande vinit n'a pas ete appele avant"<<"\n";
 //	VInit(di, argc, argv);
@@ -647,7 +630,7 @@ static int VAxo(Draw_Interpretor& di, Standard_Integer , char** )
 //Draw arg : No args
 //==============================================================================
 
-static int VTop(Draw_Interpretor& di, Standard_Integer , char** )
+static int VTop(Draw_Interpretor& di, Standard_Integer , const char** )
 {
 
   if ( ViewerTest::CurrentView().IsNull() ) {
@@ -667,7 +650,7 @@ static int VTop(Draw_Interpretor& di, Standard_Integer , char** )
 //Draw arg : No args
 //==============================================================================
 
-static int VHelp(Draw_Interpretor& di, Standard_Integer , char** )
+static int VHelp(Draw_Interpretor& di, Standard_Integer , const char** )
 {
 
   di << "Q : Quit the application" << "\n";
@@ -713,7 +696,7 @@ Standard_Boolean DragFirst;
 
 static Standard_Boolean Ppick = 0;
 static Standard_Integer Pargc = 0;
-static char**           Pargv = NULL;
+static const char**           Pargv = NULL;
 
 
 static LRESULT WINAPI AdvViewerWindowProc( HWND hwnd,
@@ -738,18 +721,14 @@ static LRESULT WINAPI AdvViewerWindowProc( HWND hwnd,
          Rectangle( hdc, xx1, yy1, xx2, yy2 );
          ReleaseDC( hwnd, hdc );
 
-         Handle( AIS_InteractiveContext ) aContext = ViewerTest::GetAISContext();
-         if( aContext.IsNull() )
-           cout << "The context is null. Please use vinit before createmesh" << endl;
+         const Handle(ViewerTest_EventManager) EM =
+           ViewerTest::CurrentEventManager();
+         if ( fwKeys & MK_SHIFT )
+           EM->ShiftSelect( min( xx1, xx2 ), max( yy1, yy2 ),
+                            max( xx1, xx2 ), min( yy1, yy2 ));
          else
-           if ( fwKeys & MK_SHIFT )
-             aContext->ShiftSelect( min( xx1, xx2 ), min( yy1, yy2 ),
-                                    max( xx1, xx2 ), max( yy1, yy2 ),
-                                    ViewerTest::CurrentView() );
-           else
-             aContext->Select( min( xx1, xx2 ), min( yy1, yy2 ),
-                               max( xx1, xx2 ), max( yy1, yy2 ),
-                               ViewerTest::CurrentView() );
+           EM->Select( min( xx1, xx2 ), max( yy1, yy2 ),
+                       max( xx1, xx2 ), min( yy1, yy2 ));
       }
       return ViewerWindowProc( hwnd, Msg, wParam, lParam );
 
@@ -941,7 +920,7 @@ static LRESULT WINAPI ViewerWindowProc( HWND hwnd,
 //==============================================================================
 
 
-static int ViewerMainLoop(Standard_Integer argc, char** argv)
+static int ViewerMainLoop(Standard_Integer argc, const char** argv)
 {
 
 //cout << "No yet implemented on WNT" << endl;
@@ -994,7 +973,7 @@ int max( int a, int b )
 		return b;
 }
 
-int ViewerMainLoop(Standard_Integer argc, char** argv)
+int ViewerMainLoop(Standard_Integer argc, const char** argv)
 
 { Standard_Boolean pick = argc > 0;
 
@@ -1100,7 +1079,7 @@ int ViewerMainLoop(Standard_Integer argc, char** argv)
                  {
                    aContext->ShiftSelect( min( xx1, xx2 ), min( yy1, yy2 ),
                                           max( xx1, xx2 ), max( yy1, yy2 ),
-                                          ViewerTest::CurrentView() );
+                                          ViewerTest::CurrentView());
 //                   cout << "shift select" << endl;
                  }
                  else
@@ -1266,14 +1245,22 @@ static void OSWindowSetup()
 
 //==============================================================================
 //function : VFit
+
 //purpose  : Fitall, no DRAW arguments
 //Draw arg : No args
 //==============================================================================
 
-static int VFit(Draw_Interpretor& , Standard_Integer , char** )
+static int VFit(Draw_Interpretor& , Standard_Integer , const char** )
 {
-  Handle(V3d_View) V = ViewerTest::CurrentView();
-  if ( !V.IsNull() ) V->FitAll(); return 0; }
+  const Handle(V3d_View) aView = ViewerTest::CurrentView();
+  Handle(NIS_View) V = Handle(NIS_View)::DownCast(aView);
+  if (V.IsNull() == Standard_False) {
+    V->FitAll3d();
+  } else if (aView.IsNull() == Standard_False) {
+    aView->FitAll();
+  }
+  return 0;
+}
 
 //==============================================================================
 //function : VZFit
@@ -1281,13 +1268,13 @@ static int VFit(Draw_Interpretor& , Standard_Integer , char** )
 //Draw arg : No args
 //==============================================================================
 
-static int VZFit(Draw_Interpretor& , Standard_Integer , char** )
+static int VZFit(Draw_Interpretor& , Standard_Integer , const char** )
 {
   Handle(V3d_View) V = ViewerTest::CurrentView();
   if ( !V.IsNull() ) V->ZFitAll(); return 0; }
 
 
-static int VRepaint(Draw_Interpretor& , Standard_Integer , char** )
+static int VRepaint(Draw_Interpretor& , Standard_Integer , const char** )
 {
   Handle(V3d_View) V = ViewerTest::CurrentView();
   if ( !V.IsNull() ) V->Redraw(); return 0;
@@ -1300,7 +1287,7 @@ static int VRepaint(Draw_Interpretor& , Standard_Integer , char** )
 //Draw arg : No args
 //==============================================================================
 
-static int VClear(Draw_Interpretor& , Standard_Integer , char** )
+static int VClear(Draw_Interpretor& , Standard_Integer , const char** )
 {
   Handle(V3d_View) V = ViewerTest::CurrentView();
   if(!V.IsNull())
@@ -1313,7 +1300,7 @@ static int VClear(Draw_Interpretor& , Standard_Integer , char** )
 //purpose  :
 //==============================================================================
 
-static int VPick(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VPick(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 { if (ViewerTest::CurrentView().IsNull() ) return 1;
 
   if ( argc < 4 ) {
@@ -1369,7 +1356,7 @@ void ViewerTest_InitViewerTest (const Handle(AIS_InteractiveContext)& context)
 //purpose  : Load image as background
 //==============================================================================
 
-static int VSetBg(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VSetBg(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2 || argc > 3)
   {
@@ -1387,7 +1374,7 @@ static int VSetBg(Draw_Interpretor& di, Standard_Integer argc, char** argv)
   Aspect_FillMethod aFillType = Aspect_FM_CENTERED;
   if (argc == 3)
   {
-    char* szType = argv[2];
+    const char* szType = argv[2];
     if      (strcmp(szType, "NONE"    ) == 0) aFillType = Aspect_FM_NONE;
     else if (strcmp(szType, "CENTERED") == 0) aFillType = Aspect_FM_CENTERED;
     else if (strcmp(szType, "TILED"   ) == 0) aFillType = Aspect_FM_TILED;
@@ -1411,7 +1398,7 @@ static int VSetBg(Draw_Interpretor& di, Standard_Integer argc, char** argv)
 //purpose  : View Scaling
 //==============================================================================
 
-static int VScale(Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static int VScale(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   Handle(V3d_View) V3dView = ViewerTest::CurrentView();
   if ( V3dView.IsNull() ) return 1;
@@ -1432,7 +1419,7 @@ static int VScale(Draw_Interpretor& di, Standard_Integer argc, char** argv)
 void ViewerTest::ViewerCommands(Draw_Interpretor& theCommands)
 {
 
-  char *group = "ZeViewer";
+  const char *group = "ZeViewer";
   theCommands.Add("vinit" ,
 		  "vinit            : Create the Viewer window",
 		  __FILE__,VInit,group);
