@@ -557,97 +557,108 @@ Standard_Real Dx, Dy, Ratio;
 		AU = AV = IntegerLast ();
 	}
 	else {
+    // NKV - 11.02.08 - Use graphic driver functions
+    Standard_Boolean Result;
 
-Standard_Real PtX, PtY, PtZ, PtT;
-Standard_Real APX, APY, APZ;
-Standard_Real APT;
+    AVertex.Coord (AX, AY, AZ);
 
-Visual3d_SetIteratorOfSetOfView MyIterator(MyDefinedView);
+    Result = MyGraphicDriver->ProjectRaster (TheCView, 
+      Standard_ShortReal (AX), Standard_ShortReal (AY), Standard_ShortReal (AZ),
+      AU, AV);
+
+    // the old code
+    if (!Result) {
+
+      Standard_Real PtX, PtY, PtZ, PtT;
+      Standard_Real APX, APY, APZ;
+      Standard_Real APT;
+
+      Visual3d_SetIteratorOfSetOfView MyIterator(MyDefinedView);
 #ifdef DEB
-	Standard_Integer Length = MyDefinedView.Extent ();
+      Standard_Integer Length = MyDefinedView.Extent ();
 #else
-        MyDefinedView.Extent ();
+      MyDefinedView.Extent ();
 #endif
 
-Standard_Integer stop = 0;
+      Standard_Integer stop = 0;
 
-		while ((! stop) && (MyIterator.More ())) {
-			if (TheCView.ViewId ==
-			   (MyIterator.Value ())->Identification ()) {
-			   Ori_Matrix	=
-				(MyIterator.Value ())->MatrixOfOrientation ();
-			   Map_Matrix	=
-				(MyIterator.Value ())->MatrixOfMapping ();
-			   stop	= 1;
-			}
-
-			// MyIterator.Next () se positionne
-			// sur la prochaine vue
-			MyIterator.Next ();
-		}
-
-		AVertex.Coord (AX, AY, AZ);
-
-		// WCS -> View Reference Coordinate Space
-		PtX	= Ori_Matrix (0, 0) * AX
-			+ Ori_Matrix (0, 1) * AY
-			+ Ori_Matrix (0, 2) * AZ
-			+ Ori_Matrix (0, 3);
-		PtY	= Ori_Matrix (1, 0) * AX
-			+ Ori_Matrix (1, 1) * AY
-			+ Ori_Matrix (1, 2) * AZ
-			+ Ori_Matrix (1, 3);
-		PtZ	= Ori_Matrix (2, 0) * AX
-			+ Ori_Matrix (2, 1) * AY
-			+ Ori_Matrix (2, 2) * AZ
-			+ Ori_Matrix (2, 3);
-		PtT	= Ori_Matrix (3, 0) * AX
-			+ Ori_Matrix (3, 1) * AY
-			+ Ori_Matrix (3, 2) * AZ
-			+ Ori_Matrix (3, 3);
-
-		// VRCS -> Normalized Projection Coordinate Space
-		APX	= Map_Matrix (0, 0) * PtX
-			+ Map_Matrix (0, 1) * PtY
-			+ Map_Matrix (0, 2) * PtZ
-			+ Map_Matrix (0, 3) * PtT;
-		APY	= Map_Matrix (1, 0) * PtX
-			+ Map_Matrix (1, 1) * PtY
-			+ Map_Matrix (1, 2) * PtZ
-			+ Map_Matrix (1, 3) * PtT;
-		APZ	= Map_Matrix (2, 0) * PtX
-			+ Map_Matrix (2, 1) * PtY
-			+ Map_Matrix (2, 2) * PtZ
-			+ Map_Matrix (2, 3) * PtT;
-		APT	= Map_Matrix (3, 0) * PtX
-			+ Map_Matrix (3, 1) * PtY
-			+ Map_Matrix (3, 2) * PtZ
-			+ Map_Matrix (3, 3) * PtT;
-
-		if (APT == 0. || stop == 0) {
-			AU = AV = IntegerLast ();
-		}
-		else {
-			APX /= APT;
-			APY /= APT;
-			APZ /= APT;
-
-			// NPCS -> Device Coordinate Space
-			AWindow->Size (Width, Height);
-			Dx	= Standard_Real (Width);
-			Dy	= Standard_Real (Height);
-			Ratio	= Dx / Dy;
-			if (Ratio >= 1.) {
-				AU = Standard_Integer (APX * Dx);
-				AV = Standard_Integer (Dy - APY * Dy * Ratio);
-			}
-			else {
-				AU = Standard_Integer (APX * Dx / Ratio);
-				AV = Standard_Integer (Dy - APY * Dy);
-			}
-		}
+      while ((! stop) && (MyIterator.More ())) {
+	if (TheCView.ViewId ==
+	    (MyIterator.Value ())->Identification ()) {
+	  Ori_Matrix	=
+	    (MyIterator.Value ())->MatrixOfOrientation ();
+	  Map_Matrix	=
+	    (MyIterator.Value ())->MatrixOfMapping ();
+	  stop	= 1;
 	}
 
+	// MyIterator.Next () se positionne
+	// sur la prochaine vue
+	MyIterator.Next ();
+      }
+
+
+      // WCS -> View Reference Coordinate Space
+      PtX	= Ori_Matrix (0, 0) * AX
+	        + Ori_Matrix (0, 1) * AY
+	        + Ori_Matrix (0, 2) * AZ
+	        + Ori_Matrix (0, 3);
+      PtY	= Ori_Matrix (1, 0) * AX
+	        + Ori_Matrix (1, 1) * AY
+	        + Ori_Matrix (1, 2) * AZ
+	        + Ori_Matrix (1, 3);
+      PtZ	= Ori_Matrix (2, 0) * AX
+	        + Ori_Matrix (2, 1) * AY
+	        + Ori_Matrix (2, 2) * AZ
+	        + Ori_Matrix (2, 3);
+      PtT	= Ori_Matrix (3, 0) * AX
+	        + Ori_Matrix (3, 1) * AY
+	        + Ori_Matrix (3, 2) * AZ
+	        + Ori_Matrix (3, 3);
+
+      // VRCS -> Normalized Projection Coordinate Space
+      APX	= Map_Matrix (0, 0) * PtX
+	        + Map_Matrix (0, 1) * PtY
+	        + Map_Matrix (0, 2) * PtZ
+	        + Map_Matrix (0, 3) * PtT;
+      APY	= Map_Matrix (1, 0) * PtX
+	        + Map_Matrix (1, 1) * PtY
+	        + Map_Matrix (1, 2) * PtZ
+	        + Map_Matrix (1, 3) * PtT;
+      APZ	= Map_Matrix (2, 0) * PtX
+	        + Map_Matrix (2, 1) * PtY
+	        + Map_Matrix (2, 2) * PtZ
+	        + Map_Matrix (2, 3) * PtT;
+      APT	= Map_Matrix (3, 0) * PtX
+	        + Map_Matrix (3, 1) * PtY
+	        + Map_Matrix (3, 2) * PtZ
+	        + Map_Matrix (3, 3) * PtT;
+
+      if (APT == 0. || stop == 0) {
+	AU = AV = IntegerLast ();
+      }
+      else {
+	APX /= APT;
+	APY /= APT;
+	APZ /= APT;
+
+	// NPCS -> Device Coordinate Space
+	AWindow->Size (Width, Height);
+	Dx	= Standard_Real (Width);
+	Dy	= Standard_Real (Height);
+	Ratio	= Dx / Dy;
+	if (Ratio >= 1.) {
+	  AU = Standard_Integer (APX * Dx);
+	  AV = Standard_Integer (Dy - APY * Dy * Ratio);
+	}
+	else {
+	  AU = Standard_Integer (APX * Dx / Ratio);
+	  AV = Standard_Integer (Dy - APY * Dy);
+	}
+      }
+    }
+  }
+
 }
 
 Graphic3d_Vertex Visual3d_ViewManager::ConvertCoord (const Handle(Aspect_Window)& AWindow, const Standard_Integer AU, const Standard_Integer AV) const {
@@ -785,6 +796,194 @@ Standard_Boolean BResult;
 
 }
 
+void Visual3d_ViewManager::ConvertCoordWithProj (const Handle(Aspect_Window)& AWindow, const Standard_Integer AU, const Standard_Integer AV, Graphic3d_Vertex& Point, Graphic3d_Vector& Proj) const {
+
+// On convertit que si les donnees sont correctes
+Graphic3d_CView TheCView;
+
+        if (! ViewExists (AWindow, TheCView)) {
+	    Point.SetCoord (RealLast (), RealLast (), RealLast ());
+	    Proj.SetCoord (0., 0., 0.);
+        }
+	else {
+Standard_Integer Width, Height;
+Standard_ShortReal x, y, z;
+Standard_ShortReal dx, dy, dz;
+Standard_Boolean Result;
+
+	    AWindow->Size (Width, Height);
+
+	    Result	= MyGraphicDriver->UnProjectRasterWithRay (TheCView,
+				0, 0, Width, Height,
+				AU, AV, x, y, z, dx, dy, dz);
+
+	    // Le unproject est realise par UnProjectRaster
+	    if (Result) {
+		Point.SetCoord
+		    (Standard_Real (x), Standard_Real (y), Standard_Real (z));
+		Proj.SetCoord
+		    (Standard_Real (dx), Standard_Real (dy), Standard_Real (dz));
+                Proj.Normalize();
+	    }
+	    // Le unproject n'est pas realisable par UnProjectRaster
+	    // Code a virer des que les drivers Phigs et Pex seront abandonnes.
+	    else {
+
+Standard_Real NPCX, NPCY, NPCZ;
+Standard_Real VRCX, VRCY, VRCZ, VRCT;
+Standard_Real WCX, WCY, WCZ, WCT;
+
+TColStd_Array2OfReal TOri_Matrix (0,3,0,3);
+TColStd_Array2OfReal TMap_Matrix (0,3,0,3);
+TColStd_Array2OfReal TOri_Matrix_Inv (0,3,0,3);
+TColStd_Array2OfReal TMap_Matrix_Inv (0,3,0,3);
+
+Standard_Real Dx, Dy, Ratio;
+Visual3d_SetIteratorOfSetOfView MyIterator(MyDefinedView);
+Standard_Integer j;
+
+Standard_Integer stop = 0;
+
+Standard_Boolean BResult;
+
+		j = MyDefinedView.Extent ();
+
+		while ((! stop) && (MyIterator.More ())) {
+		    if (TheCView.ViewId ==
+			(MyIterator.Value ())->Identification ()) {
+			TOri_Matrix	=
+				(MyIterator.Value ())->MatrixOfOrientation ();
+			TMap_Matrix	=
+				(MyIterator.Value ())->MatrixOfMapping ();
+			stop	= 1;
+		    }
+
+		    // MyIterator.Next () se positionne
+		    // sur la prochaine vue
+		    MyIterator.Next ();
+		}
+
+		// View Mapping Transformation and View Clip, inversion
+		BResult = Aspect::Inverse (TMap_Matrix, TMap_Matrix_Inv);
+
+		// View Orientation Transformation, inversion
+		BResult = Aspect::Inverse (TOri_Matrix, TOri_Matrix_Inv);
+
+		// (AU, AV) : Device Coordinate Space
+		// DCS -> NPCS Normalized Projection Coordinate Space
+		Dx	= Standard_Real (Width);
+		Dy	= Standard_Real (Height);
+		Ratio	= Dx / Dy;
+
+		if (Ratio >= 1.) {
+			NPCX	= Standard_Real (AU) / Dx;
+			NPCY	= (Dy - Standard_Real (AV)) / Dx;
+		}
+		else {
+			NPCX	= Standard_Real (AU) / Dy;
+			NPCY	= (Dy - Standard_Real (AV)) / Dy;
+		}
+		NPCZ	= 0.0;
+
+		// NPCS -> VRCS View Reference Coordinate Space
+		// PtVRC = Map_Matrix_Inv.Multiplied (PtNPC);
+
+		VRCX	= TMap_Matrix_Inv (0, 0) * NPCX
+			+ TMap_Matrix_Inv (0, 1) * NPCY
+			+ TMap_Matrix_Inv (0, 2) * NPCZ
+			+ TMap_Matrix_Inv (0, 3);
+		VRCY	= TMap_Matrix_Inv (1, 0) * NPCX
+			+ TMap_Matrix_Inv (1, 1) * NPCY
+			+ TMap_Matrix_Inv (1, 2) * NPCZ
+			+ TMap_Matrix_Inv (1, 3);
+		VRCZ	= TMap_Matrix_Inv (2, 0) * NPCX
+			+ TMap_Matrix_Inv (2, 1) * NPCY
+			+ TMap_Matrix_Inv (2, 2) * NPCZ
+			+ TMap_Matrix_Inv (2, 3);
+		VRCT	= TMap_Matrix_Inv (3, 0) * NPCX
+			+ TMap_Matrix_Inv (3, 1) * NPCY
+			+ TMap_Matrix_Inv (3, 2) * NPCZ
+			+ TMap_Matrix_Inv (3, 3);
+
+		// VRCS -> WCS World Coordinate Space
+		// PtWC = Ori_Matrix_Inv.Multiplied (PtVRC);
+
+		WCX	= TOri_Matrix_Inv (0, 0) * VRCX
+			+ TOri_Matrix_Inv (0, 1) * VRCY
+			+ TOri_Matrix_Inv (0, 2) * VRCZ
+			+ TOri_Matrix_Inv (0, 3) * VRCT;
+		WCY	= TOri_Matrix_Inv (1, 0) * VRCX
+			+ TOri_Matrix_Inv (1, 1) * VRCY
+			+ TOri_Matrix_Inv (1, 2) * VRCZ
+			+ TOri_Matrix_Inv (1, 3) * VRCT;
+		WCZ	= TOri_Matrix_Inv (2, 0) * VRCX
+			+ TOri_Matrix_Inv (2, 1) * VRCY
+			+ TOri_Matrix_Inv (2, 2) * VRCZ
+			+ TOri_Matrix_Inv (2, 3) * VRCT;
+		WCT	= TOri_Matrix_Inv (3, 0) * VRCX
+			+ TOri_Matrix_Inv (3, 1) * VRCY
+			+ TOri_Matrix_Inv (3, 2) * VRCZ
+			+ TOri_Matrix_Inv (3, 3) * VRCT;
+
+		if (WCT != 0.)
+		    Point.SetCoord (WCX/WCT, WCY/WCT, WCZ/WCT);
+		else
+		    Point.SetCoord (RealLast (), RealLast (), RealLast ());
+
+                // Define projection ray
+		NPCZ	= 10.0;
+
+		// NPCS -> VRCS View Reference Coordinate Space
+		// PtVRC = Map_Matrix_Inv.Multiplied (PtNPC);
+
+		VRCX	= TMap_Matrix_Inv (0, 0) * NPCX
+			+ TMap_Matrix_Inv (0, 1) * NPCY
+			+ TMap_Matrix_Inv (0, 2) * NPCZ
+			+ TMap_Matrix_Inv (0, 3);
+		VRCY	= TMap_Matrix_Inv (1, 0) * NPCX
+			+ TMap_Matrix_Inv (1, 1) * NPCY
+			+ TMap_Matrix_Inv (1, 2) * NPCZ
+			+ TMap_Matrix_Inv (1, 3);
+		VRCZ	= TMap_Matrix_Inv (2, 0) * NPCX
+			+ TMap_Matrix_Inv (2, 1) * NPCY
+			+ TMap_Matrix_Inv (2, 2) * NPCZ
+			+ TMap_Matrix_Inv (2, 3);
+		VRCT	= TMap_Matrix_Inv (3, 0) * NPCX
+			+ TMap_Matrix_Inv (3, 1) * NPCY
+			+ TMap_Matrix_Inv (3, 2) * NPCZ
+			+ TMap_Matrix_Inv (3, 3);
+
+		// VRCS -> WCS World Coordinate Space
+		// PtWC = Ori_Matrix_Inv.Multiplied (PtVRC);
+
+		WCX	= TOri_Matrix_Inv (0, 0) * VRCX
+			+ TOri_Matrix_Inv (0, 1) * VRCY
+			+ TOri_Matrix_Inv (0, 2) * VRCZ
+			+ TOri_Matrix_Inv (0, 3) * VRCT;
+		WCY	= TOri_Matrix_Inv (1, 0) * VRCX
+			+ TOri_Matrix_Inv (1, 1) * VRCY
+			+ TOri_Matrix_Inv (1, 2) * VRCZ
+			+ TOri_Matrix_Inv (1, 3) * VRCT;
+		WCZ	= TOri_Matrix_Inv (2, 0) * VRCX
+			+ TOri_Matrix_Inv (2, 1) * VRCY
+			+ TOri_Matrix_Inv (2, 2) * VRCZ
+			+ TOri_Matrix_Inv (2, 3) * VRCT;
+		WCT	= TOri_Matrix_Inv (3, 0) * VRCX
+			+ TOri_Matrix_Inv (3, 1) * VRCY
+			+ TOri_Matrix_Inv (3, 2) * VRCZ
+			+ TOri_Matrix_Inv (3, 3) * VRCT;
+
+                if (WCT != 0.) {
+		    Proj.SetCoord (WCX/WCT, WCY/WCT, WCZ/WCT);
+                    Proj.Normalize();
+                }
+		else
+		    Proj.SetCoord (0., 0., 0.);
+	    }
+	}
+
+}
+
 Visual3d_PickDescriptor Visual3d_ViewManager::Pick (const Visual3d_ContextPick& CTX, const Handle(Aspect_Window)& AWindow, const Standard_Integer AX, const Standard_Integer AY) {
 
 // On active le reperage que si les donnees sont correctes
