@@ -15,6 +15,9 @@
 //              It is possible now to create two files: EMF and PRN.
 // Copyright:   Matra Datavision 1993
 
+// include windows.h first to have all definitions available
+#include <windows.h>
+
 #define MFT // S3553 study
 
 #define PRO17334        //GG_060199
@@ -652,7 +655,7 @@ Standard_Boolean WNT_DDriver::SizeOfImageFile
   Handle( WNT_GraphicDevice        ) gDev  = myDevice;
   if (  myImage == NULL || iName -> String () != anImageFile  ) {
     *(  ( Aspect_Handle* )&myImage  ) =
-      LoadImageFromFile (  gDev, anImageFile, ( ::HDC )myHDCMeta  );
+      LoadImageFromFile (  gDev, (Standard_PCharacter)anImageFile, ( ::HDC )myHDCMeta  );
     if ( myImage == NULL ) return Standard_False;
     iName -> Clear ();
     iName -> AssignCat ( anImageFile );
@@ -928,7 +931,7 @@ Standard_Boolean WNT_DDriver :: PlotText (
 /*====================== MFT ====================*/
     A -> Text (
            P( Xpos ), P( Ypos ),
-           anAngle, Text, FALSE,
+           anAngle, (Standard_PCharacter)Text, FALSE,
            ( aType == Aspect_TOT_SOLID ) ? FALSE : TRUE
          );
   return Standard_True;
@@ -1002,7 +1005,7 @@ Standard_Boolean WNT_DDriver :: PlotPolyText (
 /*====================== MFT ====================*/
     A -> Polytext (
           P( Xpos ), P( Ypos ),
-          anAngle, aMarge, aText, FALSE,
+          anAngle, aMarge, (Standard_PCharacter)aText, FALSE,
           ( aType == Aspect_TOT_SOLID ) ? FALSE : TRUE
          );
   return Standard_True;
@@ -1251,7 +1254,7 @@ void WNT_DDriver::InitializeFontMap(const Handle(Aspect_FontMap)& aFontMap)
   Aspect_FontStyle           fontStyle;
   Handle( WNT_FontMapEntry ) fmEntry;
   Standard_Character         left[ 260 ], right[ 250 ];
-  Standard_CString           pSize;
+  Standard_PCharacter           pSize;
   Standard_Integer           height, mapSize = aFontMap -> Size ();
   Standard_Integer           i;
   HFONT                      hfo =
