@@ -24,6 +24,7 @@
 
 #include <Aspect_XWD.hxx>
 
+#include <WNT.h>
 #include <Quantity_Color.hxx>
 #include <WNT_GraphicDevice.hxx>
 #include <WNT_TypeOfImage.hxx>
@@ -213,7 +214,7 @@ HBITMAP LoadImageFromFile (
 
 }  // end LoadImageFromFile
 
-int SaveWindowToFile (
+int __WNT_API SaveWindowToFile (
      Handle( WNT_GraphicDevice )& gDev,
      HWND hWnd, char* fName, int x, int y, int w, int h
     ) {
