@@ -6,6 +6,9 @@
 //              each other or do not begin with '1'
 // Copyright:   Matra Datavision 1993
 
+// include windows.h first to have all definitions available
+#include <windows.h>
+
 #define MFT // Study S3553
 
 #define PRO17334	//GG_060199
@@ -767,7 +770,7 @@ void WNT_WDriver :: DrawText (
 #endif
 /*====================== MFT ====================*/
     A -> Text (
-           P( Xpos ), P( Ypos ), anAngle, Text, FALSE,
+           P( Xpos ), P( Ypos ), anAngle, (Standard_Address)Text, FALSE,
            ( aType == Aspect_TOT_SOLID ) ? FALSE : TRUE
          );
 }  // end WNT_WDriver :: DrawText
@@ -833,7 +836,7 @@ void WNT_WDriver :: DrawPolyText (
 #endif
 /*====================== MFT ====================*/
     A -> Polytext (
-           P( Xpos ), P( Ypos ), anAngle, aMarge, aText, FALSE,
+           P( Xpos ), P( Ypos ), anAngle, aMarge, (Standard_Address)aText, FALSE,
            ( aType == Aspect_TOT_SOLID ) ? FALSE : TRUE
          );
 
@@ -1126,7 +1129,7 @@ void WNT_WDriver :: InitializeFontMap (  const Handle( Aspect_FontMap )& Fontmap
   Aspect_FontStyle           fontStyle;
   Handle( WNT_FontMapEntry ) fmEntry;
   Standard_Character         left[ 260 ], right[ 250 ];
-  Standard_CString           pSize;
+  Standard_PCharacter        pSize;
   Standard_Integer           height, mapSize = Fontmap -> Size ();
   HDC                        hdc = GetDC (  ( HWND )myWNTWindow -> HWindow ()  );
   HFONT                      hfo = SelectFont(  hdc, GetStockObject ( DEFAULT_GUI_FONT )  );
@@ -1891,7 +1894,7 @@ if( !aText || (strlen(aText) <= 0) ) {
          aFontIndex < 0 ? A -> myTextFont : ( HFONT )myFonts -> Value ( aFontIndex ) -> HFont ()
         );
 
-   xo      = A -> TextSize      ( hdc, aText, &sz );
+   xo      = A -> TextSize      ( hdc, (Standard_PCharacter)aText, &sz );
    aWidth  = Standard_ShortReal ( U( sz.cx ) );
    aHeight = Standard_ShortReal ( U( sz.cy ) );
 
