@@ -6,6 +6,9 @@
 //                new method SetBackground(CString aName)
 // Copyright:   Matra Datavision 1998
 
+// include windows.h first to have all definitions available
+#include <windows.h>
+
 #define TEST    //GG_021297
 //              Protects window position when center is wrong
 
@@ -60,74 +63,75 @@ WNT_Window :: WNT_Window (
                const Quantity_Parameter           aWidth,
                const Quantity_Parameter           aHeight,
                const Quantity_NameOfColor         aBackColor,
-               const Aspect_Handle&               aParent,
-               const Aspect_Handle&               aMenu,
+               const Aspect_Handle                aParent,
+               const Aspect_Handle                aMenu,
                const Standard_Address             aClientStruct
-                  ) : Aspect_Window ( aDevice ), myWClass ( aClass ) {
-
- int   x, y, w, h, px, py, pw, ph;
- DWORD dwStyle = aStyle;
- const Handle( WNT_GraphicDevice )& dev = Handle( WNT_GraphicDevice ) ::
+                  ) : Aspect_Window ( aDevice ), myWClass ( aClass )
+{
+  int   x, y, w, h, px, py, pw, ph;
+  DWORD dwStyle = aStyle;
+  const Handle( WNT_GraphicDevice )& dev = Handle( WNT_GraphicDevice ) ::
                                            DownCast ( MyGraphicDevice );
 
- if ( Xc < 0. || Xc > 1. || Yc < 0. || Yc > 1. || aWidth <= 0. || aHeight <= 0. )
+  if ( Xc < 0. || Xc > 1. || Yc < 0. || Yc > 1. ||
+       aWidth <= 0. || aHeight <= 0. )
 
   Aspect_WindowDefinitionError :: Raise ( "Coordinate(s) out of range" );
 
- ZeroMemory (  &myExtraData, sizeof ( WNT_WindowData )  );
+  ZeroMemory (  &myExtraData, sizeof ( WNT_WindowData )  );
 
- if ( aParent ) {
+  if ( aParent ) {
 
-  RECT r;
-  GetClientRect (  ( HWND )aParent, &r  );
-  pw = r.right;
-  ph = r.bottom;  
+    RECT r;
+    GetClientRect (  ( HWND )aParent, &r  );
+    pw = r.right;
+    ph = r.bottom;  
 
- } else
+  } else
 
-  dev -> DisplaySize ( pw, ph );
+    dev -> DisplaySize ( pw, ph );
 
- w  = ( int )(  aWidth  * Min ( pw, ph )  );
- h  = ( int )(  aHeight * Min ( pw, ph )  ); 
+  w  = ( int )(  aWidth  * Min ( pw, ph )  );
+  h  = ( int )(  aHeight * Min ( pw, ph )  ); 
 
 #ifdef TEST
- if( Xc > 0. ) px = ( int )(  Xc * ( Quantity_Parameter )pw  );
- else px = w/2;
- if( Yc > 0. ) py = ( int )(  ( 1. - Yc ) * ( Quantity_Parameter )ph );
- else py = h/2;
+  if( Xc > 0. ) px = ( int )(  Xc * ( Quantity_Parameter )pw  );
+  else px = w/2;
+  if( Yc > 0. ) py = ( int )(  ( 1. - Yc ) * ( Quantity_Parameter )ph );
+  else py = h/2;
 #else
- px = ( int )(  Xc * ( Quantity_Parameter )pw  );
- py = ( int )(  ( 1. - Yc ) * ( Quantity_Parameter )ph );
+  px = ( int )(  Xc * ( Quantity_Parameter )pw  );
+  py = ( int )(  ( 1. - Yc ) * ( Quantity_Parameter )ph );
 #endif
 
- if ( px - w / 2 < 0 )
+  if ( px - w / 2 < 0 )
 
-  w = ( int )( 2 * px );
+    w = ( int )( 2 * px );
 
- if ( px + w / 2 > pw )
+  if ( px + w / 2 > pw )
 
-  w = ( int )(  2 * ( pw - px )  );
+    w = ( int )(  2 * ( pw - px )  );
 
- if ( py - h / 2 < 0 )
+  if ( py - h / 2 < 0 )
 
-  h = ( int )( 2 * py );
+    h = ( int )( 2 * py );
 
- if ( py + h / 2 > ph )
+  if ( py + h / 2 > ph )
 
-  h = ( int )(  2 * ( ph - py )  );
+    h = ( int )(  2 * ( ph - py )  );
 
- x = ( int )( px - w / 2 );
- y = ( int )( py - h / 2 ); 
+  x = ( int )( px - w / 2 );
+  y = ( int )( py - h / 2 ); 
 
- if (  aParent && !( aStyle & WS_CHILD )  )
+  if (  aParent && !( aStyle & WS_CHILD )  )
 
-  dwStyle |= WS_CHILD | WS_CLIPSIBLINGS;
+    dwStyle |= WS_CHILD | WS_CLIPSIBLINGS;
 
- else if (  !aParent && !( aStyle & WS_CLIPCHILDREN )  )
+  else if (  !aParent && !( aStyle & WS_CLIPCHILDREN )  )
 
-  dwStyle |= WS_CLIPCHILDREN;
+    dwStyle |= WS_CLIPCHILDREN;
 
- myHWindow = CreateWindow (
+  myHWindow = CreateWindow (
               myWClass -> Name (),                    // window's class name
               aTitle,                                 // window's name
               dwStyle,                                // window's style
@@ -138,40 +142,40 @@ WNT_Window :: WNT_Window (
               aClientStruct                           // pointer to
              );                                       //   CLIENTCREATESTRUCT
 
- if ( !myHWindow )
+  if ( !myHWindow )
 
-  Aspect_WindowDefinitionError :: Raise ( "Unable to create window" );
+    Aspect_WindowDefinitionError :: Raise ( "Unable to create window" );
 
- myDoubleBuffer  = Standard_False;               
- myHPixmap       = 0;
- myHParentWindow = aParent;
- myWndProc       = myWClass -> WndProc ();
- myHParentWindow = aParent;
+  myDoubleBuffer  = Standard_False;               
+  myHPixmap       = 0;
+  myHParentWindow = aParent;
+  myWndProc       = myWClass -> WndProc ();
+  myHParentWindow = aParent;
 
- SetBackground ( aBackColor );
+  SetBackground ( aBackColor );
 #ifndef _WIN64
- SetWindowLong (  ( HWND )myHWindow, GWL_WNDPROC,  ( LONG )WNT_WndProc   );
+  SetWindowLong (  ( HWND )myHWindow, GWL_WNDPROC,  ( LONG )WNT_WndProc   );
 #else
- SetWindowLong (  ( HWND )myHWindow, GWLP_WNDPROC,  ( LONG )WNT_WndProc   );
+  SetWindowLong (  ( HWND )myHWindow, GWLP_WNDPROC,  ( LONG )WNT_WndProc   );
 #endif
- myUsrData = ( Standard_Integer )SetWindowLong (  
+  myUsrData = ( Standard_Integer )SetWindowLong (  
 #ifndef _WIN64
-                                  ( HWND )myHWindow, GWL_USERDATA, ( LONG )&myExtraData
+                        ( HWND )myHWindow, GWL_USERDATA, ( LONG )&myExtraData
 #else
-                                  ( HWND )myHWindow, GWLP_USERDATA, ( LONG )&myExtraData
+                        ( HWND )myHWindow, GWLP_USERDATA, ( LONG )&myExtraData
 #endif
                                  );
 
- aXLeft   = x;
- aYTop    = y;
- aXRight  = x + w;
- aYBottom = y + h;
+  aXLeft   = x;
+  aYTop    = y;
+  aXRight  = x + w;
+  aYBottom = y + h;
 
- myExtraData.WNT_Window_Ptr  = ( void* )this;
- myExtraData.hPal            = ( HPALETTE )dev -> HPalette ();
+  myExtraData.WNT_Window_Ptr  = ( void* )this;
+  myExtraData.hPal            = ( HPALETTE )dev -> HPalette ();
 
- myImages = new WNT_ImageManager ( this );
- myFormat = WNT_TOI_XWD;
+  myImages = new WNT_ImageManager ( this );
+  myFormat = WNT_TOI_XWD;
 
 }  // end constructor
 //***//
@@ -179,7 +183,7 @@ WNT_Window :: WNT_Window (
 //***//
 WNT_Window :: WNT_Window (
                const Handle( WNT_GraphicDevice )& aDevice,
-               const Aspect_Handle&               aHandle,
+               const Aspect_Handle                aHandle,
                const Quantity_NameOfColor         aBackColor
               ) : Aspect_Window ( aDevice ) {
 
@@ -262,7 +266,7 @@ void WNT_Window :: SetBackground ( const Quantity_NameOfColor BackColor ) {
 //***//
 //************************ SetBackground (3) *****************************//
 //***//
-void WNT_Window :: SetBackground ( const Aspect_Handle& aBackPixmap ) {
+void WNT_Window :: SetBackground ( const Aspect_Handle aBackPixmap ) {
 
  Aspect_Handle bitmap = CreatePatternBrush (  ( HBITMAP )aBackPixmap  );
 
@@ -289,7 +293,7 @@ Standard_Boolean WNT_Window::SetBackground( const Standard_CString aName,
    DeleteObject( MyHBackground );
  MyHBackground = 0;
 
- HBITMAP hBmp = LoadImageFromFile( gdev, aName );
+ HBITMAP hBmp = LoadImageFromFile( gdev, (Standard_PCharacter)aName );
 
  if( hBmp ) {
    status = Standard_True;
@@ -317,7 +321,7 @@ void WNT_Window::SetBackground( const Quantity_Color& color ) {
 }  // end WNT_Window :: SetBackground
 //**************************** SetCursor *********************************//
 //***//
-void WNT_Window :: SetCursor ( const Aspect_Handle& aCursor ) const {
+void WNT_Window :: SetCursor ( const Aspect_Handle aCursor ) const {
 
 #ifndef _WIN64
  SetClassLong (  ( HWND )myHWindow, GCL_HCURSOR, ( LONG )aCursor  );
@@ -330,7 +334,7 @@ void WNT_Window :: SetCursor ( const Aspect_Handle& aCursor ) const {
 //**************************** SetIcon ***********************************//
 //***//
 void WNT_Window :: SetIcon (
-                    const Aspect_Handle&   anIcon,
+                    const Aspect_Handle    anIcon,
                     const Standard_CString aName
                    ) {
 
@@ -1054,7 +1058,7 @@ void WNT_Window :: ResetFlags ( const Standard_Integer aFlags ) {
 //***//
 void WNT_Window :: doCreate (
                     const Handle( WNT_GraphicDevice )& aDevice,
-                    const Aspect_Handle&               aHandle,
+                    const Aspect_Handle                aHandle,
                     const Quantity_NameOfColor         aBackColor
                    ) {
 
