@@ -12,6 +12,15 @@
 #endif
 
 #ifdef WNT
+
+#ifdef CreateFile
+# undef CreateFile
+#endif 
+
+#ifdef CreateDirectory
+# undef CreateDirectory
+#endif
+
 #  include <WOKNT_Path.hxx>
 #  define  WOKUtils_Path WOKNT_Path 
 #else
