@@ -87,7 +87,7 @@
 //function : newDoc
 //purpose  :
 //=======================================================================
-static Standard_Integer newDoc (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer newDoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 2) {di<<"Give document name"<<"\n";return 1;}
 
@@ -115,7 +115,7 @@ static Standard_Integer newDoc (Draw_Interpretor& di, Standard_Integer argc, cha
 //function : saveDoc
 //purpose  :
 //=======================================================================
-static Standard_Integer saveDoc (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer saveDoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   Handle(TDocStd_Document) D;
   Handle(TDocStd_Application) A;
@@ -147,7 +147,7 @@ static Standard_Integer saveDoc (Draw_Interpretor& di, Standard_Integer argc, ch
 //function : dump
 //purpose  :
 //=======================================================================
-static Standard_Integer dump (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer dump (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<2) {
     di<<"Use: "<<argv[0]<<" Doc [int deep (0/1)]"<<"\n";
@@ -267,7 +267,7 @@ static void StatAssembly(const TDF_Label L,
 //function : statdoc
 //purpose  : 
 //=======================================================================
-static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<2) {
     di<<"Use: "<<argv[0]<<" Doc "<<"\n";
@@ -351,7 +351,7 @@ static Standard_Integer statdoc (Draw_Interpretor& di, Standard_Integer argc, ch
 //function : setPrs
 //purpose  :
 //=======================================================================
-static Standard_Integer setPrs (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer setPrs (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
     di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] "<<"\n";
@@ -402,7 +402,7 @@ static Standard_Integer setPrs (Draw_Interpretor& di, Standard_Integer argc, cha
 //function : show
 //purpose  :
 //=======================================================================
-static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
     di<<"Use: "<<argv[0]<<" DocName [label1 label2 ...] "<<"\n";
@@ -475,7 +475,7 @@ static Standard_Integer show (Draw_Interpretor& di, Standard_Integer argc, char*
 //function : xwd
 //purpose  :
 //=======================================================================
-static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <3) {
     di<<"Use: "<<argv[0]<<" DocName filename.{xwd|gif|bmp}"<<"\n";
@@ -510,7 +510,7 @@ static Standard_Integer xwd (Draw_Interpretor& di, Standard_Integer argc, char**
 //function : XAttributeValue
 //purpose  :
 //=======================================================================
-static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if ( argc <4 ) { di << "ERROR: Too few args" << "\n"; return 0; }
   Handle(DDF_Browser) browser =
@@ -705,7 +705,7 @@ static Standard_Integer XAttributeValue (Draw_Interpretor& di, Standard_Integer
 //function : setviewName
 //purpose  :
 //=======================================================================
-static Standard_Integer setviewName (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer setviewName (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
     di<<"Use: "<<argv[0]<<" (1/0)"<<"\n";
@@ -723,7 +723,7 @@ static Standard_Integer setviewName (Draw_Interpretor& di, Standard_Integer argc
 //purpose  : auxilary
 //=======================================================================
 
-static Standard_Integer getviewName (Draw_Interpretor&  di, Standard_Integer /*argc*/, char** /*argv*/)
+static Standard_Integer getviewName (Draw_Interpretor&  di, Standard_Integer /*argc*/, const char** /*argv*/)
 {
   if ( XCAFPrs::GetViewNameMode() ) di << "Display names ON"<< "\n";
   else di << "Display names OFF"<< "\n";
