@@ -189,7 +189,7 @@ static Standard_Real CalculVolume(const TopoDS_Shape& So,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer SetProps (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer SetProps (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc < 3) {
     di<<"Use: "<<argv[0]<<" DocName {Shape|Label} [epsilon = 0.001]"<<"\n";
@@ -251,7 +251,7 @@ static Standard_Integer SetProps (Draw_Interpretor& di, Standard_Integer argc, c
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer SetVolume (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer SetVolume (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=4) {
     di<<"Use: "<<argv[0]<<" DocName {Label|Shape} volume"<<"\n";
@@ -289,7 +289,7 @@ static Standard_Integer SetVolume (Draw_Interpretor& di, Standard_Integer argc,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer SetArea (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer SetArea (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=4) {
     di<<"Use: "<<argv[0]<<" DocName {Label|Shape} area"<<"\n";
@@ -326,7 +326,7 @@ static Standard_Integer SetArea (Draw_Interpretor& di, Standard_Integer argc, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer SetCentroid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer SetCentroid (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=6) {
     di<<"Use: "<<argv[0]<<" DocName {Label|Shape} x y z"<<"\n";
@@ -365,7 +365,7 @@ static Standard_Integer SetCentroid (Draw_Interpretor& di, Standard_Integer argc
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer GetVolume (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer GetVolume (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=3) {
     di<<"Use: "<<argv[0]<<" DocName {Shape|Label}"<<"\n";
@@ -401,7 +401,7 @@ static Standard_Integer GetVolume (Draw_Interpretor& di, Standard_Integer argc,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer GetArea (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer GetArea (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=3) {
     di<<"Use: "<<argv[0]<<" DocName {Shape|Label}"<<"\n";
@@ -437,7 +437,7 @@ static Standard_Integer GetArea (Draw_Interpretor& di, Standard_Integer argc, ch
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer GetCentroid (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer GetCentroid (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=3) {
     di<<"Use: "<<argv[0]<<" DocName {Shape|Label} "<<"\n";
@@ -488,7 +488,7 @@ static inline Standard_Real doround (Standard_Real val, Standard_Real low)
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer CheckProps (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer CheckProps (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc <2) {
     di << "Use: "<<argv[0]<<" DocName [ 0|deflection [Shape|Label] ]"<<"\n";
@@ -704,7 +704,7 @@ static Standard_Integer CheckProps (Draw_Interpretor& di, Standard_Integer argc,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer ShapeVolume (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer ShapeVolume (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc!=3) {
     di<<"Use: "<<argv[0]<<" Shape deflection "<<"\n";
@@ -820,7 +820,7 @@ static Standard_Boolean GetMassProps(const TDF_Label& aLabel, gp_XYZ& theCenterG
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer ShapeMassProps (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer ShapeMassProps (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   
   if (argc <2) {
@@ -890,7 +890,7 @@ static Standard_Integer ShapeMassProps (Draw_Interpretor& di, Standard_Integer a
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer SetMaterial (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer SetMaterial (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<5) {
     di<<"Use: "<<argv[0]<<" Doc {Label|Shape} name density(g/cu sm) "<<"\n";
