@@ -425,7 +425,8 @@ void XSAlgo_AlgoContainer::MergeTransferInfo(const Handle(Transfer_TransientProc
 	const Message_ListOfMsg &msglist = msgmap.Find (orig);
 	for (Message_ListIteratorOfListOfMsg iter (msglist); iter.More(); iter.Next()) {
 	  const Message_Msg& mess = iter.Value();
-	  sb->AddWarning (mess.Value(), mess.Original());
+	  sb->AddWarning (TCollection_AsciiString(mess.Value()).ToCString(),
+                          TCollection_AsciiString(mess.Original()).ToCString());
 	}
       }
     }
@@ -501,7 +502,8 @@ void XSAlgo_AlgoContainer::MergeTransferInfo(const Handle(Transfer_FinderProcess
 	const Message_ListOfMsg &msglist = msgmap.Find (orig);
 	for (Message_ListIteratorOfListOfMsg iter (msglist); iter.More(); iter.Next()) {
 	  const Message_Msg& mess = iter.Value();
-	  resBinder->AddWarning (mess.Value(), mess.Original());
+	  resBinder->AddWarning (TCollection_AsciiString(mess.Value()).ToCString(),
+                                 TCollection_AsciiString(mess.Original()).ToCString());
 	}
       }
     }
