@@ -34,6 +34,7 @@
 #include <Interface_Static.hxx>
 #include <IFSelect_ParamEditor.hxx>
 #include <IFSelect_EditForm.hxx>
+#include <IFSelect_SelectModelRoots.hxx>
 
 //  Transferts
 #include <Transfer_Binder.hxx>
@@ -43,12 +44,9 @@
 
 #include <Standard_DomainError.hxx>
 #include <TCollection_HAsciiString.hxx>
-#include <Interface_DT.hxx>
 #include <Interface_Macros.hxx>
-#include <IFSelect_SelectModelRoots.hxx>
-#ifndef WNT 
-#define stricmp strcasecmp
-#endif 
+#include <Message_Messenger.hxx>
+#include <Message.hxx>
 
 static Handle(Dico_DictionaryOfTransient)& listadapt()
 {
@@ -515,12 +513,10 @@ static IFSelect_ReturnStatus TransferFinder
   for (i = 1; i <= nb; i ++) {
     Handle(Standard_Transient) anitem = theAdaptorApplied.Value(i);
     Handle(TCollection_HAsciiString) name = WS->Name(anitem);
-    if (IDT_Level > 2) {  // > 2 for debug only ( S3767 )
-      IDT_OutRef(sout);
-      sout<<" --  Customise applied n0."<<i<<" type:"<<anitem->DynamicType()->Name();
-      if (name.IsNull()) sout<<" no name"<<endl;
-      else sout<<" name:"<<name->ToCString()<<endl;
-    }
+//    Handle(Message_Messenger) sout = Message::DefaultMessenger();
+//    sout<<" --  Customise applied n0."<<i<<" type:"<<anitem->DynamicType()->Name();
+//    if (name.IsNull()) sout<<" no name"<<endl;
+//    else sout<<" name:"<<name->ToCString()<<endl;
     WS->SetAppliedModifier
       (GetCasted(IFSelect_GeneralModifier,theAdaptorApplied.Value(i)),
        WS->ShareOut() );
@@ -585,7 +581,7 @@ static IFSelect_ReturnStatus TransferFinder
   Handle(IFSelect_SelectModelRoots)    slr;
   slr = new IFSelect_SelectModelRoots;
   WS->AddNamedItem ("xst-model-roots",slr);
-  if(stricmp(WS->SelectedNorm(),"STEP")) {
+  if(strcasecmp(WS->SelectedNorm(),"STEP")) {
     Handle(XSControl_SelectForTransfer) st1 = new XSControl_SelectForTransfer;
     st1->SetInput (slr);
     st1->SetReader (WS->TransferReader());
