@@ -38,8 +38,8 @@
 #include <XSControl_SelectForTransfer.hxx>
 
 #include <Interface_Macros.hxx>
-
-
+#include <Message_Messenger.hxx>
+#include <Message.hxx>
 
 // #######################################################################
 // ##									##
@@ -60,7 +60,8 @@ static IFSelect_ReturnStatus XSControl_xinit(const Handle(IFSelect_SessionPilot)
   //        ****    xinit        ****
   if (argc > 1) return (XSControl::Session(pilot)->SelectNorm(arg1) ?
 			IFSelect_RetDone : IFSelect_RetFail);
-  cout<<"Selected Norm:"<<XSControl::Session(pilot)->SelectedNorm()<<endl;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  sout<<"Selected Norm:"<<XSControl::Session(pilot)->SelectedNorm()<<endl;
   return IFSelect_RetVoid;
 }
 
@@ -75,48 +76,49 @@ static IFSelect_ReturnStatus XSControl_xnorm(const Handle(IFSelect_SessionPilot)
   //        ****    xnorm        ****
   Handle(XSControl_WorkSession) WS = XSControl::Session(pilot);
   Handle(XSControl_Controller) control = WS->NormAdaptor();
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   if (argc == 1)
-    cout<<"Current Norm. xnorm newnorm [profile] to change , xnorm ? for the list"<<endl;
-  else cout<<"Current Norm :"<<endl;
-  if (control.IsNull()) cout<<"no norm currently defined"<<endl;
+    sout<<"Current Norm. xnorm newnorm [profile] to change , xnorm ? for the list"<<endl;
+  else sout<<"Current Norm :"<<endl;
+  if (control.IsNull()) sout<<"no norm currently defined"<<endl;
   else
-    cout<<"  Long  Name (complete) : "<<control->Name(Standard_False)<<endl
+    sout<<"  Long  Name (complete) : "<<control->Name(Standard_False)<<endl
       <<  "  Short name (resource) : "<<control->Name(Standard_True)<<endl;
   if (argc == 1) return IFSelect_RetVoid;
 
   if (arg1[0] == '?') {
-    cout<<"List of available norms"<<endl;
+    sout<<"List of available norms"<<endl;
     Standard_Integer i,nb;
     Handle(TColStd_HSequenceOfHAsciiString) norms = XSControl_Controller::ListRecorded(-1);
     nb = norms->Length();
-    cout<<"Short Proper Names (complete names) : "<<nb<<" :";
-    for (i = 1; i <= nb; i ++) cout<<"  "<<norms->Value(i)->ToCString();
-    cout<<endl;
+    sout<<"Short Proper Names (complete names) : "<<nb<<" :";
+    for (i = 1; i <= nb; i ++) sout<<"  "<<norms->Value(i)->ToCString();
+    sout<<endl;
     norms = XSControl_Controller::ListRecorded(1);
     nb = norms->Length();
-    cout<<"Long  Proper Names (resource names) : "<<nb<<" :";
-    for (i = 1; i <= nb; i ++) cout<<"  "<<norms->Value(i)->ToCString();
-    cout<<endl;
+    sout<<"Long  Proper Names (resource names) : "<<nb<<" :";
+    for (i = 1; i <= nb; i ++) sout<<"  "<<norms->Value(i)->ToCString();
+    sout<<endl;
     norms = XSControl_Controller::ListRecorded(0);
     nb = norms->Length();
-    cout<<"All Norm Names (short, long and aliases) "<<nb<<" :";
-    for (i = 1; i <= nb; i ++) cout<<"  "<<norms->Value(i)->ToCString();
-    cout<<endl;
-    cout<<"To change, xnorm newnorm"<<endl;
+    sout<<"All Norm Names (short, long and aliases) "<<nb<<" :";
+    for (i = 1; i <= nb; i ++) sout<<"  "<<norms->Value(i)->ToCString();
+    sout<<endl;
+    sout<<"To change, xnorm newnorm"<<endl;
     return IFSelect_RetVoid;
   }
 
   control = XSControl_Controller::Recorded(arg1);
-  if (control.IsNull()) { cout<<" No norm named : "<<arg1<<endl; return IFSelect_RetError; }
+  if (control.IsNull()) { sout<<" No norm named : "<<arg1<<endl; return IFSelect_RetError; }
   else {
     WS->SetController(control);
-    cout<<"new norm : "<<control->Name()<<endl;
+    sout<<"new norm : "<<control->Name()<<endl;
     if (argc > 2) {
       const Standard_CString arg2 = pilot->Arg(2);
       if (!control->Profile()->SetCurrent (arg2)) 
-	cout<<"profile could not be set to "<<arg2<<endl;
+	sout<<"profile could not be set to "<<arg2<<endl;
     }
-    cout<<"current profile : "<<control->Profile()->Current()<<endl;
+    sout<<"current profile : "<<control->Profile()->Current()<<endl;
 
     IFSelect_Activator::SetCurrentAlias (WS->SelectedNorm(Standard_True));
     return IFSelect_RetDone;
@@ -137,10 +139,11 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
   Handle(XSControl_Controller) control = WS->NormAdaptor();
   if (control.IsNull()) return IFSelect_RetFail;
   Handle(IFSelect_Profile) prof = control->Profile();
-  cout<<"Current Profile : "<<prof->Current().ToCString()<<endl;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  sout<<"Current Profile : "<<prof->Current().ToCString()<<endl;
 
   if (argc < 2) {
-    cout<<"xprofile ?   for list of profile confs"<<endl
+    sout<<"xprofile ?   for list of profile confs"<<endl
       <<  "xprofile .   to apply the current profile (after editing)"<<endl
       <<  "xprofile profname     to select one and apply it"<<endl
       <<  "xprofile profname .   to record current profile as profname"<<endl
@@ -156,12 +159,12 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
     if (arg1[0] == '?') {
       Handle(TColStd_HSequenceOfAsciiString) confs = prof->ConfList();
       Standard_Integer i, nb = confs->Length();
-      cout<<"List of Available Profile Configurations : "<<nb<<" Items"<<endl;
-      for (i = 1; i <= nb; i ++) cout<<confs->Value(i).ToCString()<<endl;
+      sout<<"List of Available Profile Configurations : "<<nb<<" Items"<<endl;
+      for (i = 1; i <= nb; i ++) sout<<confs->Value(i).ToCString()<<endl;
       return IFSelect_RetVoid;
     } else if (arg1[0] == '.' && arg1[1] == '\0') {
       if (!control->ApplyProfile(WS,".")) {
-	cout<<"Applying current profile has failed"<<endl;
+	sout<<"Applying current profile has failed"<<endl;
 	return IFSelect_RetFail;
       }
       return IFSelect_RetDone;
@@ -169,10 +172,10 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
 
       //   Select a Profile
       if (!control->ApplyProfile(WS,arg1)) {
-	cout<<"Setting "<<arg1<<" as current has failed"<<endl;
+	sout<<"Setting "<<arg1<<" as current has failed"<<endl;
 	return IFSelect_RetFail;
       }
-      cout<<"Setting "<<arg1<<" as current"<<endl;
+      sout<<"Setting "<<arg1<<" as current"<<endl;
       return IFSelect_RetDone;
     }
   }
@@ -185,16 +188,16 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
       Handle(TColStd_HSequenceOfAsciiString) opts, cases;
       prof->SwitchList (arg1,opts,cases);
       Standard_Integer i,nb = opts->Length();
-      cout<<"Option  --  Case  --  ("<<nb<<" switches on configuration "<<arg1<<")"<<endl;
+      sout<<"Option  --  Case  --  ("<<nb<<" switches on configuration "<<arg1<<")"<<endl;
       for (i = 1; i <= nb; i ++) {
-	cout<<opts->Value(i).ToCString()<<"	"<<cases->Value(i).ToCString()<<endl;
+	sout<<opts->Value(i).ToCString()<<"	"<<cases->Value(i).ToCString()<<endl;
       }
       return IFSelect_RetVoid;
 
       //   Clear a profile
     } else if (arg2[0] == '-' && arg2[1] == '\0') {
       if (!prof->ClearConf(arg1)) {
-	cout<<"Clearing profile "<<arg2<<" has failed"<<endl;
+	sout<<"Clearing profile "<<arg2<<" has failed"<<endl;
 	return IFSelect_RetFail;
       }
       return IFSelect_RetDone;
@@ -203,7 +206,7 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
     } else {
       if (!prof->HasConf (arg1)) prof->AddConf (arg1);
       if (!prof->AddFromOtherConf (arg1,arg2)) {
-	cout<<"Merging profile "<<arg2<<" to "<<arg1<<" has failed"<<endl;
+	sout<<"Merging profile "<<arg2<<" to "<<arg1<<" has failed"<<endl;
 	return IFSelect_RetFail;
       }
       return IFSelect_RetDone;
@@ -218,19 +221,19 @@ static IFSelect_ReturnStatus XSControl_xprofile(const Handle(IFSelect_SessionPil
     //    Removing a switch
     if (arg2[0] == '-' && arg2[1] == '\0') {
       if (!prof->RemoveSwitch (arg1,arg3)) {
-	cout<<"Removing switch on option "<<arg3<<" in profile "<<arg1<<" has failed"<<endl;
+	sout<<"Removing switch on option "<<arg3<<" in profile "<<arg1<<" has failed"<<endl;
 	return IFSelect_RetFail;
       }
-      cout<<"Edition of profile "<<arg1<<" done. To apply it : xprofile "<<arg1<<endl;
+      sout<<"Edition of profile "<<arg1<<" done. To apply it : xprofile "<<arg1<<endl;
       return IFSelect_RetDone;
 
       //    Setting a switch
     } else {
       if (!prof->AddSwitch (arg1,arg2,arg3)) {
-	cout<<"Setting profile "<<arg1<<" for option "<<arg2<<" to case "<<arg3<<" has failed"<<endl;
+	sout<<"Setting profile "<<arg1<<" for option "<<arg2<<" to case "<<arg3<<" has failed"<<endl;
 	return IFSelect_RetFail;
       }
-      cout<<"Edition of profile "<<arg1<<" done. To apply it : xprofile "<<arg1<<endl;
+      sout<<"Edition of profile "<<arg1<<" done. To apply it : xprofile "<<arg1<<endl;
       return IFSelect_RetDone;
     }
   }
@@ -253,10 +256,11 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
   Handle(XSControl_Controller) control = WS->NormAdaptor();
   if (control.IsNull()) return IFSelect_RetFail;
   Handle(IFSelect_Profile) prof = control->Profile();
-  cout<<"Current Profile : "<<prof->Current().ToCString()<<endl;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  sout<<"Current Profile : "<<prof->Current().ToCString()<<endl;
 
   if (argc < 2) {
-    cout<<"xoption anopt  : query an option"<<endl
+    sout<<"xoption anopt  : query an option"<<endl
       <<  "xoption anopt newcase  : switch (basic definition)"
 	<<"  (but is superseded by current configuration)"<<endl
 	<<"xoption + optname [param]  : create an option on a parameter"<<endl
@@ -266,11 +270,11 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
 
     Handle(TColStd_HSequenceOfAsciiString) optlist = prof->OptionList();
     Standard_Integer iopt, nbopt = optlist->Length();
-    cout<<"Total : "<<nbopt<<" Options"<<endl;
+    sout<<"Total : "<<nbopt<<" Options"<<endl;
     for (iopt = 1; iopt <= nbopt; iopt ++) {
       TCollection_AsciiString optname = optlist->Value(iopt);
       Handle(IFSelect_Option) opt = prof->Option (optname.ToCString());
-      cout<<optname.ToCString()<<" : "<<opt->CaseName()<<endl;
+      sout<<optname.ToCString()<<" : "<<opt->CaseName()<<endl;
     }
     return IFSelect_RetVoid;
   }
@@ -279,33 +283,33 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
 
   if (argc == 2) {
     Handle(IFSelect_Option) opt = prof->Option (arg1);
-    if (opt.IsNull()) { cout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
+    if (opt.IsNull()) { sout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
 
     //  On va lister les valeurs admises
     Handle(TColStd_HSequenceOfAsciiString) caselist = opt->ItemList();
     Standard_Integer icase, nbcase = caselist->Length();
     Handle(MoniTool_TypedValue) tv = opt->TypedValue();
-    if (tv.IsNull()) cout<<"Option : "<<arg1<<"  Type : "<<opt->Type()->Name();
-    else cout<<"Option : "<<arg1<<"  TypedValue.  Name : "<<tv->Name()<<endl<<"  Definition : "<<tv->Definition();
+    if (tv.IsNull()) sout<<"Option : "<<arg1<<"  Type : "<<opt->Type()->Name();
+    else sout<<"Option : "<<arg1<<"  TypedValue.  Name : "<<tv->Name()<<endl<<"  Definition : "<<tv->Definition();
 
-    cout<<endl<<"  Current Case (basic) : "<<opt->CaseName()<<"  Total : "<<nbcase<<" Cases :"<<endl;
+    sout<<endl<<"  Current Case (basic) : "<<opt->CaseName()<<"  Total : "<<nbcase<<" Cases :"<<endl;
     for (icase = 1; icase <= nbcase; icase ++) {
       const TCollection_AsciiString& acase = caselist->Value(icase);
-      cout<<acase.ToCString();
+      sout<<acase.ToCString();
 
       //  Aliases ?
       Handle(TColStd_HSequenceOfAsciiString) aliases = opt->Aliases(acase.ToCString());
       Standard_Integer ial, nbal = (aliases.IsNull() ? 0 : aliases->Length());
-      if (nbal > 0) cout<<"  -  Alias:";
-      for (ial = 1; ial <= nbal; ial ++)  cout<<"  "<<aliases->Value(ial);
+      if (nbal > 0) sout<<"  -  Alias:";
+      for (ial = 1; ial <= nbal; ial ++)  sout<<"  "<<aliases->Value(ial);
       if (!tv.IsNull()) {
         //  TypedValue : on peut afficher la valeur
 	Handle(TCollection_HAsciiString) str;
 	opt->Item (acase.ToCString(),str);
-	if (!str.IsNull()) cout<<" - Value:"<<str->ToCString();
+	if (!str.IsNull()) sout<<" - Value:"<<str->ToCString();
       }
 
-      cout<<endl;
+      sout<<endl;
     }
     return IFSelect_RetVoid;
   }
@@ -314,7 +318,7 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
   if (argc >= 3 && arg1[0] == '+' && arg1[1] == '\0') {
     Standard_CString parname = pilot->Arg(argc-1);
     Handle(Interface_Static) param = Interface_Static::Static(parname);
-    if (param.IsNull()) { cout<<"No static parameter is named "<<parname<<endl;
+    if (param.IsNull()) { sout<<"No static parameter is named "<<parname<<endl;
 			  return IFSelect_RetError; }
     Handle(IFSelect_Option) opt = new IFSelect_Option(param,arg2);
     prof->AddOption (opt);
@@ -324,12 +328,12 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
   //  xoption optname + case [val]
   if (argc >= 4 && arg2[0] == '+' && arg2[1] == '\0') {
     Handle(IFSelect_Option) opt = prof->Option (arg1);
-    if (opt.IsNull()) { cout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
+    if (opt.IsNull()) { sout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
     Handle(MoniTool_TypedValue) tv = opt->TypedValue();
-    if (tv.IsNull()) { cout<<"Option not for a Parameter : "<<arg1<<endl; return IFSelect_RetError; }
+    if (tv.IsNull()) { sout<<"Option not for a Parameter : "<<arg1<<endl; return IFSelect_RetError; }
     Standard_CString valname = pilot->Arg(argc-1);
     if (!opt->AddBasic (arg3,valname)) {
-      cout<<"Option "<<arg1<<" : not an allowed value : "<<valname<<endl;
+      sout<<"Option "<<arg1<<" : not an allowed value : "<<valname<<endl;
       return IFSelect_RetError;
     }
     return IFSelect_RetDone;
@@ -338,12 +342,12 @@ static IFSelect_ReturnStatus XSControl_xoption(const Handle(IFSelect_SessionPilo
   //  xoption optname newcase : edition
   if (argc == 3) {
     Handle(IFSelect_Option) opt = prof->Option (arg1);
-    if (opt.IsNull()) { cout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
+    if (opt.IsNull()) { sout<<"Not a recorded Option : "<<arg1<<endl; return IFSelect_RetError; }
     if (!opt->Switch (arg2)) {
-      cout<<"Option : "<<arg1<<" , Not a suitable case : "<<arg2<<endl;
+      sout<<"Option : "<<arg1<<" , Not a suitable case : "<<arg2<<endl;
       return IFSelect_RetFail;
     }
-    cout<<"Option : "<<arg1<<" switched to case : "<<arg2<<endl;
+    sout<<"Option : "<<arg1<<" switched to case : "<<arg2<<endl;
     return IFSelect_RetDone;
   }
 
@@ -359,7 +363,8 @@ static IFSelect_ReturnStatus XSControl_newmodel(const Handle(IFSelect_SessionPil
 {
   //        ****    newmodel        ****
   if (!XSControl::Session(pilot)->NewModel().IsNull()) return IFSelect_RetDone;
-  cout<<"No new Model produced"<<endl;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  sout<<"No new Model produced"<<endl;
   return IFSelect_RetFail;
 }
 
@@ -374,8 +379,9 @@ static IFSelect_ReturnStatus XSControl_tpclear(const Handle(IFSelect_SessionPilo
   if (pilot->Word(0).Value(2) == 'w') modew = Standard_True;
   Handle(Transfer_FinderProcess)    FP = XSControl::Session(pilot)->MapWriter();
   Handle(Transfer_TransientProcess) TP = XSControl::Session(pilot)->MapReader();
-  if ( modew) { if(!FP.IsNull()) FP->Clear(); else cout<<"No Transfer Write"<<endl; }
-  else        { if(!TP.IsNull()) TP->Clear(); else cout<<"No Transfer Read"<<endl; }
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  if ( modew) { if(!FP.IsNull()) FP->Clear(); else sout<<"No Transfer Write"<<endl; }
+  else        { if(!TP.IsNull()) TP->Clear(); else sout<<"No Transfer Read"<<endl; }
   return IFSelect_RetDone;
 }
 
@@ -389,7 +395,8 @@ static IFSelect_ReturnStatus XSControl_tpstat(const Handle(IFSelect_SessionPilot
   const Standard_CString arg1 = pilot->Arg(1);
   //const Standard_CString arg2 = pilot->Arg(2);
   Handle(Transfer_TransientProcess) TP= XSControl::Session(pilot)->MapReader();
-  if (TP.IsNull()) { cout<<"No Transfer Read"<<endl; return IFSelect_RetError;}
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  if (TP.IsNull()) { sout<<"No Transfer Read"<<endl; return IFSelect_RetError;}
   //        ****    tpstat        ****
 
   Standard_Integer mod1 = -1;
@@ -428,9 +435,9 @@ static IFSelect_ReturnStatus XSControl_tpstat(const Handle(IFSelect_SessionPilot
     }
   }
   //  A present help eventuel
-  if (mod1 < -1) cout<<"Unknown Mode"<<endl;
+  if (mod1 < -1) sout<<"Unknown Mode"<<endl;
   if (mod1 < 0) {
-    cout<<"Modes available :\n"
+    sout<<"Modes available :\n"
       <<"g : general    c : checks (count)  C (list)"<<"\n"
       <<"               f : fails  (count)  F (list)"<<"\n"
       <<"  n : numbers of transferred entities (on TRANSFER ROOTS)"<<"\n"
@@ -447,14 +454,14 @@ static IFSelect_ReturnStatus XSControl_tpstat(const Handle(IFSelect_SessionPilot
   }
 
   if (!TP.IsNull()) {
-    cout<<"TransferRead :";
-    if (TP->Model() != pilot->Session()->Model()) cout<<"Model differs from the session";
+    sout<<"TransferRead :";
+    if (TP->Model() != pilot->Session()->Model()) sout<<"Model differs from the session";
     Handle(TColStd_HSequenceOfTransient) list =
       IFSelect_Functions::GiveList(pilot->Session(),pilot->CommandPart(2));
     XSControl_TransferReader::PrintStatsOnList (TP,list,mod1,mod2);
-//    TP->PrintStats (1,cout);
+//    TP->PrintStats (1,sout);
   }
-  else cout<<"TransferRead : not defined"<<endl;
+  else sout<<"TransferRead : not defined"<<endl;
   return IFSelect_RetVoid;
 }
 
@@ -468,17 +475,18 @@ static IFSelect_ReturnStatus XSControl_tpent(const Handle(IFSelect_SessionPilot)
   const Standard_CString arg1 = pilot->Arg(1);
   Handle(Transfer_TransientProcess) TP= XSControl::Session(pilot)->MapReader();
   //        ****    tpent        ****
-  if (TP.IsNull()) { cout<<"No Transfer Read"<<endl; return IFSelect_RetError;}
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  if (TP.IsNull()) { sout<<"No Transfer Read"<<endl; return IFSelect_RetError;}
   Handle(Interface_InterfaceModel) model = TP->Model();
   if (model.IsNull())  return IFSelect_RetFail;
 
-  if (argc < 2) { cout<<"Give ENTITY NUMBER (IN MODEL TransferProcess)"<<endl; return IFSelect_RetError; }
+  if (argc < 2) { sout<<"Give ENTITY NUMBER (IN MODEL TransferProcess)"<<endl; return IFSelect_RetError; }
   Standard_Integer num = atoi(arg1);
-  if (num <= 0 || num > model->NbEntities()) { cout<<"Number not in [1 - "<<model->NbEntities()<<"]"<<endl; return IFSelect_RetError; }
+  if (num <= 0 || num > model->NbEntities()) { sout<<"Number not in [1 - "<<model->NbEntities()<<"]"<<endl; return IFSelect_RetError; }
   Handle(Standard_Transient) ent = model->Value(num);
   Standard_Integer index = TP->MapIndex  (ent);
-  if (index == 0) cout<<"Entity "<<num<<"  not recorded in transfer"<<endl;
-  else XSControl::Session(pilot)->PrintTransferStatus (index,Standard_False,cout);
+  if (index == 0) sout<<"Entity "<<num<<"  not recorded in transfer"<<endl;
+  else XSControl::Session(pilot)->PrintTransferStatus (index,Standard_False,sout);
   return IFSelect_RetVoid;
 }
 
@@ -491,7 +499,8 @@ static IFSelect_ReturnStatus XSControl_tpitem(const Handle(IFSelect_SessionPilot
   Standard_Integer argc = pilot->NbWords();
   const Standard_CString arg1 = pilot->Arg(1);
 //        ****    tpitem/tproot/twitem/twroot        ****
-  if (argc < 2) { cout<<"Give ITEM NUMBER (in TransferProcess)"<<endl; return IFSelect_RetError; }
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  if (argc < 2) { sout<<"Give ITEM NUMBER (in TransferProcess)"<<endl; return IFSelect_RetError; }
   Standard_Integer num = atoi(arg1);
   if (pilot->Word(0).Value(3) == 'r') num = -num;
   Standard_Boolean modew = Standard_False;
@@ -499,8 +508,8 @@ static IFSelect_ReturnStatus XSControl_tpitem(const Handle(IFSelect_SessionPilot
   Handle(Transfer_Binder) binder;
   Handle(Transfer_Finder) finder;
   Handle(Standard_Transient) ent;
-  if (!XSControl::Session(pilot)->PrintTransferStatus(num,modew,cout))
-    cout<<" - Num="<<num<<" incorrect"<<endl;
+  if (!XSControl::Session(pilot)->PrintTransferStatus(num,modew,sout))
+    sout<<" - Num="<<num<<" incorrect"<<endl;
   return IFSelect_RetVoid;
 }
 
@@ -508,14 +517,15 @@ static IFSelect_ReturnStatus XSControl_tpitem(const Handle(IFSelect_SessionPilot
 //=======================================================================
 //function : tpatr
 //=======================================================================
-static IFSelect_ReturnStatus XSControl_tpatr(const Handle(IFSelect_SessionPilot)& pilot)
+static IFSelect_ReturnStatus XSControl_tpatr(const Handle(IFSelect_SessionPilot)& /*pilot*/)
 {
+/*skl
   Standard_Integer argc = pilot->NbWords();
   const Standard_CString arg1 = pilot->Arg(1);
   Handle(XSControl_WorkSession) WS = XSControl::Session(pilot);
   Handle(Transfer_TransientProcess) TP = WS->MapReader();
 
-/*skl
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   //  tpatr tout court : liste tous les attributs
   //  tpatr nomatr     : sur cet attribut, liste les valeurs par entite
 
@@ -525,39 +535,39 @@ static IFSelect_ReturnStatus XSControl_tpatr(const Handle(IFSelect_SessionPilot)
       TCollection_AsciiString name = iter.Name();
       Standard_Integer nbatr = iter.Value();
       Interface_ParamType aty = TP->AttributeType (name.ToCString());
-      cout<<"Name : "<<name<<"  Count="<<nbatr<<"  Type : ";
+      sout<<"Name : "<<name<<"  Count="<<nbatr<<"  Type : ";
       switch (aty) {
-        case Interface_ParamInteger : cout<<"Integer";  break;
-        case Interface_ParamReal    : cout<<"Real";     break;
-        case Interface_ParamIdent   : cout<<"Object";   break;
-        case Interface_ParamText    : cout<<"String";   break;
-	default : cout<<"(Mixed)";
+        case Interface_ParamInteger : sout<<"Integer";  break;
+        case Interface_ParamReal    : sout<<"Real";     break;
+        case Interface_ParamIdent   : sout<<"Object";   break;
+        case Interface_ParamText    : sout<<"String";   break;
+	default : sout<<"(Mixed)";
       }
-      cout<<endl;
+      sout<<endl;
     }
   }
 
   else {
 
     Standard_Integer num , nb = 0;
-    cout<<"Attribute Name : "<<arg1<<endl;
+    sout<<"Attribute Name : "<<arg1<<endl;
     for (num = TP->NextItemWithAttribute(arg1,0);  num > 0;
 	 num = TP->NextItemWithAttribute(arg1,num)) {
       nb ++;
-      cout<<"Item "<<num<<" , Entity ";
-      WS->Model()->Print(TP->Mapped(num),cout);
+      sout<<"Item "<<num<<" , Entity ";
+      WS->Model()->Print(TP->Mapped(num),sout);
       Handle(Transfer_Binder) bnd = TP->MapItem (num);
       Interface_ParamType aty = bnd->AttributeType(arg1);
       switch (aty) {
-        case Interface_ParamInteger : cout<<"  Integer="<<bnd->IntegerAttribute(arg1); break;
-        case Interface_ParamReal    : cout<<"  Real="<<bnd->RealAttribute(arg1); break;
-        case Interface_ParamIdent   : cout<<"  Object,Type:"<<bnd->Attribute(arg1)->DynamicType()->Name(); break;
-        case Interface_ParamText    : cout<<"  String="<<bnd->StringAttribute(arg1);
-	default : cout<<"(none)"; break;
+        case Interface_ParamInteger : sout<<"  Integer="<<bnd->IntegerAttribute(arg1); break;
+        case Interface_ParamReal    : sout<<"  Real="<<bnd->RealAttribute(arg1); break;
+        case Interface_ParamIdent   : sout<<"  Object,Type:"<<bnd->Attribute(arg1)->DynamicType()->Name(); break;
+        case Interface_ParamText    : sout<<"  String="<<bnd->StringAttribute(arg1);
+	default : sout<<"(none)"; break;
       }
-      cout<<endl;
+      sout<<endl;
     }
-    cout<<"Attribute Name : "<<arg1<<" on "<<nb<<" Items"<<endl;
+    sout<<"Attribute Name : "<<arg1<<" on "<<nb<<" Items"<<endl;
   }
 skl*/
 
@@ -579,22 +589,23 @@ static IFSelect_ReturnStatus XSControl_trecord(const Handle(IFSelect_SessionPilo
   Handle(Interface_InterfaceModel)  mdl = XSControl::Session(pilot)->Model();
   Handle(XSControl_TransferReader)  TR  = XSControl::Session(pilot)->TransferReader();
   Handle(Standard_Transient) ent;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   if (mdl.IsNull() || TR.IsNull() || TP.IsNull())
-    { cout<<" init not done"<<endl; return IFSelect_RetError; }
+    { sout<<" init not done"<<endl; return IFSelect_RetError; }
   if (!tous) num = atoi(arg1);
   //    Enregistrer les racines
   if (tous) {
     Standard_Integer nb = TP->NbRoots();
-    cout<<" Recording "<<nb<<" Roots"<<endl;
+    sout<<" Recording "<<nb<<" Roots"<<endl;
     for (Standard_Integer i = 1; i <= nb; i ++) {
       ent = TP->Root(i);
-      if (TR->RecordResult (ent)) cout<<" Root n0."<<i<<endl;
-      else cout<<" Root n0."<<i<<" not recorded"<<endl;
+      if (TR->RecordResult (ent)) sout<<" Root n0."<<i<<endl;
+      else sout<<" Root n0."<<i<<" not recorded"<<endl;
     }
   } else {
-    if (num < 1 ||  num > mdl->NbEntities()) cout<<"incorrect number:"<<num<<endl;
-    else if (TR->RecordResult(mdl->Value(num))) cout<<" Entity n0."<<num<<endl;
-    else cout<<" Entity n0."<<num<<" not recorded"<<endl;
+    if (num < 1 ||  num > mdl->NbEntities()) sout<<"incorrect number:"<<num<<endl;
+    else if (TR->RecordResult(mdl->Value(num))) sout<<" Entity n0."<<num<<endl;
+    else sout<<" Entity n0."<<num<<" not recorded"<<endl;
   }
   return IFSelect_RetDone;
 }
@@ -607,28 +618,29 @@ static IFSelect_ReturnStatus XSControl_trstat(const Handle(IFSelect_SessionPilot
 {
   Standard_Integer argc = pilot->NbWords();
   const Standard_CString arg1 = pilot->Arg(1);
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
 //        ****    trstat : TransferReader        ****
   Handle(XSControl_TransferReader)  TR  = XSControl::Session(pilot)->TransferReader();
-  if (TR.IsNull()) { cout<<" init not done"<<endl; return IFSelect_RetError; }
+  if (TR.IsNull()) { sout<<" init not done"<<endl; return IFSelect_RetError; }
   Handle(Interface_InterfaceModel)  mdl = TR->Model();
-  if (mdl.IsNull()) { cout<<" No model"<<endl; return IFSelect_RetError; }
-  cout<<" Statistics : FileName : "<<TR->FileName()<<endl;
+  if (mdl.IsNull()) { sout<<" No model"<<endl; return IFSelect_RetError; }
+  sout<<" Statistics : FileName : "<<TR->FileName()<<endl;
   if (argc == 1) {
     // stats generales
     TR->PrintStats(10,0);
   } else {
     // stats unitaires
     Standard_Integer num = atoi(arg1);
-    if (num < 1 || num > mdl->NbEntities()) { cout<<" incorrect number:"<<arg1<<endl; return IFSelect_RetError; }
+    if (num < 1 || num > mdl->NbEntities()) { sout<<" incorrect number:"<<arg1<<endl; return IFSelect_RetError; }
     Handle(Standard_Transient) ent = mdl->Value(num);
-    if (!TR->IsRecorded(ent)) { cout<<" Entity "<<num<<" not recorded"<<endl; return IFSelect_RetError; }
+    if (!TR->IsRecorded(ent)) { sout<<" Entity "<<num<<" not recorded"<<endl; return IFSelect_RetError; }
     Handle(Transfer_ResultFromModel) RM = TR->FinalResult(ent);
     Handle(TColStd_HSequenceOfTransient) list = TR->CheckedList(ent);
     Standard_Integer i, nb = list->Length();
-    if (nb > 0) cout<<" Entities implied by Check/Result :"<<nb<<" i.e.:";
-    for (i = 1; i <= nb; i ++) { cout<<"  "; mdl->Print(list->Value(i),cout); }
-    cout<<endl;
-    if (RM.IsNull()) { cout<<" no other info"<<endl; return IFSelect_RetVoid; }
+    if (nb > 0) sout<<" Entities implied by Check/Result :"<<nb<<" i.e.:";
+    for (i = 1; i <= nb; i ++) { sout<<"  "; mdl->Print(list->Value(i),sout); }
+    sout<<endl;
+    if (RM.IsNull()) { sout<<" no other info"<<endl; return IFSelect_RetVoid; }
     Interface_CheckIterator chl = RM->CheckList(Standard_False);
     pilot->Session()->PrintCheckList(chl,Standard_False,IFSelect_EntitiesByItem);
   }
@@ -648,7 +660,11 @@ static IFSelect_ReturnStatus XSControl_trbegin(const Handle(IFSelect_SessionPilo
   if (init) {
     XSControl::Session(pilot)->InitTransferReader (0);
     TR  = XSControl::Session(pilot)->TransferReader();
-    if (TR.IsNull()) { cout<<" init not done or failed"<<endl; return IFSelect_RetError; }
+    if (TR.IsNull()) { 
+      Handle(Message_Messenger) sout = Message::DefaultMessenger();
+      sout<<" init not done or failed"<<endl; 
+      return IFSelect_RetError; 
+    }
   }
   TR->BeginTransfer();
   return IFSelect_RetDone;
@@ -663,22 +679,23 @@ static IFSelect_ReturnStatus XSControl_tread(const Handle(IFSelect_SessionPilot)
   Standard_Integer argc = pilot->NbWords();
   //const Standard_CString arg1 = pilot->Arg(1);
   //        ****    tread : TransferReader        ****
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   Handle(XSControl_TransferReader)  TR  = XSControl::Session(pilot)->TransferReader();
-  if (TR.IsNull()) { cout<<" init not done"<<endl; return IFSelect_RetError; }
+  if (TR.IsNull()) { sout<<" init not done"<<endl; return IFSelect_RetError; }
   Handle(Interface_InterfaceModel)  mdl = TR->Model();
-  if (mdl.IsNull()) { cout<<" No model"<<endl; return IFSelect_RetError; }
+  if (mdl.IsNull()) { sout<<" No model"<<endl; return IFSelect_RetError; }
   if (argc < 2) {
 //      DeclareAndCast(IFSelect_Selection,sel,pilot->Session()->NamedItem("xst-model-roots"));
     Handle(Standard_Transient) sel = pilot->Session()->NamedItem("xst-model-roots");
-    if (sel.IsNull()) { cout<<"Select Roots absent"<<endl; return IFSelect_RetError; }
+    if (sel.IsNull()) { sout<<"Select Roots absent"<<endl; return IFSelect_RetError; }
     Handle(TColStd_HSequenceOfTransient) list = pilot->Session()->GiveList(sel);
-    cout<<" Transferring all roots i.e. : "<<flush<<TR->TransferList(list)<<endl;
+    sout<<" Transferring all roots i.e. : "<<TR->TransferList(list)<<endl;
   } else {
     Handle(TColStd_HSequenceOfTransient) list =
       IFSelect_Functions::GiveList(pilot->Session(),pilot->CommandPart(1));
-    cout<<" Transfer of "<<list->Length()<<" entities"<<endl;
+    sout<<" Transfer of "<<list->Length()<<" entities"<<endl;
     Standard_Integer nb = TR->TransferList(list);
-    cout<<" Gives "<<nb<<" results"<<endl;
+    sout<<" Gives "<<nb<<" results"<<endl;
   }
   return IFSelect_RetDone;
 }
@@ -691,8 +708,9 @@ static IFSelect_ReturnStatus XSControl_trtp(const Handle(IFSelect_SessionPilot)&
 {
   //        ****    TReader -> TProcess         ****
   Handle(XSControl_TransferReader)  TR  = XSControl::Session(pilot)->TransferReader();
-  if (TR.IsNull()) cout<<" No TransferReader"<<endl;
-  else if (TR->TransientProcess().IsNull()) cout<<" Transfer Reader without Process"<<endl;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
+  if (TR.IsNull()) sout<<" No TransferReader"<<endl;
+  else if (TR->TransientProcess().IsNull()) sout<<" Transfer Reader without Process"<<endl;
   ////else { XSDRAW::SetTransferProcess(TR->TransientProcess()); return IFSelect_RetDone; }
   return IFSelect_RetVoid;
 }
@@ -720,18 +738,19 @@ static IFSelect_ReturnStatus XSControl_twmode(const Handle(IFSelect_SessionPilot
   Handle(XSControl_TransferWriter) TW = XSControl::Session(pilot)->TransferWriter();
   Handle(XSControl_Controller) control = XSControl::Session(pilot)->NormAdaptor();
   Standard_Integer modemin,modemax;
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   if (control->ModeWriteBounds (modemin,modemax)) {
-    cout<<"Write Mode : allowed values  "<<modemin<<" to "<<modemax<<endl;
+    sout<<"Write Mode : allowed values  "<<modemin<<" to "<<modemax<<endl;
     for (Standard_Integer modd = modemin; modd <= modemax; modd ++) {
-      cout<<modd<<"	: "<<control->ModeWriteHelp (modd)<<endl;;
+      sout<<modd<<"	: "<<control->ModeWriteHelp (modd)<<endl;;
     }
   }
-  cout<<"Write Mode : actual = "<<TW->TransferMode()<<endl;
+  sout<<"Write Mode : actual = "<<TW->TransferMode()<<endl;
   if (argc <= 1) return IFSelect_RetVoid;
   Standard_Integer mod = atoi(arg1);
-  cout<<"New value -> "<<arg1<<endl;
+  sout<<"New value -> "<<arg1<<endl;
   TW->SetTransferMode(mod);
-  if (!control->IsModeWrite (mod)) cout<<"Warning : this new value is not supported"<<endl;
+  if (!control->IsModeWrite (mod)) sout<<"Warning : this new value is not supported"<<endl;
   return IFSelect_RetDone;
 }
 
@@ -747,12 +766,13 @@ static IFSelect_ReturnStatus XSControl_twstat(const Handle(IFSelect_SessionPilot
   Handle(Transfer_FinderProcess)    FP = XSControl::Session(pilot)->MapWriter();
   //        ****    twstat        ****
   //  Pour Write
+  Handle(Message_Messenger) sout = Message::DefaultMessenger();
   if (!FP.IsNull()) {
-    cout<<"TransferWrite:";
+    sout<<"TransferWrite:";
     //    XSControl_TransferWriter::PrintStatsProcess (FP,mod1,mod2);
-    FP->PrintStats (1,cout);
+    FP->PrintStats (1,sout);
   }
-  else cout<<"TransferWrite: not defined"<<endl;
+  else sout<<"TransferWrite: not defined"<<endl;
   return IFSelect_RetVoid;
 }
 
