@@ -13,7 +13,6 @@
 #include <TopoDS_HShape.hxx>
 #include <XSControl_Utils.hxx>
 #include <TopTools_MapOfShape.hxx>
-//#include <MoniTool_DB.hxx>
 
 //  Precision :
 #include <Interface_Static.hxx>
@@ -27,7 +26,6 @@
 #include <Interface_MSG.hxx>
 
 #include <TCollection_HAsciiString.hxx>
-#include <Interface_TraceFile.hxx>
 #include <Interface_Macros.hxx>
 
 #include <Transfer_IteratorOfProcessForTransient.hxx>
@@ -37,15 +35,15 @@
 #include <Interface_SignLabel.hxx>
 #include <Interface_Check.hxx>
 
+#include <Message_Messenger.hxx>
+
 #include <ShapeFix.hxx>
 #include <stdio.h>
 
-static char* tracemode = NULL;
-
 /*
 #ifdef DEB
 static  void monDBPE
-  (Standard_OStream& S, const Handle(Standard_Transient)& ent, const Handle(Standard_Transient)& context)
+  (const Handle(Message_Messenger)& S, const Handle(Standard_Transient)& ent, const Handle(Standard_Transient)& context)
 {
   if (ent.IsNull())  {  S<<"(null)";  return;  }
   DeclareAndCast(Interface_InterfaceModel,model,context);
@@ -826,28 +824,19 @@ Handle(TColStd_HSequenceOfTransient)  XSControl_TransferReader::CheckedList
 
 Standard_Boolean XSControl_TransferReader::BeginTransfer ()
 {
-  tracemode = getenv ("DEBUGMODE");
-  Standard_Integer level = Interface_TraceFile::DefLevel();
   if (theModel.IsNull()) return Standard_False;
   if (Actor().IsNull())  return Standard_False;
-  if (tracemode) cout<<" - BeginTransferRead"<<flush;
   theShapeResult.Nullify();
 
   if (theTransfer.IsNull()) theTransfer = new Transfer_TransientProcess
     (theModel->NbEntities());
-  //CKY 8-JUL-1998  if (tracemode) cout<<" - prepare TP:Clear"<<flush;
-  //CKY 8-JUL-1998  theTransfer->Clear();  permettre le cumul
-  if (tracemode) cout<<" - prepare TP:SetActor"<<flush;
 
   Handle(Transfer_ActorOfTransientProcess) actor;
   theTransfer->SetActor (actor);        // -> RAZ
   actor = Actor();
   theTransfer->SetActor (actor);        // Set proprement dit
-  theTransfer->SetErrorHandle (Standard_True,level);
+  theTransfer->SetErrorHandle (Standard_True);
   theTransfer->Context() = theContext;
-  if (tracemode) cout<<" done"<<endl;
-  //MoniTool_DB::Cur().Clear();
-  //MoniTool_DB::Cur().SetSignEntity (new Interface_SignLabel); // monDBPE
   return Standard_True;
 }
 
@@ -873,12 +862,13 @@ Standard_Boolean XSControl_TransferReader::Recognize
 Standard_Integer XSControl_TransferReader::TransferOne
   (const Handle(Standard_Transient)& ent, const Standard_Boolean rec)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer level = Interface_TraceFile::DefLevel();
   if (theActor.IsNull() || theModel.IsNull()) return 0;
 
   if (theTransfer.IsNull())  {  if (!BeginTransfer()) return 0;  }
 
+  Handle(Message_Messenger) sout = theTransfer->Messenger();
+  Standard_Integer level = theTransfer->TraceLevel();
+
   //BRepBuilderAPI::Precision (Interface_Static::RVal("read.precision.val")); //szv#11:CASCADE30:01Feb00
   //Interface_Static::SetRVal("lastpreci",0.0);
 
@@ -887,7 +877,7 @@ Standard_Integer XSControl_TransferReader::TransferOne
   else                   theTransfer->SetGraph(theGraph);
 
   //  pour le log-file
-  if (level > 0) {
+  if (level > 1) {
     Standard_Integer num = theModel->Number(ent);
     Handle(TCollection_HAsciiString) lab = theModel->StringLabel(ent);
     sout<<"\n*******************************************************************\n";
@@ -905,16 +895,8 @@ Standard_Integer XSControl_TransferReader::TransferOne
   //  seule difference entre TransferRoots et TransferOne
   Standard_Integer res = 0;
   Handle(Standard_Transient) obj = ent;
-  if (tracemode) cout<<"  -- TransferOne, Trace level="<<level<<endl;
-
-  if (tracemode) cout<<" entite n0."<<theModel->Number(obj)<<endl;//" NewScope : "<<flush;
-  //    Standard_Integer scop = theTransfer->NewScope (obj);
-  //    if (tracemode) cout<<scop<<flush;
   TP.Transfer (obj);
-  if (tracemode) cout<<" Transfer"<<flush;
-  //    theTransfer->EndScope (scop);
   theTransfer->SetRoot (obj);
-  //    if (tracemode) cout<<" EndScope"<<endl;
 
   //  Resultat ...
   Handle(Transfer_Binder) binder = theTransfer->Find (obj);
@@ -923,7 +905,6 @@ Standard_Integer XSControl_TransferReader::TransferOne
 
   if (!binder->HasResult()) return res;
   res ++;
-  if (tracemode) cout<<" Res.n0."<<res<<flush;
 
   return res;
 }
@@ -937,12 +918,13 @@ Standard_Integer XSControl_TransferReader::TransferOne
 Standard_Integer XSControl_TransferReader::TransferList
   (const Handle(TColStd_HSequenceOfTransient)& list, const Standard_Boolean rec)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer level = Interface_TraceFile::DefLevel();
   if (theActor.IsNull() || theModel.IsNull()) return 0;
 
   if (theTransfer.IsNull())  {  if (!BeginTransfer()) return 0;  }
 
+  Handle(Message_Messenger) sout = theTransfer->Messenger();
+  Standard_Integer level = theTransfer->TraceLevel();
+
   //BRepBuilderAPI::Precision (Interface_Static::RVal("read.precision.val")); //szv#11:CASCADE30:01Feb00
   //Interface_Static::SetRVal("lastpreci",0.0);
   Transfer_TransferOutput TP (theTransfer,theModel);
@@ -968,20 +950,12 @@ Standard_Integer XSControl_TransferReader::TransferList
   //  seule difference entre TransferRoots et TransferOne
   Standard_Integer res = 0;
   nb = list->Length();
-  if (tracemode) cout<<"  -- TransferList, Trace level="<<level<<" NB:"<<nb<<endl;
   Handle(Standard_Transient) obj;
-  if (tracemode) cout<<"  LIST:nb="<<nb<<endl;
 
   for (i = 1; i <= nb; i ++) {
     obj = list->Value(i);
-    if (tracemode) cout<<" entite n0."<<theModel->Number(obj)<<endl;//" NewScope : "<<flush;
-    //    Standard_Integer scop = theTransfer->NewScope (obj);
-    //    if (tracemode) cout<<scop<<flush;
     TP.Transfer (obj);
-    if (tracemode) cout<<" Transfer"<<flush;
-    //    theTransfer->EndScope (scop);
     theTransfer->SetRoot (obj);
-    //    if (tracemode) cout<<" EndScope"<<endl;
 
     //  Resultat ...
     Handle(Transfer_Binder) binder = theTransfer->Find (obj);
@@ -990,7 +964,6 @@ Standard_Integer XSControl_TransferReader::TransferList
 
     if (!binder->HasResult()) continue;
     res ++;
-    if (tracemode) cout<<" Res.n0."<<res<<flush;
   }
   return res;
 }
@@ -1006,17 +979,16 @@ Standard_Integer XSControl_TransferReader::TransferList
 
 Standard_Integer XSControl_TransferReader::TransferRoots(const Interface_Graph& G)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
-  Standard_Integer level = Interface_TraceFile::DefLevel();
   if (theModel != G.Model()) return -1;
   if (!BeginTransfer()) return -1;
+  Handle(Message_Messenger) sout = theTransfer->Messenger();
+  Standard_Integer level = theTransfer->TraceLevel();
 
   //BRepBuilderAPI::Precision (Interface_Static::RVal("read.precision.val")); //szv#11:CASCADE30:01Feb00
   //Interface_Static::SetRVal("lastpreci",0.0);
   Transfer_TransferOutput TP (theTransfer,theModel);
   if (theGraph.IsNull()) theTransfer->SetModel(theModel);
   else                   theTransfer->SetGraph(theGraph);
-  if (tracemode) sout<<"  -- Trace level="<<level<<endl;
 
   //   Pour le log-file
   if (level > 0) {
@@ -1083,11 +1055,11 @@ void XSControl_TransferReader::TransferClear(const Handle(Standard_Transient)& e
 void XSControl_TransferReader::PrintStats
   (const Standard_Integer what, const Standard_Integer mode) const
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = theTransfer->Messenger();
   //  A ameliorer ... !
-    sout<<"\n*******************************************************************\n";
-    sout << "******        Statistics on Transfer (Read)                  ******"<<endl;
-    sout<<"\n*******************************************************************\n";
+  sout<<"\n*******************************************************************\n";
+  sout << "******        Statistics on Transfer (Read)                  ******"<<endl;
+  sout<<"\n*******************************************************************\n";
   if (what > 10)  {  sout<<" ***  Not yet implemented"<<endl;  return;  }
   if (what < 10)  {
     sout << "******        Data recorded on Last Transfer                 ******"<<endl;
@@ -1227,7 +1199,7 @@ static Standard_Integer BinderStatus (const Handle(Transfer_Binder)& binder, cha
 //function : 
 //purpose  : 
 //=======================================================================
-static void PrintPercent(Standard_OStream& sout, const Standard_CString mess,
+static void PrintPercent(const Handle(Message_Messenger)& sout, const Standard_CString mess,
                          const Standard_Integer nb, const Standard_Integer nl)
 {
   if (nb <= 0 || nl == 0) return;
@@ -1262,7 +1234,7 @@ void XSControl_TransferReader::PrintStatsOnList(const Handle(Transfer_TransientP
                                                 const Standard_Integer what,
                                                 const Standard_Integer mode)
 {
-  Standard_OStream& sout = Interface_TraceFile::Def();
+  Handle(Message_Messenger) sout = TP->Messenger();
   char mess[250];
   if (TP.IsNull()) return;
   if (what == 0) {  TP->PrintStats(0,sout);  return;  }
