@@ -3,7 +3,6 @@
 #include <XSControl_WorkSession.ixx>
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
-#include <Interface_TraceFile.hxx>
 #include <Interface_HGraph.hxx>
 #include <Interface_Graph.hxx>
 
@@ -28,6 +27,7 @@
 #include <Interface_Macros.hxx>
 #include <Interface_Check.hxx>
 
+#include <Message_Messenger.hxx>
 
 //=======================================================================
 //function : XSControl_WorkSession
@@ -214,7 +214,7 @@ void XSControl_WorkSession::ClearContext ()
 
 Standard_Boolean  XSControl_WorkSession::PrintTransferStatus(const Standard_Integer num,
                                                              const Standard_Boolean wri,
-                                                             Standard_OStream& S) const
+                                                             const Handle(Message_Messenger)& S) const
 {
   Handle(Transfer_FinderProcess)    FP = MapWriter();
   Handle(Transfer_TransientProcess) TP = MapReader();
