@@ -4,7 +4,6 @@
 
 #include <Standard_ErrorHandler.hxx>
 #include <Standard_Failure.hxx>
-#include <Interface_DT.hxx>
 #include <Interface_Static.hxx>
 
 #include <IGESControl_Writer.hxx>
@@ -37,8 +36,10 @@
 #include <Geom_Surface.hxx>
 
 #include <Interface_Macros.hxx>
+#include <Message_Messenger.hxx>
 
 #include <Draw_Appli.hxx>
+#include <Draw_Printer.hxx>
 #include <DrawTrSurf.hxx>
 #include <DBRep.hxx>
 //#include <GeometryTest.hxx>  essai CKY 4-AUT-1998
@@ -54,7 +55,6 @@
 #include <Transfer_TransferOutput.hxx>
 #include <Transfer_FinderProcess.hxx>
 #include <XSControl_WorkSession.hxx>
-#include <MDBLIST.hxx>
 
 // + tplosttrim
 #include <IFSelect_SessionPilot.hxx>
@@ -65,7 +65,7 @@
 #include <TColStd_MapIteratorOfMapOfTransient.hxx>
 #include <IGESControl_Reader.hxx>
 #include <Interface_InterfaceModel.hxx>
-#include <XSDRAW_ProgressIndicator.hxx>
+#include <Draw_ProgressIndicator.hxx>
 #include <TopExp_Explorer.hxx>
 #include <Message_ProgressSentry.hxx>
 
@@ -74,13 +74,13 @@
 //
 //--------------------------------------------------------------
 
-static Standard_Integer igesbrep (Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static Standard_Integer igesbrep (Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   DeclareAndCast(IGESControl_Controller,ctl,XSDRAW::Controller());
   if (ctl.IsNull()) XSDRAW::SetNorm("IGES");
 
   // Progress indicator
-  Handle(XSDRAW_ProgressIndicator) progress = new XSDRAW_ProgressIndicator ( di, 1 );
+  Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
   progress->SetScale ( 0, 100, 1 );
   progress->Show();
  
@@ -97,7 +97,6 @@ static Standard_Integer igesbrep (Draw_Interpretor& di, Standard_Integer argc, c
   di<<" -- Names of variables BREP-DRAW prefixed by : "<<rnom.ToCString()<<"\n";
   IFSelect_ReturnStatus readstat = IFSelect_RetVoid;
 
-  SDBCUR.Clear();
 #ifdef CHRONOMESURE
   OSD_Timer Chr; Chr.Reset();
   IDT_SetLevel(3);
@@ -375,7 +374,7 @@ static Standard_Integer igesbrep (Draw_Interpretor& di, Standard_Integer argc, c
 // Function : testreadiges
 //
 //--------------------------------------------------------------
-static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   if (argc != 3)                                                                                      
     {                                                                                             
@@ -406,7 +405,7 @@ static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, c
 //
 //--------------------------------------------------------------
 
-static Standard_Integer brepiges (Draw_Interpretor& di, Standard_Integer n, char** a) 
+static Standard_Integer brepiges (Draw_Interpretor& di, Standard_Integer n, const char** a) 
 {
   XSDRAW::SetNorm ("IGES");
   // ecriture dans le model d'une entite :
@@ -423,16 +422,16 @@ static Standard_Integer brepiges (Draw_Interpretor& di, Standard_Integer n, char
 
 //  Mode d emploi (K4B ->) : brepiges shape [+shape][ +shape] nomfic
 //   c a d tant qu il y a des + on ajoute ce qui suit
-  char* ficnom = NULL;
+  const char* ficnom = NULL;
   Standard_Integer npris = 0;
 
-  Handle(XSDRAW_ProgressIndicator) progress = new XSDRAW_ProgressIndicator ( di, 1 );
+  Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
   progress->NewScope(90,"Translating");
   progress->Show();
   ICW.TransferProcess()->SetProgress(progress);
 
   for ( Standard_Integer i = 1; i < n; i++) {
-    char* nomvar = a[i];
+    const char* nomvar = a[i];
     if (a[i][0] == '+') nomvar = &(a[i])[1];
     else if (i > 1)  {  ficnom = a[i];  break;  }
     TopoDS_Shape Shape = DBRep::Get(nomvar);
@@ -498,7 +497,7 @@ static Standard_Integer brepiges (Draw_Interpretor& di, Standard_Integer n, char
 //
 //--------------------------------------------------------------
 
-static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer n, char** a) 
+static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer n, const char** a) 
 {
   if (n != 3)                                                                                      
     {                                                                                             
@@ -528,7 +527,7 @@ static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer n, cha
 //--------------------------------------------------------------
 
 
-static Standard_Integer igesparam (Draw_Interpretor& di, Standard_Integer , char** ) 
+static Standard_Integer igesparam (Draw_Interpretor& di, Standard_Integer , const char** ) 
 {
 //  liste des parametres
   di<<"List of parameters which control IGES :"<<"\n";
@@ -546,7 +545,7 @@ static Standard_Integer igesparam (Draw_Interpretor& di, Standard_Integer , char
 //
 //--------------------------------------------------------------
 
-static Standard_Integer XSDRAWIGES_tplosttrim (Draw_Interpretor& di, Standard_Integer n, char** a) 
+static Standard_Integer XSDRAWIGES_tplosttrim (Draw_Interpretor& di, Standard_Integer n, const char** a) 
 {
   Handle(IFSelect_SessionPilot) pilot = XSDRAW::Pilot();
 
@@ -607,11 +606,13 @@ static Standard_Integer XSDRAWIGES_tplosttrim (Draw_Interpretor& di, Standard_In
       case 3:
 	di << "Face: " << "\n"; break;
       }
+      Handle(Message_Messenger) aDIMessenger = 
+	new Message_Messenger (new Draw_Printer(di));
       TColStd_MapIteratorOfMapOfTransient itmap;
       for(itmap.Initialize(aMap); itmap.More(); itmap.Next()) {
 	//XSDRAW::Model()->Print(itmap.Key(),cout);
 	Standard_SStream aSStream;
-	XSDRAW::Model()->Print(itmap.Key(),aSStream);
+	XSDRAW::Model()->Print(itmap.Key(),aDIMessenger);
 	di << GetSString(aSStream);
 	di<<"  ";
       }
@@ -632,7 +633,7 @@ static Standard_Integer XSDRAWIGES_tplosttrim (Draw_Interpretor& di, Standard_In
 // Function : TPSTAT
 //
 //--------------------------------------------------------------
-static Standard_Integer XSDRAWIGES_TPSTAT(Draw_Interpretor& di,Standard_Integer n, char** a)
+static Standard_Integer XSDRAWIGES_TPSTAT(Draw_Interpretor& di,Standard_Integer n, const char** a)
 {
   Handle(IFSelect_SessionPilot) pilot = XSDRAW::Pilot();
   Standard_Integer argc = n;//= pilot->NbWords();
@@ -676,7 +677,7 @@ static Standard_Integer XSDRAWIGES_TPSTAT(Draw_Interpretor& di,Standard_Integer
   return 0;
 }
 
-static Standard_Integer etest(Draw_Interpretor& di, Standard_Integer argc, char** a)
+static Standard_Integer etest(Draw_Interpretor& di, Standard_Integer argc, const char** a)
 {
   if(argc < 3) {
     di<<"etest igesfile shape"<<"\n";
@@ -713,7 +714,7 @@ void  XSDRAWIGES::InitSelect ()
 
 void  XSDRAWIGES::InitToBRep (Draw_Interpretor& theCommands)
 {
-  char* g = "DE: IGES";
+  const char* g = "DE: IGES";
   theCommands.Add("igesbrep",     "igesbrep [file else already loaded model] [name DRAW]",     __FILE__, igesbrep,              g);
   theCommands.Add("testreadiges", "testreadiges [file else already loaded model] [name DRAW]", __FILE__, testread,              g);
   theCommands.Add("igesread",     "igesread [file else already loaded model] [name DRAW]",     __FILE__, igesbrep,              g);
@@ -732,7 +733,7 @@ void  XSDRAWIGES::InitToBRep (Draw_Interpretor& theCommands)
 
 void  XSDRAWIGES::InitFromBRep (Draw_Interpretor& theCommands)
 {
-  char* g = "DE: IGES";
+  const char* g = "DE: IGES";
   theCommands.Add("brepiges",      "brepiges sh1 [+sh2 [+sh3 ..]] filename.igs", __FILE__, brepiges,  g);
   theCommands.Add("testwriteiges", "testwriteiges filename.igs shape",           __FILE__, testwrite, g);
 }
