@@ -8,9 +8,10 @@
 #include <XSDRAW.hxx>
 #include <StepSelect_Activator.hxx>
 
-
 #include <Draw_Appli.hxx>
 #include <Draw_Interpretor.hxx>
+#include <Draw_Printer.hxx>
+#include <Message_Messenger.hxx>
 
 #include <DBRep.hxx>
 
@@ -41,7 +42,7 @@
 #include <STEPSelections_Counter.hxx>
 #include <STEPSelections_AssemblyExplorer.hxx>
 
-#include <XSDRAW_ProgressIndicator.hxx>
+#include <Draw_ProgressIndicator.hxx>
 #include <Transfer_TransientProcess.hxx>
 
 #include <TopExp_Explorer.hxx>
@@ -67,14 +68,14 @@ void XSDRAWSTEP::Init ()
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer stepread (Draw_Interpretor& di/*theCommands*/, Standard_Integer argc, char** argv) 
+static Standard_Integer stepread (Draw_Interpretor& di/*theCommands*/, Standard_Integer argc, const char** argv) 
 {
 //  On admet le controller AP214 ou une variante
   DeclareAndCast(STEPControl_Controller,ctl,XSDRAW::Controller());
   if (ctl.IsNull()) XSDRAW::SetNorm("STEP");
 
   // Progress indicator
-  Handle(XSDRAW_ProgressIndicator) progress = new XSDRAW_ProgressIndicator ( di, 1 );
+  Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
   progress->SetScale ( 0, 100, 1 );
   progress->Show();
   
@@ -106,17 +107,15 @@ static Standard_Integer stepread (Draw_Interpretor& di/*theCommands*/, Standard_
 //   nom = "." -> fichier deja lu
   Standard_Integer i, num, nbs, modepri = 1;
   if (fromtcl) modepri = 4;
+  Handle(Message_Messenger) aDIMessenger = 
+    new Message_Messenger (new Draw_Printer(di));
   while (modepri) {
     num = sr.NbRootsForTransfer();
     if (!fromtcl) {
       di<<"NbRootsForTransfer="<<num<<" :\n";
       for (i = 1; i <= num; i ++) {
 	di<<"Root."<<i<<", Ent. ";
-	//sr.Model()->Print(sr.RootForTransfer(i),di);
-	Standard_SStream aSStream;
-	sr.Model()->Print(sr.RootForTransfer(i),aSStream);
-	aSStream << ends;
-	di << GetSString(aSStream);
+	sr.Model()->Print(sr.RootForTransfer(i),aDIMessenger);
 	di<<" Type:"<<sr.RootForTransfer(i)->DynamicType()->Name()<<"\n";
       }
 
@@ -224,7 +223,7 @@ static Standard_Integer stepread (Draw_Interpretor& di/*theCommands*/, Standard_
 //function : testreadstep
 //purpose  : 
 //=======================================================================
-static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc != 3)                                                                                      
     {                                                                                             
@@ -255,7 +254,7 @@ static Standard_Integer testread (Draw_Interpretor& di, Standard_Integer argc, c
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer readstep (Draw_Interpretor& di, Standard_Integer /*argc*/, char** argv) 
+static Standard_Integer readstep (Draw_Interpretor& di, Standard_Integer /*argc*/, const char** argv) 
 {
 //  On admet le controller AP214 ou une variante
   
@@ -297,7 +296,7 @@ static Standard_Integer readstep (Draw_Interpretor& di, Standard_Integer /*argc*
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer steptrans (Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static Standard_Integer steptrans (Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   if (argc < 5) { di<<"give shape-name new-shape + entity-n0 entity-n0: AXIS2"<<"\n";
 		  return 1; }
@@ -330,7 +329,7 @@ static Standard_Integer steptrans (Draw_Interpretor& di, Standard_Integer argc,
 //purpose  : 
 //=======================================================================
 
-static Standard_Integer stepwrite (Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static Standard_Integer stepwrite (Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
 //  On admet le controller AP214 ou une variante
   DeclareAndCast(STEPControl_Controller,ctl,XSDRAW::Controller());
@@ -372,7 +371,7 @@ static Standard_Integer stepwrite (Draw_Interpretor& di, Standard_Integer argc,
   Handle(Interface_InterfaceModel) stepmodel = sw.Model();
   Standard_Integer nbavant = (stepmodel.IsNull() ? 0 : stepmodel->NbEntities());
 
-  Handle(XSDRAW_ProgressIndicator) progress = new XSDRAW_ProgressIndicator ( di, 1 );
+  Handle(Draw_ProgressIndicator) progress = new Draw_ProgressIndicator ( di, 1 );
   progress->NewScope(90,"Translating");
   progress->Show();
   sw.WS()->TransferWriter()->FinderProcess()->SetProgress(progress);
@@ -425,7 +424,7 @@ static Standard_Integer stepwrite (Draw_Interpretor& di, Standard_Integer argc,
 //function : testwritestep
 //purpose  : 
 //=======================================================================
-static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer argc, char** argv) 
+static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer argc, const char** argv) 
 {
   if (argc != 3)                                                                                      
     {                                                                                             
@@ -452,7 +451,7 @@ static Standard_Integer testwrite (Draw_Interpretor& di, Standard_Integer argc,
 //=======================================================================
 
 static Standard_Integer countexpected
-  (Draw_Interpretor& di, Standard_Integer /*argc*/, char** /*argv*/)
+  (Draw_Interpretor& di, Standard_Integer /*argc*/, const char** /*argv*/)
 {
   Handle(IFSelect_SessionPilot) pilot = XSDRAW::Pilot();
   Handle(IFSelect_WorkSession) WS = pilot->Session();
@@ -481,7 +480,7 @@ static Standard_Integer countexpected
 }
 
 static Standard_Integer dumpassembly
-  (Draw_Interpretor& /*di*/, Standard_Integer /*argc*/, char** /*argv*/)
+  (Draw_Interpretor& /*di*/, Standard_Integer /*argc*/, const char** /*argv*/)
 {
   Handle(IFSelect_SessionPilot) pilot = XSDRAW::Pilot();
   Handle(IFSelect_WorkSession) WS = pilot->Session();
@@ -496,7 +495,7 @@ static Standard_Integer dumpassembly
 
 void XSDRAWSTEP::InitCommands (Draw_Interpretor& theCommands)
 {
-  char* g = "DE: STEP";  // Step transfer file commands
+  const char* g = "DE: STEP";  // Step transfer file commands
   XSDRAWSTEP::Init();
   XSDRAW::LoadDraw(theCommands);
   theCommands.Add("stepwrite" ,    "stepwrite mode[0-4 afsmw] shape",  __FILE__, stepwrite,     g);
