@@ -39,7 +39,7 @@
 #include <MeshVS_MeshPrsBuilder.hxx>
 #include <MeshVS_Drawer.hxx>
 #include <MeshVS_DrawerAttribute.hxx>
-#include <MeshVS_MeshOwner.hxx>
+#include <MeshVS_MeshEntityOwner.hxx>
 
 #include <XSDRAWSTLVRML_DataSource.hxx>
 #include <XSDRAWSTLVRML_DrawableMesh.hxx>
@@ -48,6 +48,9 @@
 #include <TColStd_HPackedMapOfInteger.hxx>
 #include <TColStd_MapIteratorOfPackedMapOfInteger.hxx>
 #include <Standard_ErrorHandler.hxx>
+#include <VrmlData_Scene.hxx>
+#include <VrmlData_ShapeConvert.hxx>
+#include <VrmlData_DataMapOfShapeAppearance.hxx>
 
 
 // avoid warnings on 'extern "C"' functions returning C++ classes
@@ -60,7 +63,7 @@
 #endif
 
 static Standard_Integer writestl
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<3) di << "wrong number of parameters"    << "\n";
   else {
@@ -74,7 +77,7 @@ static Standard_Integer writestl
 }
 
 static Standard_Integer readstl
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<3) di << "wrong number of parameters"    << "\n";
   else {
@@ -86,7 +89,7 @@ static Standard_Integer readstl
 }
 
 static Standard_Integer writevrml
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv)
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   if (argc<3) di << "wrong number of parameters"    << "\n";
   else {
@@ -106,9 +109,114 @@ static Standard_Integer writevrml
   return 0;
 }
 
+//=======================================================================
+//function : loadvrml
+//purpose  : 
+//=======================================================================
+
+static Standard_Integer loadvrml
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
+{
+  if (argc<3) di << "wrong number of parameters"    << "\n";
+  else {
+    TopoDS_Shape shape ;
+    VrmlData_DataMapOfShapeAppearance ShapeAppMap;
+
+    //-----------------------------------------------------------
+    filebuf fic;
+    istream aStream (&fic);
+
+    if (fic.open(argv[2], ios::in)) {
+
+      VrmlData_Scene aScene;
+
+      aScene.SetVrmlDir (".");
+      aScene << aStream;
+      const char * aStr = 0L;
+      switch (aScene.Status()) {
+
+      case VrmlData_StatusOK:
+        {
+	  shape = aScene.GetShape(ShapeAppMap);
+          break;
+        }
+      case VrmlData_EmptyData:          aStr = "EmptyData"; break;
+      case VrmlData_UnrecoverableError: aStr = "UnrecoverableError"; break;
+      case VrmlData_GeneralError:       aStr = "GeneralError"; break;
+      case VrmlData_EndOfFile:          aStr = "EndOfFile"; break;
+      case VrmlData_NotVrmlFile:        aStr = "NotVrmlFile"; break;
+      case VrmlData_CannotOpenFile:     aStr = "CannotOpenFile"; break;
+      case VrmlData_VrmlFormatError:    aStr = "VrmlFormatError"; break;
+      case VrmlData_NumericInputError:  aStr = "NumericInputError"; break;
+      case VrmlData_IrrelevantNumber:   aStr = "IrrelevantNumber"; break;
+      case VrmlData_BooleanInputError:  aStr = "BooleanInputError"; break;
+      case VrmlData_StringInputError:   aStr = "StringInputError"; break;
+      case VrmlData_NodeNameUnknown:    aStr = "NodeNameUnknown"; break;
+      case VrmlData_NonPositiveSize:    aStr = "NonPositiveSize"; break;
+      case VrmlData_ReadUnknownNode:    aStr = "ReadUnknownNode"; break;
+      case VrmlData_NonSupportedFeature:aStr = "NonSupportedFeature"; break;
+      }
+      if (aStr) {
+        di << " ++ VRML Error: " << aStr << " in line "
+             << aScene.GetLineError() << "\n";
+      }
+      else {
+	DBRep::Set(argv[1],shape);
+      }
+    }
+    else {
+      di << "cannot open file" << "\n";
+    }
+  
+
+    //-----------------------------------------------------------
+  }
+  return 0;
+}
+
+//=======================================================================
+//function : storevrml
+//purpose  : 
+//=======================================================================
+
+static Standard_Integer storevrml
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv)
+{
+  if (argc < 4) {
+    di << "wrong number of parameters"    << "\n";
+    di << "use: storevrml shape file defl type_of_conversion (0, 1, 2)"    << "\n";
+  }
+  else {
+    TopAbs_ShapeEnum Types[3] = {TopAbs_FACE, TopAbs_WIRE, TopAbs_EDGE};
+    TopoDS_Shape shape = DBRep::Get(argv[1]);
+    Standard_Real defl = atof(argv[3]);
+    Standard_Integer type = 1;
+    if(argc > 4) type = atoi(argv[4]);
+    type = Max(0, type);
+    type = Min(2, type);
+
+    Standard_Boolean ExtFace = Standard_False;
+    if(type == 0 || type == 2) ExtFace = Standard_True;
+    Standard_Boolean ExtEdge = Standard_False;
+    if(type == 1 || type == 2) ExtEdge = Standard_True;
+
+    VrmlData_Scene aScene;
+    VrmlData_ShapeConvert Conv(aScene);
+    Conv.AddShape(shape);
+    Conv.Convert(ExtFace, ExtEdge, defl);
+
+    filebuf foc;
+    ostream outStream (&foc);
+    if (foc.open (argv[2], ios::out))
+      outStream << aScene;       
+  }
+  return 0;
+}
+
+
 //-----------------------------------------------------------------------------
 static Standard_Integer createmesh
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
 
   if (argc<3)
@@ -158,7 +266,7 @@ static Standard_Integer createmesh
   return 0;
 }
 //-----------------------------------------------------------------------------
-Handle( MeshVS_Mesh ) getMesh( char* name, Draw_Interpretor& di)
+Handle( MeshVS_Mesh ) getMesh( const char* name, Draw_Interpretor& di)
 {
   Handle( XSDRAWSTLVRML_DrawableMesh ) aDrawMesh =
     Handle( XSDRAWSTLVRML_DrawableMesh )::DownCast( Draw::Get( name ) );
@@ -182,7 +290,7 @@ Handle( MeshVS_Mesh ) getMesh( char* name, Draw_Interpretor& di)
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer meshdm
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<3)
     di << "wrong number of parameters" << "\n";
@@ -216,7 +324,7 @@ static Standard_Integer meshdm
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer meshsm
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<3)
     di << "wrong number of parameters" << "\n";
@@ -273,7 +381,7 @@ static Standard_Integer meshsm
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer setcolor
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv, Standard_Integer Param )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv, Standard_Integer Param )
 {
   if (argc<5)
     di << "wrong number of parameters" << "\n";
@@ -300,19 +408,19 @@ static Standard_Integer setcolor
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer meshcolor
-  (Draw_Interpretor& interp, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& interp, Standard_Integer argc, const char** argv )
 {
   return setcolor( interp, argc, argv, MeshVS_DA_InteriorColor );
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer linecolor
-  (Draw_Interpretor& interp, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& interp, Standard_Integer argc, const char** argv )
 {
   return setcolor( interp, argc, argv, MeshVS_DA_EdgeColor );
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer meshmat
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<3)
     di << "wrong number of parameters" << "\n";
@@ -342,7 +450,7 @@ static Standard_Integer meshmat
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer shrink
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<3)
     di << "wrong number of parameters" << "\n";
@@ -368,7 +476,7 @@ static Standard_Integer shrink
 //-----------------------------------------------------------------------------
 
 static Standard_Integer mdisplay
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<2)
     di << "wrong number of parameters" << "\n";
@@ -394,7 +502,7 @@ static Standard_Integer mdisplay
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer merase
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<2)
     di << "wrong number of parameters" << "\n";
@@ -422,7 +530,7 @@ static Standard_Integer merase
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer hidesel
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<1)
   {
@@ -447,7 +555,8 @@ static Standard_Integer hidesel
     Handle(TColStd_HPackedMapOfInteger) aHiddenElements = aMesh->GetHiddenElems();
     for( aContext->InitSelected(); aContext->MoreSelected(); aContext->NextSelected() )
     {
-      Handle( MeshVS_MeshOwner ) anOwner = Handle( MeshVS_MeshOwner )::DownCast( aContext->SelectedOwner() );
+      Handle( MeshVS_MeshEntityOwner ) anOwner =
+        Handle( MeshVS_MeshEntityOwner )::DownCast( aContext->SelectedOwner() );
       if( !anOwner.IsNull() )
         if( anOwner->Type()==MeshVS_ET_Node )
           aHiddenNodes->ChangeMap().Add( anOwner->ID() );
@@ -464,7 +573,7 @@ static Standard_Integer hidesel
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer showonly
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<1)
   {
@@ -491,7 +600,8 @@ static Standard_Integer showonly
       new TColStd_HPackedMapOfInteger(aMesh->GetDataSource()->GetAllElements());
     for( aContext->InitSelected(); aContext->MoreSelected(); aContext->NextSelected() )
     {
-      Handle( MeshVS_MeshOwner ) anOwner = Handle( MeshVS_MeshOwner )::DownCast( aContext->SelectedOwner() );
+      Handle( MeshVS_MeshEntityOwner ) anOwner =
+        Handle( MeshVS_MeshEntityOwner )::DownCast( aContext->SelectedOwner() );
       if( !anOwner.IsNull() )
         if( anOwner->Type()==MeshVS_ET_Node )
           aHiddenNodes->ChangeMap().Remove( anOwner->ID() );
@@ -507,7 +617,7 @@ static Standard_Integer showonly
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer showall
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<1)
   {
@@ -536,7 +646,7 @@ static Standard_Integer showall
 }
 //-----------------------------------------------------------------------------
 static Standard_Integer delmesh
-  (Draw_Interpretor& di, Standard_Integer argc, char** argv )
+  (Draw_Interpretor& di, Standard_Integer argc, const char** argv )
 {
   if (argc<2)
   {
@@ -575,7 +685,7 @@ static Standard_Integer delmesh
 
 static Standard_Integer nodalcolor_id( Draw_Interpretor& di, 
                                        Standard_Integer argc, 
-                                       char** argv )
+                                       const char** argv )
 {
   try
   {
@@ -629,7 +739,7 @@ static Standard_Integer nodalcolor_id( Draw_Interpretor& di,
 
 static Standard_Integer mesh_edge_width( Draw_Interpretor& di, 
                                          Standard_Integer argc, 
-                                         char** argv )
+                                         const char** argv )
 {
   try
   {
@@ -647,7 +757,7 @@ static Standard_Integer mesh_edge_width( Draw_Interpretor& di,
       return 0;
     }
 
-    char* aWidthStr = argv[ 2 ];
+    const char* aWidthStr = argv[ 2 ];
     if ( aWidthStr == 0 || atof( aWidthStr ) <= 0 )
     {
       di << "Width must be real value more than zero" << "\n";
@@ -685,12 +795,14 @@ static Standard_Integer mesh_edge_width( Draw_Interpretor& di,
 
 void  XSDRAWSTLVRML::InitCommands (Draw_Interpretor& theCommands)
 {
-  char* g = "XSTEP-STL/VRML";  // Step transfer file commands
+  const char* g = "XSTEP-STL/VRML";  // Step transfer file commands
   //XSDRAW::LoadDraw(theCommands);
 
   theCommands.Add ("writevrml", "shape file",__FILE__,writevrml,g);
   theCommands.Add ("writestl",  "shape file",__FILE__,writestl,g);
   theCommands.Add ("readstl",   "shape file",__FILE__,readstl,g);
+  theCommands.Add ("loadvrml" , "shape file",__FILE__,loadvrml,g);
+  theCommands.Add ("storevrml" , "shape file defl [type]",__FILE__,storevrml,g);
 
   theCommands.Add ("meshfromstl",   "creates MeshVS_Mesh from STL file",  __FILE__, createmesh, g );
   theCommands.Add ("meshdispmode",  "changes MeshVS_Mesh display mode",   __FILE__, meshdm,     g );
