@@ -526,7 +526,10 @@ float size,slant ;
             }
 #endif
             TCollection_AsciiString aname(style.FullName()) ;
-            status = Xw_get_font_index(MyExtendedFontMap,size,aname.ToCString(),&hindex) ;
+            status = Xw_get_font_index(MyExtendedFontMap,
+				       size,
+				       (Standard_PCharacter)aname.ToCString(),
+				       &hindex) ;
             oindex = hindex ;
             MyFontIndexs->SetValue(iindex,oindex) ;
         }
@@ -880,7 +883,8 @@ float zoom;
         pimage = Xw_get_image_handle( MyExtendedDrawable,(void*)hashcode ) ;
         if( !pimage ) {
             pimage = Xw_load_image(MyExtendedDrawable,
-                                (void*)hashcode,anImageFile );
+				   (void*)hashcode,
+				   (Standard_PCharacter)anImageFile );
         }
 
         if( pimage ) {
@@ -935,7 +939,8 @@ void Xw_Driver::DrawImageFile (const Standard_CString anImageFile,
   pimage = Xw_get_image_handle( MyExtendedDrawable,(void*)hashcode );
   if (!pimage) {
     pimage = Xw_load_image(MyExtendedDrawable,
-                           (void*)(hashcode),anImageFile );
+                           (void*)(hashcode),
+			   (Standard_PCharacter)anImageFile );
   }
 
   if (pimage && aScale > 0.) {
@@ -1258,8 +1263,12 @@ void Xw_Driver::DrawText (const TCollection_ExtendedString& aText, const Standar
 #endif
           if( aText.IsAscii() ) {
             TCollection_AsciiString atext(aText,'?');
-            status = Xw_draw_text (MyExtendedDrawable, Xpos, Ypos,
-                                atext.ToCString (), Angle, (int)aType);
+            status = Xw_draw_text (MyExtendedDrawable, 
+				   Xpos, 
+				   Ypos,
+				   (Standard_PCharacter)atext.ToCString (), 
+				   Angle, 
+				   (int)aType);
           } else status = XW_ERROR ;    /*Must be Implemented more later*/
 
           if( !status ) PrintError() ;
@@ -1319,8 +1328,13 @@ Standard_ShortReal marge = aMarge ;
 #endif
           if( aText.IsAscii() ) {
             TCollection_AsciiString atext(aText,'?');
-            status = Xw_draw_polytext (MyExtendedDrawable, Xpos, Ypos, 
-                                atext.ToCString (), Angle, marge, (int)aType);
+            status = Xw_draw_polytext (MyExtendedDrawable, 
+				       Xpos, 
+				       Ypos, 
+				       (Standard_PCharacter)atext.ToCString (),
+				       Angle, 
+				       marge, 
+				       (int)aType);
           } else status = XW_ERROR ;    /*Must be Implemented more later*/
 
           if( !status ) PrintError() ;
@@ -1643,8 +1657,13 @@ Standard_Integer theFont = (aFontIndex >= 0 ) ? aFontIndex : MyTextFont ;
 #endif
         if (aText.IsAscii ()) {
           TCollection_AsciiString atext(aText,'?');
-          status = Xw_get_text_size (MyExtendedDrawable, font, 
-                atext.ToCString(), &Width, &Height, &Xoffset, &Yoffset) ;
+          status = Xw_get_text_size (MyExtendedDrawable, 
+				     font, 
+				     (Standard_PCharacter)atext.ToCString(), 
+				     &Width, 
+				     &Height, 
+				     &Xoffset, 
+				     &Yoffset) ;
           if( !status ) PrintError() ;
         } else {                /*Must be Implemented more later*/
           Width = Height = Xoffset = Yoffset = 0.;
