@@ -120,19 +120,55 @@ Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)& Device) : Aspect_Window(De
 }
 
 
-Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)& Device, const Standard_Integer aPart1, const Standard_Integer aPart2, const Xw_WindowQuality Quality, const Quantity_NameOfColor BackColor) : Aspect_Window(Device) {
+//=======================================================================
+//function : Xw_Window
+//purpose  : 
+//=======================================================================
+
+Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)&   Device,
+                      const Standard_Integer            aPart1,
+                      const Standard_Integer            aPart2,
+                      const Xw_WindowQuality            Quality,
+                      const Quantity_NameOfColor        BackColor)
+  : Aspect_Window(Device)
+{
   Init();
   Aspect_Handle aWindow = (aPart1 << 16) | (aPart2 & 0xFFFF);
   
   SetWindow(aWindow,Quality,BackColor) ;
 }
 
-Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)& Device, const Aspect_Handle& aWindow, const Xw_WindowQuality Quality, const Quantity_NameOfColor BackColor) : Aspect_Window(Device) {
+//=======================================================================
+//function : Xw_Window
+//purpose  : 
+//=======================================================================
+
+Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)&   Device,
+                      const Aspect_Handle               aWindow,
+                      const Xw_WindowQuality            Quality,
+                      const Quantity_NameOfColor        BackColor)
+  : Aspect_Window(Device)
+{
   Init();
   SetWindow(aWindow,Quality,BackColor) ;
 }
 
-Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)& Device, const Standard_CString Title, const Quantity_Parameter Xc, const Quantity_Parameter Yc, const Quantity_Parameter Width, const Quantity_Parameter Height, const Xw_WindowQuality Quality, const Quantity_NameOfColor BackColor, const Aspect_Handle& Parent) : Aspect_Window(Device) {
+//=======================================================================
+//function : Xw_Window
+//purpose  : 
+//=======================================================================
+
+Xw_Window::Xw_Window (const Handle(Xw_GraphicDevice)&   Device,
+                      const Standard_CString            Title,
+                      const Quantity_Parameter          Xc,
+                      const Quantity_Parameter          Yc,
+                      const Quantity_Parameter          Width,
+                      const Quantity_Parameter          Height,
+                      const Xw_WindowQuality            Quality,
+                      const Quantity_NameOfColor        BackColor,
+                      const Aspect_Handle               Parent)
+  : Aspect_Window(Device)
+{
   Init();
   SetWindow (Title,Xc,Yc,Width,Height,Quality,BackColor,Parent);
 }
@@ -157,44 +193,52 @@ void Xw_Window::Init()
   MyVisualClass = Xw_TOV_STATICGRAY;
 }
 
-void Xw_Window::SetWindow (const Aspect_Handle& aWindow, const Xw_WindowQuality Quality, const Quantity_NameOfColor BackColor) {
+//=======================================================================
+//function : SetWindow
+//purpose  : 
+//=======================================================================
 
-    if( (Quality == Xw_WQ_TRANSPARENT) || (Quality == Xw_WQ_OVERLAY) ) {
-      SetWindow ("",0.5,0.5,1.0,1.0,Quality,BackColor,aWindow);
-    } else {
-      Aspect_Handle window,root,colormap,pixmap ;
-      Xw_TypeOfVisual visualclass ;
-      int visualdepth,visualid ;
-      const Handle(Xw_GraphicDevice)& Device = 
-		Handle(Xw_GraphicDevice)::DownCast(MyGraphicDevice);
+void Xw_Window::SetWindow (const Aspect_Handle          aWindow,
+                           const Xw_WindowQuality       Quality,
+                           const Quantity_NameOfColor   BackColor)
+{
+  if( (Quality == Xw_WQ_TRANSPARENT) || (Quality == Xw_WQ_OVERLAY) ) {
+    SetWindow ("",0.5,0.5,1.0,1.0,Quality,BackColor,aWindow);
+  } else {
+    Aspect_Handle window,root,colormap,pixmap ;
+    Xw_TypeOfVisual visualclass ;
+    int visualdepth,visualid ;
+    const Handle(Xw_GraphicDevice)& Device = 
+      Handle(Xw_GraphicDevice)::DownCast(MyGraphicDevice);
 
-      MyExtendedDisplay = Device->ExtendedDisplay() ;
+    MyExtendedDisplay = Device->ExtendedDisplay() ;
 
-      MyBackgroundIndex = 0 ;
-      MyXWindow = aWindow ; 
-      MyXParentWindow = aWindow ;
-      MyQuality = Quality ;
+    MyBackgroundIndex = 0 ;
+    MyXWindow = aWindow ; 
+    MyXParentWindow = aWindow ;
+    MyQuality = Quality ;
 
-      if( !MyXWindow ) {
-	PrintError() ;
-      }
+    if( !MyXWindow ) {
+      PrintError() ;
+    }
 
-      MyExtendedWindow = 
-		Xw_def_window (MyExtendedDisplay,MyXWindow,Standard_False);
+    MyExtendedWindow = 
+      Xw_def_window (MyExtendedDisplay,MyXWindow,Standard_False);
 
-      status = Xw_get_window_info(MyExtendedWindow,&window,&pixmap,
-			&root,&colormap,&visualclass,&visualdepth,&visualid);
-      if( !status ) {
-	PrintError() ;
-      }
+    status = Xw_get_window_info(MyExtendedWindow,&window,&pixmap,
+                                &root,&colormap,&visualclass,
+                                &visualdepth,&visualid);
+    if( !status ) {
+      PrintError() ;
+    }
 
-Standard_Boolean Res1 =
+    Standard_Boolean Res1 =
 	(Device->ExtendedColorMap3D() == Device->ExtendedColorMap2D());
-Standard_Boolean Res2 =
+    Standard_Boolean Res2 =
 	(Quality == Xw_WQ_SAMEQUALITY);
-Standard_Boolean Res3 =
+    Standard_Boolean Res3 =
 	(Quality == Xw_WQ_DRAWINGQUALITY && visualclass == Xw_TOV_PSEUDOCOLOR);
-Standard_Boolean Res4 =
+    Standard_Boolean Res4 =
 	(Quality == Xw_WQ_3DQUALITY && visualclass == Xw_TOV_TRUECOLOR);
 
       //if (Quality == Xw_WQ_3DQUALITY && visualclass == Xw_TOV_PSEUDOCOLOR) {
@@ -202,245 +246,260 @@ Standard_Boolean Res4 =
 	//visualclass = Xw_TOV_TRUECOLOR;
       //}
 
-      if (Res1 || Res2 || Res3 || Res4) {
+    if (Res1 || Res2 || Res3 || Res4) {
 
-	MyVisualClass = visualclass ;
-	MyXPixmap = pixmap ;
-        MyDepth = visualdepth ;
+      MyVisualClass = visualclass ;
+      MyXPixmap = pixmap ;
+      MyDepth = visualdepth ;
 
-	if( MyVisualClass == Xw_TOV_TRUECOLOR ) {
-	    MyColorMap = Device->ColorMap3D() ;
-	} else {
-	    MyColorMap = Device->ColorMap2D() ;
-	}
-
-	if( visualid == MyColorMap->OverlayVisualID() ) {
-	  MyExtendedColorMap = MyColorMap->ExtendedOverlayColorMap();
-	} else {
-	  MyExtendedColorMap = MyColorMap->ExtendedColorMap();
-	}
-
-	MyTypeMap = Device->TypeMap() ;
-	MyExtendedTypeMap = Device->ExtendedTypeMap();
-	MyWidthMap = Device->WidthMap() ;
-	MyExtendedWidthMap = Device->ExtendedWidthMap();
-	MyFontMap = Device->FontMap() ;
-	MyExtendedFontMap = Device->ExtendedFontMap();
-	MyMarkMap = Device->MarkMap() ;
-	MyExtendedMarkMap = Device->ExtendedMarkMap();
-
-	status = Xw_set_colormap(MyExtendedWindow,MyExtendedColorMap) ;
-
-	if( !status ) {
-	    PrintError() ;
-    	}
-
-	status = Xw_set_typemap(MyExtendedWindow,MyExtendedTypeMap) ;
-
-	if( !status ) {
-	    PrintError() ;
-    	}
-
-	status = Xw_set_widthmap(MyExtendedWindow,MyExtendedWidthMap) ;
-
-	if( !status ) {
-	    PrintError() ;
-    	}
-
-	status = Xw_set_fontmap(MyExtendedWindow,MyExtendedFontMap) ;
-
-	if( !status ) {
-	    PrintError() ;
-    	}
-
-	status = Xw_set_markmap(MyExtendedWindow,MyExtendedMarkMap) ;
-
-	if( !status ) {
-	    PrintError() ;
-    	}
-	SetBackground(BackColor) ;
-
-      } else { 	// Create a child of this Window in the right Visual
-XW_WINDOWSTATE state = XW_WS_UNKNOWN ;
-int pxc, pyc;
-int width, height;
-float ratio;
-Quantity_Parameter Width = 1.0;
-Quantity_Parameter Height= 1.0;
-
-	state = Xw_get_window_position (MyExtendedWindow,
-						&pxc,&pyc,&width,&height);
-	if( state == XW_WS_UNKNOWN ) {
-	    Xw_print_error() ;
-	}
-	ratio = float (width)/ float (height);
-	if (ratio > 1.)
-	    Width = Width*ratio;
-	else
-	    Height = Height/ratio;
-	SetWindow ("",0.5,0.5,Width,Height,Quality,BackColor,MyXWindow);
+      if( MyVisualClass == Xw_TOV_TRUECOLOR ) {
+        MyColorMap = Device->ColorMap3D() ;
+      } else {
+        MyColorMap = Device->ColorMap2D() ;
       }
-   }
+
+      if( visualid == MyColorMap->OverlayVisualID() ) {
+        MyExtendedColorMap = MyColorMap->ExtendedOverlayColorMap();
+      } else {
+        MyExtendedColorMap = MyColorMap->ExtendedColorMap();
+      }
+
+      MyTypeMap = Device->TypeMap() ;
+      MyExtendedTypeMap = Device->ExtendedTypeMap();
+      MyWidthMap = Device->WidthMap() ;
+      MyExtendedWidthMap = Device->ExtendedWidthMap();
+      MyFontMap = Device->FontMap() ;
+      MyExtendedFontMap = Device->ExtendedFontMap();
+      MyMarkMap = Device->MarkMap() ;
+      MyExtendedMarkMap = Device->ExtendedMarkMap();
+
+      status = Xw_set_colormap(MyExtendedWindow,MyExtendedColorMap) ;
+
+      if( !status ) {
+        PrintError() ;
+      }
+
+      status = Xw_set_typemap(MyExtendedWindow,MyExtendedTypeMap) ;
+
+      if( !status ) {
+        PrintError() ;
+      }
+
+      status = Xw_set_widthmap(MyExtendedWindow,MyExtendedWidthMap) ;
+
+      if( !status ) {
+        PrintError() ;
+      }
+
+      status = Xw_set_fontmap(MyExtendedWindow,MyExtendedFontMap) ;
+
+      if( !status ) {
+        PrintError() ;
+      }
+
+      status = Xw_set_markmap(MyExtendedWindow,MyExtendedMarkMap) ;
+
+      if( !status ) {
+        PrintError() ;
+      }
+      SetBackground(BackColor) ;
+
+    } else { 	// Create a child of this Window in the right Visual
+      XW_WINDOWSTATE state = XW_WS_UNKNOWN ;
+      int pxc, pyc;
+      int width, height;
+      float ratio;
+      Quantity_Parameter Width = 1.0;
+      Quantity_Parameter Height= 1.0;
+
+      state = Xw_get_window_position (MyExtendedWindow,
+                                      &pxc,&pyc,&width,&height);
+      if( state == XW_WS_UNKNOWN ) {
+        Xw_print_error() ;
+      }
+      ratio = float (width)/ float (height);
+      if (ratio > 1.)
+        Width = Width*ratio;
+      else
+        Height = Height/ratio;
+      SetWindow ("",0.5,0.5,Width,Height,Quality,BackColor,MyXWindow);
+    }
+  }
 }
 
-void Xw_Window::SetWindow (const Standard_CString Title, const Quantity_Parameter Xc, const Quantity_Parameter Yc, const Quantity_Parameter Width, const Quantity_Parameter Height, const Xw_WindowQuality Quality, const Quantity_NameOfColor BackColor, const Aspect_Handle& Parent) {
-Aspect_Handle window,root,colormap,pixmap,*display ;
-Xw_TypeOfVisual visualclass ;
-Standard_Integer visualdepth,visualid,istransparent = Standard_False ;
+//=======================================================================
+//function : SetWindow
+//purpose  : 
+//=======================================================================
 
-        const Handle(Xw_GraphicDevice)& Device = 
-		Handle(Xw_GraphicDevice)::DownCast(MyGraphicDevice);
+void Xw_Window::SetWindow (const Standard_CString       Title,
+                           const Quantity_Parameter     Xc,
+                           const Quantity_Parameter     Yc,
+                           const Quantity_Parameter     Width,
+                           const Quantity_Parameter     Height,
+                           const Xw_WindowQuality       Quality,
+                           const Quantity_NameOfColor   BackColor,
+                           const Aspect_Handle          Parent)
+{
+  Aspect_Handle window,root,colormap,pixmap,*display ;
+  Xw_TypeOfVisual visualclass ;
+  Standard_Integer visualdepth,visualid,istransparent = Standard_False ;
 
-	MyBackgroundIndex = 0 ;
-	MyExtendedDisplay = Device->ExtendedDisplay() ;
-	MyXParentWindow = Parent ;
-	MyXWindow = 0 ;
-	MyQuality = Quality ;
+  const Handle(Xw_GraphicDevice)& Device = 
+    Handle(Xw_GraphicDevice)::DownCast(MyGraphicDevice);
 
-	switch (Quality) {
-	    case Xw_WQ_3DQUALITY :
-	    case Xw_WQ_PICTUREQUALITY :
-		MyColorMap = Device->ColorMap3D() ;
-		MyVisualClass = Device->VisualClass3D() ;
-		MyExtendedColorMap = Device->ExtendedColorMap3D();
-		break ;
-	    case Xw_WQ_DRAWINGQUALITY :
-		MyColorMap = Device->ColorMap2D() ;
-		MyVisualClass = Device->VisualClass2D() ;
-		MyExtendedColorMap = Device->ExtendedColorMap2D();
-		break ;
-	    case Xw_WQ_SAMEQUALITY :
-		if( !MyXParentWindow ) {
-	            status = Xw_get_display_info (MyExtendedDisplay,
-			&display,&root,&colormap,&visualclass,&visualdepth) ;
-		} else {
-		    MyExtendedWindow = Xw_def_window(MyExtendedDisplay,
-					MyXParentWindow,Standard_False);
+  MyBackgroundIndex = 0 ;
+  MyExtendedDisplay = Device->ExtendedDisplay() ;
+  MyXParentWindow = Parent ;
+  MyXWindow = 0 ;
+  MyQuality = Quality ;
 
-		    status = Xw_get_window_info(MyExtendedWindow,&window,
-			&pixmap,&root,&colormap,&visualclass,&visualdepth,
-			&visualid) ;
-		    Xw_close_window(MyExtendedWindow,Standard_False) ;
-		    MyExtendedWindow = NULL;
-		}
+  switch (Quality) {
+  case Xw_WQ_3DQUALITY :
+  case Xw_WQ_PICTUREQUALITY :
+    MyColorMap = Device->ColorMap3D() ;
+    MyVisualClass = Device->VisualClass3D() ;
+    MyExtendedColorMap = Device->ExtendedColorMap3D();
+    break ;
+  case Xw_WQ_DRAWINGQUALITY :
+    MyColorMap = Device->ColorMap2D() ;
+    MyVisualClass = Device->VisualClass2D() ;
+    MyExtendedColorMap = Device->ExtendedColorMap2D();
+    break ;
+  case Xw_WQ_SAMEQUALITY :
+    if( !MyXParentWindow ) {
+      status = Xw_get_display_info (MyExtendedDisplay,
+                                    &display,&root,&colormap,&visualclass,
+                                    &visualdepth) ;
+    } else {
+      MyExtendedWindow = Xw_def_window(MyExtendedDisplay,
+                                       MyXParentWindow,Standard_False);
 
-        	if( !status ) {
-	    	    PrintError() ;
-                }
-		if( visualclass == Xw_TOV_TRUECOLOR ) {
-		    MyColorMap = Device->ColorMap3D() ;
-		    MyVisualClass = Device->VisualClass3D() ;
-		    MyExtendedColorMap = Device->ExtendedColorMap3D();
-		} else if( visualclass == Xw_TOV_PSEUDOCOLOR ) {
-		    MyColorMap = Device->ColorMap2D() ;
-		    MyVisualClass = Device->VisualClass2D() ;
-		    MyExtendedColorMap = Device->ExtendedColorMap2D();
-		}
-		break ;
-	    case Xw_WQ_TRANSPARENT :
-		istransparent = Standard_True ;
-	    case Xw_WQ_OVERLAY :
-		if( !MyXParentWindow ) {
-	            status = Xw_get_display_info (MyExtendedDisplay,
-			&display,&root,&colormap,&visualclass,&visualdepth) ;
-		} else {
-		    MyExtendedWindow = Xw_def_window(MyExtendedDisplay,
-					MyXParentWindow,istransparent);
+      status = Xw_get_window_info(MyExtendedWindow,&window,
+                                  &pixmap,&root,&colormap,&visualclass,&visualdepth,
+                                  &visualid) ;
+      Xw_close_window(MyExtendedWindow,Standard_False) ;
+      MyExtendedWindow = NULL;
+    }
 
-		    status = Xw_get_window_info(MyExtendedWindow,&window,
-			&pixmap,&root,&colormap,&visualclass,&visualdepth,
-			&visualid) ;
-		    Xw_close_window(MyExtendedWindow,Standard_False) ;
-		    MyExtendedWindow = NULL;
-		}
+    if( !status ) {
+      PrintError() ;
+    }
+    if( visualclass == Xw_TOV_TRUECOLOR ) {
+      MyColorMap = Device->ColorMap3D() ;
+      MyVisualClass = Device->VisualClass3D() ;
+      MyExtendedColorMap = Device->ExtendedColorMap3D();
+    } else if( visualclass == Xw_TOV_PSEUDOCOLOR ) {
+      MyColorMap = Device->ColorMap2D() ;
+      MyVisualClass = Device->VisualClass2D() ;
+      MyExtendedColorMap = Device->ExtendedColorMap2D();
+    }
+    break ;
+  case Xw_WQ_TRANSPARENT :
+    istransparent = Standard_True ;
+  case Xw_WQ_OVERLAY :
+    if( !MyXParentWindow ) {
+      status = Xw_get_display_info (MyExtendedDisplay,
+                                    &display,&root,&colormap,&visualclass,
+                                    &visualdepth) ;
+    } else {
+      MyExtendedWindow = Xw_def_window(MyExtendedDisplay,
+                                       MyXParentWindow,istransparent);
 
-        	if( !status ) {
-	    	    PrintError() ;
-                }
-		if( visualclass == Xw_TOV_TRUECOLOR ) {
-		    MyColorMap = Device->ColorMap3D() ;
-		    MyExtendedColorMap = Device->ExtendedOverlayColorMap3D();
-		    MyVisualClass = Xw_TOV_OVERLAY;
-		    if( !MyExtendedColorMap ) {
-		      MyVisualClass = Device->VisualClass3D() ;
-		      MyExtendedColorMap = Device->ExtendedColorMap3D();
-		    }
-		} else if( visualclass == Xw_TOV_PSEUDOCOLOR ) {
-		    MyColorMap = Device->ColorMap2D() ;
-		    MyExtendedColorMap = Device->ExtendedOverlayColorMap2D();
-		    MyVisualClass = Xw_TOV_OVERLAY;
-		    if( !MyExtendedColorMap ) {
-		      MyVisualClass = Device->VisualClass2D() ;
-		      MyExtendedColorMap = Device->ExtendedColorMap2D();
-		    }
-		}
-		break ;
-	}
+      status = Xw_get_window_info(MyExtendedWindow,&window,
+                                  &pixmap,&root,&colormap,&visualclass,&visualdepth,
+                                  &visualid) ;
+      Xw_close_window(MyExtendedWindow,Standard_False) ;
+      MyExtendedWindow = NULL;
+    }
 
-	if( MyVisualClass != Xw_TOV_DEFAULT ) {
-	  MyTypeMap = Device->TypeMap() ;
-	  MyExtendedTypeMap = Device->ExtendedTypeMap();
-	  MyWidthMap = Device->WidthMap() ;
-	  MyExtendedWidthMap = Device->ExtendedWidthMap();
-	  MyFontMap = Device->FontMap() ;
-	  MyExtendedFontMap = Device->ExtendedFontMap();
-	  MyMarkMap = Device->MarkMap() ;
-	  MyExtendedMarkMap = Device->ExtendedMarkMap();
+    if( !status ) {
+      PrintError() ;
+    }
+    if( visualclass == Xw_TOV_TRUECOLOR ) {
+      MyColorMap = Device->ColorMap3D() ;
+      MyExtendedColorMap = Device->ExtendedOverlayColorMap3D();
+      MyVisualClass = Xw_TOV_OVERLAY;
+      if( !MyExtendedColorMap ) {
+        MyVisualClass = Device->VisualClass3D() ;
+        MyExtendedColorMap = Device->ExtendedColorMap3D();
+      }
+    } else if( visualclass == Xw_TOV_PSEUDOCOLOR ) {
+      MyColorMap = Device->ColorMap2D() ;
+      MyExtendedColorMap = Device->ExtendedOverlayColorMap2D();
+      MyVisualClass = Xw_TOV_OVERLAY;
+      if( !MyExtendedColorMap ) {
+        MyVisualClass = Device->VisualClass2D() ;
+        MyExtendedColorMap = Device->ExtendedColorMap2D();
+      }
+    }
+    break ;
+  }
 
-	  MyXWindow = Xw_open_window(MyExtendedDisplay,MyVisualClass,MyXParentWindow,
-			(float)Xc,(float)Yc,(float)Width,(float)Height,
-							Title,istransparent) ;
-	  if( !MyXWindow ) {
-	    PrintError() ;
-	  }
+  if( MyVisualClass != Xw_TOV_DEFAULT ) {
+    MyTypeMap = Device->TypeMap() ;
+    MyExtendedTypeMap = Device->ExtendedTypeMap();
+    MyWidthMap = Device->WidthMap() ;
+    MyExtendedWidthMap = Device->ExtendedWidthMap();
+    MyFontMap = Device->FontMap() ;
+    MyExtendedFontMap = Device->ExtendedFontMap();
+    MyMarkMap = Device->MarkMap() ;
+    MyExtendedMarkMap = Device->ExtendedMarkMap();
 
-	  MyExtendedWindow = 
-		Xw_def_window (MyExtendedDisplay,MyXWindow,istransparent);
+    MyXWindow = Xw_open_window(MyExtendedDisplay,MyVisualClass,MyXParentWindow,
+                               (float)Xc,(float)Yc,(float)Width,(float)Height,
+                               (Standard_PCharacter)Title,istransparent) ;
+    if( !MyXWindow ) {
+      PrintError() ;
+    }
 
-	  status = Xw_get_window_info(MyExtendedWindow,&window,&pixmap,
-			&root,&colormap,&visualclass,&visualdepth,&visualid) ;
-          if( !status ) {
-	    PrintError() ;
-          }
+    MyExtendedWindow = 
+      Xw_def_window (MyExtendedDisplay,MyXWindow,istransparent);
 
-	  MyXPixmap = pixmap ;
-	  MyDepth = visualdepth ;
+    status = Xw_get_window_info(MyExtendedWindow,&window,&pixmap,
+                                &root,&colormap,&visualclass,&visualdepth,
+                                &visualid) ;
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  status = Xw_set_colormap(MyExtendedWindow,MyExtendedColorMap) ;
+    MyXPixmap = pixmap ;
+    MyDepth = visualdepth ;
 
-	  if( !status ) {
-	    PrintError() ;
-    	  }
+    status = Xw_set_colormap(MyExtendedWindow,MyExtendedColorMap) ;
 
-	  status = Xw_set_typemap(MyExtendedWindow,MyExtendedTypeMap) ;
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  if( !status ) {
-	    PrintError() ;
-    	  }
+    status = Xw_set_typemap(MyExtendedWindow,MyExtendedTypeMap) ;
 
-	  status = Xw_set_widthmap(MyExtendedWindow,MyExtendedWidthMap) ;
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  if( !status ) {
-	    PrintError() ;
-    	  }
+    status = Xw_set_widthmap(MyExtendedWindow,MyExtendedWidthMap) ;
 
-	  status = Xw_set_fontmap(MyExtendedWindow,MyExtendedFontMap) ;
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  if( !status ) {
-	    PrintError() ;
-    	  }
+    status = Xw_set_fontmap(MyExtendedWindow,MyExtendedFontMap) ;
 
-	  status = Xw_set_markmap(MyExtendedWindow,MyExtendedMarkMap) ;
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  if( !status ) {
-	    PrintError() ;
-    	  }
+    status = Xw_set_markmap(MyExtendedWindow,MyExtendedMarkMap) ;
 
+    if( !status ) {
+      PrintError() ;
+    }
 
-	  SetBackground(BackColor) ;
+    SetBackground(BackColor) ;
 
-	  if( MyXParentWindow && (MyXWindow != MyXParentWindow) ) Map() ;
-	}
+    if( MyXParentWindow && (MyXWindow != MyXParentWindow) ) Map() ;
+  }
 }
 
 void Xw_Window::SetBackground (const Aspect_Background& Background) {
@@ -504,15 +563,21 @@ void Xw_Window::SetBackground(const Quantity_Color& color )
   }
 }
 
-void Xw_Window :: SetBackground( const Aspect_Handle& aPixmap) {
-   status = Xw_set_background_pixmap( MyExtendedWindow, aPixmap);
-   if ( status ) {
-     MyHBackground = aPixmap;
-     MyBackgroundImage.Clear();
-     MyBackgroundFillMethod = Aspect_FM_NONE;
-   } else {
-     PrintError(); 
-   }
+//=======================================================================
+//function : SetBackground
+//purpose  : 
+//=======================================================================
+
+void Xw_Window::SetBackground (const Aspect_Handle aPixmap)
+{
+  status = Xw_set_background_pixmap( MyExtendedWindow, aPixmap);
+  if ( status ) {
+    MyHBackground = aPixmap;
+    MyBackgroundImage.Clear();
+    MyBackgroundFillMethod = Aspect_FM_NONE;
+  } else {
+    PrintError(); 
+  }
 }
 
 Standard_Boolean Xw_Window::SetBackground( const Standard_CString aName,
@@ -527,7 +592,7 @@ Standard_Boolean Xw_Window::SetBackground( const Standard_CString aName,
  pimage = Xw_get_image_handle( MyExtendedWindow,(void*)hash_code );
 
  if ( !pimage )
-  pimage = Xw_load_image(MyExtendedWindow,(void*)hash_code,aName );
+  pimage = Xw_load_image(MyExtendedWindow,(void*)hash_code,(Standard_PCharacter)aName );
  
  if ( pimage )
     status = Xw_put_background_image( MyExtendedWindow, pimage, aMethod );
@@ -674,11 +739,11 @@ int pxc,pyc,width,height;
 #ifdef BUC60701
       pxc = width/2; pyc = height/2;
 #endif
-      pimage = Xw_get_image(MyExtendedWindow,aFilename,pxc,pyc,width,height) ;
+      pimage = Xw_get_image(MyExtendedWindow,(Standard_PCharacter)aFilename,pxc,pyc,width,height) ;
       if( !pimage ) return Standard_False;
       if( aGammaValue != 1.0 )
         Xw_gamma_image (pimage,Standard_ShortReal(aGammaValue));
-      status = Xw_save_image (MyExtendedWindow,pimage,aFilename);
+      status = Xw_save_image (MyExtendedWindow,pimage,(Standard_PCharacter)aFilename);
       Xw_close_image(pimage);
     } else {
       status = XW_ERROR ;
@@ -699,11 +764,11 @@ int height = Abs(Height);
 
     status = XW_ERROR;
     if( width && height ) {
-      pimage = Xw_get_image(MyExtendedWindow,aFilename,Xc,Yc,width,height) ;
+      pimage = Xw_get_image(MyExtendedWindow,(Standard_PCharacter)aFilename,Xc,Yc,width,height) ;
       if( pimage ) {
         if( aGammaValue != 1.0 )
           Xw_gamma_image (pimage,Standard_ShortReal(aGammaValue));
-        status = Xw_save_image (MyExtendedWindow,pimage,aFilename);
+        status = Xw_save_image (MyExtendedWindow,pimage,(Standard_PCharacter)aFilename);
         Xw_close_image(pimage);
       } else status = XW_ERROR ;
     }
@@ -727,7 +792,7 @@ float izoom;
     status = XW_ERROR;
     pimage = Xw_get_image_handle( MyExtendedWindow,(void*)hashcode ) ;
     if( !pimage ) { 
-        pimage = Xw_load_image(MyExtendedWindow,(void*)hashcode,aFilename );
+        pimage = Xw_load_image(MyExtendedWindow,(void*)hashcode,(Standard_PCharacter)aFilename );
     }
 
     if( pimage ) {
@@ -774,7 +839,7 @@ float izoom,uxc,uyc;
     status = XW_ERROR;
     pimage = Xw_get_image_handle( MyExtendedWindow,(void*)hashcode ) ;
     if( !pimage ) { 
-        pimage = Xw_load_image(MyExtendedWindow,(void*)hashcode,aFilename );
+        pimage = Xw_load_image(MyExtendedWindow,(void*)hashcode,(Standard_PCharacter)aFilename );
     }
 
     if( pimage ) {
@@ -1043,32 +1108,34 @@ int visualdepth,visualid ;
 	return (pixmap);
 }
 
-Standard_Address Xw_Window::XVisual( ) const {
-Aspect_Handle *VisualInfo ;
-Xw_TypeOfVisual VisualClass ;
-int MaxColor,BaseColor,MaxUserColor,MaxDefineColor,FirstFreeColorIndex,visualid ;
+Standard_Address Xw_Window::XVisual( ) const
+{
+  Aspect_Handle *VisualInfo ;
+  Xw_TypeOfVisual VisualClass ;
+  int MaxColor,BaseColor,MaxUserColor,MaxDefineColor,FirstFreeColorIndex,visualid ;
 
-        status = Xw_get_colormap_info(MyExtendedColorMap,&VisualInfo,
-                &VisualClass,&visualid,&MaxColor,&BaseColor,
-                &MaxUserColor,&MaxDefineColor,&FirstFreeColorIndex) ;
+  status = Xw_get_colormap_info(MyExtendedColorMap,&VisualInfo,
+                                &VisualClass,&visualid,&MaxColor,&BaseColor,
+                                &MaxUserColor,&MaxDefineColor,&FirstFreeColorIndex);
 
-        if( !status ) {
-            PrintError() ;
-        }
+  if( !status ) {
+    PrintError() ;
+  }
 
-        return (VisualInfo) ;
+  return (VisualInfo) ;
 }
 
-Aspect_Handle Xw_Window::XColorMap( ) const {
-Aspect_Handle colormap ;
+Aspect_Handle Xw_Window::XColorMap( ) const
+{
+  Aspect_Handle colormap ;
 
-        colormap = Xw_get_colormap_xid(MyExtendedColorMap) ;
+  colormap = Xw_get_colormap_xid(MyExtendedColorMap) ;
 
-        if( !colormap ) {
-            PrintError() ;
-        }
+  if( !colormap ) {
+    PrintError() ;
+  }
 
-        return (colormap) ;
+  return (colormap) ;
 }
 
 Standard_Boolean Xw_Window::PointerPosition (Standard_Integer& X, Standard_Integer& Y) const {
