@@ -121,7 +121,7 @@ static int  MaxColorCube = MAXCOLORCUBE ;
 static int  EnableSunOverlay = False;	
 static char svalue[80] ;
 static Atom DefaultAtom = 0 ; 
-static char *XW_RGB_BEST_MAP = "Xw_RGB_BEST_MAP" ;
+static const char *XW_RGB_BEST_MAP = "Xw_RGB_BEST_MAP" ;
 
 #ifdef XW_PROTOTYPE
 void* Xw_def_colormap (void* adisplay,Xw_TypeOfVisual pclass,
