@@ -452,30 +452,28 @@ static BOOL _convert_image_to_256_RGB_indices
 
   return (!i);
 }
-/*********************************************************************/
-/* Xw_save_gif_image                                                 */
-/*                                                                   */
-/*********************************************************************/
-XW_STATUS Xw_save_gif_image
 #ifdef XW_PROTOTYPE
- (void *awindow,void *aimage,char *filename)
+XW_STATUS Xw_save_gif_image_adv (Display *aDisplay,Window aWindow,XWindowAttributes aWinAttr,XImage *aPximage,Colormap aColormap,int aNcolors,char *filename)
 #else
- (awindow,aimage,filename)
-void *awindow;
-void *aimage;
-char *filename ;
+XW_STATUS Xw_save_gif_image_adv (aDisplay,aWindow,aWinAttr,aPximage,aColormap,aNcolors,filename)
+Display *aDisplay;
+Window aWindow;
+XWindowAttributes aWinAttr;
+XImage *aPximage;
+Colormap aColormap;
+int ncolors;
+char *filename;
 #endif /*XW_PROTOTYPE*/
 {
-  XW_EXT_WINDOW *pwindow = (XW_EXT_WINDOW*)awindow;
-  XW_EXT_IMAGEDATA *pimage = (XW_EXT_IMAGEDATA*) aimage;
-  XImage *pximage = NULL;
-  FILE *fimage = NULL ;
-  XColor *pcolors = NULL;
   BYTE colors256[256][3];
   BYTE *pBits = NULL;
   char *wname = NULL,*pname = NULL ;
-  int i,isize,lname,ncolors,iclass, x,y;
-  int status = XW_SUCCESS;
+  int i,isize,lname,iclass,ncolors, x,y;
+  Visual *pvisual = aWinAttr.visual;
+  XColor *pcolors = NULL;
+  XWDColor *qcolors = NULL;
+  FILE *fimage = NULL ;
+  XW_STATUS status = XW_SUCCESS;
   BYTE image_sep = 0x2C; /* gif colormap delimiter */
   WORD wZero = 0x00;
 #if defined(LIN) || defined(linux)
@@ -486,18 +484,7 @@ char *filename ;
   IMAGE_DESCR id;
 #endif
   BYTE *pbCell;
-  
 
-  if (!Xw_isdefine_window(pwindow)) { /*ERROR*Bad EXT_WINDOW Address*/
-    Xw_set_error(24,"Xw_save_gif_image",pwindow) ;
-    return (XW_ERROR) ;
-  }
-
-  if( !Xw_isdefine_image(pimage) ) { /*ERROR*Bad EXT_IMAGEDATA Address*/
-    Xw_set_error(25,"Xw_save_gif_image",pimage) ;
-    return (XW_ERROR) ;
-  }
-  
   /* Open GIF File */
   pname = Xw_get_filename (filename, "gif");
   if (pname)
@@ -509,41 +496,34 @@ char *filename ;
   }
 
   /* Get Window name */	
-  XFetchName(_DISPLAY,_WINDOW,&wname);
+  XFetchName(aDisplay,aWindow,&wname);
   
   if (!wname || !strlen (wname))
     wname = (char*) strdup(pname);
   lname = strlen (wname) + 1;
   
-  
-  pximage = (_ZIMAGE) ? _ZIMAGE : _IIMAGE;
-
-  
-  
-  iclass = _CLASS ;
+  iclass = pvisual->c_class;
 #ifdef PRO5356
-  if( (iclass == PseudoColor) && (pximage->red_mask > 0) ) iclass = TrueColor;
-/*    iclass = (pximage->depth > 8) ? TrueColor : _CLASS;  GG_240898 */
+  if( (iclass == PseudoColor) && (aPximage->red_mask > 0) ) iclass = TrueColor;
+/*    iclass = (aPximage->depth > 8) ? TrueColor : pvisual->c_class;  GG_240898 */
 #endif
-
   
 #ifdef DEBUG
   fprintf (stderr, "Xw_save_gif_image: max colors available = %d\r\n",
-	   _COLORMAP? _COLORMAP->maxhcolor: 0);
+	   aColormap? aNcolors: 0);
 #endif
 
-
   /* Get color table */ 
   switch (iclass) {
     
   case PseudoColor :
-    ncolors = _COLORMAP->maxhcolor;
+    ncolors = aNcolors;
     if ((pcolors = (XColor*) Xw_calloc(ncolors,sizeof(XColor)))) {
       for (i=0 ; i<ncolors ; i++) {
 	pcolors[i].pixel = i;
 	pcolors[i].pad = 0;
       }
-      XQueryColors(_DISPLAY,_COLORMAP->info.colormap,pcolors,ncolors);
+      XQueryColors(aDisplay,aColormap,pcolors,ncolors);
     }
     else {
       /*ERROR*Bad Image allocation*/
@@ -559,7 +539,7 @@ char *filename ;
 
     
   case DirectColor :
-    ncolors = _COLORMAP->maxhcolor;
+    ncolors = aNcolors;
 
     if (ncolors > 256) {
       ncolors = 0;
@@ -567,20 +547,20 @@ char *filename ;
     }
 
     if(( pcolors = (XColor*) Xw_calloc(ncolors,sizeof(XColor)) )) {
-      unsigned long red = 0,lred = LOWBIT(_VISUAL->red_mask);
-      unsigned long green = 0,lgreen = LOWBIT(_VISUAL->green_mask);
-      unsigned long blue = 0,lblue = LOWBIT(_VISUAL->blue_mask);
+      unsigned long red = 0,lred = LOWBIT(pvisual->red_mask);
+      unsigned long green = 0,lgreen = LOWBIT(pvisual->green_mask);
+      unsigned long blue = 0,lblue = LOWBIT(pvisual->blue_mask);
       for( i=0 ; i<ncolors ; i++) {
 	pcolors[i].pixel = red|green|blue;
 	pcolors[i].pad = 0;
 	red += lred;
-	if( red > _VISUAL->red_mask ) red = 0;
+	if( red > pvisual->red_mask ) red = 0;
 	green += lgreen;
-	if( green > _VISUAL->green_mask ) green = 0;
+	if( green > pvisual->green_mask ) green = 0;
 	blue += lblue;
-	if( blue > _VISUAL->blue_mask ) blue = 0;
+	if( blue > pvisual->blue_mask ) blue = 0;
       }
-      XQueryColors(_DISPLAY,_COLORMAP->info.colormap,pcolors,ncolors);
+      XQueryColors(aDisplay,aColormap,pcolors,ncolors);
     }
     else {  /*ERROR*Bad Image allocation*/
       Xw_set_error(60,"Xw_save_gif_image",0) ;
@@ -608,9 +588,8 @@ char *filename ;
     fclose(fimage);
     return (XW_ERROR);
   }
-    
 
-  isize = pximage->width * pximage->height; /* size of array of pixel color indices */
+  isize = aPximage->width * aPximage->height; /* size of array of pixel color indices */
   pBits = (BYTE *) Xw_malloc (isize);
 
   if (pBits == NULL) {  /*ERROR*Bad Image allocation*/
@@ -622,31 +601,30 @@ char *filename ;
     fclose(fimage);
     return (XW_ERROR) ;
   } 
-
-
+  
   /* Build file header */
 #if defined(LIN) || defined(linux)
   sd = (SCREEN_DESCR *) Xw_malloc(11);
   memcpy (sd->gifID, "GIF87a", 6);
-  sd->scrnWidth  = DisplayWidth(_DISPLAY, DefaultScreen(_DISPLAY));
-  sd->scrnHeight = DisplayHeight(_DISPLAY, DefaultScreen(_DISPLAY));
+  sd->scrnWidth  = DisplayWidth(aDisplay, DefaultScreen(aDisplay));
+  sd->scrnHeight = DisplayHeight(aDisplay, DefaultScreen(aDisplay));
   sd->scrnFlag   = 0x80 | (  ( 7/*[=depth-1]*/ << 4 ) & 0x70  ) | 0x07;
 
   id = (IMAGE_DESCR*) Xw_malloc(9);
   id->imgX      = 0;
   id->imgY      = 0;
-  id->imgWidth  = (WORD) pximage->width;
-  id->imgHeight = (WORD) pximage->height;
+  id->imgWidth  = (WORD) aPximage->width;
+  id->imgHeight = (WORD) aPximage->height;
 #else
   memcpy (sd.gifID, "GIF87a", 6);
-  sd.scrnWidth  = SWAP_WORD (DisplayWidth(_DISPLAY, DefaultScreen(_DISPLAY)));
-  sd.scrnHeight	= SWAP_WORD (DisplayHeight(_DISPLAY, DefaultScreen(_DISPLAY)));
+  sd.scrnWidth  = SWAP_WORD (DisplayWidth(aDisplay, DefaultScreen(aDisplay)));
+  sd.scrnHeight	= SWAP_WORD (DisplayHeight(aDisplay, DefaultScreen(aDisplay)));
   sd.scrnFlag   = 0x80 | (  ( 7/*[=depth-1]*/ << 4 ) & 0x70  ) | 0x07;
 
   id.imgX      = 0;
   id.imgY      = 0;
-  id.imgWidth  = SWAP_WORD ((WORD) pximage->width);
-  id.imgHeight = SWAP_WORD ((WORD) pximage->height);
+  id.imgWidth  = SWAP_WORD ((WORD) aPximage->width);
+  id.imgHeight = SWAP_WORD ((WORD) aPximage->height);
 #endif
   
 /*
@@ -683,9 +661,9 @@ char *filename ;
     }
 
     pbCell = pBits;
-    for (y=0; y<pximage->height; y++)
-      for (x=0; x<pximage->width; x++) {
-	unsigned long pixel = XGetPixel (pximage, x, y);
+    for (y=0; y<aPximage->height; y++)
+      for (x=0; x<aPximage->width; x++) {
+	unsigned long pixel = XGetPixel (aPximage, x, y);
 	*pbCell++ = pixel;
       }
   }
@@ -706,7 +684,7 @@ char *filename ;
     }
 
     /* Search for the top 256 colors and convert pixels to indices */
-    if (! _convert_image_to_256_RGB_indices (pximage,
+    if (! _convert_image_to_256_RGB_indices (aPximage,
 					     pcolors,
 					     (BYTE*)colors256, pBits)) {
 
@@ -721,9 +699,6 @@ char *filename ;
       return (XW_ERROR);
     }
   }
-    
-  
-
 
   /* write off the buffers */
 #if defined(LIN) || defined(linux)
@@ -772,12 +747,10 @@ char *filename ;
     status = XW_ERROR;
 #endif
 //  status && (status
-//    = _lzw_encode (fimage, pBits, pximage->width, pximage->height, pximage->width));
-  _lzw_encode (fimage, pBits, pximage->width, pximage->height, pximage->width);
-
+//    = _lzw_encode (fimage, pBits, aPximage->width, aPximage->height, aPximage->width));
+  _lzw_encode (fimage, pBits, aPximage->width, aPximage->height, aPximage->width);
   
   fclose(fimage);
-
   
 #ifndef PRO16753       
   Xw_free(pname);
@@ -787,14 +760,48 @@ char *filename ;
     Xw_free (pcolors);
   if (pBits)
     Xw_free (pBits);
-  
 
+  return status;
+}
+
+/*********************************************************************/
+/* Xw_save_gif_image                                                 */
+/*                                                                   */
+/*********************************************************************/
+XW_STATUS Xw_save_gif_image
+#ifdef XW_PROTOTYPE
+ (void *awindow,void *aimage,char *filename)
+#else
+ (awindow,aimage,filename)
+void *awindow;
+void *aimage;
+char *filename ;
+#endif /*XW_PROTOTYPE*/
+{
+  XW_EXT_WINDOW *pwindow = (XW_EXT_WINDOW*)awindow;
+  XW_EXT_IMAGEDATA *pimage = (XW_EXT_IMAGEDATA*) aimage;
+  XImage *pximage = NULL;  
+  XW_STATUS status = XW_SUCCESS;
+
+  if (!Xw_isdefine_window(pwindow)) { /*ERROR*Bad EXT_WINDOW Address*/
+    Xw_set_error(24,"Xw_save_gif_image",pwindow) ;
+    return (XW_ERROR) ;
+  }
+
+  if( !Xw_isdefine_image(pimage) ) { /*ERROR*Bad EXT_IMAGEDATA Address*/
+    Xw_set_error(25,"Xw_save_gif_image",pimage) ;
+    return (XW_ERROR) ;
+  }
+  
+  pximage = (_ZIMAGE) ? _ZIMAGE : _IIMAGE;
+
+  status = Xw_save_gif_image_adv(_DISPLAY,_WINDOW,_ATTRIBUTES,pximage,_COLORMAP->info.colormap,_COLORMAP->maxhcolor,filename);
+    
 #ifdef  TRACE_SAVE_IMAGE
   if (Xw_get_trace ())
     printf (" %d = Xw_save_gif_image(%lx,%lx,'%s')\n",
 	    status, (long ) pwindow, (long ) pimage, filename);
-#endif
-  
+#endif  
   
   return (XW_STATUS) status;
 }
@@ -1151,10 +1158,10 @@ static int ppm_quant
   register int     index;
   chist_vec chv, colormap;
   chash_table  cht;
-  int              i;
-  unsigned char    *picptr;
-  static char      *fn = "ppmquant()";
-  BYTE*            pByte;
+  int               i;
+  unsigned char     *picptr;
+  static const char *fn = "ppmquant()";
+  BYTE*             pByte;
 
   index = 0;
   maxval = 255;
