@@ -155,11 +155,11 @@ int Xw_get_trace()
 */
 
 #ifdef XW_PROTOTYPE
-void Xw_set_error(int code,char *routine,void* param)
+void Xw_set_error(int code,const char *routine,void* param)
 #else
 void Xw_set_error(code,routine,param)
 int code ;
-char *routine ;
+const char *routine ;
 void *param ;
 #endif /*XW_PROTOTYPE*/
 {
