@@ -42,7 +42,7 @@ void gp_Trsf::SetMirror (const gp_Ax2& A2)
 } 
 
 void gp_Trsf::SetRotation (const gp_Ax1& A1,
-			   const Standard_Real Ang)
+                           const Standard_Real Ang)
 {
   shape = gp_Rotation;
   scale = 1.;
@@ -77,7 +77,7 @@ void gp_Trsf::SetScale (const gp_Pnt& P, const Standard_Real S)
 //=======================================================================
 
 void gp_Trsf::SetTransformation (const gp_Ax3& FromA1,
-				 const gp_Ax3& ToA2)
+                                 const gp_Ax3& ToA2)
 {
   shape = gp_CompoundTrsf;
   scale = 1.0;
@@ -111,7 +111,7 @@ void gp_Trsf::SetTransformation (const gp_Ax3& A3)
   loc = A3.Location().XYZ();
   matrix.SetCols (A3.XDirection().XYZ(),
                   A3.YDirection().XYZ(),
-		  A3. Direction().XYZ());
+                  A3. Direction().XYZ());
   matrix.Transpose();
   loc.Multiply (matrix);
   loc.Reverse ();
@@ -123,7 +123,7 @@ void gp_Trsf::SetTransformation (const gp_Ax3& A3)
 //=======================================================================
 
 void gp_Trsf::SetDisplacement (const gp_Ax3& FromA1,
-			       const gp_Ax3& ToA2)
+                               const gp_Ax3& ToA2)
 {
   shape = gp_CompoundTrsf;
   scale = 1.0;
@@ -240,20 +240,20 @@ void gp_Trsf::SetScaleFactor (const Standard_Real S)
 //=======================================================================
 
 void gp_Trsf::SetValues(const Standard_Real a11, 
-			const Standard_Real a12, 
-			const Standard_Real a13, 
-			const Standard_Real a14, 
-			const Standard_Real a21, 
-			const Standard_Real a22, 
-			const Standard_Real a23, 
-			const Standard_Real a24, 
-			const Standard_Real a31, 
-			const Standard_Real a32,
-			const Standard_Real a33, 
-			const Standard_Real a34, 
-//			const Standard_Real Tolang, 
-			const Standard_Real , 
-			const Standard_Real
+                        const Standard_Real a12, 
+                        const Standard_Real a13, 
+                        const Standard_Real a14, 
+                        const Standard_Real a21, 
+                        const Standard_Real a22, 
+                        const Standard_Real a23, 
+                        const Standard_Real a24, 
+                        const Standard_Real a31, 
+                        const Standard_Real a32,
+                        const Standard_Real a33, 
+                        const Standard_Real a34, 
+//                      const Standard_Real Tolang, 
+                        const Standard_Real , 
+                        const Standard_Real
 #ifndef No_Exception
                                             TolDist
 #endif
@@ -340,8 +340,8 @@ gp_Mat gp_Trsf::VectorialPart () const
   gp_Mat M = matrix;
   if (shape == gp_Scale || shape == gp_PntMirror)
     M.SetDiagonal(scale*M.Value(1,1),
-		  scale*M.Value(2,2),
-		  scale*M.Value(3,3));
+                  scale*M.Value(2,2),
+                  scale*M.Value(3,3));
   else
     M.Multiply (scale);
   return M;
@@ -514,94 +514,94 @@ void gp_Trsf::Power (const Standard_Integer N)
     else {
       if (N < 0) { Invert(); }
       if (shape == gp_Translation) {
-	Standard_Integer Npower = N;
-	if (Npower < 0) Npower = - Npower;
-	Npower--;
-	gp_XYZ Temploc = loc;
-	while (1) {
-	  if (IsOdd(Npower))  loc.Add (Temploc);
-	  if (Npower == 1) break;
-	  Temploc.Add (Temploc);
-	  Npower = Npower/2;
-	}
+        Standard_Integer Npower = N;
+        if (Npower < 0) Npower = - Npower;
+        Npower--;
+        gp_XYZ Temploc = loc;
+        while (1) {
+          if (IsOdd(Npower))  loc.Add (Temploc);
+          if (Npower == 1) break;
+          Temploc.Add (Temploc);
+          Npower = Npower/2;
+        }
       }
       else if (shape == gp_Scale) {
-	Standard_Integer Npower = N;
-	if (Npower < 0) Npower = - Npower;
-	Npower--;
-	gp_XYZ Temploc = loc;
-	Standard_Real Tempscale = scale;
-	while (1) {
-	  if (IsOdd(Npower)) {
-	    loc.Add (Temploc.Multiplied(scale));
-	    scale = scale * Tempscale;
-	  }
-	  if (Npower == 1) break;
-	  Temploc.Add (Temploc.Multiplied(Tempscale));
-	  Tempscale = Tempscale * Tempscale;
-	  Npower = Npower/2;
-	}
+        Standard_Integer Npower = N;
+        if (Npower < 0) Npower = - Npower;
+        Npower--;
+        gp_XYZ Temploc = loc;
+        Standard_Real Tempscale = scale;
+        while (1) {
+          if (IsOdd(Npower)) {
+            loc.Add (Temploc.Multiplied(scale));
+            scale = scale * Tempscale;
+          }
+          if (Npower == 1) break;
+          Temploc.Add (Temploc.Multiplied(Tempscale));
+          Tempscale = Tempscale * Tempscale;
+          Npower = Npower/2;
+        }
       }
       else if (shape == gp_Rotation) {
-	Standard_Integer Npower = N;
-	if (Npower < 0) Npower = - Npower;
-	Npower--;
-	gp_Mat Tempmatrix (matrix);
-	if (loc.X() == 0.0 && loc.Y() == 0.0 && loc.Z() == 0.0) {
-	  while (1) {
-	    if (IsOdd(Npower)) matrix.Multiply (Tempmatrix);
-	    if (Npower == 1)   break;
-	    Tempmatrix.Multiply (Tempmatrix);
-	    Npower = Npower/2;
-	  }
-	}
-	else {
-	  gp_XYZ Temploc = loc;
-	  while (1) {
-	    if (IsOdd(Npower)) {
-	      loc.Add (Temploc.Multiplied (matrix));
-	      matrix.Multiply (Tempmatrix);
-	    }
-	    if (Npower == 1) break;
-	    Temploc.Add (Temploc.Multiplied (Tempmatrix));
-	    Tempmatrix.Multiply (Tempmatrix);
-	    Npower = Npower/2;
-	  }
-	}
+        Standard_Integer Npower = N;
+        if (Npower < 0) Npower = - Npower;
+        Npower--;
+        gp_Mat Tempmatrix (matrix);
+        if (loc.X() == 0.0 && loc.Y() == 0.0 && loc.Z() == 0.0) {
+          while (1) {
+            if (IsOdd(Npower)) matrix.Multiply (Tempmatrix);
+            if (Npower == 1)   break;
+            Tempmatrix.Multiply (Tempmatrix);
+            Npower = Npower/2;
+          }
+        }
+        else {
+          gp_XYZ Temploc = loc;
+          while (1) {
+            if (IsOdd(Npower)) {
+              loc.Add (Temploc.Multiplied (matrix));
+              matrix.Multiply (Tempmatrix);
+            }
+            if (Npower == 1) break;
+            Temploc.Add (Temploc.Multiplied (Tempmatrix));
+            Tempmatrix.Multiply (Tempmatrix);
+            Npower = Npower/2;
+          }
+        }
       }
       else if (shape == gp_PntMirror || shape == gp_Ax1Mirror ||
-	       shape == gp_Ax2Mirror) {
-	if (IsEven (N)) {
-	  shape = gp_Identity;
-	  scale = 1.0;
-	  matrix.SetIdentity ();
-	  loc.SetX(0);
-	  loc.SetY(0);
-	  loc.SetZ(0);
-	}
+               shape == gp_Ax2Mirror) {
+        if (IsEven (N)) {
+          shape = gp_Identity;
+          scale = 1.0;
+          matrix.SetIdentity ();
+          loc.SetX(0);
+          loc.SetY(0);
+          loc.SetZ(0);
+        }
       }
       else {
-	shape = gp_CompoundTrsf;
-	Standard_Integer Npower = N;
-	if (Npower < 0) Npower = - Npower;
-	Npower--;
-	gp_XYZ Temploc = loc;
-	Standard_Real Tempscale = scale;
-	gp_Mat Tempmatrix (matrix);
-	while (1) {
-	  if (IsOdd(Npower)) {
-	    loc.Add ((Temploc.Multiplied (matrix)).Multiplied (scale));
-	    scale = scale * Tempscale;
-	    matrix.Multiply (Tempmatrix);
-	  }
-	  if (Npower == 1) break;
-	  Tempscale = Tempscale * Tempscale;
-	  Temploc.Add ( (Temploc.Multiplied (Tempmatrix)).Multiplied 
-		       (Tempscale)
-		       );
-	  Tempmatrix.Multiply (Tempmatrix);
-	  Npower = Npower/2;
-	}
+        shape = gp_CompoundTrsf;
+        Standard_Integer Npower = N;
+        if (Npower < 0) Npower = - Npower;
+        Npower--;
+        gp_XYZ Temploc = loc;
+        Standard_Real Tempscale = scale;
+        gp_Mat Tempmatrix (matrix);
+        while (1) {
+          if (IsOdd(Npower)) {
+            loc.Add ((Temploc.Multiplied (matrix)).Multiplied (scale));
+            scale = scale * Tempscale;
+            matrix.Multiply (Tempmatrix);
+          }
+          if (Npower == 1) break;
+          Tempscale = Tempscale * Tempscale;
+          Temploc.Add ( (Temploc.Multiplied (Tempmatrix)).Multiplied 
+                        (Tempscale)
+                        );
+          Tempmatrix.Multiply (Tempmatrix);
+          Npower = Npower/2;
+        }
       }
     }
   }
@@ -647,17 +647,17 @@ void gp_Trsf::PreMultiply (const gp_Trsf& T)
     matrix.PreMultiply(T.matrix);
   }
   else if ((shape == gp_CompoundTrsf || shape == gp_Rotation ||
-	    shape == gp_Ax1Mirror || shape == gp_Ax2Mirror)
-	   && T.shape == gp_Translation) {
+            shape == gp_Ax1Mirror || shape == gp_Ax2Mirror)
+           && T.shape == gp_Translation) {
     loc.Add (T.loc);
   }
   else if ((shape == gp_Scale || shape == gp_PntMirror)
-	   && T.shape == gp_Translation) {
+           && T.shape == gp_Translation) {
     loc.Add (T.loc);
   }
   else if (shape == gp_Translation && 
-	   (T.shape == gp_CompoundTrsf || T.shape == gp_Rotation
-	    || T.shape == gp_Ax1Mirror || T.shape == gp_Ax2Mirror)) {
+           (T.shape == gp_CompoundTrsf || T.shape == gp_Rotation
+            || T.shape == gp_Ax1Mirror || T.shape == gp_Ax2Mirror)) {
     shape = gp_CompoundTrsf;
     matrix = T.matrix;
     if (T.scale == 1.0)  loc.Multiply (T.matrix);
@@ -669,30 +669,30 @@ void gp_Trsf::PreMultiply (const gp_Trsf& T)
     loc.Add (T.loc);
   }
   else if ((T.shape == gp_Scale || T.shape == gp_PntMirror)
-	   && shape == gp_Translation) {
+           && shape == gp_Translation) {
     loc.Multiply (T.scale);
     loc.Add (T.loc);
     scale = T.scale;
     shape = T.shape;
   }
   else if ((shape == gp_PntMirror || shape == gp_Scale) &&
-	   (T.shape == gp_PntMirror || T.shape == gp_Scale)) {
+           (T.shape == gp_PntMirror || T.shape == gp_Scale)) {
     shape = gp_CompoundTrsf;
     loc.Multiply (T.scale);
     loc.Add (T.loc);
     scale = scale * T.scale;
   }
   else if ((shape == gp_CompoundTrsf || shape == gp_Rotation ||
-	    shape == gp_Ax1Mirror || shape == gp_Ax2Mirror) 
-	   && (T.shape == gp_Scale || T.shape == gp_PntMirror)) {
+            shape == gp_Ax1Mirror || shape == gp_Ax2Mirror) 
+           && (T.shape == gp_Scale || T.shape == gp_PntMirror)) {
     shape = gp_CompoundTrsf;
     loc.Multiply (T.scale);
     loc.Add (T.loc);
     scale = scale * T.scale;
   } 
   else if ((T.shape == gp_CompoundTrsf || T.shape == gp_Rotation ||
-	    T.shape == gp_Ax1Mirror || T.shape == gp_Ax2Mirror) 
-	   && (shape == gp_Scale || shape == gp_PntMirror)) {
+            T.shape == gp_Ax1Mirror || T.shape == gp_Ax2Mirror) 
+           && (shape == gp_Scale || shape == gp_PntMirror)) {
     shape = gp_CompoundTrsf;
     matrix = T.matrix;
     if (T.scale == 1.0)  loc.Multiply (T.matrix);
@@ -714,3 +714,113 @@ void gp_Trsf::PreMultiply (const gp_Trsf& T)
   }
 }
 
+//=======================================================================
+//function : GetRotation
+//purpose  : algorithm from A.Korn, M.Korn, "Mathematical Handbook for
+//           scientists and Engineers" McGraw-Hill, 1961, ch.14.10-2.
+//=======================================================================
+
+Standard_Boolean gp_Trsf::GetRotation (gp_XYZ&        theAxis,
+                                       Standard_Real& theAngle) const
+{
+  Standard_Boolean aResult (Standard_False);
+  if (shape != gp_Identity || shape != gp_Translation)
+  {
+    const Standard_Real aResolution
+      (Precision::Confusion()*Precision::Confusion());
+    Standard_Real aCosDelta(0.5 *(matrix(1,1) + matrix(2,2) + matrix(3,3) -1.));
+    if ((1. - aCosDelta*aCosDelta) > aResolution) {
+      const Standard_Real aSinDelta = sqrt (1. - aCosDelta*aCosDelta);
+      theAngle = atan2(aSinDelta, aCosDelta);
+      theAxis.SetCoord (matrix(3,2) - matrix(2,3),
+                        matrix(1,3) - matrix(3,1),
+                        matrix(2,1) - matrix(1,2));
+      const Standard_Real aMag2 = theAxis.SquareModulus();
+      if (aMag2 > Precision::Confusion()) {
+        theAxis /= sqrt(aMag2);
+        aResult = Standard_True;
+      }
+    }
+    if (aResult == Standard_False) {
+      // Special case of symmetrical rotation matrix.
+      // .. check that rotation matrix is non-unity (otherwise no rotation)
+      if (matrix(1,2)*matrix(1,2) + matrix(1,3)*matrix(1,3) +
+          matrix(2,1)*matrix(2,1) + matrix(2,3)*matrix(2,3) +
+          matrix(3,1)*matrix(3,1) + matrix(3,2)*matrix(3,2)
+                > Precision::Confusion() ||
+          matrix(1,1) < 0. || matrix(2,2) < 0. || matrix(3,3) < 0.)
+      {
+        // Create three points, they are located on a single circle that
+        // is made by the first point when it is rotated.
+        gp_XYZ aProbe[3];
+        aProbe[0] = gp_XYZ(1., 2., 3.);
+        aProbe[1] = aProbe[0] * matrix;
+        aProbe[2] = aProbe[1] * matrix;
+
+        // The rotation  axis is the vectorial product of two chords.
+        gp_XYZ aProduct = (aProbe[1]-aProbe[0]) ^ (aProbe[2]-aProbe[1]);
+        Standard_Real aPMagnitude = aProduct.Modulus();
+        if (aPMagnitude > 0.001*Precision::Confusion())
+          aResult = Standard_True;
+        else {
+          if ((aProbe[1]-aProbe[0]).SquareModulus() > Precision::Confusion())
+          {
+            // Case when the rotation is nearly PI. Both chords can be treated
+            // as diameter, their middle point indicates the rotation axis
+            aProduct = (aProbe[0] + 2*aProbe[1] + aProbe[2]);
+            aPMagnitude = aProduct.Modulus();
+            aResult = (aPMagnitude > Precision::Confusion());
+          }
+          if (aResult == Standard_False) {
+            // Rotation is too small or the point aProbe[0] is near the axis.
+            // Take a different probe.
+            aProbe[0] = gp_XYZ(1., 1., 1.);
+            aProbe[1] = aProbe[0] * matrix;
+            aProbe[2] = aProbe[1] * matrix;
+            aProduct = (aProbe[1]-aProbe[0]) ^ (aProbe[2]-aProbe[1]);
+            aPMagnitude = aProduct.Modulus();
+            if (aPMagnitude < 0.001*Precision::Confusion())
+              if ((aProbe[1] - aProbe[0]).SquareModulus() >
+                  Precision::Confusion())
+              {
+                aProduct = (aProbe[0] + 2*aProbe[1] + aProbe[2]);
+                aPMagnitude = aProduct.Modulus();
+                aResult = Standard_True;
+              }
+          }
+        }
+        if (aResult) {
+          theAxis = (aProduct/aPMagnitude);
+          gp_Vec aVecOrth (theAxis.Y(), -theAxis.X(), 0.);
+          Standard_Real aVecMagnitude2 = aVecOrth.SquareMagnitude();
+          if (aVecMagnitude2 < aResolution) {
+            aVecOrth = gp_Vec (0., theAxis.Z(), -theAxis.Y());
+            aVecMagnitude2 = aVecOrth.SquareMagnitude();
+          }
+          aVecOrth /= sqrt(aVecMagnitude2);
+          const gp_Vec aVecRotated = aVecOrth.XYZ() * matrix;
+          theAngle = aVecOrth.AngleWithRef (aVecRotated, theAxis);
+        }
+      }
+    }
+
+    if (aResult) {
+      Standard_Boolean isCorrected (Standard_False);
+      if (theAxis.X()*theAxis.X() < aResolution) {
+        theAxis.SetX(0.);
+        isCorrected = Standard_True;
+      }
+      if (theAxis.Y()*theAxis.Y() < aResolution) {
+        theAxis.SetY(0.);
+        isCorrected = Standard_True;
+      }
+      if (theAxis.Z()*theAxis.Z() < aResolution) {
+        theAxis.SetZ(0.);
+        isCorrected = Standard_True;
+      }
+      if (isCorrected)
+        theAxis.Normalize();
+    }
+  }
+  return aResult;
+}
